/* Automatically @generated by tree-sitter v0.25.10 */

#include "tree_sitter/parser.h"

#if defined(__GNUC__) || defined(__clang__)
#pragma GCC diagnostic ignored "-Wmissing-field-initializers"
#endif

#ifdef _MSC_VER
#pragma optimize("", off)
#elif defined(__clang__)
#pragma clang optimize off
#elif defined(__GNUC__)
#pragma GCC optimize ("O0")
#endif

#define LANGUAGE_VERSION 15
#define STATE_COUNT 2451
#define LARGE_STATE_COUNT 90
#define SYMBOL_COUNT 291
#define ALIAS_COUNT 10
#define TOKEN_COUNT 136
#define EXTERNAL_TOKEN_COUNT 10
#define FIELD_COUNT 27
#define MAX_ALIAS_SEQUENCE_LENGTH 10
#define MAX_RESERVED_WORD_SET_SIZE 0
#define PRODUCTION_ID_COUNT 124
#define SUPERTYPE_COUNT 0

enum ts_symbol_identifiers {
  sym_identifier = 1,
  aux_sym_block_token1 = 2,
  anon_sym_RPAREN = 3,
  anon_sym_LPAREN = 4,
  anon_sym_LBRACE = 5,
  anon_sym_RBRACE = 6,
  aux_sym_subroutine_block_token1 = 7,
  aux_sym_if_block_token1 = 8,
  aux_sym_elif_block_token1 = 9,
  aux_sym_while_block_token1 = 10,
  aux_sym_while_block_token2 = 11,
  aux_sym__repeat_block_pre_condition_format_token1 = 12,
  anon_sym_EQ = 13,
  anon_sym_PLUS = 14,
  anon_sym_DASH = 15,
  anon_sym_TILDE = 16,
  anon_sym_BANG = 17,
  anon_sym_PLUS_PLUS = 18,
  anon_sym_DASH_DASH = 19,
  anon_sym_CARET_CARET = 20,
  anon_sym_PIPE_PIPE = 21,
  anon_sym_STAR = 22,
  anon_sym_SLASH = 23,
  anon_sym_PERCENT = 24,
  anon_sym_PIPE = 25,
  anon_sym_CARET = 26,
  anon_sym_EQ_EQ = 27,
  anon_sym_BANG_EQ = 28,
  anon_sym_GT = 29,
  anon_sym_GT_EQ = 30,
  anon_sym_LT_EQ = 31,
  anon_sym_LT = 32,
  anon_sym_LT_LT = 33,
  anon_sym_GT_GT = 34,
  anon_sym_DOT_DOT = 35,
  anon_sym_AMP_AMP = 36,
  anon_sym_AMP = 37,
  anon_sym_COLON = 38,
  aux_sym_macro_definition_token1 = 39,
  aux_sym_parameter_declaration_token1 = 40,
  aux_sym_parameter_declaration_token2 = 41,
  aux_sym_parameter_declaration_token3 = 42,
  aux_sym_parameter_declaration_token4 = 43,
  aux_sym_subroutine_call_expression_token1 = 44,
  aux_sym_macro_definition_command_token1 = 45,
  aux_sym_macro_definition_command_token2 = 46,
  aux_sym_macro_definition_command_token3 = 47,
  aux_sym__host_command_with_default_format_token1 = 48,
  anon_sym_DOT = 49,
  anon_sym_COMMA = 50,
  aux_sym__host_command_argument_list_default_format_token1 = 51,
  aux_sym__hll_non_default_format_var_command_token1 = 52,
  aux_sym__hll_non_default_format_var_command_token2 = 53,
  aux_sym__hll_non_default_format_var_command_token3 = 54,
  aux_sym__hll_non_default_format_var_command_token4 = 55,
  aux_sym__hll_non_default_format_var_command_token5 = 56,
  aux_sym__hll_var_definition_command_token1 = 57,
  aux_sym__var_command_with_non_hll_format_token1 = 58,
  aux_sym__var_command_with_non_hll_format_token2 = 59,
  aux_sym__var_command_with_non_hll_format_token3 = 60,
  aux_sym__hll_var_definition_command_expression_token1 = 61,
  aux_sym__hll_var_definition_command_expression_token2 = 62,
  anon_sym_QMARK = 63,
  anon_sym_BSLASH = 64,
  anon_sym_DASH_GT = 65,
  anon_sym_LBRACK = 66,
  anon_sym_RBRACK = 67,
  anon_sym_sizeof = 68,
  anon_sym_STAR_EQ = 69,
  anon_sym_SLASH_EQ = 70,
  anon_sym_PERCENT_EQ = 71,
  anon_sym_PLUS_EQ = 72,
  anon_sym_DASH_EQ = 73,
  anon_sym_LT_LT_EQ = 74,
  anon_sym_GT_GT_EQ = 75,
  anon_sym_AMP_EQ = 76,
  anon_sym_CARET_EQ = 77,
  anon_sym_PIPE_EQ = 78,
  anon_sym_L_SQUOTE = 79,
  anon_sym_u_SQUOTE = 80,
  anon_sym_U_SQUOTE = 81,
  anon_sym_u8_SQUOTE = 82,
  anon_sym_SQUOTE = 83,
  aux_sym_hll_char_literal_token1 = 84,
  anon_sym_L_DQUOTE = 85,
  anon_sym_u_DQUOTE = 86,
  anon_sym_U_DQUOTE = 87,
  anon_sym_u8_DQUOTE = 88,
  anon_sym_DQUOTE = 89,
  aux_sym_hll_string_literal_token1 = 90,
  anon_sym_const = 91,
  anon_sym_volatile = 92,
  anon_sym_struct = 93,
  anon_sym_union = 94,
  anon_sym_enum = 95,
  anon_sym_signed = 96,
  anon_sym_unsigned = 97,
  anon_sym_long = 98,
  anon_sym_short = 99,
  sym_hll_primitive_type = 100,
  sym_hll_escape_sequence = 101,
  aux_sym__hll_expression_separator_token1 = 102,
  aux_sym__hll_expression_separator_token2 = 103,
  anon_sym_COLON_COLON_COLON = 104,
  anon_sym_COLON_COLON = 105,
  sym_access_class = 106,
  aux_sym_integer_token1 = 107,
  aux_sym_integer_token2 = 108,
  sym_float = 109,
  aux_sym_bitmask_token1 = 110,
  aux_sym_bitmask_token2 = 111,
  aux_sym_string_token1 = 112,
  aux_sym_string_token2 = 113,
  aux_sym_character_token1 = 114,
  aux_sym_character_token2 = 115,
  aux_sym_symbol_token1 = 116,
  aux_sym_symbol_token2 = 117,
  aux_sym_symbol_token3 = 118,
  sym__composed_name = 119,
  sym_time = 120,
  sym_frequency = 121,
  sym_percentage = 122,
  sym_file_handle = 123,
  sym_comment = 124,
  sym__blank_line = 125,
  sym__line_continuation = 126,
  sym__blank = 127,
  sym_label_identifier = 128,
  sym__and_operator_pre_hook = 129,
  sym__decimal_number = 130,
  sym__decimal_number_pre_hook = 131,
  sym_hll_number_literal = 132,
  sym__hll_number_literal_pre_hook = 133,
  sym_path = 134,
  sym__ampersand_char = 135,
  sym_script = 136,
  sym_block = 137,
  sym__statement = 138,
  sym__non_labeled_statement = 139,
  sym__expression = 140,
  sym__parenthesized_expression = 141,
  sym__path_expression = 142,
  sym_labeled_expression = 143,
  sym_subroutine_block = 144,
  sym_if_block = 145,
  sym_elif_block = 146,
  sym_else_block = 147,
  sym_while_block = 148,
  sym_repeat_block = 149,
  sym__repeat_block_pre_condition_format = 150,
  sym__repeat_block_post_condition_format = 151,
  sym_macro_assignment_expression = 152,
  sym_unary_expression = 153,
  sym__unary_expression = 154,
  sym__prefix_postfix_expression = 155,
  sym_binary_expression = 156,
  sym__binary_expression = 157,
  sym__and_expression = 158,
  sym_assignment_expression = 159,
  sym__label = 160,
  sym_macro_definition = 161,
  sym_parameter_declaration = 162,
  sym_subroutine_call_expression = 163,
  sym_macro = 164,
  sym_recursive_macro_expansion = 165,
  sym_macro_definition_command = 166,
  sym_command_expression = 167,
  sym__host_command = 168,
  sym__host_command_with_default_format = 169,
  sym__other_command = 170,
  sym__command_identifier = 171,
  sym__command_arguments = 172,
  sym__host_command_argument_list_default_format = 173,
  sym__command_argument = 174,
  sym_option_expression = 175,
  sym_format_expression = 176,
  sym_call_expression = 177,
  sym__function_identifier = 178,
  sym_argument_list = 179,
  sym__var_command = 180,
  sym__hll_var_command = 181,
  sym__hll_default_format_var_command = 182,
  sym__hll_non_default_format_var_command = 183,
  sym__non_hll_var_command = 184,
  sym__hll_var_definition_command = 185,
  sym__hll_var_command_with_default_format = 186,
  sym__var_command_with_non_hll_format = 187,
  sym__hll_var_definition_command_expression = 188,
  sym__hll_var_if_command = 189,
  sym__hll_var_command_argument_list_default_format = 190,
  sym__hll_var_command_argument_list_non_default_format = 191,
  sym__hll_var_pattern_command_argument_list_format = 192,
  sym__var_command_argument_list_non_hll_format = 193,
  sym__var_definition_command_argument_list_format = 194,
  sym__hll_var_call_expression_function = 195,
  sym__hll_var_call_expression = 196,
  sym_hll_var_call_expression_argument_list = 197,
  sym_hll_type_pattern = 198,
  sym_trace32_hll_variable = 199,
  sym__hll_expression = 200,
  sym_hll_call_expression = 201,
  sym_hll_field_expression = 202,
  sym_hll_subscript_expression = 203,
  sym_hll_cast_expression = 204,
  sym_hll_sizeof_expression = 205,
  sym_hll_pointer_expression = 206,
  sym_hll_comma_expression = 207,
  sym_hll_update_expression = 208,
  sym_hll_unary_expression = 209,
  sym_hll_binary_expression = 210,
  sym_hll_range_expression = 211,
  sym_hll_assignment_expression = 212,
  sym__hll_assignment_left_expression = 213,
  sym_hll_conditional_expression = 214,
  sym_hll_char_literal = 215,
  sym_hll_string_literal = 216,
  sym_hll_parenthesized_expression = 217,
  sym_hll_type_descriptor = 218,
  sym_hll_type_qualifier = 219,
  sym__hll_declaration_modifiers = 220,
  sym__hll_type_specifier = 221,
  sym_hll_struct_specifier = 222,
  sym_hll_union_specifier = 223,
  sym_hll_enum_specifier = 224,
  sym_hll_sized_type_specifier = 225,
  sym_hll_declaration = 226,
  sym__hll_declaration_specifiers = 227,
  sym__hll_declarator = 228,
  sym_hll_pointer_declarator = 229,
  sym_hll_function_declarator = 230,
  sym_hll_array_declarator = 231,
  sym_hll_parenthesized_declarator = 232,
  sym__hll_pointer_declarator_specifier = 233,
  sym__hll_abstract_declarator = 234,
  sym_hll_abstract_pointer_declarator = 235,
  sym_hll_abstract_function_declarator = 236,
  sym_hll_abstract_array_declarator = 237,
  sym_hll_abstract_parenthesized_declarator = 238,
  sym_hll_parameter_list = 239,
  sym_hll_parameter_declaration = 240,
  sym_hll_argument_list = 241,
  sym__hll_type_identifier = 242,
  sym__hll_field_identifier = 243,
  sym__literal = 244,
  sym__address_expression = 245,
  sym_memory_space = 246,
  sym_address = 247,
  sym__parenthesized_address_expression = 248,
  sym__address_binary_expression = 249,
  sym_integer = 250,
  sym_bitmask = 251,
  sym_string = 252,
  sym_character = 253,
  sym_symbol = 254,
  sym__special_command_operator = 255,
  sym__file_dialog = 256,
  aux_sym_script_repeat1 = 257,
  aux_sym_block_repeat1 = 258,
  aux_sym_block_repeat2 = 259,
  aux_sym__path_expression_repeat1 = 260,
  aux_sym__path_expression_repeat2 = 261,
  aux_sym_labeled_expression_repeat1 = 262,
  aux_sym_subroutine_block_repeat1 = 263,
  aux_sym_if_block_repeat1 = 264,
  aux_sym_macro_definition_repeat1 = 265,
  aux_sym__command_identifier_repeat1 = 266,
  aux_sym__command_arguments_repeat1 = 267,
  aux_sym__command_arguments_repeat2 = 268,
  aux_sym__command_arguments_repeat3 = 269,
  aux_sym__host_command_argument_list_default_format_repeat1 = 270,
  aux_sym__host_command_argument_list_default_format_repeat2 = 271,
  aux_sym_format_expression_repeat1 = 272,
  aux_sym__function_identifier_repeat1 = 273,
  aux_sym_argument_list_repeat1 = 274,
  aux_sym__hll_var_command_argument_list_default_format_repeat1 = 275,
  aux_sym__hll_var_command_argument_list_default_format_repeat2 = 276,
  aux_sym__hll_var_pattern_command_argument_list_format_repeat1 = 277,
  aux_sym__hll_var_pattern_command_argument_list_format_repeat2 = 278,
  aux_sym__var_command_argument_list_non_hll_format_repeat1 = 279,
  aux_sym_hll_type_pattern_repeat1 = 280,
  aux_sym_hll_string_literal_repeat1 = 281,
  aux_sym_hll_type_descriptor_repeat1 = 282,
  aux_sym_hll_type_descriptor_repeat2 = 283,
  aux_sym_hll_sized_type_specifier_repeat1 = 284,
  aux_sym__hll_declaration_specifiers_repeat1 = 285,
  aux_sym__hll_declaration_specifiers_repeat2 = 286,
  aux_sym__hll_pointer_declarator_specifier_repeat1 = 287,
  aux_sym_hll_parameter_list_repeat1 = 288,
  aux_sym_hll_argument_list_repeat1 = 289,
  aux_sym_string_repeat1 = 290,
  anon_alias_sym_IF = 291,
  anon_alias_sym_command = 292,
  anon_alias_sym_function = 293,
  alias_sym_hll_field_identifier = 294,
  alias_sym_hll_type_identifier = 295,
  anon_alias_sym_module = 296,
  anon_alias_sym_name = 297,
  anon_alias_sym_subcommand = 298,
  anon_alias_sym_subfunction = 299,
  anon_alias_sym_type = 300,
};

static const char * const ts_symbol_names[] = {
  [ts_builtin_sym_end] = "end",
  [sym_identifier] = "identifier",
  [aux_sym_block_token1] = "block_token1",
  [anon_sym_RPAREN] = ")",
  [anon_sym_LPAREN] = "(",
  [anon_sym_LBRACE] = "{",
  [anon_sym_RBRACE] = "}",
  [aux_sym_subroutine_block_token1] = "identifier",
  [aux_sym_if_block_token1] = "identifier",
  [aux_sym_elif_block_token1] = "identifier",
  [aux_sym_while_block_token1] = "identifier",
  [aux_sym_while_block_token2] = "identifier",
  [aux_sym__repeat_block_pre_condition_format_token1] = "identifier",
  [anon_sym_EQ] = "=",
  [anon_sym_PLUS] = "+",
  [anon_sym_DASH] = "-",
  [anon_sym_TILDE] = "~",
  [anon_sym_BANG] = "!",
  [anon_sym_PLUS_PLUS] = "++",
  [anon_sym_DASH_DASH] = "--",
  [anon_sym_CARET_CARET] = "^^",
  [anon_sym_PIPE_PIPE] = "||",
  [anon_sym_STAR] = "*",
  [anon_sym_SLASH] = "/",
  [anon_sym_PERCENT] = "%",
  [anon_sym_PIPE] = "|",
  [anon_sym_CARET] = "^",
  [anon_sym_EQ_EQ] = "==",
  [anon_sym_BANG_EQ] = "!=",
  [anon_sym_GT] = ">",
  [anon_sym_GT_EQ] = ">=",
  [anon_sym_LT_EQ] = "<=",
  [anon_sym_LT] = "<",
  [anon_sym_LT_LT] = "<<",
  [anon_sym_GT_GT] = ">>",
  [anon_sym_DOT_DOT] = "..",
  [anon_sym_AMP_AMP] = "&&",
  [anon_sym_AMP] = "&",
  [anon_sym_COLON] = ":",
  [aux_sym_macro_definition_token1] = "macro_definition_token1",
  [aux_sym_parameter_declaration_token1] = "identifier",
  [aux_sym_parameter_declaration_token2] = "identifier",
  [aux_sym_parameter_declaration_token3] = "identifier",
  [aux_sym_parameter_declaration_token4] = "identifier",
  [aux_sym_subroutine_call_expression_token1] = "identifier",
  [aux_sym_macro_definition_command_token1] = "GLOBAL",
  [aux_sym_macro_definition_command_token2] = "LOCAL",
  [aux_sym_macro_definition_command_token3] = "PRIVATE",
  [aux_sym__host_command_with_default_format_token1] = "OS",
  [anon_sym_DOT] = ".",
  [anon_sym_COMMA] = ",",
  [aux_sym__host_command_argument_list_default_format_token1] = "_host_command_argument_list_default_format_token1",
  [aux_sym__hll_non_default_format_var_command_token1] = "Var",
  [aux_sym__hll_non_default_format_var_command_token2] = "AddSticker",
  [aux_sym__hll_non_default_format_var_command_token3] = "EXPORT",
  [aux_sym__hll_non_default_format_var_command_token4] = "WRITE",
  [aux_sym__hll_non_default_format_var_command_token5] = "PATtern",
  [aux_sym__hll_var_definition_command_token1] = "_hll_var_definition_command_token1",
  [aux_sym__var_command_with_non_hll_format_token1] = "Local",
  [aux_sym__var_command_with_non_hll_format_token2] = "Ref",
  [aux_sym__var_command_with_non_hll_format_token3] = "TREE",
  [aux_sym__hll_var_definition_command_expression_token1] = "NEWLOCAL",
  [aux_sym__hll_var_definition_command_expression_token2] = "NEWGLOBAL",
  [anon_sym_QMARK] = "\?",
  [anon_sym_BSLASH] = "\\",
  [anon_sym_DASH_GT] = "->",
  [anon_sym_LBRACK] = "[",
  [anon_sym_RBRACK] = "]",
  [anon_sym_sizeof] = "sizeof",
  [anon_sym_STAR_EQ] = "*=",
  [anon_sym_SLASH_EQ] = "/=",
  [anon_sym_PERCENT_EQ] = "%=",
  [anon_sym_PLUS_EQ] = "+=",
  [anon_sym_DASH_EQ] = "-=",
  [anon_sym_LT_LT_EQ] = "<<=",
  [anon_sym_GT_GT_EQ] = ">>=",
  [anon_sym_AMP_EQ] = "&=",
  [anon_sym_CARET_EQ] = "^=",
  [anon_sym_PIPE_EQ] = "|=",
  [anon_sym_L_SQUOTE] = "L'",
  [anon_sym_u_SQUOTE] = "u'",
  [anon_sym_U_SQUOTE] = "U'",
  [anon_sym_u8_SQUOTE] = "u8'",
  [anon_sym_SQUOTE] = "'",
  [aux_sym_hll_char_literal_token1] = "character",
  [anon_sym_L_DQUOTE] = "L\"",
  [anon_sym_u_DQUOTE] = "u\"",
  [anon_sym_U_DQUOTE] = "U\"",
  [anon_sym_u8_DQUOTE] = "u8\"",
  [anon_sym_DQUOTE] = "\"",
  [aux_sym_hll_string_literal_token1] = "hll_string_literal_token1",
  [anon_sym_const] = "const",
  [anon_sym_volatile] = "volatile",
  [anon_sym_struct] = "struct",
  [anon_sym_union] = "union",
  [anon_sym_enum] = "enum",
  [anon_sym_signed] = "signed",
  [anon_sym_unsigned] = "unsigned",
  [anon_sym_long] = "long",
  [anon_sym_short] = "short",
  [sym_hll_primitive_type] = "hll_primitive_type",
  [sym_hll_escape_sequence] = "hll_escape_sequence",
  [aux_sym__hll_expression_separator_token1] = "_hll_expression_separator_token1",
  [aux_sym__hll_expression_separator_token2] = "_hll_expression_separator_token2",
  [anon_sym_COLON_COLON_COLON] = ":::",
  [anon_sym_COLON_COLON] = "::",
  [sym_access_class] = "access_class",
  [aux_sym_integer_token1] = "integer_token1",
  [aux_sym_integer_token2] = "integer_token2",
  [sym_float] = "float",
  [aux_sym_bitmask_token1] = "bitmask_token1",
  [aux_sym_bitmask_token2] = "bitmask_token2",
  [aux_sym_string_token1] = "string_token1",
  [aux_sym_string_token2] = "string_token2",
  [aux_sym_character_token1] = "character_token1",
  [aux_sym_character_token2] = "character_token2",
  [aux_sym_symbol_token1] = "symbol_token1",
  [aux_sym_symbol_token2] = "symbol_token2",
  [aux_sym_symbol_token3] = "symbol_token3",
  [sym__composed_name] = "identifier",
  [sym_time] = "time",
  [sym_frequency] = "frequency",
  [sym_percentage] = "percentage",
  [sym_file_handle] = "file_handle",
  [sym_comment] = "comment",
  [sym__blank_line] = "_blank_line",
  [sym__line_continuation] = "_line_continuation",
  [sym__blank] = "_blank",
  [sym_label_identifier] = "identifier",
  [sym__and_operator_pre_hook] = "_and_operator_pre_hook",
  [sym__decimal_number] = "_decimal_number",
  [sym__decimal_number_pre_hook] = "_decimal_number_pre_hook",
  [sym_hll_number_literal] = "hll_number_literal",
  [sym__hll_number_literal_pre_hook] = "_hll_number_literal_pre_hook",
  [sym_path] = "path",
  [sym__ampersand_char] = "_ampersand_char",
  [sym_script] = "script",
  [sym_block] = "block",
  [sym__statement] = "_statement",
  [sym__non_labeled_statement] = "_non_labeled_statement",
  [sym__expression] = "_expression",
  [sym__parenthesized_expression] = "_parenthesized_expression",
  [sym__path_expression] = "_path_expression",
  [sym_labeled_expression] = "labeled_expression",
  [sym_subroutine_block] = "subroutine_block",
  [sym_if_block] = "if_block",
  [sym_elif_block] = "elif_block",
  [sym_else_block] = "else_block",
  [sym_while_block] = "while_block",
  [sym_repeat_block] = "repeat_block",
  [sym__repeat_block_pre_condition_format] = "_repeat_block_pre_condition_format",
  [sym__repeat_block_post_condition_format] = "_repeat_block_post_condition_format",
  [sym_macro_assignment_expression] = "assignment_expression",
  [sym_unary_expression] = "unary_expression",
  [sym__unary_expression] = "_unary_expression",
  [sym__prefix_postfix_expression] = "_prefix_postfix_expression",
  [sym_binary_expression] = "binary_expression",
  [sym__binary_expression] = "_binary_expression",
  [sym__and_expression] = "_and_expression",
  [sym_assignment_expression] = "assignment_expression",
  [sym__label] = "_label",
  [sym_macro_definition] = "macro_definition",
  [sym_parameter_declaration] = "parameter_declaration",
  [sym_subroutine_call_expression] = "subroutine_call_expression",
  [sym_macro] = "macro",
  [sym_recursive_macro_expansion] = "recursive_macro_expansion",
  [sym_macro_definition_command] = "identifier",
  [sym_command_expression] = "command_expression",
  [sym__host_command] = "_host_command",
  [sym__host_command_with_default_format] = "identifier",
  [sym__other_command] = "_other_command",
  [sym__command_identifier] = "identifier",
  [sym__command_arguments] = "argument_list",
  [sym__host_command_argument_list_default_format] = "argument_list",
  [sym__command_argument] = "_command_argument",
  [sym_option_expression] = "option_expression",
  [sym_format_expression] = "format_expression",
  [sym_call_expression] = "call_expression",
  [sym__function_identifier] = "identifier",
  [sym_argument_list] = "argument_list",
  [sym__var_command] = "_var_command",
  [sym__hll_var_command] = "_hll_var_command",
  [sym__hll_default_format_var_command] = "_hll_default_format_var_command",
  [sym__hll_non_default_format_var_command] = "_hll_non_default_format_var_command",
  [sym__non_hll_var_command] = "_non_hll_var_command",
  [sym__hll_var_definition_command] = "_hll_var_definition_command",
  [sym__hll_var_command_with_default_format] = "identifier",
  [sym__var_command_with_non_hll_format] = "identifier",
  [sym__hll_var_definition_command_expression] = "identifier",
  [sym__hll_var_if_command] = "identifier",
  [sym__hll_var_command_argument_list_default_format] = "argument_list",
  [sym__hll_var_command_argument_list_non_default_format] = "argument_list",
  [sym__hll_var_pattern_command_argument_list_format] = "argument_list",
  [sym__var_command_argument_list_non_hll_format] = "argument_list",
  [sym__var_definition_command_argument_list_format] = "argument_list",
  [sym__hll_var_call_expression_function] = "identifier",
  [sym__hll_var_call_expression] = "_hll_var_call_expression",
  [sym_hll_var_call_expression_argument_list] = "argument_list",
  [sym_hll_type_pattern] = "hll_type_pattern",
  [sym_trace32_hll_variable] = "trace32_hll_variable",
  [sym__hll_expression] = "_hll_expression",
  [sym_hll_call_expression] = "hll_call_expression",
  [sym_hll_field_expression] = "hll_field_expression",
  [sym_hll_subscript_expression] = "hll_subscript_expression",
  [sym_hll_cast_expression] = "hll_cast_expression",
  [sym_hll_sizeof_expression] = "hll_sizeof_expression",
  [sym_hll_pointer_expression] = "hll_pointer_expression",
  [sym_hll_comma_expression] = "hll_comma_expression",
  [sym_hll_update_expression] = "hll_update_expression",
  [sym_hll_unary_expression] = "hll_unary_expression",
  [sym_hll_binary_expression] = "hll_binary_expression",
  [sym_hll_range_expression] = "hll_range_expression",
  [sym_hll_assignment_expression] = "hll_assignment_expression",
  [sym__hll_assignment_left_expression] = "_hll_assignment_left_expression",
  [sym_hll_conditional_expression] = "hll_conditional_expression",
  [sym_hll_char_literal] = "hll_char_literal",
  [sym_hll_string_literal] = "hll_string_literal",
  [sym_hll_parenthesized_expression] = "hll_parenthesized_expression",
  [sym_hll_type_descriptor] = "hll_type_descriptor",
  [sym_hll_type_qualifier] = "hll_type_qualifier",
  [sym__hll_declaration_modifiers] = "_hll_declaration_modifiers",
  [sym__hll_type_specifier] = "_hll_type_specifier",
  [sym_hll_struct_specifier] = "hll_struct_specifier",
  [sym_hll_union_specifier] = "hll_union_specifier",
  [sym_hll_enum_specifier] = "hll_enum_specifier",
  [sym_hll_sized_type_specifier] = "hll_sized_type_specifier",
  [sym_hll_declaration] = "hll_declaration",
  [sym__hll_declaration_specifiers] = "_hll_declaration_specifiers",
  [sym__hll_declarator] = "_hll_declarator",
  [sym_hll_pointer_declarator] = "hll_pointer_declarator",
  [sym_hll_function_declarator] = "hll_function_declarator",
  [sym_hll_array_declarator] = "hll_array_declarator",
  [sym_hll_parenthesized_declarator] = "hll_parenthesized_declarator",
  [sym__hll_pointer_declarator_specifier] = "_hll_pointer_declarator_specifier",
  [sym__hll_abstract_declarator] = "_hll_abstract_declarator",
  [sym_hll_abstract_pointer_declarator] = "hll_abstract_pointer_declarator",
  [sym_hll_abstract_function_declarator] = "hll_abstract_function_declarator",
  [sym_hll_abstract_array_declarator] = "hll_abstract_array_declarator",
  [sym_hll_abstract_parenthesized_declarator] = "hll_abstract_parenthesized_declarator",
  [sym_hll_parameter_list] = "hll_parameter_list",
  [sym_hll_parameter_declaration] = "hll_parameter_declaration",
  [sym_hll_argument_list] = "hll_argument_list",
  [sym__hll_type_identifier] = "_hll_type_identifier",
  [sym__hll_field_identifier] = "_hll_field_identifier",
  [sym__literal] = "_literal",
  [sym__address_expression] = "_address_expression",
  [sym_memory_space] = "memory_space",
  [sym_address] = "address",
  [sym__parenthesized_address_expression] = "_parenthesized_address_expression",
  [sym__address_binary_expression] = "binary_expression",
  [sym_integer] = "integer",
  [sym_bitmask] = "bitmask",
  [sym_string] = "string",
  [sym_character] = "character",
  [sym_symbol] = "symbol",
  [sym__special_command_operator] = "literal",
  [sym__file_dialog] = "_file_dialog",
  [aux_sym_script_repeat1] = "script_repeat1",
  [aux_sym_block_repeat1] = "block_repeat1",
  [aux_sym_block_repeat2] = "block_repeat2",
  [aux_sym__path_expression_repeat1] = "_path_expression_repeat1",
  [aux_sym__path_expression_repeat2] = "_path_expression_repeat2",
  [aux_sym_labeled_expression_repeat1] = "labeled_expression_repeat1",
  [aux_sym_subroutine_block_repeat1] = "subroutine_block_repeat1",
  [aux_sym_if_block_repeat1] = "if_block_repeat1",
  [aux_sym_macro_definition_repeat1] = "macro_definition_repeat1",
  [aux_sym__command_identifier_repeat1] = "_command_identifier_repeat1",
  [aux_sym__command_arguments_repeat1] = "_command_arguments_repeat1",
  [aux_sym__command_arguments_repeat2] = "_command_arguments_repeat2",
  [aux_sym__command_arguments_repeat3] = "_command_arguments_repeat3",
  [aux_sym__host_command_argument_list_default_format_repeat1] = "_host_command_argument_list_default_format_repeat1",
  [aux_sym__host_command_argument_list_default_format_repeat2] = "_host_command_argument_list_default_format_repeat2",
  [aux_sym_format_expression_repeat1] = "format_expression_repeat1",
  [aux_sym__function_identifier_repeat1] = "_function_identifier_repeat1",
  [aux_sym_argument_list_repeat1] = "argument_list_repeat1",
  [aux_sym__hll_var_command_argument_list_default_format_repeat1] = "_hll_var_command_argument_list_default_format_repeat1",
  [aux_sym__hll_var_command_argument_list_default_format_repeat2] = "_hll_var_command_argument_list_default_format_repeat2",
  [aux_sym__hll_var_pattern_command_argument_list_format_repeat1] = "_hll_var_pattern_command_argument_list_format_repeat1",
  [aux_sym__hll_var_pattern_command_argument_list_format_repeat2] = "_hll_var_pattern_command_argument_list_format_repeat2",
  [aux_sym__var_command_argument_list_non_hll_format_repeat1] = "_var_command_argument_list_non_hll_format_repeat1",
  [aux_sym_hll_type_pattern_repeat1] = "hll_type_pattern_repeat1",
  [aux_sym_hll_string_literal_repeat1] = "hll_string_literal_repeat1",
  [aux_sym_hll_type_descriptor_repeat1] = "hll_type_descriptor_repeat1",
  [aux_sym_hll_type_descriptor_repeat2] = "hll_type_descriptor_repeat2",
  [aux_sym_hll_sized_type_specifier_repeat1] = "hll_sized_type_specifier_repeat1",
  [aux_sym__hll_declaration_specifiers_repeat1] = "_hll_declaration_specifiers_repeat1",
  [aux_sym__hll_declaration_specifiers_repeat2] = "_hll_declaration_specifiers_repeat2",
  [aux_sym__hll_pointer_declarator_specifier_repeat1] = "_hll_pointer_declarator_specifier_repeat1",
  [aux_sym_hll_parameter_list_repeat1] = "hll_parameter_list_repeat1",
  [aux_sym_hll_argument_list_repeat1] = "hll_argument_list_repeat1",
  [aux_sym_string_repeat1] = "string_repeat1",
  [anon_alias_sym_IF] = "IF",
  [anon_alias_sym_command] = "command",
  [anon_alias_sym_function] = "function",
  [alias_sym_hll_field_identifier] = "hll_field_identifier",
  [alias_sym_hll_type_identifier] = "hll_type_identifier",
  [anon_alias_sym_module] = "module",
  [anon_alias_sym_name] = "name",
  [anon_alias_sym_subcommand] = "subcommand",
  [anon_alias_sym_subfunction] = "subfunction",
  [anon_alias_sym_type] = "type",
};

static const TSSymbol ts_symbol_map[] = {
  [ts_builtin_sym_end] = ts_builtin_sym_end,
  [sym_identifier] = sym_identifier,
  [aux_sym_block_token1] = aux_sym_block_token1,
  [anon_sym_RPAREN] = anon_sym_RPAREN,
  [anon_sym_LPAREN] = anon_sym_LPAREN,
  [anon_sym_LBRACE] = anon_sym_LBRACE,
  [anon_sym_RBRACE] = anon_sym_RBRACE,
  [aux_sym_subroutine_block_token1] = sym_identifier,
  [aux_sym_if_block_token1] = sym_identifier,
  [aux_sym_elif_block_token1] = sym_identifier,
  [aux_sym_while_block_token1] = sym_identifier,
  [aux_sym_while_block_token2] = sym_identifier,
  [aux_sym__repeat_block_pre_condition_format_token1] = sym_identifier,
  [anon_sym_EQ] = anon_sym_EQ,
  [anon_sym_PLUS] = anon_sym_PLUS,
  [anon_sym_DASH] = anon_sym_DASH,
  [anon_sym_TILDE] = anon_sym_TILDE,
  [anon_sym_BANG] = anon_sym_BANG,
  [anon_sym_PLUS_PLUS] = anon_sym_PLUS_PLUS,
  [anon_sym_DASH_DASH] = anon_sym_DASH_DASH,
  [anon_sym_CARET_CARET] = anon_sym_CARET_CARET,
  [anon_sym_PIPE_PIPE] = anon_sym_PIPE_PIPE,
  [anon_sym_STAR] = anon_sym_STAR,
  [anon_sym_SLASH] = anon_sym_SLASH,
  [anon_sym_PERCENT] = anon_sym_PERCENT,
  [anon_sym_PIPE] = anon_sym_PIPE,
  [anon_sym_CARET] = anon_sym_CARET,
  [anon_sym_EQ_EQ] = anon_sym_EQ_EQ,
  [anon_sym_BANG_EQ] = anon_sym_BANG_EQ,
  [anon_sym_GT] = anon_sym_GT,
  [anon_sym_GT_EQ] = anon_sym_GT_EQ,
  [anon_sym_LT_EQ] = anon_sym_LT_EQ,
  [anon_sym_LT] = anon_sym_LT,
  [anon_sym_LT_LT] = anon_sym_LT_LT,
  [anon_sym_GT_GT] = anon_sym_GT_GT,
  [anon_sym_DOT_DOT] = anon_sym_DOT_DOT,
  [anon_sym_AMP_AMP] = anon_sym_AMP_AMP,
  [anon_sym_AMP] = anon_sym_AMP,
  [anon_sym_COLON] = anon_sym_COLON,
  [aux_sym_macro_definition_token1] = aux_sym_macro_definition_token1,
  [aux_sym_parameter_declaration_token1] = sym_identifier,
  [aux_sym_parameter_declaration_token2] = sym_identifier,
  [aux_sym_parameter_declaration_token3] = sym_identifier,
  [aux_sym_parameter_declaration_token4] = sym_identifier,
  [aux_sym_subroutine_call_expression_token1] = sym_identifier,
  [aux_sym_macro_definition_command_token1] = aux_sym_macro_definition_command_token1,
  [aux_sym_macro_definition_command_token2] = aux_sym_macro_definition_command_token2,
  [aux_sym_macro_definition_command_token3] = aux_sym_macro_definition_command_token3,
  [aux_sym__host_command_with_default_format_token1] = aux_sym__host_command_with_default_format_token1,
  [anon_sym_DOT] = anon_sym_DOT,
  [anon_sym_COMMA] = anon_sym_COMMA,
  [aux_sym__host_command_argument_list_default_format_token1] = aux_sym__host_command_argument_list_default_format_token1,
  [aux_sym__hll_non_default_format_var_command_token1] = aux_sym__hll_non_default_format_var_command_token1,
  [aux_sym__hll_non_default_format_var_command_token2] = aux_sym__hll_non_default_format_var_command_token2,
  [aux_sym__hll_non_default_format_var_command_token3] = aux_sym__hll_non_default_format_var_command_token3,
  [aux_sym__hll_non_default_format_var_command_token4] = aux_sym__hll_non_default_format_var_command_token4,
  [aux_sym__hll_non_default_format_var_command_token5] = aux_sym__hll_non_default_format_var_command_token5,
  [aux_sym__hll_var_definition_command_token1] = aux_sym__hll_var_definition_command_token1,
  [aux_sym__var_command_with_non_hll_format_token1] = aux_sym__var_command_with_non_hll_format_token1,
  [aux_sym__var_command_with_non_hll_format_token2] = aux_sym__var_command_with_non_hll_format_token2,
  [aux_sym__var_command_with_non_hll_format_token3] = aux_sym__var_command_with_non_hll_format_token3,
  [aux_sym__hll_var_definition_command_expression_token1] = aux_sym__hll_var_definition_command_expression_token1,
  [aux_sym__hll_var_definition_command_expression_token2] = aux_sym__hll_var_definition_command_expression_token2,
  [anon_sym_QMARK] = anon_sym_QMARK,
  [anon_sym_BSLASH] = anon_sym_BSLASH,
  [anon_sym_DASH_GT] = anon_sym_DASH_GT,
  [anon_sym_LBRACK] = anon_sym_LBRACK,
  [anon_sym_RBRACK] = anon_sym_RBRACK,
  [anon_sym_sizeof] = anon_sym_sizeof,
  [anon_sym_STAR_EQ] = anon_sym_STAR_EQ,
  [anon_sym_SLASH_EQ] = anon_sym_SLASH_EQ,
  [anon_sym_PERCENT_EQ] = anon_sym_PERCENT_EQ,
  [anon_sym_PLUS_EQ] = anon_sym_PLUS_EQ,
  [anon_sym_DASH_EQ] = anon_sym_DASH_EQ,
  [anon_sym_LT_LT_EQ] = anon_sym_LT_LT_EQ,
  [anon_sym_GT_GT_EQ] = anon_sym_GT_GT_EQ,
  [anon_sym_AMP_EQ] = anon_sym_AMP_EQ,
  [anon_sym_CARET_EQ] = anon_sym_CARET_EQ,
  [anon_sym_PIPE_EQ] = anon_sym_PIPE_EQ,
  [anon_sym_L_SQUOTE] = anon_sym_L_SQUOTE,
  [anon_sym_u_SQUOTE] = anon_sym_u_SQUOTE,
  [anon_sym_U_SQUOTE] = anon_sym_U_SQUOTE,
  [anon_sym_u8_SQUOTE] = anon_sym_u8_SQUOTE,
  [anon_sym_SQUOTE] = anon_sym_SQUOTE,
  [aux_sym_hll_char_literal_token1] = sym_character,
  [anon_sym_L_DQUOTE] = anon_sym_L_DQUOTE,
  [anon_sym_u_DQUOTE] = anon_sym_u_DQUOTE,
  [anon_sym_U_DQUOTE] = anon_sym_U_DQUOTE,
  [anon_sym_u8_DQUOTE] = anon_sym_u8_DQUOTE,
  [anon_sym_DQUOTE] = anon_sym_DQUOTE,
  [aux_sym_hll_string_literal_token1] = aux_sym_hll_string_literal_token1,
  [anon_sym_const] = anon_sym_const,
  [anon_sym_volatile] = anon_sym_volatile,
  [anon_sym_struct] = anon_sym_struct,
  [anon_sym_union] = anon_sym_union,
  [anon_sym_enum] = anon_sym_enum,
  [anon_sym_signed] = anon_sym_signed,
  [anon_sym_unsigned] = anon_sym_unsigned,
  [anon_sym_long] = anon_sym_long,
  [anon_sym_short] = anon_sym_short,
  [sym_hll_primitive_type] = sym_hll_primitive_type,
  [sym_hll_escape_sequence] = sym_hll_escape_sequence,
  [aux_sym__hll_expression_separator_token1] = aux_sym__hll_expression_separator_token1,
  [aux_sym__hll_expression_separator_token2] = aux_sym__hll_expression_separator_token2,
  [anon_sym_COLON_COLON_COLON] = anon_sym_COLON_COLON_COLON,
  [anon_sym_COLON_COLON] = anon_sym_COLON_COLON,
  [sym_access_class] = sym_access_class,
  [aux_sym_integer_token1] = aux_sym_integer_token1,
  [aux_sym_integer_token2] = aux_sym_integer_token2,
  [sym_float] = sym_float,
  [aux_sym_bitmask_token1] = aux_sym_bitmask_token1,
  [aux_sym_bitmask_token2] = aux_sym_bitmask_token2,
  [aux_sym_string_token1] = aux_sym_string_token1,
  [aux_sym_string_token2] = aux_sym_string_token2,
  [aux_sym_character_token1] = aux_sym_character_token1,
  [aux_sym_character_token2] = aux_sym_character_token2,
  [aux_sym_symbol_token1] = aux_sym_symbol_token1,
  [aux_sym_symbol_token2] = aux_sym_symbol_token2,
  [aux_sym_symbol_token3] = aux_sym_symbol_token3,
  [sym__composed_name] = sym_identifier,
  [sym_time] = sym_time,
  [sym_frequency] = sym_frequency,
  [sym_percentage] = sym_percentage,
  [sym_file_handle] = sym_file_handle,
  [sym_comment] = sym_comment,
  [sym__blank_line] = sym__blank_line,
  [sym__line_continuation] = sym__line_continuation,
  [sym__blank] = sym__blank,
  [sym_label_identifier] = sym_identifier,
  [sym__and_operator_pre_hook] = sym__and_operator_pre_hook,
  [sym__decimal_number] = sym__decimal_number,
  [sym__decimal_number_pre_hook] = sym__decimal_number_pre_hook,
  [sym_hll_number_literal] = sym_hll_number_literal,
  [sym__hll_number_literal_pre_hook] = sym__hll_number_literal_pre_hook,
  [sym_path] = sym_path,
  [sym__ampersand_char] = sym__ampersand_char,
  [sym_script] = sym_script,
  [sym_block] = sym_block,
  [sym__statement] = sym__statement,
  [sym__non_labeled_statement] = sym__non_labeled_statement,
  [sym__expression] = sym__expression,
  [sym__parenthesized_expression] = sym__parenthesized_expression,
  [sym__path_expression] = sym__path_expression,
  [sym_labeled_expression] = sym_labeled_expression,
  [sym_subroutine_block] = sym_subroutine_block,
  [sym_if_block] = sym_if_block,
  [sym_elif_block] = sym_elif_block,
  [sym_else_block] = sym_else_block,
  [sym_while_block] = sym_while_block,
  [sym_repeat_block] = sym_repeat_block,
  [sym__repeat_block_pre_condition_format] = sym__repeat_block_pre_condition_format,
  [sym__repeat_block_post_condition_format] = sym__repeat_block_post_condition_format,
  [sym_macro_assignment_expression] = sym_assignment_expression,
  [sym_unary_expression] = sym_unary_expression,
  [sym__unary_expression] = sym__unary_expression,
  [sym__prefix_postfix_expression] = sym__prefix_postfix_expression,
  [sym_binary_expression] = sym_binary_expression,
  [sym__binary_expression] = sym__binary_expression,
  [sym__and_expression] = sym__and_expression,
  [sym_assignment_expression] = sym_assignment_expression,
  [sym__label] = sym__label,
  [sym_macro_definition] = sym_macro_definition,
  [sym_parameter_declaration] = sym_parameter_declaration,
  [sym_subroutine_call_expression] = sym_subroutine_call_expression,
  [sym_macro] = sym_macro,
  [sym_recursive_macro_expansion] = sym_recursive_macro_expansion,
  [sym_macro_definition_command] = sym_identifier,
  [sym_command_expression] = sym_command_expression,
  [sym__host_command] = sym__host_command,
  [sym__host_command_with_default_format] = sym_identifier,
  [sym__other_command] = sym__other_command,
  [sym__command_identifier] = sym_identifier,
  [sym__command_arguments] = sym_argument_list,
  [sym__host_command_argument_list_default_format] = sym_argument_list,
  [sym__command_argument] = sym__command_argument,
  [sym_option_expression] = sym_option_expression,
  [sym_format_expression] = sym_format_expression,
  [sym_call_expression] = sym_call_expression,
  [sym__function_identifier] = sym_identifier,
  [sym_argument_list] = sym_argument_list,
  [sym__var_command] = sym__var_command,
  [sym__hll_var_command] = sym__hll_var_command,
  [sym__hll_default_format_var_command] = sym__hll_default_format_var_command,
  [sym__hll_non_default_format_var_command] = sym__hll_non_default_format_var_command,
  [sym__non_hll_var_command] = sym__non_hll_var_command,
  [sym__hll_var_definition_command] = sym__hll_var_definition_command,
  [sym__hll_var_command_with_default_format] = sym_identifier,
  [sym__var_command_with_non_hll_format] = sym_identifier,
  [sym__hll_var_definition_command_expression] = sym_identifier,
  [sym__hll_var_if_command] = sym_identifier,
  [sym__hll_var_command_argument_list_default_format] = sym_argument_list,
  [sym__hll_var_command_argument_list_non_default_format] = sym_argument_list,
  [sym__hll_var_pattern_command_argument_list_format] = sym_argument_list,
  [sym__var_command_argument_list_non_hll_format] = sym_argument_list,
  [sym__var_definition_command_argument_list_format] = sym_argument_list,
  [sym__hll_var_call_expression_function] = sym_identifier,
  [sym__hll_var_call_expression] = sym__hll_var_call_expression,
  [sym_hll_var_call_expression_argument_list] = sym_argument_list,
  [sym_hll_type_pattern] = sym_hll_type_pattern,
  [sym_trace32_hll_variable] = sym_trace32_hll_variable,
  [sym__hll_expression] = sym__hll_expression,
  [sym_hll_call_expression] = sym_hll_call_expression,
  [sym_hll_field_expression] = sym_hll_field_expression,
  [sym_hll_subscript_expression] = sym_hll_subscript_expression,
  [sym_hll_cast_expression] = sym_hll_cast_expression,
  [sym_hll_sizeof_expression] = sym_hll_sizeof_expression,
  [sym_hll_pointer_expression] = sym_hll_pointer_expression,
  [sym_hll_comma_expression] = sym_hll_comma_expression,
  [sym_hll_update_expression] = sym_hll_update_expression,
  [sym_hll_unary_expression] = sym_hll_unary_expression,
  [sym_hll_binary_expression] = sym_hll_binary_expression,
  [sym_hll_range_expression] = sym_hll_range_expression,
  [sym_hll_assignment_expression] = sym_hll_assignment_expression,
  [sym__hll_assignment_left_expression] = sym__hll_assignment_left_expression,
  [sym_hll_conditional_expression] = sym_hll_conditional_expression,
  [sym_hll_char_literal] = sym_hll_char_literal,
  [sym_hll_string_literal] = sym_hll_string_literal,
  [sym_hll_parenthesized_expression] = sym_hll_parenthesized_expression,
  [sym_hll_type_descriptor] = sym_hll_type_descriptor,
  [sym_hll_type_qualifier] = sym_hll_type_qualifier,
  [sym__hll_declaration_modifiers] = sym__hll_declaration_modifiers,
  [sym__hll_type_specifier] = sym__hll_type_specifier,
  [sym_hll_struct_specifier] = sym_hll_struct_specifier,
  [sym_hll_union_specifier] = sym_hll_union_specifier,
  [sym_hll_enum_specifier] = sym_hll_enum_specifier,
  [sym_hll_sized_type_specifier] = sym_hll_sized_type_specifier,
  [sym_hll_declaration] = sym_hll_declaration,
  [sym__hll_declaration_specifiers] = sym__hll_declaration_specifiers,
  [sym__hll_declarator] = sym__hll_declarator,
  [sym_hll_pointer_declarator] = sym_hll_pointer_declarator,
  [sym_hll_function_declarator] = sym_hll_function_declarator,
  [sym_hll_array_declarator] = sym_hll_array_declarator,
  [sym_hll_parenthesized_declarator] = sym_hll_parenthesized_declarator,
  [sym__hll_pointer_declarator_specifier] = sym__hll_pointer_declarator_specifier,
  [sym__hll_abstract_declarator] = sym__hll_abstract_declarator,
  [sym_hll_abstract_pointer_declarator] = sym_hll_abstract_pointer_declarator,
  [sym_hll_abstract_function_declarator] = sym_hll_abstract_function_declarator,
  [sym_hll_abstract_array_declarator] = sym_hll_abstract_array_declarator,
  [sym_hll_abstract_parenthesized_declarator] = sym_hll_abstract_parenthesized_declarator,
  [sym_hll_parameter_list] = sym_hll_parameter_list,
  [sym_hll_parameter_declaration] = sym_hll_parameter_declaration,
  [sym_hll_argument_list] = sym_hll_argument_list,
  [sym__hll_type_identifier] = sym__hll_type_identifier,
  [sym__hll_field_identifier] = sym__hll_field_identifier,
  [sym__literal] = sym__literal,
  [sym__address_expression] = sym__address_expression,
  [sym_memory_space] = sym_memory_space,
  [sym_address] = sym_address,
  [sym__parenthesized_address_expression] = sym__parenthesized_address_expression,
  [sym__address_binary_expression] = sym_binary_expression,
  [sym_integer] = sym_integer,
  [sym_bitmask] = sym_bitmask,
  [sym_string] = sym_string,
  [sym_character] = sym_character,
  [sym_symbol] = sym_symbol,
  [sym__special_command_operator] = sym__special_command_operator,
  [sym__file_dialog] = sym__file_dialog,
  [aux_sym_script_repeat1] = aux_sym_script_repeat1,
  [aux_sym_block_repeat1] = aux_sym_block_repeat1,
  [aux_sym_block_repeat2] = aux_sym_block_repeat2,
  [aux_sym__path_expression_repeat1] = aux_sym__path_expression_repeat1,
  [aux_sym__path_expression_repeat2] = aux_sym__path_expression_repeat2,
  [aux_sym_labeled_expression_repeat1] = aux_sym_labeled_expression_repeat1,
  [aux_sym_subroutine_block_repeat1] = aux_sym_subroutine_block_repeat1,
  [aux_sym_if_block_repeat1] = aux_sym_if_block_repeat1,
  [aux_sym_macro_definition_repeat1] = aux_sym_macro_definition_repeat1,
  [aux_sym__command_identifier_repeat1] = aux_sym__command_identifier_repeat1,
  [aux_sym__command_arguments_repeat1] = aux_sym__command_arguments_repeat1,
  [aux_sym__command_arguments_repeat2] = aux_sym__command_arguments_repeat2,
  [aux_sym__command_arguments_repeat3] = aux_sym__command_arguments_repeat3,
  [aux_sym__host_command_argument_list_default_format_repeat1] = aux_sym__host_command_argument_list_default_format_repeat1,
  [aux_sym__host_command_argument_list_default_format_repeat2] = aux_sym__host_command_argument_list_default_format_repeat2,
  [aux_sym_format_expression_repeat1] = aux_sym_format_expression_repeat1,
  [aux_sym__function_identifier_repeat1] = aux_sym__function_identifier_repeat1,
  [aux_sym_argument_list_repeat1] = aux_sym_argument_list_repeat1,
  [aux_sym__hll_var_command_argument_list_default_format_repeat1] = aux_sym__hll_var_command_argument_list_default_format_repeat1,
  [aux_sym__hll_var_command_argument_list_default_format_repeat2] = aux_sym__hll_var_command_argument_list_default_format_repeat2,
  [aux_sym__hll_var_pattern_command_argument_list_format_repeat1] = aux_sym__hll_var_pattern_command_argument_list_format_repeat1,
  [aux_sym__hll_var_pattern_command_argument_list_format_repeat2] = aux_sym__hll_var_pattern_command_argument_list_format_repeat2,
  [aux_sym__var_command_argument_list_non_hll_format_repeat1] = aux_sym__var_command_argument_list_non_hll_format_repeat1,
  [aux_sym_hll_type_pattern_repeat1] = aux_sym_hll_type_pattern_repeat1,
  [aux_sym_hll_string_literal_repeat1] = aux_sym_hll_string_literal_repeat1,
  [aux_sym_hll_type_descriptor_repeat1] = aux_sym_hll_type_descriptor_repeat1,
  [aux_sym_hll_type_descriptor_repeat2] = aux_sym_hll_type_descriptor_repeat2,
  [aux_sym_hll_sized_type_specifier_repeat1] = aux_sym_hll_sized_type_specifier_repeat1,
  [aux_sym__hll_declaration_specifiers_repeat1] = aux_sym__hll_declaration_specifiers_repeat1,
  [aux_sym__hll_declaration_specifiers_repeat2] = aux_sym__hll_declaration_specifiers_repeat2,
  [aux_sym__hll_pointer_declarator_specifier_repeat1] = aux_sym__hll_pointer_declarator_specifier_repeat1,
  [aux_sym_hll_parameter_list_repeat1] = aux_sym_hll_parameter_list_repeat1,
  [aux_sym_hll_argument_list_repeat1] = aux_sym_hll_argument_list_repeat1,
  [aux_sym_string_repeat1] = aux_sym_string_repeat1,
  [anon_alias_sym_IF] = anon_alias_sym_IF,
  [anon_alias_sym_command] = anon_alias_sym_command,
  [anon_alias_sym_function] = anon_alias_sym_function,
  [alias_sym_hll_field_identifier] = alias_sym_hll_field_identifier,
  [alias_sym_hll_type_identifier] = alias_sym_hll_type_identifier,
  [anon_alias_sym_module] = anon_alias_sym_module,
  [anon_alias_sym_name] = anon_alias_sym_name,
  [anon_alias_sym_subcommand] = anon_alias_sym_subcommand,
  [anon_alias_sym_subfunction] = anon_alias_sym_subfunction,
  [anon_alias_sym_type] = anon_alias_sym_type,
};

static const TSSymbolMetadata ts_symbol_metadata[] = {
  [ts_builtin_sym_end] = {
    .visible = false,
    .named = true,
  },
  [sym_identifier] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_block_token1] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_RPAREN] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LPAREN] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LBRACE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RBRACE] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_subroutine_block_token1] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_if_block_token1] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_elif_block_token1] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_while_block_token1] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_while_block_token2] = {
    .visible = true,
    .named = true,
  },
  [aux_sym__repeat_block_pre_condition_format_token1] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PLUS] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DASH] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_TILDE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_BANG] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PLUS_PLUS] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DASH_DASH] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_CARET_CARET] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PIPE_PIPE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_STAR] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_SLASH] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PERCENT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PIPE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_CARET] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_EQ_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_BANG_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_GT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_GT_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LT_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LT_LT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_GT_GT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DOT_DOT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_AMP_AMP] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_AMP] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COLON] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_macro_definition_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_parameter_declaration_token1] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_parameter_declaration_token2] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_parameter_declaration_token3] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_parameter_declaration_token4] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_subroutine_call_expression_token1] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_macro_definition_command_token1] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_macro_definition_command_token2] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_macro_definition_command_token3] = {
    .visible = true,
    .named = false,
  },
  [aux_sym__host_command_with_default_format_token1] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DOT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COMMA] = {
    .visible = true,
    .named = false,
  },
  [aux_sym__host_command_argument_list_default_format_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__hll_non_default_format_var_command_token1] = {
    .visible = true,
    .named = false,
  },
  [aux_sym__hll_non_default_format_var_command_token2] = {
    .visible = true,
    .named = false,
  },
  [aux_sym__hll_non_default_format_var_command_token3] = {
    .visible = true,
    .named = false,
  },
  [aux_sym__hll_non_default_format_var_command_token4] = {
    .visible = true,
    .named = false,
  },
  [aux_sym__hll_non_default_format_var_command_token5] = {
    .visible = true,
    .named = false,
  },
  [aux_sym__hll_var_definition_command_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__var_command_with_non_hll_format_token1] = {
    .visible = true,
    .named = false,
  },
  [aux_sym__var_command_with_non_hll_format_token2] = {
    .visible = true,
    .named = false,
  },
  [aux_sym__var_command_with_non_hll_format_token3] = {
    .visible = true,
    .named = false,
  },
  [aux_sym__hll_var_definition_command_expression_token1] = {
    .visible = true,
    .named = false,
  },
  [aux_sym__hll_var_definition_command_expression_token2] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_QMARK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_BSLASH] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DASH_GT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LBRACK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RBRACK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_sizeof] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_STAR_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_SLASH_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PERCENT_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PLUS_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DASH_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LT_LT_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_GT_GT_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_AMP_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_CARET_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PIPE_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_L_SQUOTE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_u_SQUOTE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_U_SQUOTE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_u8_SQUOTE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_SQUOTE] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_hll_char_literal_token1] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_L_DQUOTE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_u_DQUOTE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_U_DQUOTE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_u8_DQUOTE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DQUOTE] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_hll_string_literal_token1] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_const] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_volatile] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_struct] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_union] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_enum] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_signed] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_unsigned] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_long] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_short] = {
    .visible = true,
    .named = false,
  },
  [sym_hll_primitive_type] = {
    .visible = true,
    .named = true,
  },
  [sym_hll_escape_sequence] = {
    .visible = true,
    .named = true,
  },
  [aux_sym__hll_expression_separator_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__hll_expression_separator_token2] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_COLON_COLON_COLON] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COLON_COLON] = {
    .visible = true,
    .named = false,
  },
  [sym_access_class] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_integer_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_integer_token2] = {
    .visible = false,
    .named = false,
  },
  [sym_float] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_bitmask_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_bitmask_token2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_string_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_string_token2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_character_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_character_token2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_symbol_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_symbol_token2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_symbol_token3] = {
    .visible = false,
    .named = false,
  },
  [sym__composed_name] = {
    .visible = true,
    .named = true,
  },
  [sym_time] = {
    .visible = true,
    .named = true,
  },
  [sym_frequency] = {
    .visible = true,
    .named = true,
  },
  [sym_percentage] = {
    .visible = true,
    .named = true,
  },
  [sym_file_handle] = {
    .visible = true,
    .named = true,
  },
  [sym_comment] = {
    .visible = true,
    .named = true,
  },
  [sym__blank_line] = {
    .visible = false,
    .named = true,
  },
  [sym__line_continuation] = {
    .visible = false,
    .named = true,
  },
  [sym__blank] = {
    .visible = false,
    .named = true,
  },
  [sym_label_identifier] = {
    .visible = true,
    .named = true,
  },
  [sym__and_operator_pre_hook] = {
    .visible = false,
    .named = true,
  },
  [sym__decimal_number] = {
    .visible = false,
    .named = true,
  },
  [sym__decimal_number_pre_hook] = {
    .visible = false,
    .named = true,
  },
  [sym_hll_number_literal] = {
    .visible = true,
    .named = true,
  },
  [sym__hll_number_literal_pre_hook] = {
    .visible = false,
    .named = true,
  },
  [sym_path] = {
    .visible = true,
    .named = true,
  },
  [sym__ampersand_char] = {
    .visible = false,
    .named = true,
  },
  [sym_script] = {
    .visible = true,
    .named = true,
  },
  [sym_block] = {
    .visible = true,
    .named = true,
  },
  [sym__statement] = {
    .visible = false,
    .named = true,
  },
  [sym__non_labeled_statement] = {
    .visible = false,
    .named = true,
  },
  [sym__expression] = {
    .visible = false,
    .named = true,
  },
  [sym__parenthesized_expression] = {
    .visible = false,
    .named = true,
  },
  [sym__path_expression] = {
    .visible = false,
    .named = true,
  },
  [sym_labeled_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_subroutine_block] = {
    .visible = true,
    .named = true,
  },
  [sym_if_block] = {
    .visible = true,
    .named = true,
  },
  [sym_elif_block] = {
    .visible = true,
    .named = true,
  },
  [sym_else_block] = {
    .visible = true,
    .named = true,
  },
  [sym_while_block] = {
    .visible = true,
    .named = true,
  },
  [sym_repeat_block] = {
    .visible = true,
    .named = true,
  },
  [sym__repeat_block_pre_condition_format] = {
    .visible = false,
    .named = true,
  },
  [sym__repeat_block_post_condition_format] = {
    .visible = false,
    .named = true,
  },
  [sym_macro_assignment_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_unary_expression] = {
    .visible = true,
    .named = true,
  },
  [sym__unary_expression] = {
    .visible = false,
    .named = true,
  },
  [sym__prefix_postfix_expression] = {
    .visible = false,
    .named = true,
  },
  [sym_binary_expression] = {
    .visible = true,
    .named = true,
  },
  [sym__binary_expression] = {
    .visible = false,
    .named = true,
  },
  [sym__and_expression] = {
    .visible = false,
    .named = true,
  },
  [sym_assignment_expression] = {
    .visible = true,
    .named = true,
  },
  [sym__label] = {
    .visible = false,
    .named = true,
  },
  [sym_macro_definition] = {
    .visible = true,
    .named = true,
  },
  [sym_parameter_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_subroutine_call_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_macro] = {
    .visible = true,
    .named = true,
  },
  [sym_recursive_macro_expansion] = {
    .visible = true,
    .named = true,
  },
  [sym_macro_definition_command] = {
    .visible = true,
    .named = true,
  },
  [sym_command_expression] = {
    .visible = true,
    .named = true,
  },
  [sym__host_command] = {
    .visible = false,
    .named = true,
  },
  [sym__host_command_with_default_format] = {
    .visible = true,
    .named = true,
  },
  [sym__other_command] = {
    .visible = false,
    .named = true,
  },
  [sym__command_identifier] = {
    .visible = true,
    .named = true,
  },
  [sym__command_arguments] = {
    .visible = true,
    .named = true,
  },
  [sym__host_command_argument_list_default_format] = {
    .visible = true,
    .named = true,
  },
  [sym__command_argument] = {
    .visible = false,
    .named = true,
  },
  [sym_option_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_format_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_call_expression] = {
    .visible = true,
    .named = true,
  },
  [sym__function_identifier] = {
    .visible = true,
    .named = true,
  },
  [sym_argument_list] = {
    .visible = true,
    .named = true,
  },
  [sym__var_command] = {
    .visible = false,
    .named = true,
  },
  [sym__hll_var_command] = {
    .visible = false,
    .named = true,
  },
  [sym__hll_default_format_var_command] = {
    .visible = false,
    .named = true,
  },
  [sym__hll_non_default_format_var_command] = {
    .visible = false,
    .named = true,
  },
  [sym__non_hll_var_command] = {
    .visible = false,
    .named = true,
  },
  [sym__hll_var_definition_command] = {
    .visible = false,
    .named = true,
  },
  [sym__hll_var_command_with_default_format] = {
    .visible = true,
    .named = true,
  },
  [sym__var_command_with_non_hll_format] = {
    .visible = true,
    .named = true,
  },
  [sym__hll_var_definition_command_expression] = {
    .visible = true,
    .named = true,
  },
  [sym__hll_var_if_command] = {
    .visible = true,
    .named = true,
  },
  [sym__hll_var_command_argument_list_default_format] = {
    .visible = true,
    .named = true,
  },
  [sym__hll_var_command_argument_list_non_default_format] = {
    .visible = true,
    .named = true,
  },
  [sym__hll_var_pattern_command_argument_list_format] = {
    .visible = true,
    .named = true,
  },
  [sym__var_command_argument_list_non_hll_format] = {
    .visible = true,
    .named = true,
  },
  [sym__var_definition_command_argument_list_format] = {
    .visible = true,
    .named = true,
  },
  [sym__hll_var_call_expression_function] = {
    .visible = true,
    .named = true,
  },
  [sym__hll_var_call_expression] = {
    .visible = false,
    .named = true,
  },
  [sym_hll_var_call_expression_argument_list] = {
    .visible = true,
    .named = true,
  },
  [sym_hll_type_pattern] = {
    .visible = true,
    .named = true,
  },
  [sym_trace32_hll_variable] = {
    .visible = true,
    .named = true,
  },
  [sym__hll_expression] = {
    .visible = false,
    .named = true,
  },
  [sym_hll_call_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_hll_field_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_hll_subscript_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_hll_cast_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_hll_sizeof_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_hll_pointer_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_hll_comma_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_hll_update_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_hll_unary_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_hll_binary_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_hll_range_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_hll_assignment_expression] = {
    .visible = true,
    .named = true,
  },
  [sym__hll_assignment_left_expression] = {
    .visible = false,
    .named = true,
  },
  [sym_hll_conditional_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_hll_char_literal] = {
    .visible = true,
    .named = true,
  },
  [sym_hll_string_literal] = {
    .visible = true,
    .named = true,
  },
  [sym_hll_parenthesized_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_hll_type_descriptor] = {
    .visible = true,
    .named = true,
  },
  [sym_hll_type_qualifier] = {
    .visible = true,
    .named = true,
  },
  [sym__hll_declaration_modifiers] = {
    .visible = false,
    .named = true,
  },
  [sym__hll_type_specifier] = {
    .visible = false,
    .named = true,
  },
  [sym_hll_struct_specifier] = {
    .visible = true,
    .named = true,
  },
  [sym_hll_union_specifier] = {
    .visible = true,
    .named = true,
  },
  [sym_hll_enum_specifier] = {
    .visible = true,
    .named = true,
  },
  [sym_hll_sized_type_specifier] = {
    .visible = true,
    .named = true,
  },
  [sym_hll_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym__hll_declaration_specifiers] = {
    .visible = false,
    .named = true,
  },
  [sym__hll_declarator] = {
    .visible = false,
    .named = true,
  },
  [sym_hll_pointer_declarator] = {
    .visible = true,
    .named = true,
  },
  [sym_hll_function_declarator] = {
    .visible = true,
    .named = true,
  },
  [sym_hll_array_declarator] = {
    .visible = true,
    .named = true,
  },
  [sym_hll_parenthesized_declarator] = {
    .visible = true,
    .named = true,
  },
  [sym__hll_pointer_declarator_specifier] = {
    .visible = false,
    .named = true,
  },
  [sym__hll_abstract_declarator] = {
    .visible = false,
    .named = true,
  },
  [sym_hll_abstract_pointer_declarator] = {
    .visible = true,
    .named = true,
  },
  [sym_hll_abstract_function_declarator] = {
    .visible = true,
    .named = true,
  },
  [sym_hll_abstract_array_declarator] = {
    .visible = true,
    .named = true,
  },
  [sym_hll_abstract_parenthesized_declarator] = {
    .visible = true,
    .named = true,
  },
  [sym_hll_parameter_list] = {
    .visible = true,
    .named = true,
  },
  [sym_hll_parameter_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_hll_argument_list] = {
    .visible = true,
    .named = true,
  },
  [sym__hll_type_identifier] = {
    .visible = false,
    .named = true,
  },
  [sym__hll_field_identifier] = {
    .visible = false,
    .named = true,
  },
  [sym__literal] = {
    .visible = false,
    .named = true,
  },
  [sym__address_expression] = {
    .visible = false,
    .named = true,
  },
  [sym_memory_space] = {
    .visible = true,
    .named = true,
  },
  [sym_address] = {
    .visible = true,
    .named = true,
  },
  [sym__parenthesized_address_expression] = {
    .visible = false,
    .named = true,
  },
  [sym__address_binary_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_integer] = {
    .visible = true,
    .named = true,
  },
  [sym_bitmask] = {
    .visible = true,
    .named = true,
  },
  [sym_string] = {
    .visible = true,
    .named = true,
  },
  [sym_character] = {
    .visible = true,
    .named = true,
  },
  [sym_symbol] = {
    .visible = true,
    .named = true,
  },
  [sym__special_command_operator] = {
    .visible = true,
    .named = true,
  },
  [sym__file_dialog] = {
    .visible = false,
    .named = true,
  },
  [aux_sym_script_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_block_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_block_repeat2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__path_expression_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__path_expression_repeat2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_labeled_expression_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_subroutine_block_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_if_block_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_macro_definition_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__command_identifier_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__command_arguments_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__command_arguments_repeat2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__command_arguments_repeat3] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__host_command_argument_list_default_format_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__host_command_argument_list_default_format_repeat2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_format_expression_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__function_identifier_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_argument_list_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__hll_var_command_argument_list_default_format_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__hll_var_command_argument_list_default_format_repeat2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__hll_var_pattern_command_argument_list_format_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__hll_var_pattern_command_argument_list_format_repeat2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__var_command_argument_list_non_hll_format_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_hll_type_pattern_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_hll_string_literal_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_hll_type_descriptor_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_hll_type_descriptor_repeat2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_hll_sized_type_specifier_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__hll_declaration_specifiers_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__hll_declaration_specifiers_repeat2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__hll_pointer_declarator_specifier_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_hll_parameter_list_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_hll_argument_list_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_string_repeat1] = {
    .visible = false,
    .named = false,
  },
  [anon_alias_sym_IF] = {
    .visible = true,
    .named = false,
  },
  [anon_alias_sym_command] = {
    .visible = true,
    .named = false,
  },
  [anon_alias_sym_function] = {
    .visible = true,
    .named = false,
  },
  [alias_sym_hll_field_identifier] = {
    .visible = true,
    .named = true,
  },
  [alias_sym_hll_type_identifier] = {
    .visible = true,
    .named = true,
  },
  [anon_alias_sym_module] = {
    .visible = true,
    .named = false,
  },
  [anon_alias_sym_name] = {
    .visible = true,
    .named = false,
  },
  [anon_alias_sym_subcommand] = {
    .visible = true,
    .named = false,
  },
  [anon_alias_sym_subfunction] = {
    .visible = true,
    .named = false,
  },
  [anon_alias_sym_type] = {
    .visible = true,
    .named = false,
  },
};

enum ts_field_identifiers {
  field_access = 1,
  field_alternative = 2,
  field_argument = 3,
  field_arguments = 4,
  field_command = 5,
  field_condition = 6,
  field_consequence = 7,
  field_declarator = 8,
  field_field = 9,
  field_function = 10,
  field_index = 11,
  field_label = 12,
  field_left = 13,
  field_location = 14,
  field_machine = 15,
  field_macro = 16,
  field_name = 17,
  field_operator = 18,
  field_option = 19,
  field_parameters = 20,
  field_right = 21,
  field_segment = 22,
  field_size = 23,
  field_space = 24,
  field_subroutine = 25,
  field_type = 26,
  field_value = 27,
};

static const char * const ts_field_names[] = {
  [0] = NULL,
  [field_access] = "access",
  [field_alternative] = "alternative",
  [field_argument] = "argument",
  [field_arguments] = "arguments",
  [field_command] = "command",
  [field_condition] = "condition",
  [field_consequence] = "consequence",
  [field_declarator] = "declarator",
  [field_field] = "field",
  [field_function] = "function",
  [field_index] = "index",
  [field_label] = "label",
  [field_left] = "left",
  [field_location] = "location",
  [field_machine] = "machine",
  [field_macro] = "macro",
  [field_name] = "name",
  [field_operator] = "operator",
  [field_option] = "option",
  [field_parameters] = "parameters",
  [field_right] = "right",
  [field_segment] = "segment",
  [field_size] = "size",
  [field_space] = "space",
  [field_subroutine] = "subroutine",
  [field_type] = "type",
  [field_value] = "value",
};

static const TSMapSlice ts_field_map_slices[PRODUCTION_ID_COUNT] = {
  [2] = {.index = 0, .length = 2},
  [3] = {.index = 2, .length = 1},
  [4] = {.index = 3, .length = 2},
  [5] = {.index = 5, .length = 3},
  [6] = {.index = 8, .length = 1},
  [8] = {.index = 9, .length = 1},
  [10] = {.index = 10, .length = 2},
  [11] = {.index = 12, .length = 3},
  [12] = {.index = 15, .length = 2},
  [14] = {.index = 17, .length = 2},
  [15] = {.index = 19, .length = 3},
  [16] = {.index = 22, .length = 1},
  [17] = {.index = 23, .length = 2},
  [18] = {.index = 25, .length = 2},
  [22] = {.index = 27, .length = 2},
  [24] = {.index = 29, .length = 1},
  [25] = {.index = 30, .length = 2},
  [26] = {.index = 32, .length = 2},
  [27] = {.index = 34, .length = 2},
  [28] = {.index = 36, .length = 2},
  [29] = {.index = 38, .length = 1},
  [30] = {.index = 39, .length = 1},
  [31] = {.index = 40, .length = 1},
  [32] = {.index = 41, .length = 1},
  [33] = {.index = 42, .length = 1},
  [34] = {.index = 43, .length = 2},
  [36] = {.index = 45, .length = 2},
  [37] = {.index = 47, .length = 2},
  [38] = {.index = 49, .length = 3},
  [39] = {.index = 52, .length = 1},
  [40] = {.index = 53, .length = 2},
  [41] = {.index = 55, .length = 1},
  [43] = {.index = 56, .length = 2},
  [45] = {.index = 58, .length = 2},
  [47] = {.index = 60, .length = 3},
  [48] = {.index = 63, .length = 2},
  [49] = {.index = 65, .length = 2},
  [50] = {.index = 67, .length = 4},
  [52] = {.index = 71, .length = 3},
  [53] = {.index = 74, .length = 3},
  [54] = {.index = 77, .length = 2},
  [55] = {.index = 79, .length = 1},
  [56] = {.index = 80, .length = 3},
  [57] = {.index = 83, .length = 2},
  [58] = {.index = 85, .length = 1},
  [59] = {.index = 86, .length = 2},
  [60] = {.index = 88, .length = 2},
  [61] = {.index = 90, .length = 2},
  [62] = {.index = 92, .length = 2},
  [63] = {.index = 94, .length = 2},
  [64] = {.index = 96, .length = 2},
  [65] = {.index = 98, .length = 2},
  [66] = {.index = 100, .length = 2},
  [67] = {.index = 102, .length = 1},
  [68] = {.index = 103, .length = 2},
  [69] = {.index = 105, .length = 2},
  [70] = {.index = 107, .length = 2},
  [71] = {.index = 109, .length = 3},
  [72] = {.index = 112, .length = 3},
  [73] = {.index = 115, .length = 2},
  [74] = {.index = 117, .length = 2},
  [75] = {.index = 119, .length = 1},
  [76] = {.index = 120, .length = 1},
  [77] = {.index = 121, .length = 2},
  [78] = {.index = 123, .length = 2},
  [79] = {.index = 125, .length = 1},
  [80] = {.index = 126, .length = 1},
  [81] = {.index = 127, .length = 2},
  [82] = {.index = 129, .length = 2},
  [83] = {.index = 131, .length = 2},
  [84] = {.index = 133, .length = 2},
  [85] = {.index = 135, .length = 1},
  [86] = {.index = 136, .length = 3},
  [87] = {.index = 139, .length = 3},
  [88] = {.index = 142, .length = 3},
  [89] = {.index = 145, .length = 2},
  [90] = {.index = 147, .length = 1},
  [91] = {.index = 148, .length = 3},
  [92] = {.index = 151, .length = 2},
  [93] = {.index = 153, .length = 1},
  [94] = {.index = 154, .length = 2},
  [95] = {.index = 156, .length = 2},
  [96] = {.index = 158, .length = 2},
  [97] = {.index = 160, .length = 2},
  [98] = {.index = 162, .length = 2},
  [99] = {.index = 164, .length = 3},
  [100] = {.index = 167, .length = 2},
  [101] = {.index = 169, .length = 3},
  [102] = {.index = 172, .length = 1},
  [103] = {.index = 173, .length = 2},
  [104] = {.index = 175, .length = 2},
  [105] = {.index = 177, .length = 3},
  [106] = {.index = 180, .length = 2},
  [107] = {.index = 182, .length = 3},
  [108] = {.index = 185, .length = 2},
  [109] = {.index = 187, .length = 3},
  [110] = {.index = 190, .length = 2},
  [111] = {.index = 192, .length = 3},
  [112] = {.index = 195, .length = 2},
  [113] = {.index = 197, .length = 3},
  [114] = {.index = 200, .length = 1},
  [115] = {.index = 201, .length = 3},
  [116] = {.index = 204, .length = 4},
  [117] = {.index = 208, .length = 3},
  [118] = {.index = 211, .length = 3},
  [119] = {.index = 214, .length = 2},
  [120] = {.index = 216, .length = 3},
  [121] = {.index = 219, .length = 4},
  [122] = {.index = 223, .length = 3},
  [123] = {.index = 226, .length = 3},
};

static const TSFieldMapEntry ts_field_map_entries[] = {
  [0] =
    {field_command, 0, .inherited = true},
    {field_condition, 0, .inherited = true},
  [2] =
    {field_command, 0},
  [3] =
    {field_arguments, 0, .inherited = true},
    {field_command, 0, .inherited = true},
  [5] =
    {field_arguments, 0, .inherited = true},
    {field_command, 0, .inherited = true},
    {field_value, 0, .inherited = true},
  [8] =
    {field_label, 0},
  [9] =
    {field_label, 0, .inherited = true},
  [10] =
    {field_argument, 0, .inherited = true},
    {field_operator, 0, .inherited = true},
  [12] =
    {field_left, 0, .inherited = true},
    {field_operator, 0, .inherited = true},
    {field_right, 0, .inherited = true},
  [15] =
    {field_arguments, 0, .inherited = true},
    {field_function, 0, .inherited = true},
  [17] =
    {field_arguments, 1, .inherited = true},
    {field_command, 1, .inherited = true},
  [19] =
    {field_arguments, 1, .inherited = true},
    {field_command, 1, .inherited = true},
    {field_value, 1, .inherited = true},
  [22] =
    {field_macro, 1},
  [23] =
    {field_command, 0},
    {field_macro, 1, .inherited = true},
  [25] =
    {field_macro, 0, .inherited = true},
    {field_macro, 1, .inherited = true},
  [27] =
    {field_arguments, 2},
    {field_command, 0},
  [29] =
    {field_type, 0},
  [30] =
    {field_argument, 1},
    {field_operator, 0},
  [32] =
    {field_access, 0},
    {field_location, 1},
  [34] =
    {field_argument, 0},
    {field_operator, 1},
  [36] =
    {field_arguments, 1},
    {field_function, 0},
  [38] =
    {field_segment, 0},
  [39] =
    {field_machine, 0},
  [40] =
    {field_space, 0},
  [41] =
    {field_location, 1},
  [42] =
    {field_value, 1},
  [43] =
    {field_command, 0},
    {field_condition, 2},
  [45] =
    {field_command, 1},
    {field_macro, 2, .inherited = true},
  [47] =
    {field_command, 0},
    {field_subroutine, 2},
  [49] =
    {field_left, 0},
    {field_operator, 1},
    {field_right, 2},
  [52] =
    {field_option, 1},
  [53] =
    {field_declarator, 1},
    {field_type, 0, .inherited = true},
  [55] =
    {field_type, 1},
  [56] =
    {field_access, 0},
    {field_location, 2},
  [58] =
    {field_declarator, 1},
    {field_type, 0},
  [60] =
    {field_argument, 0},
    {field_field, 2},
    {field_operator, 1},
  [63] =
    {field_command, 1},
    {field_subroutine, 3},
  [65] =
    {field_command, 0},
    {field_macro, 3, .inherited = true},
  [67] =
    {field_arguments, 4},
    {field_command, 0},
    {field_command, 1},
    {field_command, 2},
  [71] =
    {field_left, 0},
    {field_operator, 1},
    {field_right, 3},
  [74] =
    {field_left, 0},
    {field_operator, 2},
    {field_right, 3},
  [77] =
    {field_value, 1},
    {field_value, 2, .inherited = true},
  [79] =
    {field_name, 2},
  [80] =
    {field_arguments, 2},
    {field_command, 0},
    {field_value, 4},
  [83] =
    {field_declarator, 0},
    {field_parameters, 1},
  [85] =
    {field_declarator, 1},
  [86] =
    {field_declarator, 2},
    {field_type, 0, .inherited = true},
  [88] =
    {field_machine, 0},
    {field_segment, 2},
  [90] =
    {field_machine, 0},
    {field_space, 2},
  [92] =
    {field_segment, 2},
    {field_space, 0},
  [94] =
    {field_left, 0},
    {field_right, 2},
  [96] =
    {field_type, 1},
    {field_value, 3},
  [98] =
    {field_declarator, 2},
    {field_type, 0},
  [100] =
    {field_declarator, 2},
    {field_type, 1},
  [102] =
    {field_type, 2},
  [103] =
    {field_alternative, 3},
    {field_condition, 0},
  [105] =
    {field_argument, 0},
    {field_index, 2},
  [107] =
    {field_command, 1},
    {field_macro, 4, .inherited = true},
  [109] =
    {field_arguments, 4},
    {field_command, 0},
    {field_subroutine, 2},
  [112] =
    {field_left, 0},
    {field_operator, 2},
    {field_right, 4},
  [115] =
    {field_option, 1},
    {field_value, 3},
  [117] =
    {field_value, 0, .inherited = true},
    {field_value, 1, .inherited = true},
  [119] =
    {field_declarator, 2},
  [120] =
    {field_type, 0, .inherited = true},
  [121] =
    {field_declarator, 0},
    {field_parameters, 2},
  [123] =
    {field_type, 1},
    {field_value, 4},
  [125] =
    {field_size, 1},
  [126] =
    {field_declarator, 0},
  [127] =
    {field_declarator, 3},
    {field_type, 0},
  [129] =
    {field_type, 2},
    {field_value, 4},
  [131] =
    {field_declarator, 3},
    {field_type, 1},
  [133] =
    {field_declarator, 3},
    {field_type, 2},
  [135] =
    {field_type, 3},
  [136] =
    {field_alternative, 4},
    {field_condition, 0},
    {field_consequence, 2},
  [139] =
    {field_command, 0},
    {field_command, 3},
    {field_condition, 5},
  [142] =
    {field_arguments, 5},
    {field_command, 1},
    {field_subroutine, 3},
  [145] =
    {field_declarator, 3},
    {field_size, 1},
  [147] =
    {field_declarator, 3},
  [148] =
    {field_machine, 0},
    {field_segment, 4},
    {field_space, 2},
  [151] =
    {field_size, 1},
    {field_size, 2},
  [153] =
    {field_size, 2},
  [154] =
    {field_declarator, 0},
    {field_size, 2},
  [156] =
    {field_declarator, 0},
    {field_declarator, 1},
  [158] =
    {field_type, 2},
    {field_value, 5},
  [160] =
    {field_declarator, 4},
    {field_type, 1},
  [162] =
    {field_declarator, 4},
    {field_type, 2},
  [164] =
    {field_command, 0},
    {field_command, 4},
    {field_condition, 6},
  [167] =
    {field_declarator, 4},
    {field_size, 1},
  [169] =
    {field_declarator, 4},
    {field_size, 1},
    {field_size, 2},
  [172] =
    {field_declarator, 4},
  [173] =
    {field_declarator, 4},
    {field_size, 2},
  [175] =
    {field_size, 2},
    {field_size, 3},
  [177] =
    {field_declarator, 0},
    {field_size, 2},
    {field_size, 3},
  [180] =
    {field_declarator, 0},
    {field_size, 3},
  [182] =
    {field_declarator, 0},
    {field_declarator, 1},
    {field_size, 3},
  [185] =
    {field_declarator, 5},
    {field_type, 2},
  [187] =
    {field_command, 0},
    {field_command, 5},
    {field_condition, 7},
  [190] =
    {field_declarator, 5},
    {field_size, 1},
  [192] =
    {field_declarator, 5},
    {field_size, 1},
    {field_size, 2},
  [195] =
    {field_declarator, 5},
    {field_size, 2},
  [197] =
    {field_declarator, 5},
    {field_size, 2},
    {field_size, 3},
  [200] =
    {field_declarator, 5},
  [201] =
    {field_declarator, 0},
    {field_size, 3},
    {field_size, 4},
  [204] =
    {field_declarator, 0},
    {field_declarator, 1},
    {field_size, 3},
    {field_size, 4},
  [208] =
    {field_declarator, 0},
    {field_declarator, 1},
    {field_size, 4},
  [211] =
    {field_declarator, 6},
    {field_size, 1},
    {field_size, 2},
  [214] =
    {field_declarator, 6},
    {field_size, 2},
  [216] =
    {field_declarator, 6},
    {field_size, 2},
    {field_size, 3},
  [219] =
    {field_declarator, 0},
    {field_declarator, 1},
    {field_size, 4},
    {field_size, 5},
  [223] =
    {field_declarator, 7},
    {field_size, 2},
    {field_size, 3},
  [226] =
    {field_command, 0},
    {field_command, 2},
    {field_condition, 4},
};

static const TSSymbol ts_alias_sequences[PRODUCTION_ID_COUNT][MAX_ALIAS_SEQUENCE_LENGTH] = {
  [0] = {0},
  [1] = {
    [0] = anon_alias_sym_command,
  },
  [7] = {
    [1] = anon_alias_sym_name,
  },
  [9] = {
    [0] = anon_alias_sym_function,
  },
  [13] = {
    [0] = anon_alias_sym_module,
  },
  [19] = {
    [2] = anon_alias_sym_subcommand,
  },
  [20] = {
    [2] = anon_alias_sym_IF,
  },
  [21] = {
    [1] = anon_alias_sym_subcommand,
  },
  [23] = {
    [0] = alias_sym_hll_type_identifier,
  },
  [35] = {
    [2] = anon_alias_sym_name,
  },
  [42] = {
    [2] = anon_alias_sym_subfunction,
  },
  [44] = {
    [1] = anon_alias_sym_subfunction,
  },
  [46] = {
    [0] = alias_sym_hll_field_identifier,
  },
  [50] = {
    [1] = sym_identifier,
  },
  [51] = {
    [0] = anon_alias_sym_type,
  },
};

static const uint16_t ts_non_terminal_alias_map[] = {
  sym_trace32_hll_variable, 2,
    sym_trace32_hll_variable,
    anon_alias_sym_module,
  0,
};

static const TSStateId ts_primary_state_ids[STATE_COUNT] = {
  [0] = 0,
  [1] = 1,
  [2] = 2,
  [3] = 3,
  [4] = 2,
  [5] = 3,
  [6] = 3,
  [7] = 2,
  [8] = 3,
  [9] = 9,
  [10] = 9,
  [11] = 9,
  [12] = 9,
  [13] = 13,
  [14] = 14,
  [15] = 15,
  [16] = 16,
  [17] = 16,
  [18] = 14,
  [19] = 13,
  [20] = 15,
  [21] = 15,
  [22] = 16,
  [23] = 14,
  [24] = 13,
  [25] = 16,
  [26] = 14,
  [27] = 15,
  [28] = 13,
  [29] = 29,
  [30] = 30,
  [31] = 31,
  [32] = 32,
  [33] = 33,
  [34] = 16,
  [35] = 15,
  [36] = 14,
  [37] = 13,
  [38] = 38,
  [39] = 32,
  [40] = 40,
  [41] = 41,
  [42] = 41,
  [43] = 38,
  [44] = 16,
  [45] = 41,
  [46] = 38,
  [47] = 41,
  [48] = 38,
  [49] = 32,
  [50] = 40,
  [51] = 41,
  [52] = 38,
  [53] = 41,
  [54] = 38,
  [55] = 41,
  [56] = 56,
  [57] = 41,
  [58] = 38,
  [59] = 32,
  [60] = 40,
  [61] = 41,
  [62] = 38,
  [63] = 41,
  [64] = 38,
  [65] = 32,
  [66] = 40,
  [67] = 32,
  [68] = 40,
  [69] = 32,
  [70] = 40,
  [71] = 32,
  [72] = 40,
  [73] = 15,
  [74] = 40,
  [75] = 32,
  [76] = 40,
  [77] = 32,
  [78] = 40,
  [79] = 14,
  [80] = 13,
  [81] = 38,
  [82] = 15,
  [83] = 13,
  [84] = 16,
  [85] = 14,
  [86] = 13,
  [87] = 16,
  [88] = 15,
  [89] = 14,
  [90] = 90,
  [91] = 91,
  [92] = 92,
  [93] = 93,
  [94] = 94,
  [95] = 95,
  [96] = 92,
  [97] = 94,
  [98] = 90,
  [99] = 99,
  [100] = 95,
  [101] = 16,
  [102] = 15,
  [103] = 14,
  [104] = 13,
  [105] = 90,
  [106] = 106,
  [107] = 107,
  [108] = 108,
  [109] = 99,
  [110] = 92,
  [111] = 111,
  [112] = 93,
  [113] = 94,
  [114] = 95,
  [115] = 106,
  [116] = 93,
  [117] = 94,
  [118] = 118,
  [119] = 99,
  [120] = 120,
  [121] = 95,
  [122] = 16,
  [123] = 123,
  [124] = 124,
  [125] = 125,
  [126] = 15,
  [127] = 14,
  [128] = 128,
  [129] = 129,
  [130] = 13,
  [131] = 131,
  [132] = 132,
  [133] = 92,
  [134] = 132,
  [135] = 90,
  [136] = 131,
  [137] = 132,
  [138] = 132,
  [139] = 106,
  [140] = 106,
  [141] = 93,
  [142] = 142,
  [143] = 142,
  [144] = 142,
  [145] = 145,
  [146] = 146,
  [147] = 147,
  [148] = 145,
  [149] = 149,
  [150] = 150,
  [151] = 151,
  [152] = 152,
  [153] = 153,
  [154] = 154,
  [155] = 155,
  [156] = 156,
  [157] = 157,
  [158] = 150,
  [159] = 151,
  [160] = 160,
  [161] = 161,
  [162] = 162,
  [163] = 163,
  [164] = 164,
  [165] = 146,
  [166] = 166,
  [167] = 147,
  [168] = 149,
  [169] = 154,
  [170] = 161,
  [171] = 164,
  [172] = 166,
  [173] = 173,
  [174] = 174,
  [175] = 175,
  [176] = 173,
  [177] = 174,
  [178] = 175,
  [179] = 156,
  [180] = 155,
  [181] = 156,
  [182] = 157,
  [183] = 150,
  [184] = 151,
  [185] = 185,
  [186] = 155,
  [187] = 156,
  [188] = 157,
  [189] = 150,
  [190] = 151,
  [191] = 174,
  [192] = 175,
  [193] = 166,
  [194] = 160,
  [195] = 185,
  [196] = 150,
  [197] = 162,
  [198] = 198,
  [199] = 163,
  [200] = 151,
  [201] = 174,
  [202] = 146,
  [203] = 203,
  [204] = 160,
  [205] = 185,
  [206] = 147,
  [207] = 145,
  [208] = 149,
  [209] = 154,
  [210] = 161,
  [211] = 164,
  [212] = 160,
  [213] = 185,
  [214] = 166,
  [215] = 175,
  [216] = 160,
  [217] = 185,
  [218] = 162,
  [219] = 162,
  [220] = 160,
  [221] = 185,
  [222] = 163,
  [223] = 163,
  [224] = 224,
  [225] = 198,
  [226] = 173,
  [227] = 146,
  [228] = 224,
  [229] = 147,
  [230] = 145,
  [231] = 149,
  [232] = 173,
  [233] = 155,
  [234] = 156,
  [235] = 157,
  [236] = 224,
  [237] = 154,
  [238] = 198,
  [239] = 161,
  [240] = 155,
  [241] = 164,
  [242] = 157,
  [243] = 243,
  [244] = 244,
  [245] = 245,
  [246] = 246,
  [247] = 247,
  [248] = 248,
  [249] = 249,
  [250] = 250,
  [251] = 251,
  [252] = 252,
  [253] = 253,
  [254] = 254,
  [255] = 255,
  [256] = 251,
  [257] = 257,
  [258] = 254,
  [259] = 259,
  [260] = 253,
  [261] = 261,
  [262] = 250,
  [263] = 263,
  [264] = 252,
  [265] = 255,
  [266] = 251,
  [267] = 267,
  [268] = 268,
  [269] = 267,
  [270] = 259,
  [271] = 250,
  [272] = 259,
  [273] = 250,
  [274] = 261,
  [275] = 257,
  [276] = 259,
  [277] = 257,
  [278] = 254,
  [279] = 263,
  [280] = 253,
  [281] = 261,
  [282] = 263,
  [283] = 252,
  [284] = 255,
  [285] = 251,
  [286] = 257,
  [287] = 254,
  [288] = 253,
  [289] = 261,
  [290] = 263,
  [291] = 252,
  [292] = 255,
  [293] = 268,
  [294] = 294,
  [295] = 294,
  [296] = 294,
  [297] = 294,
  [298] = 298,
  [299] = 299,
  [300] = 300,
  [301] = 301,
  [302] = 302,
  [303] = 302,
  [304] = 301,
  [305] = 302,
  [306] = 302,
  [307] = 301,
  [308] = 301,
  [309] = 309,
  [310] = 309,
  [311] = 309,
  [312] = 309,
  [313] = 313,
  [314] = 314,
  [315] = 315,
  [316] = 316,
  [317] = 317,
  [318] = 318,
  [319] = 319,
  [320] = 319,
  [321] = 321,
  [322] = 322,
  [323] = 323,
  [324] = 324,
  [325] = 322,
  [326] = 326,
  [327] = 327,
  [328] = 328,
  [329] = 326,
  [330] = 330,
  [331] = 331,
  [332] = 332,
  [333] = 333,
  [334] = 334,
  [335] = 335,
  [336] = 336,
  [337] = 337,
  [338] = 338,
  [339] = 339,
  [340] = 330,
  [341] = 328,
  [342] = 342,
  [343] = 343,
  [344] = 344,
  [345] = 345,
  [346] = 346,
  [347] = 347,
  [348] = 348,
  [349] = 349,
  [350] = 350,
  [351] = 351,
  [352] = 352,
  [353] = 353,
  [354] = 354,
  [355] = 355,
  [356] = 356,
  [357] = 357,
  [358] = 358,
  [359] = 359,
  [360] = 360,
  [361] = 361,
  [362] = 362,
  [363] = 363,
  [364] = 347,
  [365] = 350,
  [366] = 366,
  [367] = 367,
  [368] = 368,
  [369] = 369,
  [370] = 370,
  [371] = 371,
  [372] = 372,
  [373] = 373,
  [374] = 374,
  [375] = 375,
  [376] = 376,
  [377] = 377,
  [378] = 378,
  [379] = 379,
  [380] = 380,
  [381] = 381,
  [382] = 382,
  [383] = 383,
  [384] = 384,
  [385] = 385,
  [386] = 386,
  [387] = 387,
  [388] = 388,
  [389] = 389,
  [390] = 390,
  [391] = 391,
  [392] = 392,
  [393] = 393,
  [394] = 394,
  [395] = 395,
  [396] = 396,
  [397] = 397,
  [398] = 398,
  [399] = 399,
  [400] = 400,
  [401] = 401,
  [402] = 402,
  [403] = 403,
  [404] = 403,
  [405] = 405,
  [406] = 406,
  [407] = 407,
  [408] = 408,
  [409] = 409,
  [410] = 410,
  [411] = 411,
  [412] = 401,
  [413] = 403,
  [414] = 401,
  [415] = 415,
  [416] = 403,
  [417] = 417,
  [418] = 391,
  [419] = 419,
  [420] = 420,
  [421] = 395,
  [422] = 422,
  [423] = 423,
  [424] = 424,
  [425] = 419,
  [426] = 420,
  [427] = 401,
  [428] = 428,
  [429] = 428,
  [430] = 430,
  [431] = 431,
  [432] = 432,
  [433] = 433,
  [434] = 431,
  [435] = 433,
  [436] = 436,
  [437] = 430,
  [438] = 438,
  [439] = 430,
  [440] = 431,
  [441] = 430,
  [442] = 428,
  [443] = 428,
  [444] = 433,
  [445] = 431,
  [446] = 430,
  [447] = 428,
  [448] = 448,
  [449] = 449,
  [450] = 450,
  [451] = 451,
  [452] = 452,
  [453] = 453,
  [454] = 454,
  [455] = 433,
  [456] = 430,
  [457] = 457,
  [458] = 428,
  [459] = 459,
  [460] = 460,
  [461] = 461,
  [462] = 462,
  [463] = 431,
  [464] = 430,
  [465] = 431,
  [466] = 428,
  [467] = 433,
  [468] = 433,
  [469] = 433,
  [470] = 470,
  [471] = 433,
  [472] = 472,
  [473] = 473,
  [474] = 474,
  [475] = 436,
  [476] = 431,
  [477] = 430,
  [478] = 431,
  [479] = 479,
  [480] = 480,
  [481] = 436,
  [482] = 472,
  [483] = 428,
  [484] = 472,
  [485] = 472,
  [486] = 431,
  [487] = 430,
  [488] = 428,
  [489] = 433,
  [490] = 433,
  [491] = 430,
  [492] = 436,
  [493] = 428,
  [494] = 431,
  [495] = 495,
  [496] = 496,
  [497] = 495,
  [498] = 496,
  [499] = 496,
  [500] = 500,
  [501] = 495,
  [502] = 495,
  [503] = 503,
  [504] = 504,
  [505] = 495,
  [506] = 495,
  [507] = 495,
  [508] = 495,
  [509] = 509,
  [510] = 510,
  [511] = 496,
  [512] = 495,
  [513] = 495,
  [514] = 514,
  [515] = 515,
  [516] = 516,
  [517] = 517,
  [518] = 518,
  [519] = 519,
  [520] = 520,
  [521] = 521,
  [522] = 522,
  [523] = 523,
  [524] = 524,
  [525] = 525,
  [526] = 526,
  [527] = 527,
  [528] = 517,
  [529] = 526,
  [530] = 530,
  [531] = 531,
  [532] = 532,
  [533] = 533,
  [534] = 534,
  [535] = 535,
  [536] = 518,
  [537] = 519,
  [538] = 520,
  [539] = 520,
  [540] = 521,
  [541] = 522,
  [542] = 527,
  [543] = 523,
  [544] = 524,
  [545] = 545,
  [546] = 546,
  [547] = 521,
  [548] = 417,
  [549] = 527,
  [550] = 517,
  [551] = 526,
  [552] = 530,
  [553] = 531,
  [554] = 532,
  [555] = 533,
  [556] = 534,
  [557] = 535,
  [558] = 518,
  [559] = 521,
  [560] = 424,
  [561] = 519,
  [562] = 520,
  [563] = 522,
  [564] = 517,
  [565] = 521,
  [566] = 522,
  [567] = 530,
  [568] = 523,
  [569] = 524,
  [570] = 523,
  [571] = 526,
  [572] = 572,
  [573] = 527,
  [574] = 517,
  [575] = 575,
  [576] = 576,
  [577] = 577,
  [578] = 545,
  [579] = 526,
  [580] = 580,
  [581] = 530,
  [582] = 531,
  [583] = 583,
  [584] = 532,
  [585] = 533,
  [586] = 531,
  [587] = 524,
  [588] = 534,
  [589] = 523,
  [590] = 530,
  [591] = 535,
  [592] = 518,
  [593] = 593,
  [594] = 531,
  [595] = 524,
  [596] = 527,
  [597] = 520,
  [598] = 517,
  [599] = 522,
  [600] = 519,
  [601] = 532,
  [602] = 526,
  [603] = 530,
  [604] = 531,
  [605] = 532,
  [606] = 533,
  [607] = 534,
  [608] = 535,
  [609] = 518,
  [610] = 532,
  [611] = 519,
  [612] = 519,
  [613] = 533,
  [614] = 534,
  [615] = 535,
  [616] = 521,
  [617] = 520,
  [618] = 575,
  [619] = 576,
  [620] = 577,
  [621] = 545,
  [622] = 519,
  [623] = 533,
  [624] = 534,
  [625] = 521,
  [626] = 522,
  [627] = 535,
  [628] = 523,
  [629] = 520,
  [630] = 518,
  [631] = 575,
  [632] = 576,
  [633] = 577,
  [634] = 545,
  [635] = 524,
  [636] = 518,
  [637] = 519,
  [638] = 576,
  [639] = 521,
  [640] = 527,
  [641] = 641,
  [642] = 575,
  [643] = 576,
  [644] = 545,
  [645] = 526,
  [646] = 575,
  [647] = 576,
  [648] = 545,
  [649] = 530,
  [650] = 575,
  [651] = 576,
  [652] = 545,
  [653] = 531,
  [654] = 575,
  [655] = 576,
  [656] = 545,
  [657] = 532,
  [658] = 575,
  [659] = 576,
  [660] = 545,
  [661] = 533,
  [662] = 575,
  [663] = 576,
  [664] = 545,
  [665] = 534,
  [666] = 522,
  [667] = 523,
  [668] = 535,
  [669] = 669,
  [670] = 518,
  [671] = 519,
  [672] = 523,
  [673] = 673,
  [674] = 674,
  [675] = 675,
  [676] = 676,
  [677] = 677,
  [678] = 678,
  [679] = 524,
  [680] = 680,
  [681] = 681,
  [682] = 682,
  [683] = 520,
  [684] = 684,
  [685] = 522,
  [686] = 669,
  [687] = 521,
  [688] = 522,
  [689] = 577,
  [690] = 527,
  [691] = 691,
  [692] = 523,
  [693] = 693,
  [694] = 694,
  [695] = 526,
  [696] = 527,
  [697] = 517,
  [698] = 526,
  [699] = 530,
  [700] = 531,
  [701] = 532,
  [702] = 533,
  [703] = 534,
  [704] = 535,
  [705] = 518,
  [706] = 706,
  [707] = 524,
  [708] = 524,
  [709] = 527,
  [710] = 710,
  [711] = 530,
  [712] = 712,
  [713] = 669,
  [714] = 517,
  [715] = 531,
  [716] = 532,
  [717] = 533,
  [718] = 534,
  [719] = 535,
  [720] = 518,
  [721] = 519,
  [722] = 520,
  [723] = 390,
  [724] = 527,
  [725] = 521,
  [726] = 522,
  [727] = 517,
  [728] = 523,
  [729] = 526,
  [730] = 524,
  [731] = 530,
  [732] = 520,
  [733] = 531,
  [734] = 575,
  [735] = 532,
  [736] = 533,
  [737] = 534,
  [738] = 535,
  [739] = 739,
  [740] = 517,
  [741] = 741,
  [742] = 684,
  [743] = 681,
  [744] = 710,
  [745] = 438,
  [746] = 746,
  [747] = 747,
  [748] = 674,
  [749] = 749,
  [750] = 417,
  [751] = 751,
  [752] = 752,
  [753] = 753,
  [754] = 712,
  [755] = 678,
  [756] = 756,
  [757] = 757,
  [758] = 676,
  [759] = 474,
  [760] = 691,
  [761] = 761,
  [762] = 682,
  [763] = 448,
  [764] = 675,
  [765] = 765,
  [766] = 766,
  [767] = 673,
  [768] = 768,
  [769] = 546,
  [770] = 424,
  [771] = 739,
  [772] = 693,
  [773] = 641,
  [774] = 694,
  [775] = 580,
  [776] = 583,
  [777] = 706,
  [778] = 778,
  [779] = 779,
  [780] = 593,
  [781] = 781,
  [782] = 390,
  [783] = 680,
  [784] = 572,
  [785] = 677,
  [786] = 786,
  [787] = 787,
  [788] = 788,
  [789] = 525,
  [790] = 786,
  [791] = 779,
  [792] = 787,
  [793] = 746,
  [794] = 751,
  [795] = 756,
  [796] = 761,
  [797] = 741,
  [798] = 778,
  [799] = 781,
  [800] = 800,
  [801] = 474,
  [802] = 768,
  [803] = 757,
  [804] = 765,
  [805] = 766,
  [806] = 778,
  [807] = 781,
  [808] = 448,
  [809] = 438,
  [810] = 810,
  [811] = 778,
  [812] = 781,
  [813] = 752,
  [814] = 788,
  [815] = 747,
  [816] = 749,
  [817] = 753,
  [818] = 390,
  [819] = 641,
  [820] = 525,
  [821] = 546,
  [822] = 580,
  [823] = 583,
  [824] = 593,
  [825] = 572,
  [826] = 673,
  [827] = 674,
  [828] = 675,
  [829] = 676,
  [830] = 677,
  [831] = 678,
  [832] = 680,
  [833] = 681,
  [834] = 682,
  [835] = 684,
  [836] = 691,
  [837] = 694,
  [838] = 706,
  [839] = 710,
  [840] = 712,
  [841] = 778,
  [842] = 781,
  [843] = 739,
  [844] = 693,
  [845] = 641,
  [846] = 424,
  [847] = 525,
  [848] = 546,
  [849] = 580,
  [850] = 583,
  [851] = 593,
  [852] = 673,
  [853] = 674,
  [854] = 675,
  [855] = 676,
  [856] = 677,
  [857] = 678,
  [858] = 680,
  [859] = 681,
  [860] = 682,
  [861] = 684,
  [862] = 691,
  [863] = 694,
  [864] = 706,
  [865] = 710,
  [866] = 712,
  [867] = 390,
  [868] = 417,
  [869] = 424,
  [870] = 572,
  [871] = 739,
  [872] = 693,
  [873] = 417,
  [874] = 746,
  [875] = 768,
  [876] = 438,
  [877] = 757,
  [878] = 786,
  [879] = 757,
  [880] = 765,
  [881] = 751,
  [882] = 756,
  [883] = 749,
  [884] = 778,
  [885] = 781,
  [886] = 768,
  [887] = 765,
  [888] = 766,
  [889] = 778,
  [890] = 781,
  [891] = 474,
  [892] = 778,
  [893] = 781,
  [894] = 761,
  [895] = 753,
  [896] = 766,
  [897] = 787,
  [898] = 778,
  [899] = 747,
  [900] = 781,
  [901] = 749,
  [902] = 751,
  [903] = 756,
  [904] = 752,
  [905] = 788,
  [906] = 761,
  [907] = 741,
  [908] = 448,
  [909] = 779,
  [910] = 438,
  [911] = 787,
  [912] = 788,
  [913] = 741,
  [914] = 746,
  [915] = 778,
  [916] = 781,
  [917] = 752,
  [918] = 474,
  [919] = 786,
  [920] = 448,
  [921] = 747,
  [922] = 753,
  [923] = 779,
  [924] = 924,
  [925] = 925,
  [926] = 926,
  [927] = 800,
  [928] = 928,
  [929] = 929,
  [930] = 930,
  [931] = 931,
  [932] = 932,
  [933] = 933,
  [934] = 934,
  [935] = 800,
  [936] = 424,
  [937] = 937,
  [938] = 938,
  [939] = 939,
  [940] = 940,
  [941] = 390,
  [942] = 942,
  [943] = 943,
  [944] = 417,
  [945] = 945,
  [946] = 765,
  [947] = 438,
  [948] = 766,
  [949] = 448,
  [950] = 768,
  [951] = 786,
  [952] = 800,
  [953] = 757,
  [954] = 954,
  [955] = 955,
  [956] = 956,
  [957] = 957,
  [958] = 958,
  [959] = 959,
  [960] = 960,
  [961] = 961,
  [962] = 962,
  [963] = 334,
  [964] = 424,
  [965] = 710,
  [966] = 712,
  [967] = 328,
  [968] = 681,
  [969] = 969,
  [970] = 328,
  [971] = 546,
  [972] = 328,
  [973] = 682,
  [974] = 674,
  [975] = 328,
  [976] = 739,
  [977] = 693,
  [978] = 641,
  [979] = 684,
  [980] = 328,
  [981] = 981,
  [982] = 525,
  [983] = 546,
  [984] = 984,
  [985] = 580,
  [986] = 583,
  [987] = 593,
  [988] = 583,
  [989] = 981,
  [990] = 984,
  [991] = 984,
  [992] = 675,
  [993] = 684,
  [994] = 417,
  [995] = 676,
  [996] = 677,
  [997] = 691,
  [998] = 981,
  [999] = 694,
  [1000] = 710,
  [1001] = 706,
  [1002] = 580,
  [1003] = 678,
  [1004] = 334,
  [1005] = 680,
  [1006] = 694,
  [1007] = 390,
  [1008] = 691,
  [1009] = 1009,
  [1010] = 739,
  [1011] = 693,
  [1012] = 981,
  [1013] = 641,
  [1014] = 1014,
  [1015] = 706,
  [1016] = 333,
  [1017] = 1017,
  [1018] = 712,
  [1019] = 333,
  [1020] = 673,
  [1021] = 674,
  [1022] = 675,
  [1023] = 676,
  [1024] = 677,
  [1025] = 678,
  [1026] = 680,
  [1027] = 525,
  [1028] = 681,
  [1029] = 682,
  [1030] = 593,
  [1031] = 673,
  [1032] = 984,
  [1033] = 348,
  [1034] = 347,
  [1035] = 350,
  [1036] = 346,
  [1037] = 353,
  [1038] = 356,
  [1039] = 357,
  [1040] = 1040,
  [1041] = 358,
  [1042] = 359,
  [1043] = 363,
  [1044] = 360,
  [1045] = 1045,
  [1046] = 347,
  [1047] = 362,
  [1048] = 1048,
  [1049] = 345,
  [1050] = 1040,
  [1051] = 328,
  [1052] = 350,
  [1053] = 1053,
  [1054] = 343,
  [1055] = 348,
  [1056] = 363,
  [1057] = 1057,
  [1058] = 349,
  [1059] = 1059,
  [1060] = 347,
  [1061] = 345,
  [1062] = 1062,
  [1063] = 1063,
  [1064] = 351,
  [1065] = 1065,
  [1066] = 355,
  [1067] = 355,
  [1068] = 344,
  [1069] = 1069,
  [1070] = 349,
  [1071] = 351,
  [1072] = 1072,
  [1073] = 369,
  [1074] = 448,
  [1075] = 344,
  [1076] = 1076,
  [1077] = 1077,
  [1078] = 346,
  [1079] = 369,
  [1080] = 350,
  [1081] = 1081,
  [1082] = 1082,
  [1083] = 1082,
  [1084] = 1084,
  [1085] = 1085,
  [1086] = 1057,
  [1087] = 438,
  [1088] = 1045,
  [1089] = 1069,
  [1090] = 343,
  [1091] = 1072,
  [1092] = 1092,
  [1093] = 1082,
  [1094] = 1057,
  [1095] = 362,
  [1096] = 1045,
  [1097] = 347,
  [1098] = 350,
  [1099] = 352,
  [1100] = 1053,
  [1101] = 1101,
  [1102] = 1082,
  [1103] = 361,
  [1104] = 1057,
  [1105] = 1045,
  [1106] = 1077,
  [1107] = 354,
  [1108] = 347,
  [1109] = 354,
  [1110] = 350,
  [1111] = 1069,
  [1112] = 1072,
  [1113] = 1113,
  [1114] = 1040,
  [1115] = 1101,
  [1116] = 1069,
  [1117] = 1072,
  [1118] = 1040,
  [1119] = 786,
  [1120] = 768,
  [1121] = 757,
  [1122] = 353,
  [1123] = 1101,
  [1124] = 1101,
  [1125] = 356,
  [1126] = 357,
  [1127] = 358,
  [1128] = 359,
  [1129] = 360,
  [1130] = 352,
  [1131] = 765,
  [1132] = 766,
  [1133] = 361,
  [1134] = 1134,
  [1135] = 1135,
  [1136] = 1136,
  [1137] = 367,
  [1138] = 1138,
  [1139] = 1139,
  [1140] = 373,
  [1141] = 373,
  [1142] = 1142,
  [1143] = 673,
  [1144] = 1144,
  [1145] = 674,
  [1146] = 1146,
  [1147] = 675,
  [1148] = 1148,
  [1149] = 372,
  [1150] = 1150,
  [1151] = 1151,
  [1152] = 1152,
  [1153] = 676,
  [1154] = 677,
  [1155] = 678,
  [1156] = 1156,
  [1157] = 381,
  [1158] = 680,
  [1159] = 681,
  [1160] = 385,
  [1161] = 1161,
  [1162] = 682,
  [1163] = 387,
  [1164] = 684,
  [1165] = 1165,
  [1166] = 388,
  [1167] = 1167,
  [1168] = 1168,
  [1169] = 641,
  [1170] = 374,
  [1171] = 1171,
  [1172] = 371,
  [1173] = 376,
  [1174] = 739,
  [1175] = 693,
  [1176] = 641,
  [1177] = 1152,
  [1178] = 1178,
  [1179] = 1161,
  [1180] = 374,
  [1181] = 525,
  [1182] = 1182,
  [1183] = 546,
  [1184] = 691,
  [1185] = 580,
  [1186] = 583,
  [1187] = 593,
  [1188] = 694,
  [1189] = 706,
  [1190] = 1190,
  [1191] = 382,
  [1192] = 1192,
  [1193] = 710,
  [1194] = 712,
  [1195] = 739,
  [1196] = 379,
  [1197] = 693,
  [1198] = 379,
  [1199] = 390,
  [1200] = 381,
  [1201] = 366,
  [1202] = 387,
  [1203] = 378,
  [1204] = 1204,
  [1205] = 347,
  [1206] = 350,
  [1207] = 1207,
  [1208] = 378,
  [1209] = 1209,
  [1210] = 388,
  [1211] = 1211,
  [1212] = 383,
  [1213] = 1213,
  [1214] = 389,
  [1215] = 380,
  [1216] = 372,
  [1217] = 1217,
  [1218] = 371,
  [1219] = 382,
  [1220] = 383,
  [1221] = 1221,
  [1222] = 673,
  [1223] = 1223,
  [1224] = 674,
  [1225] = 675,
  [1226] = 676,
  [1227] = 677,
  [1228] = 389,
  [1229] = 422,
  [1230] = 678,
  [1231] = 680,
  [1232] = 525,
  [1233] = 384,
  [1234] = 681,
  [1235] = 422,
  [1236] = 380,
  [1237] = 367,
  [1238] = 368,
  [1239] = 384,
  [1240] = 385,
  [1241] = 1217,
  [1242] = 682,
  [1243] = 375,
  [1244] = 417,
  [1245] = 376,
  [1246] = 684,
  [1247] = 546,
  [1248] = 368,
  [1249] = 1211,
  [1250] = 691,
  [1251] = 375,
  [1252] = 694,
  [1253] = 706,
  [1254] = 1213,
  [1255] = 580,
  [1256] = 583,
  [1257] = 710,
  [1258] = 712,
  [1259] = 593,
  [1260] = 424,
  [1261] = 1152,
  [1262] = 366,
  [1263] = 1207,
  [1264] = 1136,
  [1265] = 678,
  [1266] = 1266,
  [1267] = 710,
  [1268] = 415,
  [1269] = 1269,
  [1270] = 712,
  [1271] = 1271,
  [1272] = 1272,
  [1273] = 673,
  [1274] = 674,
  [1275] = 675,
  [1276] = 676,
  [1277] = 677,
  [1278] = 680,
  [1279] = 681,
  [1280] = 682,
  [1281] = 684,
  [1282] = 691,
  [1283] = 694,
  [1284] = 706,
  [1285] = 473,
  [1286] = 710,
  [1287] = 712,
  [1288] = 1288,
  [1289] = 1289,
  [1290] = 1290,
  [1291] = 546,
  [1292] = 593,
  [1293] = 448,
  [1294] = 1294,
  [1295] = 473,
  [1296] = 1296,
  [1297] = 438,
  [1298] = 1298,
  [1299] = 423,
  [1300] = 691,
  [1301] = 415,
  [1302] = 694,
  [1303] = 706,
  [1304] = 423,
  [1305] = 1305,
  [1306] = 1306,
  [1307] = 1298,
  [1308] = 786,
  [1309] = 641,
  [1310] = 768,
  [1311] = 1311,
  [1312] = 739,
  [1313] = 1313,
  [1314] = 693,
  [1315] = 757,
  [1316] = 673,
  [1317] = 674,
  [1318] = 675,
  [1319] = 676,
  [1320] = 1320,
  [1321] = 641,
  [1322] = 677,
  [1323] = 678,
  [1324] = 680,
  [1325] = 765,
  [1326] = 766,
  [1327] = 525,
  [1328] = 390,
  [1329] = 417,
  [1330] = 681,
  [1331] = 682,
  [1332] = 1266,
  [1333] = 1333,
  [1334] = 1269,
  [1335] = 1335,
  [1336] = 1266,
  [1337] = 1269,
  [1338] = 1294,
  [1339] = 1339,
  [1340] = 1340,
  [1341] = 1341,
  [1342] = 424,
  [1343] = 1313,
  [1344] = 390,
  [1345] = 417,
  [1346] = 1335,
  [1347] = 1294,
  [1348] = 1335,
  [1349] = 1294,
  [1350] = 424,
  [1351] = 580,
  [1352] = 684,
  [1353] = 1266,
  [1354] = 1269,
  [1355] = 1077,
  [1356] = 583,
  [1357] = 1335,
  [1358] = 389,
  [1359] = 1359,
  [1360] = 1360,
  [1361] = 1361,
  [1362] = 1361,
  [1363] = 1363,
  [1364] = 1364,
  [1365] = 1363,
  [1366] = 1363,
  [1367] = 1367,
  [1368] = 1368,
  [1369] = 1367,
  [1370] = 479,
  [1371] = 453,
  [1372] = 449,
  [1373] = 448,
  [1374] = 459,
  [1375] = 474,
  [1376] = 480,
  [1377] = 457,
  [1378] = 450,
  [1379] = 1379,
  [1380] = 1367,
  [1381] = 1367,
  [1382] = 1367,
  [1383] = 1139,
  [1384] = 1384,
  [1385] = 1367,
  [1386] = 1386,
  [1387] = 1367,
  [1388] = 1388,
  [1389] = 1389,
  [1390] = 1367,
  [1391] = 1367,
  [1392] = 451,
  [1393] = 1360,
  [1394] = 452,
  [1395] = 366,
  [1396] = 387,
  [1397] = 449,
  [1398] = 1398,
  [1399] = 450,
  [1400] = 451,
  [1401] = 372,
  [1402] = 438,
  [1403] = 381,
  [1404] = 452,
  [1405] = 374,
  [1406] = 453,
  [1407] = 384,
  [1408] = 376,
  [1409] = 368,
  [1410] = 375,
  [1411] = 388,
  [1412] = 457,
  [1413] = 385,
  [1414] = 379,
  [1415] = 378,
  [1416] = 383,
  [1417] = 459,
  [1418] = 1367,
  [1419] = 479,
  [1420] = 438,
  [1421] = 480,
  [1422] = 380,
  [1423] = 373,
  [1424] = 1424,
  [1425] = 1425,
  [1426] = 1360,
  [1427] = 1361,
  [1428] = 1428,
  [1429] = 800,
  [1430] = 448,
  [1431] = 474,
  [1432] = 1432,
  [1433] = 1433,
  [1434] = 1434,
  [1435] = 1435,
  [1436] = 1436,
  [1437] = 1437,
  [1438] = 1438,
  [1439] = 1439,
  [1440] = 1440,
  [1441] = 1441,
  [1442] = 1442,
  [1443] = 1443,
  [1444] = 1444,
  [1445] = 1445,
  [1446] = 1446,
  [1447] = 1447,
  [1448] = 1448,
  [1449] = 1449,
  [1450] = 1450,
  [1451] = 1451,
  [1452] = 1452,
  [1453] = 1453,
  [1454] = 1435,
  [1455] = 1455,
  [1456] = 1456,
  [1457] = 1457,
  [1458] = 1458,
  [1459] = 1459,
  [1460] = 1425,
  [1461] = 1461,
  [1462] = 1462,
  [1463] = 1463,
  [1464] = 1464,
  [1465] = 1465,
  [1466] = 1466,
  [1467] = 1467,
  [1468] = 1468,
  [1469] = 1469,
  [1470] = 1470,
  [1471] = 1471,
  [1472] = 1472,
  [1473] = 1473,
  [1474] = 1474,
  [1475] = 1475,
  [1476] = 1476,
  [1477] = 1477,
  [1478] = 1478,
  [1479] = 1479,
  [1480] = 1480,
  [1481] = 1481,
  [1482] = 1482,
  [1483] = 1483,
  [1484] = 1484,
  [1485] = 1485,
  [1486] = 1486,
  [1487] = 1487,
  [1488] = 1488,
  [1489] = 1298,
  [1490] = 1490,
  [1491] = 1491,
  [1492] = 1492,
  [1493] = 1493,
  [1494] = 1494,
  [1495] = 1495,
  [1496] = 1496,
  [1497] = 1497,
  [1498] = 1498,
  [1499] = 1450,
  [1500] = 1500,
  [1501] = 1435,
  [1502] = 1502,
  [1503] = 1503,
  [1504] = 1504,
  [1505] = 1505,
  [1506] = 1506,
  [1507] = 1507,
  [1508] = 1508,
  [1509] = 1386,
  [1510] = 1510,
  [1511] = 1511,
  [1512] = 1512,
  [1513] = 1513,
  [1514] = 1450,
  [1515] = 1512,
  [1516] = 800,
  [1517] = 1517,
  [1518] = 1518,
  [1519] = 1519,
  [1520] = 1520,
  [1521] = 1520,
  [1522] = 1522,
  [1523] = 1523,
  [1524] = 1524,
  [1525] = 1525,
  [1526] = 1204,
  [1527] = 1527,
  [1528] = 1528,
  [1529] = 1529,
  [1530] = 1530,
  [1531] = 1531,
  [1532] = 1532,
  [1533] = 1533,
  [1534] = 1534,
  [1535] = 1535,
  [1536] = 1536,
  [1537] = 1537,
  [1538] = 356,
  [1539] = 1539,
  [1540] = 1540,
  [1541] = 1541,
  [1542] = 1542,
  [1543] = 1543,
  [1544] = 1544,
  [1545] = 1545,
  [1546] = 358,
  [1547] = 359,
  [1548] = 360,
  [1549] = 1549,
  [1550] = 354,
  [1551] = 357,
  [1552] = 1552,
  [1553] = 1553,
  [1554] = 353,
  [1555] = 1555,
  [1556] = 1556,
  [1557] = 1557,
  [1558] = 1558,
  [1559] = 1557,
  [1560] = 1557,
  [1561] = 1561,
  [1562] = 1562,
  [1563] = 1563,
  [1564] = 1556,
  [1565] = 1565,
  [1566] = 1566,
  [1567] = 1567,
  [1568] = 1556,
  [1569] = 1569,
  [1570] = 1557,
  [1571] = 1571,
  [1572] = 1556,
  [1573] = 1573,
  [1574] = 1574,
  [1575] = 1575,
  [1576] = 360,
  [1577] = 800,
  [1578] = 1578,
  [1579] = 1579,
  [1580] = 1580,
  [1581] = 1581,
  [1582] = 1582,
  [1583] = 1583,
  [1584] = 1584,
  [1585] = 1585,
  [1586] = 1586,
  [1587] = 1580,
  [1588] = 1588,
  [1589] = 1589,
  [1590] = 1590,
  [1591] = 1591,
  [1592] = 1574,
  [1593] = 1580,
  [1594] = 1585,
  [1595] = 1585,
  [1596] = 1580,
  [1597] = 1585,
  [1598] = 1584,
  [1599] = 1586,
  [1600] = 1590,
  [1601] = 1580,
  [1602] = 1588,
  [1603] = 1585,
  [1604] = 356,
  [1605] = 1580,
  [1606] = 1583,
  [1607] = 1585,
  [1608] = 1608,
  [1609] = 1580,
  [1610] = 1608,
  [1611] = 1585,
  [1612] = 1612,
  [1613] = 1613,
  [1614] = 1614,
  [1615] = 1580,
  [1616] = 1616,
  [1617] = 1585,
  [1618] = 1578,
  [1619] = 1619,
  [1620] = 1620,
  [1621] = 1621,
  [1622] = 1622,
  [1623] = 1623,
  [1624] = 1612,
  [1625] = 1625,
  [1626] = 1626,
  [1627] = 1619,
  [1628] = 1628,
  [1629] = 1620,
  [1630] = 1622,
  [1631] = 1582,
  [1632] = 1632,
  [1633] = 1633,
  [1634] = 1634,
  [1635] = 1581,
  [1636] = 1633,
  [1637] = 1623,
  [1638] = 1625,
  [1639] = 1634,
  [1640] = 1640,
  [1641] = 1641,
  [1642] = 1621,
  [1643] = 1626,
  [1644] = 1640,
  [1645] = 1645,
  [1646] = 359,
  [1647] = 1613,
  [1648] = 1614,
  [1649] = 1616,
  [1650] = 1650,
  [1651] = 1628,
  [1652] = 1580,
  [1653] = 1585,
  [1654] = 358,
  [1655] = 1580,
  [1656] = 1585,
  [1657] = 1632,
  [1658] = 1658,
  [1659] = 1659,
  [1660] = 1660,
  [1661] = 1661,
  [1662] = 1662,
  [1663] = 1663,
  [1664] = 1664,
  [1665] = 1665,
  [1666] = 1666,
  [1667] = 1667,
  [1668] = 959,
  [1669] = 1669,
  [1670] = 1670,
  [1671] = 1671,
  [1672] = 1672,
  [1673] = 1673,
  [1674] = 1674,
  [1675] = 1675,
  [1676] = 1676,
  [1677] = 1677,
  [1678] = 1678,
  [1679] = 1679,
  [1680] = 1680,
  [1681] = 1681,
  [1682] = 1682,
  [1683] = 1683,
  [1684] = 1684,
  [1685] = 1685,
  [1686] = 1686,
  [1687] = 1687,
  [1688] = 1688,
  [1689] = 1687,
  [1690] = 1688,
  [1691] = 1688,
  [1692] = 1692,
  [1693] = 1687,
  [1694] = 1692,
  [1695] = 1692,
  [1696] = 800,
  [1697] = 1688,
  [1698] = 1687,
  [1699] = 1692,
  [1700] = 1700,
  [1701] = 1701,
  [1702] = 1702,
  [1703] = 1703,
  [1704] = 1704,
  [1705] = 1705,
  [1706] = 1678,
  [1707] = 1701,
  [1708] = 1703,
  [1709] = 1701,
  [1710] = 1703,
  [1711] = 1711,
  [1712] = 1712,
  [1713] = 1703,
  [1714] = 1714,
  [1715] = 1715,
  [1716] = 1716,
  [1717] = 1701,
  [1718] = 1701,
  [1719] = 1719,
  [1720] = 1701,
  [1721] = 1721,
  [1722] = 1722,
  [1723] = 1723,
  [1724] = 1682,
  [1725] = 1725,
  [1726] = 1223,
  [1727] = 1511,
  [1728] = 1728,
  [1729] = 1701,
  [1730] = 1703,
  [1731] = 1701,
  [1732] = 1732,
  [1733] = 1733,
  [1734] = 1703,
  [1735] = 1701,
  [1736] = 1684,
  [1737] = 1737,
  [1738] = 1738,
  [1739] = 1703,
  [1740] = 1740,
  [1741] = 1741,
  [1742] = 1742,
  [1743] = 1743,
  [1744] = 1744,
  [1745] = 1745,
  [1746] = 1746,
  [1747] = 1747,
  [1748] = 1701,
  [1749] = 1749,
  [1750] = 1681,
  [1751] = 1703,
  [1752] = 1752,
  [1753] = 1753,
  [1754] = 1703,
  [1755] = 1755,
  [1756] = 1756,
  [1757] = 1753,
  [1758] = 1703,
  [1759] = 1703,
  [1760] = 1701,
  [1761] = 1761,
  [1762] = 1701,
  [1763] = 1703,
  [1764] = 1764,
  [1765] = 1765,
  [1766] = 1766,
  [1767] = 1767,
  [1768] = 1768,
  [1769] = 1745,
  [1770] = 1770,
  [1771] = 1771,
  [1772] = 1737,
  [1773] = 1773,
  [1774] = 1774,
  [1775] = 1775,
  [1776] = 1761,
  [1777] = 1777,
  [1778] = 1725,
  [1779] = 1779,
  [1780] = 1733,
  [1781] = 1781,
  [1782] = 1782,
  [1783] = 1783,
  [1784] = 1714,
  [1785] = 1785,
  [1786] = 1755,
  [1787] = 1728,
  [1788] = 1746,
  [1789] = 1789,
  [1790] = 1719,
  [1791] = 1749,
  [1792] = 1792,
  [1793] = 1793,
  [1794] = 1705,
  [1795] = 1702,
  [1796] = 1796,
  [1797] = 1797,
  [1798] = 1798,
  [1799] = 1799,
  [1800] = 1711,
  [1801] = 1801,
  [1802] = 1715,
  [1803] = 1803,
  [1804] = 1804,
  [1805] = 1756,
  [1806] = 1806,
  [1807] = 1700,
  [1808] = 1716,
  [1809] = 1809,
  [1810] = 1810,
  [1811] = 1811,
  [1812] = 1812,
  [1813] = 1813,
  [1814] = 1814,
  [1815] = 800,
  [1816] = 1816,
  [1817] = 1817,
  [1818] = 1818,
  [1819] = 1819,
  [1820] = 1820,
  [1821] = 1821,
  [1822] = 1704,
  [1823] = 1823,
  [1824] = 1824,
  [1825] = 1825,
  [1826] = 1826,
  [1827] = 1827,
  [1828] = 1827,
  [1829] = 1829,
  [1830] = 1830,
  [1831] = 1831,
  [1832] = 1832,
  [1833] = 1833,
  [1834] = 1834,
  [1835] = 1835,
  [1836] = 1836,
  [1837] = 1837,
  [1838] = 1818,
  [1839] = 1741,
  [1840] = 1840,
  [1841] = 334,
  [1842] = 800,
  [1843] = 1843,
  [1844] = 1844,
  [1845] = 1845,
  [1846] = 1846,
  [1847] = 1847,
  [1848] = 1848,
  [1849] = 1849,
  [1850] = 1824,
  [1851] = 333,
  [1852] = 1852,
  [1853] = 1830,
  [1854] = 1854,
  [1855] = 1855,
  [1856] = 1856,
  [1857] = 1857,
  [1858] = 1858,
  [1859] = 1859,
  [1860] = 1860,
  [1861] = 1861,
  [1862] = 1862,
  [1863] = 1863,
  [1864] = 1864,
  [1865] = 1852,
  [1866] = 474,
  [1867] = 1867,
  [1868] = 1868,
  [1869] = 1869,
  [1870] = 1830,
  [1871] = 1832,
  [1872] = 1837,
  [1873] = 1873,
  [1874] = 1874,
  [1875] = 1875,
  [1876] = 1876,
  [1877] = 1877,
  [1878] = 1878,
  [1879] = 1879,
  [1880] = 1880,
  [1881] = 1832,
  [1882] = 1882,
  [1883] = 1837,
  [1884] = 1884,
  [1885] = 1885,
  [1886] = 1886,
  [1887] = 1832,
  [1888] = 1888,
  [1889] = 1889,
  [1890] = 1890,
  [1891] = 1891,
  [1892] = 1892,
  [1893] = 1893,
  [1894] = 1894,
  [1895] = 1895,
  [1896] = 1896,
  [1897] = 1897,
  [1898] = 1898,
  [1899] = 1899,
  [1900] = 1900,
  [1901] = 1901,
  [1902] = 1902,
  [1903] = 1903,
  [1904] = 1904,
  [1905] = 1905,
  [1906] = 1855,
  [1907] = 1907,
  [1908] = 1908,
  [1909] = 1813,
  [1910] = 1833,
  [1911] = 1834,
  [1912] = 1831,
  [1913] = 1835,
  [1914] = 1868,
  [1915] = 1840,
  [1916] = 1916,
  [1917] = 1917,
  [1918] = 1918,
  [1919] = 1908,
  [1920] = 1813,
  [1921] = 1921,
  [1922] = 1922,
  [1923] = 1923,
  [1924] = 1924,
  [1925] = 1925,
  [1926] = 1926,
  [1927] = 1844,
  [1928] = 1928,
  [1929] = 1929,
  [1930] = 1855,
  [1931] = 1908,
  [1932] = 1813,
  [1933] = 1831,
  [1934] = 1835,
  [1935] = 1868,
  [1936] = 1837,
  [1937] = 1937,
  [1938] = 1938,
  [1939] = 1939,
  [1940] = 1855,
  [1941] = 1908,
  [1942] = 1831,
  [1943] = 1835,
  [1944] = 1868,
  [1945] = 1945,
  [1946] = 1860,
  [1947] = 1947,
  [1948] = 1948,
  [1949] = 1948,
  [1950] = 1950,
  [1951] = 1951,
  [1952] = 1952,
  [1953] = 1953,
  [1954] = 1954,
  [1955] = 1955,
  [1956] = 1956,
  [1957] = 1948,
  [1958] = 1810,
  [1959] = 1959,
  [1960] = 1950,
  [1961] = 1961,
  [1962] = 1962,
  [1963] = 1963,
  [1964] = 1964,
  [1965] = 1965,
  [1966] = 1966,
  [1967] = 1967,
  [1968] = 1968,
  [1969] = 1950,
  [1970] = 1773,
  [1971] = 1971,
  [1972] = 1972,
  [1973] = 1817,
  [1974] = 1974,
  [1975] = 1975,
  [1976] = 1976,
  [1977] = 1962,
  [1978] = 1978,
  [1979] = 1979,
  [1980] = 1980,
  [1981] = 1981,
  [1982] = 1982,
  [1983] = 1983,
  [1984] = 1984,
  [1985] = 1985,
  [1986] = 1959,
  [1987] = 1948,
  [1988] = 1988,
  [1989] = 474,
  [1990] = 1990,
  [1991] = 1991,
  [1992] = 1992,
  [1993] = 1950,
  [1994] = 1846,
  [1995] = 1995,
  [1996] = 1996,
  [1997] = 1997,
  [1998] = 1998,
  [1999] = 1999,
  [2000] = 2000,
  [2001] = 2001,
  [2002] = 2002,
  [2003] = 2003,
  [2004] = 2004,
  [2005] = 1966,
  [2006] = 1796,
  [2007] = 1959,
  [2008] = 1766,
  [2009] = 1966,
  [2010] = 1907,
  [2011] = 1948,
  [2012] = 1950,
  [2013] = 2013,
  [2014] = 1955,
  [2015] = 1953,
  [2016] = 1965,
  [2017] = 2017,
  [2018] = 1948,
  [2019] = 1950,
  [2020] = 2020,
  [2021] = 2021,
  [2022] = 1948,
  [2023] = 1959,
  [2024] = 1966,
  [2025] = 2025,
  [2026] = 1916,
  [2027] = 1950,
  [2028] = 1950,
  [2029] = 2029,
  [2030] = 2030,
  [2031] = 1948,
  [2032] = 2032,
  [2033] = 2033,
  [2034] = 2034,
  [2035] = 2035,
  [2036] = 2036,
  [2037] = 2037,
  [2038] = 2038,
  [2039] = 2039,
  [2040] = 2040,
  [2041] = 2041,
  [2042] = 2042,
  [2043] = 1901,
  [2044] = 2040,
  [2045] = 2045,
  [2046] = 2046,
  [2047] = 2047,
  [2048] = 2048,
  [2049] = 2049,
  [2050] = 2050,
  [2051] = 2051,
  [2052] = 2052,
  [2053] = 2053,
  [2054] = 2048,
  [2055] = 2055,
  [2056] = 2056,
  [2057] = 2057,
  [2058] = 2058,
  [2059] = 2059,
  [2060] = 2060,
  [2061] = 2061,
  [2062] = 2033,
  [2063] = 2048,
  [2064] = 2055,
  [2065] = 2056,
  [2066] = 2066,
  [2067] = 2067,
  [2068] = 2034,
  [2069] = 2069,
  [2070] = 2036,
  [2071] = 2037,
  [2072] = 2040,
  [2073] = 2041,
  [2074] = 2042,
  [2075] = 2057,
  [2076] = 2058,
  [2077] = 2066,
  [2078] = 2067,
  [2079] = 2079,
  [2080] = 2052,
  [2081] = 2060,
  [2082] = 2082,
  [2083] = 2061,
  [2084] = 2058,
  [2085] = 2061,
  [2086] = 2033,
  [2087] = 2033,
  [2088] = 2056,
  [2089] = 2066,
  [2090] = 2067,
  [2091] = 2036,
  [2092] = 2041,
  [2093] = 2042,
  [2094] = 2034,
  [2095] = 2095,
  [2096] = 424,
  [2097] = 2052,
  [2098] = 2035,
  [2099] = 2058,
  [2100] = 2061,
  [2101] = 2033,
  [2102] = 2102,
  [2103] = 2056,
  [2104] = 2066,
  [2105] = 2067,
  [2106] = 2036,
  [2107] = 2041,
  [2108] = 2042,
  [2109] = 2109,
  [2110] = 2052,
  [2111] = 2111,
  [2112] = 2058,
  [2113] = 2061,
  [2114] = 2033,
  [2115] = 2115,
  [2116] = 2056,
  [2117] = 2066,
  [2118] = 2067,
  [2119] = 2036,
  [2120] = 2042,
  [2121] = 2121,
  [2122] = 2122,
  [2123] = 2052,
  [2124] = 2124,
  [2125] = 2058,
  [2126] = 2061,
  [2127] = 2127,
  [2128] = 2056,
  [2129] = 2066,
  [2130] = 2067,
  [2131] = 2036,
  [2132] = 2042,
  [2133] = 2040,
  [2134] = 2134,
  [2135] = 2052,
  [2136] = 2058,
  [2137] = 2061,
  [2138] = 2033,
  [2139] = 2056,
  [2140] = 2066,
  [2141] = 2067,
  [2142] = 2036,
  [2143] = 2042,
  [2144] = 2144,
  [2145] = 2145,
  [2146] = 2146,
  [2147] = 2147,
  [2148] = 2052,
  [2149] = 2051,
  [2150] = 2052,
  [2151] = 2058,
  [2152] = 2061,
  [2153] = 2033,
  [2154] = 2051,
  [2155] = 2056,
  [2156] = 2066,
  [2157] = 2067,
  [2158] = 2036,
  [2159] = 2042,
  [2160] = 2160,
  [2161] = 2052,
  [2162] = 2042,
  [2163] = 2055,
  [2164] = 2042,
  [2165] = 2165,
  [2166] = 2057,
  [2167] = 2058,
  [2168] = 2168,
  [2169] = 2056,
  [2170] = 2066,
  [2171] = 2041,
  [2172] = 2172,
  [2173] = 2173,
  [2174] = 2042,
  [2175] = 2067,
  [2176] = 2176,
  [2177] = 2177,
  [2178] = 2178,
  [2179] = 2060,
  [2180] = 2061,
  [2181] = 2034,
  [2182] = 2182,
  [2183] = 2183,
  [2184] = 2184,
  [2185] = 2183,
  [2186] = 2186,
  [2187] = 2187,
  [2188] = 2177,
  [2189] = 2033,
  [2190] = 334,
  [2191] = 2191,
  [2192] = 2192,
  [2193] = 2193,
  [2194] = 2041,
  [2195] = 2195,
  [2196] = 2196,
  [2197] = 2048,
  [2198] = 2198,
  [2199] = 2186,
  [2200] = 2042,
  [2201] = 333,
  [2202] = 2202,
  [2203] = 2203,
  [2204] = 2051,
  [2205] = 2052,
  [2206] = 2191,
  [2207] = 2207,
  [2208] = 2208,
  [2209] = 2209,
  [2210] = 2210,
  [2211] = 2036,
  [2212] = 2212,
  [2213] = 2213,
  [2214] = 2195,
  [2215] = 2036,
  [2216] = 2057,
  [2217] = 2058,
  [2218] = 2218,
  [2219] = 2060,
  [2220] = 2061,
  [2221] = 2221,
  [2222] = 2037,
  [2223] = 2223,
  [2224] = 2033,
  [2225] = 417,
  [2226] = 2037,
  [2227] = 2041,
  [2228] = 2184,
  [2229] = 2229,
  [2230] = 2042,
  [2231] = 2231,
  [2232] = 2232,
  [2233] = 2233,
  [2234] = 2055,
  [2235] = 2056,
  [2236] = 2066,
  [2237] = 2237,
  [2238] = 2067,
  [2239] = 2239,
  [2240] = 765,
  [2241] = 2241,
  [2242] = 2242,
  [2243] = 2243,
  [2244] = 2244,
  [2245] = 2245,
  [2246] = 2246,
  [2247] = 2242,
  [2248] = 2248,
  [2249] = 2249,
  [2250] = 2250,
  [2251] = 2251,
  [2252] = 334,
  [2253] = 2253,
  [2254] = 2254,
  [2255] = 2242,
  [2256] = 390,
  [2257] = 2257,
  [2258] = 2258,
  [2259] = 2242,
  [2260] = 2260,
  [2261] = 2261,
  [2262] = 2262,
  [2263] = 2263,
  [2264] = 2242,
  [2265] = 2265,
  [2266] = 417,
  [2267] = 2267,
  [2268] = 2268,
  [2269] = 2269,
  [2270] = 2270,
  [2271] = 2271,
  [2272] = 2272,
  [2273] = 2273,
  [2274] = 362,
  [2275] = 2246,
  [2276] = 2241,
  [2277] = 2277,
  [2278] = 2249,
  [2279] = 343,
  [2280] = 2280,
  [2281] = 2281,
  [2282] = 2258,
  [2283] = 2283,
  [2284] = 2284,
  [2285] = 2285,
  [2286] = 2286,
  [2287] = 2249,
  [2288] = 2288,
  [2289] = 2289,
  [2290] = 2290,
  [2291] = 2249,
  [2292] = 2258,
  [2293] = 2293,
  [2294] = 768,
  [2295] = 2249,
  [2296] = 2296,
  [2297] = 2249,
  [2298] = 2298,
  [2299] = 2249,
  [2300] = 2249,
  [2301] = 2301,
  [2302] = 333,
  [2303] = 2242,
  [2304] = 2304,
  [2305] = 2305,
  [2306] = 2306,
  [2307] = 2246,
  [2308] = 2308,
  [2309] = 2254,
  [2310] = 2262,
  [2311] = 2241,
  [2312] = 2272,
  [2313] = 2313,
  [2314] = 2314,
  [2315] = 2283,
  [2316] = 2316,
  [2317] = 2317,
  [2318] = 2318,
  [2319] = 2319,
  [2320] = 2320,
  [2321] = 1953,
  [2322] = 2283,
  [2323] = 2277,
  [2324] = 2254,
  [2325] = 2272,
  [2326] = 2254,
  [2327] = 2272,
  [2328] = 2328,
  [2329] = 2329,
  [2330] = 2330,
  [2331] = 424,
  [2332] = 2332,
  [2333] = 766,
  [2334] = 2334,
  [2335] = 2253,
  [2336] = 2336,
  [2337] = 2263,
  [2338] = 2338,
  [2339] = 2339,
  [2340] = 2340,
  [2341] = 2341,
  [2342] = 2253,
  [2343] = 2242,
  [2344] = 2344,
  [2345] = 2345,
  [2346] = 2281,
  [2347] = 2258,
  [2348] = 2348,
  [2349] = 2257,
  [2350] = 2350,
  [2351] = 2283,
  [2352] = 2242,
  [2353] = 2242,
  [2354] = 2257,
  [2355] = 2260,
  [2356] = 2356,
  [2357] = 2262,
  [2358] = 2241,
  [2359] = 2260,
  [2360] = 2360,
  [2361] = 2242,
  [2362] = 2262,
  [2363] = 2242,
  [2364] = 2364,
  [2365] = 2365,
  [2366] = 2366,
  [2367] = 2367,
  [2368] = 2365,
  [2369] = 2369,
  [2370] = 2370,
  [2371] = 2371,
  [2372] = 2372,
  [2373] = 2365,
  [2374] = 2374,
  [2375] = 2364,
  [2376] = 2376,
  [2377] = 2370,
  [2378] = 2378,
  [2379] = 2365,
  [2380] = 457,
  [2381] = 2365,
  [2382] = 2382,
  [2383] = 2383,
  [2384] = 2384,
  [2385] = 334,
  [2386] = 333,
  [2387] = 2387,
  [2388] = 2388,
  [2389] = 2365,
  [2390] = 2390,
  [2391] = 2364,
  [2392] = 2390,
  [2393] = 2393,
  [2394] = 2364,
  [2395] = 2370,
  [2396] = 2396,
  [2397] = 2370,
  [2398] = 2388,
  [2399] = 2399,
  [2400] = 2400,
  [2401] = 2396,
  [2402] = 2388,
  [2403] = 2366,
  [2404] = 2369,
  [2405] = 2371,
  [2406] = 2406,
  [2407] = 2388,
  [2408] = 448,
  [2409] = 2370,
  [2410] = 2371,
  [2411] = 2374,
  [2412] = 2388,
  [2413] = 2365,
  [2414] = 2414,
  [2415] = 2415,
  [2416] = 2378,
  [2417] = 2367,
  [2418] = 2364,
  [2419] = 2370,
  [2420] = 2420,
  [2421] = 2371,
  [2422] = 2367,
  [2423] = 2423,
  [2424] = 2388,
  [2425] = 2414,
  [2426] = 2423,
  [2427] = 2365,
  [2428] = 2374,
  [2429] = 2366,
  [2430] = 2371,
  [2431] = 2364,
  [2432] = 2396,
  [2433] = 2370,
  [2434] = 2434,
  [2435] = 2371,
  [2436] = 2390,
  [2437] = 2393,
  [2438] = 2390,
  [2439] = 2390,
  [2440] = 2364,
  [2441] = 438,
  [2442] = 2442,
  [2443] = 2390,
  [2444] = 2378,
  [2445] = 2390,
  [2446] = 2396,
  [2447] = 2371,
  [2448] = 2448,
  [2449] = 2374,
  [2450] = 2388,
};

static bool ts_lex(TSLexer *lexer, TSStateId state) {
  START_LEXER();
  eof = lexer->eof(lexer);
  switch (state) {
    case 0:
      if (eof) ADVANCE(145);
      ADVANCE_MAP(
        '\n', 339,
        '\r', 243,
        '!', 164,
        '"', 250,
        '%', 176,
        '&', 200,
        '\'', 241,
        '(', 150,
        ')', 149,
        '*', 170,
        '+', 156,
        ',', 211,
        '-', 159,
        '.', 209,
        '/', 172,
        ':', 203,
        '<', 191,
        '=', 154,
        '>', 186,
        '?', 221,
        '[', 225,
        '\\', 222,
        ']', 226,
        '^', 181,
        '{', 151,
        '|', 178,
        '}', 152,
        '~', 163,
        '\t', 244,
        ' ', 244,
      );
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(216);
      if (('A' <= lookahead && lookahead <= '_') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(217);
      if (lookahead != 0) ADVANCE(212);
      END_STATE();
    case 1:
      if (lookahead == '\n') ADVANCE(339);
      END_STATE();
    case 2:
      ADVANCE_MAP(
        '\n', 339,
        '\r', 1,
        '!', 165,
        '"', 250,
        '#', 118,
        '%', 176,
        '&', 200,
        '\'', 241,
        '(', 150,
        ')', 149,
        '*', 170,
        '+', 157,
        ',', 211,
        '-', 160,
        '.', 51,
        '/', 173,
        '0', 43,
        ':', 204,
        ';', 21,
        '<', 192,
        '=', 155,
        '>', 187,
        '\\', 223,
        '^', 183,
        '_', 323,
        '`', 137,
        '{', 151,
        '|', 180,
        '}', 152,
        '~', 163,
        '\t', 344,
        ' ', 344,
      );
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(44);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(322);
      END_STATE();
    case 3:
      ADVANCE_MAP(
        '\n', 339,
        '\r', 1,
        '!', 165,
        '"', 250,
        '#', 118,
        '%', 176,
        '&', 201,
        '\'', 241,
        '(', 150,
        ')', 149,
        '*', 170,
        '+', 157,
        ',', 211,
        '-', 162,
        '.', 210,
        '/', 173,
        '0', 43,
        ':', 54,
        ';', 21,
        '<', 192,
        '=', 155,
        '>', 187,
        '?', 221,
        'B', 320,
        '[', 225,
        '\\', 223,
        ']', 226,
        '^', 183,
        '_', 323,
        '`', 137,
        '{', 151,
        '|', 180,
        '~', 163,
        '\t', 344,
        ' ', 344,
        'V', 317,
        'v', 317,
      );
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(44);
      if (('A' <= lookahead && lookahead <= 'z')) ADVANCE(322);
      END_STATE();
    case 4:
      ADVANCE_MAP(
        '\n', 339,
        '\r', 1,
        '!', 165,
        '"', 250,
        '%', 176,
        '&', 201,
        '\'', 241,
        '(', 150,
        ')', 149,
        '*', 170,
        '+', 157,
        ',', 256,
        '-', 162,
        '.', 209,
        '/', 173,
        ':', 203,
        ';', 257,
        '<', 192,
        '=', 63,
        '>', 187,
        '?', 221,
        'L', 310,
        'U', 311,
        '[', 225,
        '\\', 223,
        ']', 226,
        '^', 181,
        '`', 137,
        'u', 312,
        '|', 180,
        '~', 163,
        '\t', 342,
        ' ', 342,
      );
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(79);
      if (('A' <= lookahead && lookahead <= 'z')) ADVANCE(323);
      END_STATE();
    case 5:
      ADVANCE_MAP(
        '\n', 339,
        '\r', 1,
        '!', 165,
        '"', 250,
        '%', 177,
        '&', 202,
        '\'', 241,
        '(', 150,
        '*', 171,
        '+', 158,
        ',', 256,
        '-', 161,
        '.', 209,
        '/', 174,
        ';', 257,
        '<', 193,
        '=', 155,
        '>', 188,
        '?', 221,
        'L', 310,
        'U', 311,
        '[', 225,
        '\\', 223,
        '^', 182,
        '`', 137,
        'u', 312,
        '|', 179,
        '~', 163,
        '\t', 342,
        ' ', 342,
      );
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(79);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('_' <= lookahead && lookahead <= 'z')) ADVANCE(323);
      END_STATE();
    case 6:
      ADVANCE_MAP(
        '\n', 339,
        '\r', 1,
        '!', 165,
        '"', 250,
        '%', 177,
        '&', 202,
        '\'', 241,
        '(', 150,
        '*', 171,
        '+', 158,
        '-', 161,
        '.', 209,
        '/', 174,
        ';', 21,
        '<', 193,
        '=', 155,
        '>', 188,
        '?', 221,
        'L', 310,
        'U', 311,
        '[', 225,
        '\\', 223,
        '^', 182,
        '`', 137,
        'u', 312,
        '|', 179,
        '~', 163,
        '\t', 344,
        ' ', 344,
      );
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(79);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('_' <= lookahead && lookahead <= 'z')) ADVANCE(323);
      END_STATE();
    case 7:
      ADVANCE_MAP(
        '\n', 339,
        '\r', 1,
        '!', 62,
        '"', 250,
        '%', 177,
        '&', 202,
        '\'', 241,
        '(', 150,
        '*', 171,
        '+', 158,
        ',', 256,
        '-', 161,
        '.', 209,
        '/', 174,
        '0', 104,
        ';', 257,
        '<', 193,
        '=', 155,
        '>', 188,
        '?', 221,
        'L', 37,
        'U', 38,
        '[', 225,
        '\\', 20,
        '^', 182,
        'u', 39,
        '|', 179,
        '\t', 342,
        ' ', 342,
      );
      END_STATE();
    case 8:
      ADVANCE_MAP(
        '\n', 339,
        '\r', 1,
        '!', 62,
        '%', 176,
        '&', 201,
        '(', 150,
        ')', 149,
        '*', 170,
        '+', 157,
        ',', 256,
        '-', 162,
        '.', 209,
        '/', 173,
        ':', 203,
        ';', 257,
        '<', 192,
        '=', 63,
        '>', 187,
        '?', 221,
        '[', 225,
        '\\', 20,
        ']', 226,
        '^', 181,
        '|', 180,
        '\t', 342,
        ' ', 342,
      );
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(117);
      if (('A' <= lookahead && lookahead <= '_') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(336);
      END_STATE();
    case 9:
      ADVANCE_MAP(
        '\n', 339,
        '\r', 1,
        '!', 62,
        '%', 176,
        '&', 201,
        '(', 150,
        '*', 170,
        '+', 157,
        ',', 211,
        '-', 160,
        '.', 210,
        '/', 173,
        ':', 205,
        ';', 21,
        '<', 192,
        '=', 155,
        '>', 187,
        'B', 321,
        '\\', 20,
        '^', 183,
        '|', 180,
        '\t', 344,
        ' ', 344,
        'V', 318,
        'v', 318,
      );
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(117);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(336);
      END_STATE();
    case 10:
      ADVANCE_MAP(
        '\n', 339,
        '\r', 1,
        '!', 62,
        '%', 177,
        '&', 202,
        '(', 150,
        '*', 171,
        '+', 158,
        '-', 161,
        '.', 209,
        '/', 174,
        ';', 21,
        '<', 193,
        '=', 155,
        '>', 188,
        '?', 221,
        '[', 225,
        '\\', 20,
        '^', 182,
        '|', 179,
        '\t', 344,
        ' ', 344,
        'L', 219,
        'l', 219,
      );
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(117);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(336);
      END_STATE();
    case 11:
      ADVANCE_MAP(
        '\n', 339,
        '\r', 1,
        '(', 150,
        '/', 52,
        ';', 21,
        '=', 218,
        '\\', 19,
        '\t', 343,
        ' ', 343,
      );
      END_STATE();
    case 12:
      ADVANCE_MAP(
        '\n', 339,
        '\r', 1,
        '(', 147,
        '*', 170,
        '/', 52,
        ';', 21,
        '?', 221,
        '\\', 19,
        '\t', 344,
        ' ', 344,
      );
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(117);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(336);
      END_STATE();
    case 13:
      if (lookahead == '\n') ADVANCE(339);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == ',') ADVANCE(256);
      if (lookahead == '/') ADVANCE(52);
      if (lookahead == ';') ADVANCE(257);
      if (lookahead == '\t' ||
          lookahead == ' ') ADVANCE(13);
      END_STATE();
    case 14:
      if (lookahead == '\n') ADVANCE(339);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '/') ADVANCE(52);
      if (lookahead == ';') ADVANCE(21);
      if (lookahead == '=') ADVANCE(218);
      if (lookahead == '\t' ||
          lookahead == ' ') ADVANCE(14);
      END_STATE();
    case 15:
      if (lookahead == '\n') ADVANCE(339);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '/') ADVANCE(52);
      if (lookahead == ';') ADVANCE(21);
      if (lookahead == '\t' ||
          lookahead == ' ') ADVANCE(15);
      END_STATE();
    case 16:
      if (lookahead == '\n') ADVANCE(339);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '/') ADVANCE(215);
      if (lookahead == ';') ADVANCE(214);
      if (lookahead == '\\') ADVANCE(213);
      if (lookahead == '\t' ||
          lookahead == ' ') ADVANCE(344);
      if (lookahead != 0) ADVANCE(212);
      END_STATE();
    case 17:
      if (lookahead == '\n') ADVANCE(339);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '\t' ||
          lookahead == ' ') ADVANCE(17);
      END_STATE();
    case 18:
      if (lookahead == '\n') ADVANCE(340);
      END_STATE();
    case 19:
      if (lookahead == '\n') ADVANCE(340);
      if (lookahead == '\r') ADVANCE(18);
      END_STATE();
    case 20:
      if (lookahead == '\n') ADVANCE(340);
      if (lookahead == '\r') ADVANCE(18);
      if (lookahead == '`') ADVANCE(140);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(300);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('_' <= lookahead && lookahead <= 'z')) ADVANCE(60);
      END_STATE();
    case 21:
      if (lookahead == '\n') ADVANCE(337);
      if (lookahead == '\\') ADVANCE(22);
      if (lookahead != 0) ADVANCE(21);
      END_STATE();
    case 22:
      if (lookahead == '\n') ADVANCE(338);
      if (lookahead == '\r') ADVANCE(23);
      if (lookahead == '\\') ADVANCE(22);
      if (lookahead != 0) ADVANCE(21);
      END_STATE();
    case 23:
      if (lookahead == '\n') ADVANCE(338);
      if (lookahead == '\\') ADVANCE(22);
      if (lookahead != 0) ADVANCE(21);
      END_STATE();
    case 24:
      if (lookahead == '\n') ADVANCE(253);
      if (lookahead == '\r') ADVANCE(253);
      if (lookahead == 'U') ADVANCE(132);
      if (lookahead == 'u') ADVANCE(128);
      if (lookahead == 'x') ADVANCE(126);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(255);
      if (lookahead != 0) ADVANCE(253);
      END_STATE();
    case 25:
      ADVANCE_MAP(
        '!', 164,
        '"', 250,
        '%', 176,
        '&', 200,
        '\'', 241,
        '(', 150,
        ')', 149,
        '*', 170,
        '+', 157,
        '-', 160,
        '/', 172,
        ':', 203,
        'L', 310,
        'U', 311,
        '\\', 223,
        ']', 226,
        '`', 137,
        'u', 312,
        '~', 163,
        '\t', 341,
        ' ', 341,
      );
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(79);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('_' <= lookahead && lookahead <= 'z')) ADVANCE(323);
      END_STATE();
    case 26:
      ADVANCE_MAP(
        '!', 165,
        '"', 250,
        '#', 118,
        '%', 176,
        '&', 200,
        '\'', 241,
        '(', 150,
        ')', 149,
        '*', 170,
        '+', 157,
        ',', 211,
        '-', 160,
        '.', 210,
        '/', 172,
        '0', 43,
        ':', 204,
        '<', 192,
        '=', 155,
        '>', 187,
        '[', 225,
        '\\', 223,
        ']', 226,
        '^', 183,
        '_', 323,
        '`', 137,
        '{', 151,
        '|', 180,
        '}', 152,
        '~', 163,
        '\t', 341,
        ' ', 341,
      );
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(44);
      if (('A' <= lookahead && lookahead <= 'z')) ADVANCE(322);
      END_STATE();
    case 27:
      ADVANCE_MAP(
        '!', 165,
        '"', 250,
        '%', 176,
        '&', 201,
        '\'', 241,
        '(', 150,
        ')', 149,
        '*', 170,
        '+', 157,
        ',', 211,
        '-', 162,
        '.', 210,
        '/', 172,
        ':', 203,
        '<', 192,
        '=', 63,
        '>', 187,
        '?', 221,
        'L', 310,
        'U', 311,
        '[', 225,
        '\\', 223,
        ']', 226,
        '^', 181,
        '`', 137,
        'u', 312,
        '|', 180,
        '~', 163,
        '\t', 341,
        ' ', 341,
      );
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(79);
      if (('A' <= lookahead && lookahead <= 'z')) ADVANCE(323);
      END_STATE();
    case 28:
      ADVANCE_MAP(
        '!', 165,
        '"', 250,
        '%', 176,
        '&', 201,
        '\'', 241,
        '(', 150,
        '*', 170,
        '+', 157,
        ',', 256,
        '-', 162,
        '.', 209,
        '/', 172,
        ';', 258,
        '<', 192,
        '=', 63,
        '>', 187,
        '?', 221,
        'L', 310,
        'U', 311,
        '[', 225,
        '\\', 223,
        '^', 181,
        '`', 137,
        'u', 312,
        '|', 180,
        '~', 163,
        '\t', 345,
        ' ', 345,
      );
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(79);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('_' <= lookahead && lookahead <= 'z')) ADVANCE(323);
      END_STATE();
    case 29:
      ADVANCE_MAP(
        '!', 165,
        '"', 250,
        '%', 177,
        '&', 202,
        '\'', 241,
        '(', 150,
        ')', 149,
        '*', 171,
        '+', 158,
        ',', 211,
        '-', 161,
        '.', 210,
        '/', 175,
        ':', 203,
        '<', 193,
        '=', 155,
        '>', 188,
        '?', 221,
        'L', 310,
        'U', 311,
        '[', 225,
        '\\', 223,
        ']', 226,
        '^', 182,
        '`', 137,
        'u', 312,
        '|', 179,
        '~', 163,
        '\t', 341,
        ' ', 341,
      );
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(79);
      if (('A' <= lookahead && lookahead <= 'z')) ADVANCE(323);
      END_STATE();
    case 30:
      ADVANCE_MAP(
        '!', 165,
        '"', 250,
        '%', 177,
        '&', 202,
        '\'', 241,
        '(', 150,
        '*', 171,
        '+', 158,
        ',', 256,
        '-', 161,
        '.', 209,
        '/', 175,
        ';', 258,
        '<', 193,
        '=', 155,
        '>', 188,
        '?', 221,
        'L', 310,
        'U', 311,
        '[', 225,
        '\\', 223,
        '^', 182,
        '`', 137,
        'u', 312,
        '|', 179,
        '~', 163,
        '\t', 345,
        ' ', 345,
      );
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(79);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('_' <= lookahead && lookahead <= 'z')) ADVANCE(323);
      END_STATE();
    case 31:
      ADVANCE_MAP(
        '!', 62,
        '"', 250,
        '%', 177,
        '&', 202,
        '(', 150,
        ')', 149,
        '*', 171,
        '+', 158,
        ',', 211,
        '-', 161,
        '.', 210,
        '/', 175,
        ':', 203,
        '<', 193,
        '=', 155,
        '>', 188,
        '?', 221,
        '[', 225,
        '\\', 20,
        ']', 226,
        '^', 182,
        '{', 151,
        '|', 179,
        '\t', 341,
        ' ', 341,
      );
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(117);
      if (('A' <= lookahead && lookahead <= '_') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(336);
      END_STATE();
    case 32:
      ADVANCE_MAP(
        '!', 62,
        '%', 176,
        '&', 201,
        '(', 150,
        ')', 149,
        '*', 170,
        '+', 157,
        ',', 211,
        '-', 162,
        '.', 210,
        '/', 172,
        '<', 192,
        '=', 155,
        '>', 187,
        '?', 221,
        '[', 225,
        '\\', 20,
        ']', 226,
        '^', 183,
        '|', 180,
        '}', 152,
        '\t', 341,
        ' ', 341,
      );
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(117);
      if (('A' <= lookahead && lookahead <= '_') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(336);
      END_STATE();
    case 33:
      ADVANCE_MAP(
        '!', 62,
        '%', 176,
        '&', 201,
        '(', 150,
        '*', 170,
        '+', 157,
        ',', 256,
        '-', 162,
        '.', 209,
        '/', 172,
        ';', 258,
        '<', 192,
        '=', 63,
        '>', 187,
        '?', 221,
        '[', 225,
        '\\', 20,
        '^', 181,
        '|', 180,
        '\t', 345,
        ' ', 345,
      );
      END_STATE();
    case 34:
      ADVANCE_MAP(
        '!', 62,
        '%', 177,
        '&', 202,
        '(', 150,
        '*', 171,
        '+', 158,
        ',', 256,
        '-', 161,
        '.', 209,
        '/', 175,
        ';', 258,
        '<', 193,
        '=', 155,
        '>', 188,
        '?', 221,
        '[', 225,
        '\\', 20,
        '^', 182,
        '|', 179,
        '\t', 345,
        ' ', 345,
      );
      END_STATE();
    case 35:
      if (lookahead == '"') ADVANCE(250);
      if (lookahead == '&') ADVANCE(200);
      if (lookahead == '\\') ADVANCE(213);
      if (lookahead == '\t' ||
          lookahead == ' ') ADVANCE(341);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != '\r') ADVANCE(212);
      END_STATE();
    case 36:
      if (lookahead == '"') ADVANCE(250);
      if (lookahead == '\\') ADVANCE(24);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(252);
      END_STATE();
    case 37:
      if (lookahead == '"') ADVANCE(246);
      if (lookahead == '\'') ADVANCE(237);
      END_STATE();
    case 38:
      if (lookahead == '"') ADVANCE(248);
      if (lookahead == '\'') ADVANCE(239);
      END_STATE();
    case 39:
      if (lookahead == '"') ADVANCE(247);
      if (lookahead == '\'') ADVANCE(238);
      if (lookahead == '8') ADVANCE(40);
      END_STATE();
    case 40:
      if (lookahead == '"') ADVANCE(249);
      if (lookahead == '\'') ADVANCE(240);
      END_STATE();
    case 41:
      if (lookahead == '"') ADVANCE(251);
      if (lookahead == '&') ADVANCE(200);
      if (lookahead == '\\') ADVANCE(273);
      if (lookahead != 0) ADVANCE(275);
      END_STATE();
    case 42:
      ADVANCE_MAP(
        '%', 176,
        '(', 150,
        ')', 149,
        '*', 170,
        ',', 211,
        '?', 221,
        '[', 225,
        '\\', 222,
        '\t', 341,
        ' ', 341,
      );
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(117);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(336);
      END_STATE();
    case 43:
      ADVANCE_MAP(
        '%', 308,
        '.', 45,
        'X', 330,
        '\\', 119,
        'm', 324,
        's', 305,
        'x', 327,
        'y', 328,
        'H', 329,
        'h', 329,
        'n', 325,
        'u', 325,
        'G', 326,
        'K', 326,
        'M', 326,
        'g', 326,
        'k', 326,
      );
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(44);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(331);
      END_STATE();
    case 44:
      ADVANCE_MAP(
        '%', 308,
        '.', 45,
        '\\', 119,
        'm', 324,
        's', 305,
        'H', 329,
        'h', 329,
        'n', 325,
        'u', 325,
        'G', 326,
        'K', 326,
        'M', 326,
        'g', 326,
        'k', 326,
      );
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(44);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(331);
      END_STATE();
    case 45:
      ADVANCE_MAP(
        '%', 308,
        'm', 102,
        's', 304,
        'H', 116,
        'h', 116,
        'n', 103,
        'u', 103,
        'G', 109,
        'K', 109,
        'M', 109,
        'g', 109,
        'k', 109,
      );
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(269);
      END_STATE();
    case 46:
      ADVANCE_MAP(
        '%', 177,
        '&', 64,
        '(', 147,
        ')', 149,
        '*', 65,
        '+', 66,
        ',', 211,
        '-', 67,
        '.', 51,
        '/', 175,
        '<', 61,
        '=', 154,
        '>', 72,
        '\\', 19,
        ']', 226,
        '^', 68,
        '|', 69,
        '\t', 341,
        ' ', 341,
      );
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(117);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(336);
      END_STATE();
    case 47:
      if (lookahead == '%') ADVANCE(113);
      if (lookahead == '&') ADVANCE(200);
      if (lookahead == '/') ADVANCE(172);
      if (lookahead == '\\') ADVANCE(19);
      if (lookahead == '\t' ||
          lookahead == ' ') ADVANCE(341);
      END_STATE();
    case 48:
      ADVANCE_MAP(
        '&', 201,
        '(', 147,
        ')', 149,
        ':', 54,
        '=', 154,
        'B', 321,
        '\\', 20,
        '\t', 341,
        ' ', 341,
        'V', 318,
        'v', 318,
      );
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(117);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(336);
      END_STATE();
    case 49:
      if (lookahead == '(') ADVANCE(147);
      if (lookahead == '/') ADVANCE(52);
      if (lookahead == ';') ADVANCE(21);
      if (lookahead == '\\') ADVANCE(19);
      if (lookahead == '\t' ||
          lookahead == ' ') ADVANCE(346);
      END_STATE();
    case 50:
      if (lookahead == ',') ADVANCE(256);
      if (lookahead == ';') ADVANCE(258);
      if (lookahead == '\t' ||
          lookahead == ' ') ADVANCE(50);
      END_STATE();
    case 51:
      if (lookahead == '.') ADVANCE(198);
      END_STATE();
    case 52:
      if (lookahead == '/') ADVANCE(21);
      END_STATE();
    case 53:
      if (lookahead == '/') ADVANCE(52);
      if (lookahead == ';') ADVANCE(21);
      if (lookahead == '\t' ||
          lookahead == ' ') ADVANCE(53);
      END_STATE();
    case 54:
      if (lookahead == ':') ADVANCE(73);
      END_STATE();
    case 55:
      if (lookahead == ':') ADVANCE(206);
      END_STATE();
    case 56:
      if (lookahead == ':') ADVANCE(133);
      END_STATE();
    case 57:
      if (lookahead == ':') ADVANCE(136);
      END_STATE();
    case 58:
      if (lookahead == ':') ADVANCE(55);
      END_STATE();
    case 59:
      if (lookahead == ':') ADVANCE(135);
      END_STATE();
    case 60:
      if (lookahead == ':') ADVANCE(59);
      if (lookahead == '\\') ADVANCE(100);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(60);
      END_STATE();
    case 61:
      if (lookahead == '<') ADVANCE(70);
      END_STATE();
    case 62:
      if (lookahead == '=') ADVANCE(185);
      END_STATE();
    case 63:
      if (lookahead == '=') ADVANCE(184);
      END_STATE();
    case 64:
      if (lookahead == '=') ADVANCE(234);
      END_STATE();
    case 65:
      if (lookahead == '=') ADVANCE(227);
      END_STATE();
    case 66:
      if (lookahead == '=') ADVANCE(230);
      END_STATE();
    case 67:
      if (lookahead == '=') ADVANCE(231);
      END_STATE();
    case 68:
      if (lookahead == '=') ADVANCE(235);
      END_STATE();
    case 69:
      if (lookahead == '=') ADVANCE(236);
      END_STATE();
    case 70:
      if (lookahead == '=') ADVANCE(232);
      END_STATE();
    case 71:
      if (lookahead == '=') ADVANCE(233);
      END_STATE();
    case 72:
      if (lookahead == '>') ADVANCE(71);
      END_STATE();
    case 73:
      if (lookahead == 'B') ADVANCE(58);
      END_STATE();
    case 74:
      if (lookahead == '\\') ADVANCE(101);
      if (lookahead == '`') ADVANCE(141);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('_' <= lookahead && lookahead <= 'z')) ADVANCE(282);
      END_STATE();
    case 75:
      if (lookahead == '\\') ADVANCE(298);
      END_STATE();
    case 76:
      if (lookahead == '\\') ADVANCE(298);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(76);
      END_STATE();
    case 77:
      if (lookahead == '\\') ADVANCE(280);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(279);
      END_STATE();
    case 78:
      if (lookahead == '\\') ADVANCE(245);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '\'') ADVANCE(242);
      END_STATE();
    case 79:
      if (lookahead == '\\') ADVANCE(119);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(79);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(331);
      END_STATE();
    case 80:
      if (lookahead == '\\') ADVANCE(92);
      END_STATE();
    case 81:
      if (lookahead == '\\') ADVANCE(92);
      if (lookahead == '`') ADVANCE(139);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('_' <= lookahead && lookahead <= 'z')) ADVANCE(82);
      END_STATE();
    case 82:
      if (lookahead == '\\') ADVANCE(92);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(82);
      END_STATE();
    case 83:
      if (lookahead == '\\') ADVANCE(81);
      if (lookahead == '`') ADVANCE(138);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('_' <= lookahead && lookahead <= 'z')) ADVANCE(76);
      END_STATE();
    case 84:
      if (lookahead == '\\') ADVANCE(100);
      END_STATE();
    case 85:
      if (lookahead == '\\') ADVANCE(100);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(85);
      END_STATE();
    case 86:
      if (lookahead == '\\') ADVANCE(121);
      if (lookahead == '`') ADVANCE(137);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(284);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('_' <= lookahead && lookahead <= 'z')) ADVANCE(283);
      END_STATE();
    case 87:
      if (lookahead == '\\') ADVANCE(121);
      if (lookahead == '`') ADVANCE(137);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(294);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('_' <= lookahead && lookahead <= 'z')) ADVANCE(288);
      END_STATE();
    case 88:
      if (lookahead == '\\') ADVANCE(121);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(295);
      END_STATE();
    case 89:
      if (lookahead == '\\') ADVANCE(122);
      if (lookahead == '`') ADVANCE(140);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(301);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('_' <= lookahead && lookahead <= 'z')) ADVANCE(85);
      END_STATE();
    case 90:
      if (lookahead == '`') ADVANCE(137);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(284);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('_' <= lookahead && lookahead <= 'z')) ADVANCE(283);
      END_STATE();
    case 91:
      if (lookahead == '`') ADVANCE(137);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(294);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('_' <= lookahead && lookahead <= 'z')) ADVANCE(288);
      END_STATE();
    case 92:
      if (lookahead == '`') ADVANCE(137);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('_' <= lookahead && lookahead <= 'z')) ADVANCE(283);
      END_STATE();
    case 93:
      if (lookahead == '`') ADVANCE(287);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(93);
      END_STATE();
    case 94:
      if (lookahead == '`') ADVANCE(75);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(94);
      END_STATE();
    case 95:
      if (lookahead == '`') ADVANCE(286);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(95);
      END_STATE();
    case 96:
      if (lookahead == '`') ADVANCE(80);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(96);
      END_STATE();
    case 97:
      if (lookahead == '`') ADVANCE(289);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(97);
      END_STATE();
    case 98:
      if (lookahead == '`') ADVANCE(84);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(98);
      END_STATE();
    case 99:
      if (lookahead == '`') ADVANCE(292);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(99);
      END_STATE();
    case 100:
      if (lookahead == '`') ADVANCE(140);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(301);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('_' <= lookahead && lookahead <= 'z')) ADVANCE(85);
      END_STATE();
    case 101:
      if (lookahead == '`') ADVANCE(142);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('_' <= lookahead && lookahead <= 'z')) ADVANCE(290);
      END_STATE();
    case 102:
      ADVANCE_MAP(
        'm', 102,
        's', 304,
        'H', 116,
        'h', 116,
        'n', 103,
        'u', 103,
        'G', 109,
        'K', 109,
        'M', 109,
        'g', 109,
        'k', 109,
      );
      END_STATE();
    case 103:
      if (lookahead == 's') ADVANCE(304);
      if (lookahead == 'm' ||
          lookahead == 'n' ||
          lookahead == 'u') ADVANCE(103);
      END_STATE();
    case 104:
      if (lookahead == 'y') ADVANCE(123);
      if (lookahead == 'X' ||
          lookahead == 'x') ADVANCE(124);
      END_STATE();
    case 105:
      if (lookahead == '+' ||
          lookahead == '-') ADVANCE(120);
      END_STATE();
    case 106:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(153);
      END_STATE();
    case 107:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(208);
      END_STATE();
    case 108:
      if (lookahead == 'H' ||
          lookahead == 'h') ADVANCE(110);
      END_STATE();
    case 109:
      ADVANCE_MAP(
        'H', 116,
        'h', 116,
        'G', 109,
        'K', 109,
        'M', 109,
        'g', 109,
        'k', 109,
        'm', 109,
      );
      END_STATE();
    case 110:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(112);
      END_STATE();
    case 111:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(114);
      END_STATE();
    case 112:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(106);
      END_STATE();
    case 113:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(111);
      END_STATE();
    case 114:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(107);
      END_STATE();
    case 115:
      if (lookahead == 'W' ||
          lookahead == 'w') ADVANCE(108);
      END_STATE();
    case 116:
      if (lookahead == 'Z' ||
          lookahead == 'z') ADVANCE(306);
      END_STATE();
    case 117:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(117);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(336);
      END_STATE();
    case 118:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(309);
      END_STATE();
    case 119:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(285);
      END_STATE();
    case 120:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(270);
      END_STATE();
    case 121:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(296);
      END_STATE();
    case 122:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(302);
      END_STATE();
    case 123:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(265);
      END_STATE();
    case 124:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(268);
      END_STATE();
    case 125:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(253);
      END_STATE();
    case 126:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(125);
      END_STATE();
    case 127:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(126);
      END_STATE();
    case 128:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(127);
      END_STATE();
    case 129:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(128);
      END_STATE();
    case 130:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(129);
      END_STATE();
    case 131:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(130);
      END_STATE();
    case 132:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(131);
      END_STATE();
    case 133:
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(281);
      END_STATE();
    case 134:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(303);
      END_STATE();
    case 135:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(60);
      END_STATE();
    case 136:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(283);
      END_STATE();
    case 137:
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '`') ADVANCE(93);
      END_STATE();
    case 138:
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '`') ADVANCE(94);
      END_STATE();
    case 139:
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '`') ADVANCE(96);
      END_STATE();
    case 140:
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '`') ADVANCE(98);
      END_STATE();
    case 141:
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '`') ADVANCE(95);
      END_STATE();
    case 142:
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '`') ADVANCE(97);
      END_STATE();
    case 143:
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '`') ADVANCE(99);
      END_STATE();
    case 144:
      if (eof) ADVANCE(145);
      ADVANCE_MAP(
        '\n', 339,
        '\r', 1,
        '"', 250,
        '%', 176,
        '&', 201,
        '\'', 241,
        '(', 147,
        ')', 149,
        ',', 211,
        '.', 209,
        '/', 173,
        ':', 54,
        ';', 21,
        '=', 154,
        'B', 321,
        '\\', 19,
        ']', 226,
        '}', 152,
        '\t', 344,
        ' ', 344,
        'V', 318,
        'v', 318,
      );
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(117);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(336);
      END_STATE();
    case 145:
      ACCEPT_TOKEN(ts_builtin_sym_end);
      END_STATE();
    case 146:
      ACCEPT_TOKEN(aux_sym_block_token1);
      END_STATE();
    case 147:
      ACCEPT_TOKEN(aux_sym_block_token1);
      if (lookahead == '&') ADVANCE(148);
      END_STATE();
    case 148:
      ACCEPT_TOKEN(aux_sym_block_token1);
      if (lookahead == '+' ||
          lookahead == '-') ADVANCE(146);
      END_STATE();
    case 149:
      ACCEPT_TOKEN(anon_sym_RPAREN);
      END_STATE();
    case 150:
      ACCEPT_TOKEN(anon_sym_LPAREN);
      END_STATE();
    case 151:
      ACCEPT_TOKEN(anon_sym_LBRACE);
      END_STATE();
    case 152:
      ACCEPT_TOKEN(anon_sym_RBRACE);
      END_STATE();
    case 153:
      ACCEPT_TOKEN(aux_sym_while_block_token2);
      END_STATE();
    case 154:
      ACCEPT_TOKEN(anon_sym_EQ);
      END_STATE();
    case 155:
      ACCEPT_TOKEN(anon_sym_EQ);
      if (lookahead == '=') ADVANCE(184);
      END_STATE();
    case 156:
      ACCEPT_TOKEN(anon_sym_PLUS);
      END_STATE();
    case 157:
      ACCEPT_TOKEN(anon_sym_PLUS);
      if (lookahead == '+') ADVANCE(166);
      END_STATE();
    case 158:
      ACCEPT_TOKEN(anon_sym_PLUS);
      if (lookahead == '+') ADVANCE(166);
      if (lookahead == '=') ADVANCE(230);
      END_STATE();
    case 159:
      ACCEPT_TOKEN(anon_sym_DASH);
      END_STATE();
    case 160:
      ACCEPT_TOKEN(anon_sym_DASH);
      if (lookahead == '-') ADVANCE(167);
      END_STATE();
    case 161:
      ACCEPT_TOKEN(anon_sym_DASH);
      if (lookahead == '-') ADVANCE(167);
      if (lookahead == '=') ADVANCE(231);
      if (lookahead == '>') ADVANCE(224);
      END_STATE();
    case 162:
      ACCEPT_TOKEN(anon_sym_DASH);
      if (lookahead == '-') ADVANCE(167);
      if (lookahead == '>') ADVANCE(224);
      END_STATE();
    case 163:
      ACCEPT_TOKEN(anon_sym_TILDE);
      END_STATE();
    case 164:
      ACCEPT_TOKEN(anon_sym_BANG);
      END_STATE();
    case 165:
      ACCEPT_TOKEN(anon_sym_BANG);
      if (lookahead == '=') ADVANCE(185);
      END_STATE();
    case 166:
      ACCEPT_TOKEN(anon_sym_PLUS_PLUS);
      END_STATE();
    case 167:
      ACCEPT_TOKEN(anon_sym_DASH_DASH);
      END_STATE();
    case 168:
      ACCEPT_TOKEN(anon_sym_CARET_CARET);
      END_STATE();
    case 169:
      ACCEPT_TOKEN(anon_sym_PIPE_PIPE);
      END_STATE();
    case 170:
      ACCEPT_TOKEN(anon_sym_STAR);
      END_STATE();
    case 171:
      ACCEPT_TOKEN(anon_sym_STAR);
      if (lookahead == '=') ADVANCE(227);
      END_STATE();
    case 172:
      ACCEPT_TOKEN(anon_sym_SLASH);
      END_STATE();
    case 173:
      ACCEPT_TOKEN(anon_sym_SLASH);
      if (lookahead == '/') ADVANCE(21);
      END_STATE();
    case 174:
      ACCEPT_TOKEN(anon_sym_SLASH);
      if (lookahead == '/') ADVANCE(21);
      if (lookahead == '=') ADVANCE(228);
      END_STATE();
    case 175:
      ACCEPT_TOKEN(anon_sym_SLASH);
      if (lookahead == '=') ADVANCE(228);
      END_STATE();
    case 176:
      ACCEPT_TOKEN(anon_sym_PERCENT);
      END_STATE();
    case 177:
      ACCEPT_TOKEN(anon_sym_PERCENT);
      if (lookahead == '=') ADVANCE(229);
      END_STATE();
    case 178:
      ACCEPT_TOKEN(anon_sym_PIPE);
      END_STATE();
    case 179:
      ACCEPT_TOKEN(anon_sym_PIPE);
      if (lookahead == '=') ADVANCE(236);
      if (lookahead == '|') ADVANCE(169);
      END_STATE();
    case 180:
      ACCEPT_TOKEN(anon_sym_PIPE);
      if (lookahead == '|') ADVANCE(169);
      END_STATE();
    case 181:
      ACCEPT_TOKEN(anon_sym_CARET);
      END_STATE();
    case 182:
      ACCEPT_TOKEN(anon_sym_CARET);
      if (lookahead == '=') ADVANCE(235);
      END_STATE();
    case 183:
      ACCEPT_TOKEN(anon_sym_CARET);
      if (lookahead == '^') ADVANCE(168);
      END_STATE();
    case 184:
      ACCEPT_TOKEN(anon_sym_EQ_EQ);
      END_STATE();
    case 185:
      ACCEPT_TOKEN(anon_sym_BANG_EQ);
      END_STATE();
    case 186:
      ACCEPT_TOKEN(anon_sym_GT);
      END_STATE();
    case 187:
      ACCEPT_TOKEN(anon_sym_GT);
      if (lookahead == '=') ADVANCE(189);
      if (lookahead == '>') ADVANCE(196);
      END_STATE();
    case 188:
      ACCEPT_TOKEN(anon_sym_GT);
      if (lookahead == '=') ADVANCE(189);
      if (lookahead == '>') ADVANCE(197);
      END_STATE();
    case 189:
      ACCEPT_TOKEN(anon_sym_GT_EQ);
      END_STATE();
    case 190:
      ACCEPT_TOKEN(anon_sym_LT_EQ);
      END_STATE();
    case 191:
      ACCEPT_TOKEN(anon_sym_LT);
      END_STATE();
    case 192:
      ACCEPT_TOKEN(anon_sym_LT);
      if (lookahead == '<') ADVANCE(194);
      if (lookahead == '=') ADVANCE(190);
      END_STATE();
    case 193:
      ACCEPT_TOKEN(anon_sym_LT);
      if (lookahead == '<') ADVANCE(195);
      if (lookahead == '=') ADVANCE(190);
      END_STATE();
    case 194:
      ACCEPT_TOKEN(anon_sym_LT_LT);
      END_STATE();
    case 195:
      ACCEPT_TOKEN(anon_sym_LT_LT);
      if (lookahead == '=') ADVANCE(232);
      END_STATE();
    case 196:
      ACCEPT_TOKEN(anon_sym_GT_GT);
      END_STATE();
    case 197:
      ACCEPT_TOKEN(anon_sym_GT_GT);
      if (lookahead == '=') ADVANCE(233);
      END_STATE();
    case 198:
      ACCEPT_TOKEN(anon_sym_DOT_DOT);
      END_STATE();
    case 199:
      ACCEPT_TOKEN(anon_sym_AMP_AMP);
      END_STATE();
    case 200:
      ACCEPT_TOKEN(anon_sym_AMP);
      END_STATE();
    case 201:
      ACCEPT_TOKEN(anon_sym_AMP);
      if (lookahead == '&') ADVANCE(199);
      END_STATE();
    case 202:
      ACCEPT_TOKEN(anon_sym_AMP);
      if (lookahead == '&') ADVANCE(199);
      if (lookahead == '=') ADVANCE(234);
      END_STATE();
    case 203:
      ACCEPT_TOKEN(anon_sym_COLON);
      END_STATE();
    case 204:
      ACCEPT_TOKEN(anon_sym_COLON);
      if (lookahead == ':') ADVANCE(260);
      END_STATE();
    case 205:
      ACCEPT_TOKEN(anon_sym_COLON);
      if (lookahead == ':') ADVANCE(261);
      END_STATE();
    case 206:
      ACCEPT_TOKEN(aux_sym_macro_definition_token1);
      END_STATE();
    case 207:
      ACCEPT_TOKEN(aux_sym_macro_definition_token1);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(281);
      END_STATE();
    case 208:
      ACCEPT_TOKEN(aux_sym_parameter_declaration_token4);
      END_STATE();
    case 209:
      ACCEPT_TOKEN(anon_sym_DOT);
      END_STATE();
    case 210:
      ACCEPT_TOKEN(anon_sym_DOT);
      if (lookahead == '.') ADVANCE(198);
      END_STATE();
    case 211:
      ACCEPT_TOKEN(anon_sym_COMMA);
      END_STATE();
    case 212:
      ACCEPT_TOKEN(aux_sym__host_command_argument_list_default_format_token1);
      END_STATE();
    case 213:
      ACCEPT_TOKEN(aux_sym__host_command_argument_list_default_format_token1);
      if (lookahead == '\n') ADVANCE(340);
      if (lookahead == '\r') ADVANCE(18);
      END_STATE();
    case 214:
      ACCEPT_TOKEN(aux_sym__host_command_argument_list_default_format_token1);
      if (lookahead == '\n') ADVANCE(337);
      if (lookahead == '\\') ADVANCE(22);
      if (lookahead != 0) ADVANCE(21);
      END_STATE();
    case 215:
      ACCEPT_TOKEN(aux_sym__host_command_argument_list_default_format_token1);
      if (lookahead == '/') ADVANCE(21);
      END_STATE();
    case 216:
      ACCEPT_TOKEN(aux_sym__host_command_argument_list_default_format_token1);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(117);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(336);
      END_STATE();
    case 217:
      ACCEPT_TOKEN(aux_sym__host_command_argument_list_default_format_token1);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(336);
      END_STATE();
    case 218:
      ACCEPT_TOKEN(aux_sym__hll_var_definition_command_token1);
      if (lookahead == '\t' ||
          lookahead == ' ') ADVANCE(218);
      END_STATE();
    case 219:
      ACCEPT_TOKEN(aux_sym__var_command_with_non_hll_format_token1);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(333);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(336);
      END_STATE();
    case 220:
      ACCEPT_TOKEN(aux_sym__var_command_with_non_hll_format_token1);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(336);
      END_STATE();
    case 221:
      ACCEPT_TOKEN(anon_sym_QMARK);
      END_STATE();
    case 222:
      ACCEPT_TOKEN(anon_sym_BSLASH);
      if (lookahead == '\n') ADVANCE(340);
      if (lookahead == '\r') ADVANCE(18);
      END_STATE();
    case 223:
      ACCEPT_TOKEN(anon_sym_BSLASH);
      if (lookahead == '\n') ADVANCE(340);
      if (lookahead == '\r') ADVANCE(18);
      if (lookahead == '\\') ADVANCE(74);
      if (lookahead == '`') ADVANCE(143);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('_' <= lookahead && lookahead <= 'z')) ADVANCE(82);
      END_STATE();
    case 224:
      ACCEPT_TOKEN(anon_sym_DASH_GT);
      END_STATE();
    case 225:
      ACCEPT_TOKEN(anon_sym_LBRACK);
      END_STATE();
    case 226:
      ACCEPT_TOKEN(anon_sym_RBRACK);
      END_STATE();
    case 227:
      ACCEPT_TOKEN(anon_sym_STAR_EQ);
      END_STATE();
    case 228:
      ACCEPT_TOKEN(anon_sym_SLASH_EQ);
      END_STATE();
    case 229:
      ACCEPT_TOKEN(anon_sym_PERCENT_EQ);
      END_STATE();
    case 230:
      ACCEPT_TOKEN(anon_sym_PLUS_EQ);
      END_STATE();
    case 231:
      ACCEPT_TOKEN(anon_sym_DASH_EQ);
      END_STATE();
    case 232:
      ACCEPT_TOKEN(anon_sym_LT_LT_EQ);
      END_STATE();
    case 233:
      ACCEPT_TOKEN(anon_sym_GT_GT_EQ);
      END_STATE();
    case 234:
      ACCEPT_TOKEN(anon_sym_AMP_EQ);
      END_STATE();
    case 235:
      ACCEPT_TOKEN(anon_sym_CARET_EQ);
      END_STATE();
    case 236:
      ACCEPT_TOKEN(anon_sym_PIPE_EQ);
      END_STATE();
    case 237:
      ACCEPT_TOKEN(anon_sym_L_SQUOTE);
      END_STATE();
    case 238:
      ACCEPT_TOKEN(anon_sym_u_SQUOTE);
      END_STATE();
    case 239:
      ACCEPT_TOKEN(anon_sym_U_SQUOTE);
      END_STATE();
    case 240:
      ACCEPT_TOKEN(anon_sym_u8_SQUOTE);
      END_STATE();
    case 241:
      ACCEPT_TOKEN(anon_sym_SQUOTE);
      END_STATE();
    case 242:
      ACCEPT_TOKEN(aux_sym_hll_char_literal_token1);
      END_STATE();
    case 243:
      ACCEPT_TOKEN(aux_sym_hll_char_literal_token1);
      if (lookahead == '\n') ADVANCE(339);
      END_STATE();
    case 244:
      ACCEPT_TOKEN(aux_sym_hll_char_literal_token1);
      if (lookahead == '\n') ADVANCE(339);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '\t' ||
          lookahead == ' ') ADVANCE(17);
      END_STATE();
    case 245:
      ACCEPT_TOKEN(aux_sym_hll_char_literal_token1);
      if (lookahead == '\n') ADVANCE(253);
      if (lookahead == '\r') ADVANCE(253);
      if (lookahead == 'U') ADVANCE(132);
      if (lookahead == 'u') ADVANCE(128);
      if (lookahead == 'x') ADVANCE(126);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(255);
      if (lookahead != 0) ADVANCE(253);
      END_STATE();
    case 246:
      ACCEPT_TOKEN(anon_sym_L_DQUOTE);
      END_STATE();
    case 247:
      ACCEPT_TOKEN(anon_sym_u_DQUOTE);
      END_STATE();
    case 248:
      ACCEPT_TOKEN(anon_sym_U_DQUOTE);
      END_STATE();
    case 249:
      ACCEPT_TOKEN(anon_sym_u8_DQUOTE);
      END_STATE();
    case 250:
      ACCEPT_TOKEN(anon_sym_DQUOTE);
      END_STATE();
    case 251:
      ACCEPT_TOKEN(anon_sym_DQUOTE);
      if (lookahead == '"') ADVANCE(276);
      END_STATE();
    case 252:
      ACCEPT_TOKEN(aux_sym_hll_string_literal_token1);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '"' &&
          lookahead != '\\') ADVANCE(252);
      END_STATE();
    case 253:
      ACCEPT_TOKEN(sym_hll_escape_sequence);
      END_STATE();
    case 254:
      ACCEPT_TOKEN(sym_hll_escape_sequence);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(253);
      END_STATE();
    case 255:
      ACCEPT_TOKEN(sym_hll_escape_sequence);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(254);
      END_STATE();
    case 256:
      ACCEPT_TOKEN(aux_sym__hll_expression_separator_token1);
      if (lookahead == '\t' ||
          lookahead == ' ') ADVANCE(256);
      END_STATE();
    case 257:
      ACCEPT_TOKEN(aux_sym__hll_expression_separator_token2);
      if (lookahead == '\n') ADVANCE(337);
      if (lookahead == '\\') ADVANCE(22);
      if (lookahead == '\t' ||
          lookahead == ' ') ADVANCE(257);
      if (lookahead != 0) ADVANCE(21);
      END_STATE();
    case 258:
      ACCEPT_TOKEN(aux_sym__hll_expression_separator_token2);
      if (lookahead == '\t' ||
          lookahead == ' ') ADVANCE(258);
      END_STATE();
    case 259:
      ACCEPT_TOKEN(anon_sym_COLON_COLON_COLON);
      END_STATE();
    case 260:
      ACCEPT_TOKEN(anon_sym_COLON_COLON);
      if (lookahead == ':') ADVANCE(259);
      END_STATE();
    case 261:
      ACCEPT_TOKEN(anon_sym_COLON_COLON);
      if (lookahead == ':') ADVANCE(259);
      if (lookahead == 'B') ADVANCE(58);
      END_STATE();
    case 262:
      ACCEPT_TOKEN(sym_access_class);
      if (lookahead == ':') ADVANCE(207);
      END_STATE();
    case 263:
      ACCEPT_TOKEN(sym_access_class);
      if (lookahead == ':') ADVANCE(133);
      END_STATE();
    case 264:
      ACCEPT_TOKEN(aux_sym_integer_token1);
      if (lookahead == '\\') ADVANCE(119);
      if (lookahead == 'X' ||
          lookahead == 'x') ADVANCE(271);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(264);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(331);
      END_STATE();
    case 265:
      ACCEPT_TOKEN(aux_sym_integer_token1);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(265);
      END_STATE();
    case 266:
      ACCEPT_TOKEN(aux_sym_integer_token2);
      if (lookahead == '\\') ADVANCE(119);
      if (lookahead == 'X' ||
          lookahead == 'x') ADVANCE(272);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(266);
      if (('G' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('g' <= lookahead && lookahead <= 'z')) ADVANCE(331);
      END_STATE();
    case 267:
      ACCEPT_TOKEN(aux_sym_integer_token2);
      if (lookahead == '\\') ADVANCE(119);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(267);
      if (('G' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('g' <= lookahead && lookahead <= 'z')) ADVANCE(331);
      END_STATE();
    case 268:
      ACCEPT_TOKEN(aux_sym_integer_token2);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(268);
      END_STATE();
    case 269:
      ACCEPT_TOKEN(sym_float);
      ADVANCE_MAP(
        '%', 308,
        'e', 105,
        'm', 102,
        's', 304,
        'H', 116,
        'h', 116,
        'n', 103,
        'u', 103,
        'G', 109,
        'K', 109,
        'M', 109,
        'g', 109,
        'k', 109,
      );
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(269);
      END_STATE();
    case 270:
      ACCEPT_TOKEN(sym_float);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(270);
      END_STATE();
    case 271:
      ACCEPT_TOKEN(aux_sym_bitmask_token1);
      if (lookahead == '\\') ADVANCE(119);
      if (('0' <= lookahead && lookahead <= '9') ||
          lookahead == 'X' ||
          lookahead == 'x') ADVANCE(271);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(331);
      END_STATE();
    case 272:
      ACCEPT_TOKEN(aux_sym_bitmask_token2);
      if (lookahead == '\\') ADVANCE(119);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          lookahead == 'X' ||
          ('a' <= lookahead && lookahead <= 'f') ||
          lookahead == 'x') ADVANCE(272);
      if (('G' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('g' <= lookahead && lookahead <= 'z')) ADVANCE(331);
      END_STATE();
    case 273:
      ACCEPT_TOKEN(aux_sym_string_token1);
      if (lookahead == '\n') ADVANCE(275);
      if (lookahead == '\r') ADVANCE(274);
      if (lookahead != 0 &&
          lookahead != '"' &&
          lookahead != '&') ADVANCE(275);
      END_STATE();
    case 274:
      ACCEPT_TOKEN(aux_sym_string_token1);
      if (lookahead == '\n') ADVANCE(275);
      if (lookahead != 0 &&
          lookahead != '"' &&
          lookahead != '&') ADVANCE(275);
      END_STATE();
    case 275:
      ACCEPT_TOKEN(aux_sym_string_token1);
      if (lookahead != 0 &&
          lookahead != '"' &&
          lookahead != '&') ADVANCE(275);
      END_STATE();
    case 276:
      ACCEPT_TOKEN(aux_sym_string_token2);
      END_STATE();
    case 277:
      ACCEPT_TOKEN(aux_sym_character_token1);
      END_STATE();
    case 278:
      ACCEPT_TOKEN(aux_sym_character_token1);
      if (lookahead == '\n') ADVANCE(340);
      END_STATE();
    case 279:
      ACCEPT_TOKEN(aux_sym_character_token2);
      END_STATE();
    case 280:
      ACCEPT_TOKEN(aux_sym_character_token2);
      if (lookahead == '\n') ADVANCE(340);
      if (lookahead == '\r') ADVANCE(278);
      if (lookahead != 0 &&
          lookahead != '\'') ADVANCE(277);
      END_STATE();
    case 281:
      ACCEPT_TOKEN(aux_sym_symbol_token1);
      if (lookahead == ':') ADVANCE(56);
      if (lookahead == '\\') ADVANCE(91);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(281);
      END_STATE();
    case 282:
      ACCEPT_TOKEN(aux_sym_symbol_token1);
      if (lookahead == ':') ADVANCE(57);
      if (lookahead == '\\') ADVANCE(299);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(282);
      END_STATE();
    case 283:
      ACCEPT_TOKEN(aux_sym_symbol_token1);
      if (lookahead == ':') ADVANCE(57);
      if (lookahead == '\\') ADVANCE(91);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(283);
      END_STATE();
    case 284:
      ACCEPT_TOKEN(aux_sym_symbol_token1);
      if (lookahead == ':') ADVANCE(57);
      if (lookahead == '\\') ADVANCE(87);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(284);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(283);
      END_STATE();
    case 285:
      ACCEPT_TOKEN(aux_sym_symbol_token1);
      if (lookahead == '\\') ADVANCE(88);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(285);
      END_STATE();
    case 286:
      ACCEPT_TOKEN(aux_sym_symbol_token1);
      if (lookahead == '\\') ADVANCE(299);
      END_STATE();
    case 287:
      ACCEPT_TOKEN(aux_sym_symbol_token1);
      if (lookahead == '\\') ADVANCE(91);
      END_STATE();
    case 288:
      ACCEPT_TOKEN(aux_sym_symbol_token1);
      if (lookahead == '\\') ADVANCE(91);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(288);
      END_STATE();
    case 289:
      ACCEPT_TOKEN(aux_sym_symbol_token1);
      if (lookahead == '\\') ADVANCE(297);
      END_STATE();
    case 290:
      ACCEPT_TOKEN(aux_sym_symbol_token1);
      if (lookahead == '\\') ADVANCE(297);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(290);
      END_STATE();
    case 291:
      ACCEPT_TOKEN(aux_sym_symbol_token1);
      if (lookahead == '\\') ADVANCE(86);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(291);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(293);
      END_STATE();
    case 292:
      ACCEPT_TOKEN(aux_sym_symbol_token1);
      if (lookahead == '\\') ADVANCE(90);
      END_STATE();
    case 293:
      ACCEPT_TOKEN(aux_sym_symbol_token1);
      if (lookahead == '\\') ADVANCE(90);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(293);
      END_STATE();
    case 294:
      ACCEPT_TOKEN(aux_sym_symbol_token1);
      if (lookahead == '\\') ADVANCE(87);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(294);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(288);
      END_STATE();
    case 295:
      ACCEPT_TOKEN(aux_sym_symbol_token1);
      if (lookahead == '\\') ADVANCE(121);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(295);
      END_STATE();
    case 296:
      ACCEPT_TOKEN(aux_sym_symbol_token1);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(296);
      END_STATE();
    case 297:
      ACCEPT_TOKEN(aux_sym_symbol_token2);
      if (lookahead == '\\') ADVANCE(83);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(285);
      END_STATE();
    case 298:
      ACCEPT_TOKEN(aux_sym_symbol_token2);
      if (lookahead == '\\') ADVANCE(92);
      if (lookahead == '`') ADVANCE(139);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('_' <= lookahead && lookahead <= 'z')) ADVANCE(82);
      END_STATE();
    case 299:
      ACCEPT_TOKEN(aux_sym_symbol_token2);
      if (lookahead == '\\') ADVANCE(92);
      if (lookahead == '`') ADVANCE(143);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(291);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('_' <= lookahead && lookahead <= 'z')) ADVANCE(293);
      END_STATE();
    case 300:
      ACCEPT_TOKEN(aux_sym_symbol_token3);
      if (lookahead == ':') ADVANCE(59);
      if (lookahead == '\\') ADVANCE(89);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(300);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(60);
      END_STATE();
    case 301:
      ACCEPT_TOKEN(aux_sym_symbol_token3);
      if (lookahead == '\\') ADVANCE(89);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(301);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(85);
      END_STATE();
    case 302:
      ACCEPT_TOKEN(aux_sym_symbol_token3);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(302);
      END_STATE();
    case 303:
      ACCEPT_TOKEN(sym__composed_name);
      if (lookahead == '-') ADVANCE(134);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(303);
      END_STATE();
    case 304:
      ACCEPT_TOKEN(sym_time);
      END_STATE();
    case 305:
      ACCEPT_TOKEN(sym_time);
      if (lookahead == '\\') ADVANCE(119);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(331);
      END_STATE();
    case 306:
      ACCEPT_TOKEN(sym_frequency);
      END_STATE();
    case 307:
      ACCEPT_TOKEN(sym_frequency);
      if (lookahead == '\\') ADVANCE(119);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(331);
      END_STATE();
    case 308:
      ACCEPT_TOKEN(sym_percentage);
      END_STATE();
    case 309:
      ACCEPT_TOKEN(sym_file_handle);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(309);
      END_STATE();
    case 310:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '"') ADVANCE(246);
      if (lookahead == '\'') ADVANCE(237);
      if (lookahead == ':') ADVANCE(56);
      if (lookahead == '\\') ADVANCE(119);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(323);
      END_STATE();
    case 311:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '"') ADVANCE(248);
      if (lookahead == '\'') ADVANCE(239);
      if (lookahead == ':') ADVANCE(56);
      if (lookahead == '\\') ADVANCE(119);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(323);
      END_STATE();
    case 312:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '"') ADVANCE(247);
      if (lookahead == '\'') ADVANCE(238);
      if (lookahead == '8') ADVANCE(313);
      if (lookahead == ':') ADVANCE(56);
      if (lookahead == '\\') ADVANCE(119);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(323);
      END_STATE();
    case 313:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '"') ADVANCE(249);
      if (lookahead == '\'') ADVANCE(240);
      if (lookahead == ':') ADVANCE(56);
      if (lookahead == '\\') ADVANCE(119);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(323);
      END_STATE();
    case 314:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '-') ADVANCE(134);
      if (lookahead == '.') ADVANCE(115);
      if (lookahead == ':') ADVANCE(263);
      if (lookahead == '\\') ADVANCE(119);
      if (lookahead == '_') ADVANCE(323);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(316);
      END_STATE();
    case 315:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '-') ADVANCE(134);
      if (lookahead == ':') ADVANCE(263);
      if (lookahead == '\\') ADVANCE(119);
      if (lookahead == '_') ADVANCE(323);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(314);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(316);
      END_STATE();
    case 316:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '-') ADVANCE(134);
      if (lookahead == ':') ADVANCE(263);
      if (lookahead == '\\') ADVANCE(119);
      if (lookahead == '_') ADVANCE(323);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(316);
      END_STATE();
    case 317:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '.') ADVANCE(115);
      if (lookahead == ':') ADVANCE(263);
      if (lookahead == '\\') ADVANCE(119);
      if (lookahead == '_') ADVANCE(323);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(315);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('B' <= lookahead && lookahead <= 'Z') ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(316);
      END_STATE();
    case 318:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '.') ADVANCE(115);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(335);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(336);
      END_STATE();
    case 319:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '.') ADVANCE(115);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(336);
      END_STATE();
    case 320:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == ':') ADVANCE(262);
      if (lookahead == '\\') ADVANCE(119);
      if (lookahead == '_') ADVANCE(323);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(316);
      END_STATE();
    case 321:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == ':') ADVANCE(55);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(336);
      END_STATE();
    case 322:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == ':') ADVANCE(263);
      if (lookahead == '\\') ADVANCE(119);
      if (lookahead == '_') ADVANCE(323);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(316);
      END_STATE();
    case 323:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == ':') ADVANCE(56);
      if (lookahead == '\\') ADVANCE(119);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(323);
      END_STATE();
    case 324:
      ACCEPT_TOKEN(sym_identifier);
      ADVANCE_MAP(
        '\\', 119,
        'm', 324,
        's', 305,
        'H', 329,
        'h', 329,
        'n', 325,
        'u', 325,
        'G', 326,
        'K', 326,
        'M', 326,
        'g', 326,
        'k', 326,
      );
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(331);
      END_STATE();
    case 325:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '\\') ADVANCE(119);
      if (lookahead == 's') ADVANCE(305);
      if (lookahead == 'm' ||
          lookahead == 'n' ||
          lookahead == 'u') ADVANCE(325);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(331);
      END_STATE();
    case 326:
      ACCEPT_TOKEN(sym_identifier);
      ADVANCE_MAP(
        '\\', 119,
        'H', 329,
        'h', 329,
        'G', 326,
        'K', 326,
        'M', 326,
        'g', 326,
        'k', 326,
        'm', 326,
      );
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(331);
      END_STATE();
    case 327:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '\\') ADVANCE(119);
      if (lookahead == 'X' ||
          lookahead == 'x') ADVANCE(272);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(266);
      if (('G' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('g' <= lookahead && lookahead <= 'z')) ADVANCE(331);
      END_STATE();
    case 328:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '\\') ADVANCE(119);
      if (lookahead == 'X' ||
          lookahead == 'x') ADVANCE(271);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(264);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(331);
      END_STATE();
    case 329:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '\\') ADVANCE(119);
      if (lookahead == 'Z' ||
          lookahead == 'z') ADVANCE(307);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Y') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'y')) ADVANCE(331);
      END_STATE();
    case 330:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '\\') ADVANCE(119);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(267);
      if (('G' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('g' <= lookahead && lookahead <= 'z')) ADVANCE(331);
      END_STATE();
    case 331:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '\\') ADVANCE(119);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(331);
      END_STATE();
    case 332:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(334);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(336);
      END_STATE();
    case 333:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(332);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(336);
      END_STATE();
    case 334:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(220);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(336);
      END_STATE();
    case 335:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(319);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(336);
      END_STATE();
    case 336:
      ACCEPT_TOKEN(sym_identifier);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(336);
      END_STATE();
    case 337:
      ACCEPT_TOKEN(sym_comment);
      END_STATE();
    case 338:
      ACCEPT_TOKEN(sym_comment);
      if (lookahead == '\n') ADVANCE(337);
      if (lookahead == '\\') ADVANCE(22);
      if (lookahead != 0) ADVANCE(21);
      END_STATE();
    case 339:
      ACCEPT_TOKEN(sym__blank_line);
      END_STATE();
    case 340:
      ACCEPT_TOKEN(sym__line_continuation);
      END_STATE();
    case 341:
      ACCEPT_TOKEN(sym__blank);
      END_STATE();
    case 342:
      ACCEPT_TOKEN(sym__blank);
      if (lookahead == '\n') ADVANCE(339);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == ',') ADVANCE(256);
      if (lookahead == '/') ADVANCE(52);
      if (lookahead == ';') ADVANCE(257);
      if (lookahead == '\t' ||
          lookahead == ' ') ADVANCE(13);
      END_STATE();
    case 343:
      ACCEPT_TOKEN(sym__blank);
      if (lookahead == '\n') ADVANCE(339);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '/') ADVANCE(52);
      if (lookahead == ';') ADVANCE(21);
      if (lookahead == '=') ADVANCE(218);
      if (lookahead == '\t' ||
          lookahead == ' ') ADVANCE(14);
      END_STATE();
    case 344:
      ACCEPT_TOKEN(sym__blank);
      if (lookahead == '\n') ADVANCE(339);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '/') ADVANCE(52);
      if (lookahead == ';') ADVANCE(21);
      if (lookahead == '\t' ||
          lookahead == ' ') ADVANCE(15);
      END_STATE();
    case 345:
      ACCEPT_TOKEN(sym__blank);
      if (lookahead == ',') ADVANCE(256);
      if (lookahead == ';') ADVANCE(258);
      if (lookahead == '\t' ||
          lookahead == ' ') ADVANCE(50);
      END_STATE();
    case 346:
      ACCEPT_TOKEN(sym__blank);
      if (lookahead == '/') ADVANCE(52);
      if (lookahead == ';') ADVANCE(21);
      if (lookahead == '\t' ||
          lookahead == ' ') ADVANCE(53);
      END_STATE();
    default:
      return false;
  }
}

static bool ts_lex_keywords(TSLexer *lexer, TSStateId state) {
  START_LEXER();
  eof = lexer->eof(lexer);
  switch (state) {
    case 0:
      ADVANCE_MAP(
        'E', 1,
        'I', 2,
        'L', 3,
        'S', 4,
        'V', 5,
        'b', 6,
        'c', 7,
        'd', 8,
        'e', 9,
        'f', 10,
        'i', 11,
        'l', 12,
        's', 13,
        'u', 14,
        'v', 15,
        'A', 16,
        'a', 16,
        'G', 17,
        'g', 17,
        'N', 18,
        'n', 18,
        'O', 19,
        'o', 19,
        'P', 20,
        'p', 20,
        'R', 21,
        'r', 21,
        'T', 22,
        't', 22,
        'W', 23,
        'w', 23,
      );
      END_STATE();
    case 1:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(24);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(25);
      if (lookahead == 'X' ||
          lookahead == 'x') ADVANCE(26);
      END_STATE();
    case 2:
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(27);
      END_STATE();
    case 3:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(28);
      END_STATE();
    case 4:
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(29);
      END_STATE();
    case 5:
      ACCEPT_TOKEN(aux_sym__hll_non_default_format_var_command_token1);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(30);
      END_STATE();
    case 6:
      if (lookahead == 'o') ADVANCE(31);
      END_STATE();
    case 7:
      if (lookahead == 'h') ADVANCE(32);
      if (lookahead == 'o') ADVANCE(33);
      END_STATE();
    case 8:
      if (lookahead == 'o') ADVANCE(34);
      END_STATE();
    case 9:
      if (lookahead == 'N') ADVANCE(25);
      if (lookahead == 'n') ADVANCE(35);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(24);
      if (lookahead == 'X' ||
          lookahead == 'x') ADVANCE(26);
      END_STATE();
    case 10:
      if (lookahead == 'l') ADVANCE(36);
      END_STATE();
    case 11:
      if (lookahead == 'n') ADVANCE(37);
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(27);
      END_STATE();
    case 12:
      if (lookahead == 'O') ADVANCE(28);
      if (lookahead == 'o') ADVANCE(38);
      END_STATE();
    case 13:
      if (lookahead == 'h') ADVANCE(39);
      if (lookahead == 'i') ADVANCE(40);
      if (lookahead == 's') ADVANCE(41);
      if (lookahead == 't') ADVANCE(42);
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(29);
      END_STATE();
    case 14:
      if (lookahead == 'i') ADVANCE(43);
      if (lookahead == 'n') ADVANCE(44);
      END_STATE();
    case 15:
      ACCEPT_TOKEN(aux_sym__hll_non_default_format_var_command_token1);
      if (lookahead == 'o') ADVANCE(45);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(30);
      END_STATE();
    case 16:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(46);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(47);
      END_STATE();
    case 17:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(48);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(49);
      END_STATE();
    case 18:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(50);
      END_STATE();
    case 19:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(51);
      END_STATE();
    case 20:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(52);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(53);
      END_STATE();
    case 21:
      ACCEPT_TOKEN(aux_sym__var_command_with_non_hll_format_token2);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(54);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(55);
      END_STATE();
    case 22:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(56);
      END_STATE();
    case 23:
      if (lookahead == 'H' ||
          lookahead == 'h') ADVANCE(57);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(58);
      END_STATE();
    case 24:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(59);
      END_STATE();
    case 25:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(60);
      END_STATE();
    case 26:
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(61);
      END_STATE();
    case 27:
      ACCEPT_TOKEN(aux_sym_if_block_token1);
      END_STATE();
    case 28:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(62);
      END_STATE();
    case 29:
      if (lookahead == 'B' ||
          lookahead == 'b') ADVANCE(63);
      END_STATE();
    case 30:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(64);
      END_STATE();
    case 31:
      if (lookahead == 'o') ADVANCE(65);
      END_STATE();
    case 32:
      if (lookahead == 'a') ADVANCE(66);
      END_STATE();
    case 33:
      if (lookahead == 'n') ADVANCE(67);
      END_STATE();
    case 34:
      if (lookahead == 'u') ADVANCE(68);
      END_STATE();
    case 35:
      if (lookahead == 'u') ADVANCE(69);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(60);
      END_STATE();
    case 36:
      if (lookahead == 'o') ADVANCE(70);
      END_STATE();
    case 37:
      if (lookahead == 't') ADVANCE(71);
      END_STATE();
    case 38:
      if (lookahead == 'n') ADVANCE(72);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(62);
      END_STATE();
    case 39:
      if (lookahead == 'o') ADVANCE(73);
      END_STATE();
    case 40:
      if (lookahead == 'g') ADVANCE(74);
      if (lookahead == 'z') ADVANCE(75);
      END_STATE();
    case 41:
      if (lookahead == 'i') ADVANCE(76);
      END_STATE();
    case 42:
      if (lookahead == 'r') ADVANCE(77);
      END_STATE();
    case 43:
      if (lookahead == 'n') ADVANCE(78);
      END_STATE();
    case 44:
      if (lookahead == 'i') ADVANCE(79);
      if (lookahead == 's') ADVANCE(80);
      END_STATE();
    case 45:
      if (lookahead == 'i') ADVANCE(81);
      if (lookahead == 'l') ADVANCE(82);
      END_STATE();
    case 46:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(83);
      END_STATE();
    case 47:
      ACCEPT_TOKEN(aux_sym__hll_non_default_format_var_command_token2);
      END_STATE();
    case 48:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(84);
      END_STATE();
    case 49:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(85);
      END_STATE();
    case 50:
      if (lookahead == 'W' ||
          lookahead == 'w') ADVANCE(86);
      END_STATE();
    case 51:
      ACCEPT_TOKEN(aux_sym__host_command_with_default_format_token1);
      END_STATE();
    case 52:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(87);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(88);
      END_STATE();
    case 53:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(89);
      END_STATE();
    case 54:
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(90);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(91);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(92);
      END_STATE();
    case 55:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(93);
      END_STATE();
    case 56:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(94);
      END_STATE();
    case 57:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(95);
      END_STATE();
    case 58:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(96);
      END_STATE();
    case 59:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(97);
      END_STATE();
    case 60:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(98);
      END_STATE();
    case 61:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(99);
      END_STATE();
    case 62:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(100);
      END_STATE();
    case 63:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(101);
      END_STATE();
    case 64:
      ACCEPT_TOKEN(aux_sym__hll_non_default_format_var_command_token1);
      END_STATE();
    case 65:
      if (lookahead == 'l') ADVANCE(102);
      END_STATE();
    case 66:
      if (lookahead == 'r') ADVANCE(103);
      END_STATE();
    case 67:
      if (lookahead == 's') ADVANCE(104);
      END_STATE();
    case 68:
      if (lookahead == 'b') ADVANCE(105);
      END_STATE();
    case 69:
      if (lookahead == 'm') ADVANCE(106);
      END_STATE();
    case 70:
      if (lookahead == 'a') ADVANCE(107);
      END_STATE();
    case 71:
      ACCEPT_TOKEN(sym_hll_primitive_type);
      if (lookahead == '1') ADVANCE(108);
      if (lookahead == '3') ADVANCE(109);
      if (lookahead == '6') ADVANCE(110);
      if (lookahead == '8') ADVANCE(111);
      if (lookahead == 'p') ADVANCE(112);
      END_STATE();
    case 72:
      if (lookahead == 'g') ADVANCE(113);
      END_STATE();
    case 73:
      if (lookahead == 'r') ADVANCE(114);
      END_STATE();
    case 74:
      if (lookahead == 'n') ADVANCE(115);
      END_STATE();
    case 75:
      if (lookahead == 'e') ADVANCE(116);
      END_STATE();
    case 76:
      if (lookahead == 'z') ADVANCE(117);
      END_STATE();
    case 77:
      if (lookahead == 'u') ADVANCE(118);
      END_STATE();
    case 78:
      if (lookahead == 't') ADVANCE(119);
      END_STATE();
    case 79:
      if (lookahead == 'o') ADVANCE(120);
      END_STATE();
    case 80:
      if (lookahead == 'i') ADVANCE(121);
      END_STATE();
    case 81:
      if (lookahead == 'd') ADVANCE(102);
      END_STATE();
    case 82:
      if (lookahead == 'a') ADVANCE(122);
      END_STATE();
    case 83:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(123);
      END_STATE();
    case 84:
      if (lookahead == 'B' ||
          lookahead == 'b') ADVANCE(124);
      END_STATE();
    case 85:
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(125);
      END_STATE();
    case 86:
      if (lookahead == 'G' ||
          lookahead == 'g') ADVANCE(126);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(127);
      END_STATE();
    case 87:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(128);
      END_STATE();
    case 88:
      ACCEPT_TOKEN(aux_sym__hll_non_default_format_var_command_token5);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(129);
      END_STATE();
    case 89:
      if (lookahead == 'V' ||
          lookahead == 'v') ADVANCE(130);
      END_STATE();
    case 90:
      ACCEPT_TOKEN(aux_sym__var_command_with_non_hll_format_token2);
      END_STATE();
    case 91:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(131);
      END_STATE();
    case 92:
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(132);
      END_STATE();
    case 93:
      ACCEPT_TOKEN(aux_sym__repeat_block_pre_condition_format_token1);
      END_STATE();
    case 94:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(133);
      END_STATE();
    case 95:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(134);
      END_STATE();
    case 96:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(135);
      END_STATE();
    case 97:
      ACCEPT_TOKEN(aux_sym_elif_block_token1);
      END_STATE();
    case 98:
      if (lookahead == 'Y' ||
          lookahead == 'y') ADVANCE(136);
      END_STATE();
    case 99:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(137);
      END_STATE();
    case 100:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(138);
      END_STATE();
    case 101:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(139);
      END_STATE();
    case 102:
      ACCEPT_TOKEN(sym_hll_primitive_type);
      END_STATE();
    case 103:
      ACCEPT_TOKEN(sym_hll_primitive_type);
      if (lookahead == '1') ADVANCE(140);
      if (lookahead == '3') ADVANCE(141);
      if (lookahead == '6') ADVANCE(142);
      if (lookahead == '8') ADVANCE(143);
      if (lookahead == 'p') ADVANCE(144);
      END_STATE();
    case 104:
      if (lookahead == 't') ADVANCE(145);
      END_STATE();
    case 105:
      if (lookahead == 'l') ADVANCE(146);
      END_STATE();
    case 106:
      ACCEPT_TOKEN(anon_sym_enum);
      END_STATE();
    case 107:
      if (lookahead == 't') ADVANCE(102);
      END_STATE();
    case 108:
      if (lookahead == '6') ADVANCE(147);
      END_STATE();
    case 109:
      if (lookahead == '2') ADVANCE(148);
      END_STATE();
    case 110:
      if (lookahead == '4') ADVANCE(149);
      END_STATE();
    case 111:
      if (lookahead == '_') ADVANCE(150);
      END_STATE();
    case 112:
      if (lookahead == 't') ADVANCE(151);
      END_STATE();
    case 113:
      ACCEPT_TOKEN(anon_sym_long);
      END_STATE();
    case 114:
      if (lookahead == 't') ADVANCE(152);
      END_STATE();
    case 115:
      if (lookahead == 'e') ADVANCE(153);
      END_STATE();
    case 116:
      if (lookahead == '_') ADVANCE(154);
      if (lookahead == 'o') ADVANCE(155);
      END_STATE();
    case 117:
      if (lookahead == 'e') ADVANCE(156);
      END_STATE();
    case 118:
      if (lookahead == 'c') ADVANCE(157);
      END_STATE();
    case 119:
      if (lookahead == '1') ADVANCE(158);
      if (lookahead == '3') ADVANCE(159);
      if (lookahead == '6') ADVANCE(160);
      if (lookahead == '8') ADVANCE(161);
      if (lookahead == 'p') ADVANCE(162);
      END_STATE();
    case 120:
      if (lookahead == 'n') ADVANCE(163);
      END_STATE();
    case 121:
      if (lookahead == 'g') ADVANCE(164);
      END_STATE();
    case 122:
      if (lookahead == 't') ADVANCE(165);
      END_STATE();
    case 123:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(166);
      END_STATE();
    case 124:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(167);
      END_STATE();
    case 125:
      if (lookahead == 'B' ||
          lookahead == 'b') ADVANCE(168);
      END_STATE();
    case 126:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(169);
      END_STATE();
    case 127:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(170);
      END_STATE();
    case 128:
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(171);
      END_STATE();
    case 129:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(172);
      END_STATE();
    case 130:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(173);
      END_STATE();
    case 131:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(174);
      END_STATE();
    case 132:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(175);
      END_STATE();
    case 133:
      ACCEPT_TOKEN(aux_sym__var_command_with_non_hll_format_token3);
      END_STATE();
    case 134:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(176);
      END_STATE();
    case 135:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(177);
      END_STATE();
    case 136:
      ACCEPT_TOKEN(aux_sym_parameter_declaration_token3);
      END_STATE();
    case 137:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(178);
      END_STATE();
    case 138:
      ACCEPT_TOKEN(aux_sym_macro_definition_command_token2);
      END_STATE();
    case 139:
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(179);
      END_STATE();
    case 140:
      if (lookahead == '6') ADVANCE(180);
      END_STATE();
    case 141:
      if (lookahead == '2') ADVANCE(181);
      END_STATE();
    case 142:
      if (lookahead == '4') ADVANCE(182);
      END_STATE();
    case 143:
      if (lookahead == '_') ADVANCE(183);
      END_STATE();
    case 144:
      if (lookahead == 't') ADVANCE(184);
      END_STATE();
    case 145:
      ACCEPT_TOKEN(anon_sym_const);
      END_STATE();
    case 146:
      if (lookahead == 'e') ADVANCE(102);
      END_STATE();
    case 147:
      if (lookahead == '_') ADVANCE(185);
      END_STATE();
    case 148:
      if (lookahead == '_') ADVANCE(186);
      END_STATE();
    case 149:
      if (lookahead == '_') ADVANCE(187);
      END_STATE();
    case 150:
      if (lookahead == 't') ADVANCE(102);
      END_STATE();
    case 151:
      if (lookahead == 'r') ADVANCE(188);
      END_STATE();
    case 152:
      ACCEPT_TOKEN(anon_sym_short);
      END_STATE();
    case 153:
      if (lookahead == 'd') ADVANCE(189);
      END_STATE();
    case 154:
      if (lookahead == 't') ADVANCE(102);
      END_STATE();
    case 155:
      if (lookahead == 'f') ADVANCE(190);
      END_STATE();
    case 156:
      if (lookahead == '_') ADVANCE(191);
      END_STATE();
    case 157:
      if (lookahead == 't') ADVANCE(192);
      END_STATE();
    case 158:
      if (lookahead == '6') ADVANCE(193);
      END_STATE();
    case 159:
      if (lookahead == '2') ADVANCE(194);
      END_STATE();
    case 160:
      if (lookahead == '4') ADVANCE(195);
      END_STATE();
    case 161:
      if (lookahead == '_') ADVANCE(196);
      END_STATE();
    case 162:
      if (lookahead == 't') ADVANCE(197);
      END_STATE();
    case 163:
      ACCEPT_TOKEN(anon_sym_union);
      END_STATE();
    case 164:
      if (lookahead == 'n') ADVANCE(198);
      END_STATE();
    case 165:
      if (lookahead == 'i') ADVANCE(199);
      END_STATE();
    case 166:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(200);
      END_STATE();
    case 167:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(201);
      END_STATE();
    case 168:
      ACCEPT_TOKEN(aux_sym_subroutine_call_expression_token1);
      END_STATE();
    case 169:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(202);
      END_STATE();
    case 170:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(203);
      END_STATE();
    case 171:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(204);
      END_STATE();
    case 172:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(205);
      END_STATE();
    case 173:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(206);
      END_STATE();
    case 174:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(93);
      END_STATE();
    case 175:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(207);
      END_STATE();
    case 176:
      ACCEPT_TOKEN(aux_sym_while_block_token1);
      END_STATE();
    case 177:
      ACCEPT_TOKEN(aux_sym__hll_non_default_format_var_command_token4);
      END_STATE();
    case 178:
      ACCEPT_TOKEN(aux_sym__hll_non_default_format_var_command_token3);
      END_STATE();
    case 179:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(208);
      END_STATE();
    case 180:
      if (lookahead == '_') ADVANCE(209);
      END_STATE();
    case 181:
      if (lookahead == '_') ADVANCE(210);
      END_STATE();
    case 182:
      if (lookahead == '_') ADVANCE(211);
      END_STATE();
    case 183:
      if (lookahead == 't') ADVANCE(102);
      END_STATE();
    case 184:
      if (lookahead == 'r') ADVANCE(212);
      END_STATE();
    case 185:
      if (lookahead == 't') ADVANCE(102);
      END_STATE();
    case 186:
      if (lookahead == 't') ADVANCE(102);
      END_STATE();
    case 187:
      if (lookahead == 't') ADVANCE(102);
      END_STATE();
    case 188:
      if (lookahead == '_') ADVANCE(213);
      END_STATE();
    case 189:
      ACCEPT_TOKEN(anon_sym_signed);
      END_STATE();
    case 190:
      ACCEPT_TOKEN(anon_sym_sizeof);
      END_STATE();
    case 191:
      if (lookahead == 't') ADVANCE(102);
      END_STATE();
    case 192:
      ACCEPT_TOKEN(anon_sym_struct);
      END_STATE();
    case 193:
      if (lookahead == '_') ADVANCE(214);
      END_STATE();
    case 194:
      if (lookahead == '_') ADVANCE(215);
      END_STATE();
    case 195:
      if (lookahead == '_') ADVANCE(216);
      END_STATE();
    case 196:
      if (lookahead == 't') ADVANCE(102);
      END_STATE();
    case 197:
      if (lookahead == 'r') ADVANCE(217);
      END_STATE();
    case 198:
      if (lookahead == 'e') ADVANCE(218);
      END_STATE();
    case 199:
      if (lookahead == 'l') ADVANCE(219);
      END_STATE();
    case 200:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(220);
      END_STATE();
    case 201:
      ACCEPT_TOKEN(aux_sym_macro_definition_command_token1);
      END_STATE();
    case 202:
      if (lookahead == 'B' ||
          lookahead == 'b') ADVANCE(221);
      END_STATE();
    case 203:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(222);
      END_STATE();
    case 204:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(223);
      END_STATE();
    case 205:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(224);
      END_STATE();
    case 206:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(225);
      END_STATE();
    case 207:
      if (lookahead == 'V' ||
          lookahead == 'v') ADVANCE(226);
      END_STATE();
    case 208:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(227);
      END_STATE();
    case 209:
      if (lookahead == 't') ADVANCE(102);
      END_STATE();
    case 210:
      if (lookahead == 't') ADVANCE(102);
      END_STATE();
    case 211:
      if (lookahead == 't') ADVANCE(102);
      END_STATE();
    case 212:
      if (lookahead == '_') ADVANCE(228);
      END_STATE();
    case 213:
      if (lookahead == 't') ADVANCE(102);
      END_STATE();
    case 214:
      if (lookahead == 't') ADVANCE(102);
      END_STATE();
    case 215:
      if (lookahead == 't') ADVANCE(102);
      END_STATE();
    case 216:
      if (lookahead == 't') ADVANCE(102);
      END_STATE();
    case 217:
      if (lookahead == '_') ADVANCE(229);
      END_STATE();
    case 218:
      if (lookahead == 'd') ADVANCE(230);
      END_STATE();
    case 219:
      if (lookahead == 'e') ADVANCE(231);
      END_STATE();
    case 220:
      if (lookahead == 'K' ||
          lookahead == 'k') ADVANCE(232);
      END_STATE();
    case 221:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(233);
      END_STATE();
    case 222:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(234);
      END_STATE();
    case 223:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(235);
      END_STATE();
    case 224:
      ACCEPT_TOKEN(aux_sym__hll_non_default_format_var_command_token5);
      END_STATE();
    case 225:
      ACCEPT_TOKEN(aux_sym_macro_definition_command_token3);
      END_STATE();
    case 226:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(236);
      END_STATE();
    case 227:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(237);
      END_STATE();
    case 228:
      if (lookahead == 't') ADVANCE(102);
      END_STATE();
    case 229:
      if (lookahead == 't') ADVANCE(102);
      END_STATE();
    case 230:
      ACCEPT_TOKEN(anon_sym_unsigned);
      END_STATE();
    case 231:
      ACCEPT_TOKEN(anon_sym_volatile);
      END_STATE();
    case 232:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(238);
      END_STATE();
    case 233:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(239);
      END_STATE();
    case 234:
      ACCEPT_TOKEN(aux_sym__hll_var_definition_command_expression_token1);
      END_STATE();
    case 235:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(240);
      END_STATE();
    case 236:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(241);
      END_STATE();
    case 237:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(242);
      END_STATE();
    case 238:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(47);
      END_STATE();
    case 239:
      ACCEPT_TOKEN(aux_sym__hll_var_definition_command_expression_token2);
      END_STATE();
    case 240:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(243);
      END_STATE();
    case 241:
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(244);
      END_STATE();
    case 242:
      ACCEPT_TOKEN(aux_sym_subroutine_block_token1);
      END_STATE();
    case 243:
      ACCEPT_TOKEN(aux_sym_parameter_declaration_token1);
      END_STATE();
    case 244:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(245);
      END_STATE();
    case 245:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(246);
      END_STATE();
    case 246:
      ACCEPT_TOKEN(aux_sym_parameter_declaration_token2);
      END_STATE();
    default:
      return false;
  }
}

static const TSLexerMode ts_lex_modes[STATE_COUNT] = {
  [0] = {.lex_state = 0, .external_lex_state = 1},
  [1] = {.lex_state = 144, .external_lex_state = 2},
  [2] = {.lex_state = 3, .external_lex_state = 3},
  [3] = {.lex_state = 3, .external_lex_state = 3},
  [4] = {.lex_state = 2, .external_lex_state = 4},
  [5] = {.lex_state = 26, .external_lex_state = 4},
  [6] = {.lex_state = 2, .external_lex_state = 4},
  [7] = {.lex_state = 26, .external_lex_state = 4},
  [8] = {.lex_state = 26, .external_lex_state = 4},
  [9] = {.lex_state = 9, .external_lex_state = 5},
  [10] = {.lex_state = 9, .external_lex_state = 5},
  [11] = {.lex_state = 9, .external_lex_state = 5},
  [12] = {.lex_state = 9, .external_lex_state = 5},
  [13] = {.lex_state = 29, .external_lex_state = 6},
  [14] = {.lex_state = 29, .external_lex_state = 6},
  [15] = {.lex_state = 29, .external_lex_state = 6},
  [16] = {.lex_state = 29, .external_lex_state = 6},
  [17] = {.lex_state = 5, .external_lex_state = 6},
  [18] = {.lex_state = 5, .external_lex_state = 6},
  [19] = {.lex_state = 5, .external_lex_state = 6},
  [20] = {.lex_state = 5, .external_lex_state = 6},
  [21] = {.lex_state = 6, .external_lex_state = 6},
  [22] = {.lex_state = 6, .external_lex_state = 6},
  [23] = {.lex_state = 6, .external_lex_state = 6},
  [24] = {.lex_state = 6, .external_lex_state = 6},
  [25] = {.lex_state = 30, .external_lex_state = 6},
  [26] = {.lex_state = 30, .external_lex_state = 6},
  [27] = {.lex_state = 30, .external_lex_state = 6},
  [28] = {.lex_state = 30, .external_lex_state = 6},
  [29] = {.lex_state = 2, .external_lex_state = 7},
  [30] = {.lex_state = 26, .external_lex_state = 7},
  [31] = {.lex_state = 26, .external_lex_state = 7},
  [32] = {.lex_state = 25, .external_lex_state = 8},
  [33] = {.lex_state = 2, .external_lex_state = 7},
  [34] = {.lex_state = 27, .external_lex_state = 6},
  [35] = {.lex_state = 27, .external_lex_state = 6},
  [36] = {.lex_state = 27, .external_lex_state = 6},
  [37] = {.lex_state = 27, .external_lex_state = 6},
  [38] = {.lex_state = 25, .external_lex_state = 8},
  [39] = {.lex_state = 25, .external_lex_state = 8},
  [40] = {.lex_state = 25, .external_lex_state = 8},
  [41] = {.lex_state = 25, .external_lex_state = 8},
  [42] = {.lex_state = 25, .external_lex_state = 8},
  [43] = {.lex_state = 25, .external_lex_state = 8},
  [44] = {.lex_state = 4, .external_lex_state = 6},
  [45] = {.lex_state = 25, .external_lex_state = 8},
  [46] = {.lex_state = 25, .external_lex_state = 8},
  [47] = {.lex_state = 25, .external_lex_state = 8},
  [48] = {.lex_state = 25, .external_lex_state = 8},
  [49] = {.lex_state = 25, .external_lex_state = 8},
  [50] = {.lex_state = 25, .external_lex_state = 8},
  [51] = {.lex_state = 25, .external_lex_state = 8},
  [52] = {.lex_state = 25, .external_lex_state = 8},
  [53] = {.lex_state = 25, .external_lex_state = 8},
  [54] = {.lex_state = 25, .external_lex_state = 8},
  [55] = {.lex_state = 25, .external_lex_state = 8},
  [56] = {.lex_state = 2, .external_lex_state = 7},
  [57] = {.lex_state = 25, .external_lex_state = 8},
  [58] = {.lex_state = 25, .external_lex_state = 8},
  [59] = {.lex_state = 25, .external_lex_state = 8},
  [60] = {.lex_state = 25, .external_lex_state = 8},
  [61] = {.lex_state = 25, .external_lex_state = 8},
  [62] = {.lex_state = 25, .external_lex_state = 8},
  [63] = {.lex_state = 25, .external_lex_state = 8},
  [64] = {.lex_state = 25, .external_lex_state = 8},
  [65] = {.lex_state = 25, .external_lex_state = 8},
  [66] = {.lex_state = 25, .external_lex_state = 8},
  [67] = {.lex_state = 25, .external_lex_state = 8},
  [68] = {.lex_state = 25, .external_lex_state = 8},
  [69] = {.lex_state = 25, .external_lex_state = 8},
  [70] = {.lex_state = 25, .external_lex_state = 8},
  [71] = {.lex_state = 25, .external_lex_state = 8},
  [72] = {.lex_state = 25, .external_lex_state = 8},
  [73] = {.lex_state = 4, .external_lex_state = 6},
  [74] = {.lex_state = 25, .external_lex_state = 8},
  [75] = {.lex_state = 25, .external_lex_state = 8},
  [76] = {.lex_state = 25, .external_lex_state = 8},
  [77] = {.lex_state = 25, .external_lex_state = 8},
  [78] = {.lex_state = 25, .external_lex_state = 8},
  [79] = {.lex_state = 4, .external_lex_state = 6},
  [80] = {.lex_state = 4, .external_lex_state = 6},
  [81] = {.lex_state = 25, .external_lex_state = 8},
  [82] = {.lex_state = 27, .external_lex_state = 6},
  [83] = {.lex_state = 28, .external_lex_state = 6},
  [84] = {.lex_state = 27, .external_lex_state = 6},
  [85] = {.lex_state = 27, .external_lex_state = 6},
  [86] = {.lex_state = 27, .external_lex_state = 6},
  [87] = {.lex_state = 28, .external_lex_state = 6},
  [88] = {.lex_state = 28, .external_lex_state = 6},
  [89] = {.lex_state = 28, .external_lex_state = 6},
  [90] = {.lex_state = 26, .external_lex_state = 7},
  [91] = {.lex_state = 26, .external_lex_state = 7},
  [92] = {.lex_state = 26, .external_lex_state = 7},
  [93] = {.lex_state = 26, .external_lex_state = 7},
  [94] = {.lex_state = 26, .external_lex_state = 7},
  [95] = {.lex_state = 26, .external_lex_state = 7},
  [96] = {.lex_state = 26, .external_lex_state = 7},
  [97] = {.lex_state = 26, .external_lex_state = 7},
  [98] = {.lex_state = 26, .external_lex_state = 7},
  [99] = {.lex_state = 26, .external_lex_state = 7},
  [100] = {.lex_state = 26, .external_lex_state = 7},
  [101] = {.lex_state = 28, .external_lex_state = 6},
  [102] = {.lex_state = 28, .external_lex_state = 6},
  [103] = {.lex_state = 28, .external_lex_state = 6},
  [104] = {.lex_state = 28, .external_lex_state = 6},
  [105] = {.lex_state = 26, .external_lex_state = 7},
  [106] = {.lex_state = 26, .external_lex_state = 7},
  [107] = {.lex_state = 26, .external_lex_state = 7},
  [108] = {.lex_state = 26, .external_lex_state = 7},
  [109] = {.lex_state = 26, .external_lex_state = 7},
  [110] = {.lex_state = 26, .external_lex_state = 7},
  [111] = {.lex_state = 26, .external_lex_state = 7},
  [112] = {.lex_state = 26, .external_lex_state = 7},
  [113] = {.lex_state = 26, .external_lex_state = 7},
  [114] = {.lex_state = 26, .external_lex_state = 7},
  [115] = {.lex_state = 26, .external_lex_state = 7},
  [116] = {.lex_state = 26, .external_lex_state = 7},
  [117] = {.lex_state = 26, .external_lex_state = 7},
  [118] = {.lex_state = 26, .external_lex_state = 7},
  [119] = {.lex_state = 26, .external_lex_state = 7},
  [120] = {.lex_state = 26, .external_lex_state = 7},
  [121] = {.lex_state = 26, .external_lex_state = 7},
  [122] = {.lex_state = 4, .external_lex_state = 6},
  [123] = {.lex_state = 26, .external_lex_state = 7},
  [124] = {.lex_state = 26, .external_lex_state = 7},
  [125] = {.lex_state = 26, .external_lex_state = 7},
  [126] = {.lex_state = 4, .external_lex_state = 6},
  [127] = {.lex_state = 4, .external_lex_state = 6},
  [128] = {.lex_state = 26, .external_lex_state = 7},
  [129] = {.lex_state = 26, .external_lex_state = 7},
  [130] = {.lex_state = 4, .external_lex_state = 6},
  [131] = {.lex_state = 26, .external_lex_state = 7},
  [132] = {.lex_state = 26, .external_lex_state = 7},
  [133] = {.lex_state = 26, .external_lex_state = 7},
  [134] = {.lex_state = 26, .external_lex_state = 7},
  [135] = {.lex_state = 26, .external_lex_state = 7},
  [136] = {.lex_state = 26, .external_lex_state = 7},
  [137] = {.lex_state = 26, .external_lex_state = 7},
  [138] = {.lex_state = 26, .external_lex_state = 7},
  [139] = {.lex_state = 26, .external_lex_state = 7},
  [140] = {.lex_state = 26, .external_lex_state = 7},
  [141] = {.lex_state = 26, .external_lex_state = 7},
  [142] = {.lex_state = 2, .external_lex_state = 7},
  [143] = {.lex_state = 2, .external_lex_state = 7},
  [144] = {.lex_state = 2, .external_lex_state = 7},
  [145] = {.lex_state = 2, .external_lex_state = 7},
  [146] = {.lex_state = 2, .external_lex_state = 7},
  [147] = {.lex_state = 2, .external_lex_state = 7},
  [148] = {.lex_state = 2, .external_lex_state = 7},
  [149] = {.lex_state = 2, .external_lex_state = 7},
  [150] = {.lex_state = 2, .external_lex_state = 7},
  [151] = {.lex_state = 2, .external_lex_state = 7},
  [152] = {.lex_state = 2, .external_lex_state = 7},
  [153] = {.lex_state = 2, .external_lex_state = 7},
  [154] = {.lex_state = 2, .external_lex_state = 7},
  [155] = {.lex_state = 2, .external_lex_state = 7},
  [156] = {.lex_state = 2, .external_lex_state = 7},
  [157] = {.lex_state = 2, .external_lex_state = 7},
  [158] = {.lex_state = 2, .external_lex_state = 7},
  [159] = {.lex_state = 2, .external_lex_state = 7},
  [160] = {.lex_state = 2, .external_lex_state = 7},
  [161] = {.lex_state = 2, .external_lex_state = 7},
  [162] = {.lex_state = 2, .external_lex_state = 7},
  [163] = {.lex_state = 2, .external_lex_state = 7},
  [164] = {.lex_state = 2, .external_lex_state = 7},
  [165] = {.lex_state = 2, .external_lex_state = 7},
  [166] = {.lex_state = 2, .external_lex_state = 7},
  [167] = {.lex_state = 2, .external_lex_state = 7},
  [168] = {.lex_state = 2, .external_lex_state = 7},
  [169] = {.lex_state = 2, .external_lex_state = 7},
  [170] = {.lex_state = 2, .external_lex_state = 7},
  [171] = {.lex_state = 2, .external_lex_state = 7},
  [172] = {.lex_state = 2, .external_lex_state = 7},
  [173] = {.lex_state = 2, .external_lex_state = 7},
  [174] = {.lex_state = 2, .external_lex_state = 7},
  [175] = {.lex_state = 2, .external_lex_state = 7},
  [176] = {.lex_state = 2, .external_lex_state = 7},
  [177] = {.lex_state = 2, .external_lex_state = 7},
  [178] = {.lex_state = 2, .external_lex_state = 7},
  [179] = {.lex_state = 2, .external_lex_state = 7},
  [180] = {.lex_state = 2, .external_lex_state = 7},
  [181] = {.lex_state = 2, .external_lex_state = 7},
  [182] = {.lex_state = 2, .external_lex_state = 7},
  [183] = {.lex_state = 2, .external_lex_state = 7},
  [184] = {.lex_state = 2, .external_lex_state = 7},
  [185] = {.lex_state = 2, .external_lex_state = 7},
  [186] = {.lex_state = 2, .external_lex_state = 7},
  [187] = {.lex_state = 2, .external_lex_state = 7},
  [188] = {.lex_state = 2, .external_lex_state = 7},
  [189] = {.lex_state = 2, .external_lex_state = 7},
  [190] = {.lex_state = 2, .external_lex_state = 7},
  [191] = {.lex_state = 2, .external_lex_state = 7},
  [192] = {.lex_state = 2, .external_lex_state = 7},
  [193] = {.lex_state = 2, .external_lex_state = 7},
  [194] = {.lex_state = 2, .external_lex_state = 7},
  [195] = {.lex_state = 2, .external_lex_state = 7},
  [196] = {.lex_state = 2, .external_lex_state = 7},
  [197] = {.lex_state = 2, .external_lex_state = 7},
  [198] = {.lex_state = 2, .external_lex_state = 7},
  [199] = {.lex_state = 2, .external_lex_state = 7},
  [200] = {.lex_state = 2, .external_lex_state = 7},
  [201] = {.lex_state = 2, .external_lex_state = 7},
  [202] = {.lex_state = 2, .external_lex_state = 7},
  [203] = {.lex_state = 2, .external_lex_state = 7},
  [204] = {.lex_state = 2, .external_lex_state = 7},
  [205] = {.lex_state = 2, .external_lex_state = 7},
  [206] = {.lex_state = 2, .external_lex_state = 7},
  [207] = {.lex_state = 2, .external_lex_state = 7},
  [208] = {.lex_state = 2, .external_lex_state = 7},
  [209] = {.lex_state = 2, .external_lex_state = 7},
  [210] = {.lex_state = 2, .external_lex_state = 7},
  [211] = {.lex_state = 2, .external_lex_state = 7},
  [212] = {.lex_state = 2, .external_lex_state = 7},
  [213] = {.lex_state = 2, .external_lex_state = 7},
  [214] = {.lex_state = 2, .external_lex_state = 7},
  [215] = {.lex_state = 2, .external_lex_state = 7},
  [216] = {.lex_state = 2, .external_lex_state = 7},
  [217] = {.lex_state = 2, .external_lex_state = 7},
  [218] = {.lex_state = 2, .external_lex_state = 7},
  [219] = {.lex_state = 2, .external_lex_state = 7},
  [220] = {.lex_state = 2, .external_lex_state = 7},
  [221] = {.lex_state = 2, .external_lex_state = 7},
  [222] = {.lex_state = 2, .external_lex_state = 7},
  [223] = {.lex_state = 2, .external_lex_state = 7},
  [224] = {.lex_state = 2, .external_lex_state = 7},
  [225] = {.lex_state = 2, .external_lex_state = 7},
  [226] = {.lex_state = 2, .external_lex_state = 7},
  [227] = {.lex_state = 2, .external_lex_state = 7},
  [228] = {.lex_state = 2, .external_lex_state = 7},
  [229] = {.lex_state = 2, .external_lex_state = 7},
  [230] = {.lex_state = 2, .external_lex_state = 7},
  [231] = {.lex_state = 2, .external_lex_state = 7},
  [232] = {.lex_state = 2, .external_lex_state = 7},
  [233] = {.lex_state = 2, .external_lex_state = 7},
  [234] = {.lex_state = 2, .external_lex_state = 7},
  [235] = {.lex_state = 2, .external_lex_state = 7},
  [236] = {.lex_state = 2, .external_lex_state = 7},
  [237] = {.lex_state = 2, .external_lex_state = 7},
  [238] = {.lex_state = 2, .external_lex_state = 7},
  [239] = {.lex_state = 2, .external_lex_state = 7},
  [240] = {.lex_state = 2, .external_lex_state = 7},
  [241] = {.lex_state = 2, .external_lex_state = 7},
  [242] = {.lex_state = 2, .external_lex_state = 7},
  [243] = {.lex_state = 144, .external_lex_state = 2},
  [244] = {.lex_state = 144, .external_lex_state = 2},
  [245] = {.lex_state = 144, .external_lex_state = 2},
  [246] = {.lex_state = 144, .external_lex_state = 2},
  [247] = {.lex_state = 144, .external_lex_state = 2},
  [248] = {.lex_state = 144, .external_lex_state = 2},
  [249] = {.lex_state = 144, .external_lex_state = 2},
  [250] = {.lex_state = 144, .external_lex_state = 2},
  [251] = {.lex_state = 144, .external_lex_state = 2},
  [252] = {.lex_state = 144, .external_lex_state = 2},
  [253] = {.lex_state = 144, .external_lex_state = 2},
  [254] = {.lex_state = 144, .external_lex_state = 2},
  [255] = {.lex_state = 144, .external_lex_state = 2},
  [256] = {.lex_state = 144, .external_lex_state = 2},
  [257] = {.lex_state = 144, .external_lex_state = 2},
  [258] = {.lex_state = 144, .external_lex_state = 2},
  [259] = {.lex_state = 144, .external_lex_state = 2},
  [260] = {.lex_state = 144, .external_lex_state = 2},
  [261] = {.lex_state = 144, .external_lex_state = 2},
  [262] = {.lex_state = 144, .external_lex_state = 2},
  [263] = {.lex_state = 144, .external_lex_state = 2},
  [264] = {.lex_state = 144, .external_lex_state = 2},
  [265] = {.lex_state = 144, .external_lex_state = 2},
  [266] = {.lex_state = 144, .external_lex_state = 2},
  [267] = {.lex_state = 144, .external_lex_state = 2},
  [268] = {.lex_state = 144, .external_lex_state = 2},
  [269] = {.lex_state = 144, .external_lex_state = 2},
  [270] = {.lex_state = 144, .external_lex_state = 2},
  [271] = {.lex_state = 144, .external_lex_state = 2},
  [272] = {.lex_state = 144, .external_lex_state = 2},
  [273] = {.lex_state = 144, .external_lex_state = 2},
  [274] = {.lex_state = 144, .external_lex_state = 2},
  [275] = {.lex_state = 144, .external_lex_state = 2},
  [276] = {.lex_state = 144, .external_lex_state = 2},
  [277] = {.lex_state = 144, .external_lex_state = 2},
  [278] = {.lex_state = 144, .external_lex_state = 2},
  [279] = {.lex_state = 144, .external_lex_state = 2},
  [280] = {.lex_state = 144, .external_lex_state = 2},
  [281] = {.lex_state = 144, .external_lex_state = 2},
  [282] = {.lex_state = 144, .external_lex_state = 2},
  [283] = {.lex_state = 144, .external_lex_state = 2},
  [284] = {.lex_state = 144, .external_lex_state = 2},
  [285] = {.lex_state = 144, .external_lex_state = 2},
  [286] = {.lex_state = 144, .external_lex_state = 2},
  [287] = {.lex_state = 144, .external_lex_state = 2},
  [288] = {.lex_state = 144, .external_lex_state = 2},
  [289] = {.lex_state = 144, .external_lex_state = 2},
  [290] = {.lex_state = 144, .external_lex_state = 2},
  [291] = {.lex_state = 144, .external_lex_state = 2},
  [292] = {.lex_state = 144, .external_lex_state = 2},
  [293] = {.lex_state = 144, .external_lex_state = 2},
  [294] = {.lex_state = 144, .external_lex_state = 2},
  [295] = {.lex_state = 144, .external_lex_state = 2},
  [296] = {.lex_state = 144, .external_lex_state = 2},
  [297] = {.lex_state = 144, .external_lex_state = 2},
  [298] = {.lex_state = 48, .external_lex_state = 2},
  [299] = {.lex_state = 48, .external_lex_state = 2},
  [300] = {.lex_state = 48, .external_lex_state = 2},
  [301] = {.lex_state = 48, .external_lex_state = 2},
  [302] = {.lex_state = 48, .external_lex_state = 2},
  [303] = {.lex_state = 48, .external_lex_state = 2},
  [304] = {.lex_state = 48, .external_lex_state = 2},
  [305] = {.lex_state = 48, .external_lex_state = 2},
  [306] = {.lex_state = 48, .external_lex_state = 2},
  [307] = {.lex_state = 48, .external_lex_state = 2},
  [308] = {.lex_state = 48, .external_lex_state = 2},
  [309] = {.lex_state = 48, .external_lex_state = 2},
  [310] = {.lex_state = 48, .external_lex_state = 2},
  [311] = {.lex_state = 48, .external_lex_state = 2},
  [312] = {.lex_state = 48, .external_lex_state = 2},
  [313] = {.lex_state = 25, .external_lex_state = 8},
  [314] = {.lex_state = 25, .external_lex_state = 8},
  [315] = {.lex_state = 25, .external_lex_state = 8},
  [316] = {.lex_state = 25, .external_lex_state = 8},
  [317] = {.lex_state = 25, .external_lex_state = 8},
  [318] = {.lex_state = 25, .external_lex_state = 8},
  [319] = {.lex_state = 25, .external_lex_state = 8},
  [320] = {.lex_state = 25, .external_lex_state = 8},
  [321] = {.lex_state = 25, .external_lex_state = 8},
  [322] = {.lex_state = 25, .external_lex_state = 8},
  [323] = {.lex_state = 25, .external_lex_state = 8},
  [324] = {.lex_state = 25, .external_lex_state = 8},
  [325] = {.lex_state = 25, .external_lex_state = 8},
  [326] = {.lex_state = 25, .external_lex_state = 8},
  [327] = {.lex_state = 25, .external_lex_state = 8},
  [328] = {.lex_state = 9, .external_lex_state = 9},
  [329] = {.lex_state = 25, .external_lex_state = 8},
  [330] = {.lex_state = 25, .external_lex_state = 8},
  [331] = {.lex_state = 25, .external_lex_state = 8},
  [332] = {.lex_state = 25, .external_lex_state = 8},
  [333] = {.lex_state = 9, .external_lex_state = 9},
  [334] = {.lex_state = 9, .external_lex_state = 9},
  [335] = {.lex_state = 25, .external_lex_state = 8},
  [336] = {.lex_state = 25, .external_lex_state = 8},
  [337] = {.lex_state = 25, .external_lex_state = 8},
  [338] = {.lex_state = 25, .external_lex_state = 8},
  [339] = {.lex_state = 25, .external_lex_state = 8},
  [340] = {.lex_state = 25, .external_lex_state = 8},
  [341] = {.lex_state = 9, .external_lex_state = 9},
  [342] = {.lex_state = 25, .external_lex_state = 8},
  [343] = {.lex_state = 9, .external_lex_state = 5},
  [344] = {.lex_state = 9, .external_lex_state = 5},
  [345] = {.lex_state = 9, .external_lex_state = 5},
  [346] = {.lex_state = 9, .external_lex_state = 5},
  [347] = {.lex_state = 9, .external_lex_state = 5},
  [348] = {.lex_state = 9, .external_lex_state = 5},
  [349] = {.lex_state = 9, .external_lex_state = 5},
  [350] = {.lex_state = 9, .external_lex_state = 5},
  [351] = {.lex_state = 9, .external_lex_state = 5},
  [352] = {.lex_state = 9, .external_lex_state = 5},
  [353] = {.lex_state = 9, .external_lex_state = 5},
  [354] = {.lex_state = 9, .external_lex_state = 5},
  [355] = {.lex_state = 9, .external_lex_state = 5},
  [356] = {.lex_state = 9, .external_lex_state = 5},
  [357] = {.lex_state = 9, .external_lex_state = 5},
  [358] = {.lex_state = 9, .external_lex_state = 5},
  [359] = {.lex_state = 9, .external_lex_state = 5},
  [360] = {.lex_state = 9, .external_lex_state = 5},
  [361] = {.lex_state = 9, .external_lex_state = 5},
  [362] = {.lex_state = 9, .external_lex_state = 5},
  [363] = {.lex_state = 9, .external_lex_state = 5},
  [364] = {.lex_state = 9, .external_lex_state = 5},
  [365] = {.lex_state = 9, .external_lex_state = 5},
  [366] = {.lex_state = 9, .external_lex_state = 5},
  [367] = {.lex_state = 9, .external_lex_state = 9},
  [368] = {.lex_state = 9, .external_lex_state = 5},
  [369] = {.lex_state = 9, .external_lex_state = 5},
  [370] = {.lex_state = 25, .external_lex_state = 8},
  [371] = {.lex_state = 9, .external_lex_state = 9},
  [372] = {.lex_state = 9, .external_lex_state = 5},
  [373] = {.lex_state = 9, .external_lex_state = 5},
  [374] = {.lex_state = 9, .external_lex_state = 5},
  [375] = {.lex_state = 9, .external_lex_state = 5},
  [376] = {.lex_state = 9, .external_lex_state = 5},
  [377] = {.lex_state = 25, .external_lex_state = 8},
  [378] = {.lex_state = 9, .external_lex_state = 5},
  [379] = {.lex_state = 9, .external_lex_state = 5},
  [380] = {.lex_state = 9, .external_lex_state = 5},
  [381] = {.lex_state = 9, .external_lex_state = 5},
  [382] = {.lex_state = 9, .external_lex_state = 5},
  [383] = {.lex_state = 9, .external_lex_state = 5},
  [384] = {.lex_state = 9, .external_lex_state = 5},
  [385] = {.lex_state = 9, .external_lex_state = 5},
  [386] = {.lex_state = 25, .external_lex_state = 8},
  [387] = {.lex_state = 9, .external_lex_state = 5},
  [388] = {.lex_state = 9, .external_lex_state = 5},
  [389] = {.lex_state = 9, .external_lex_state = 5},
  [390] = {.lex_state = 9, .external_lex_state = 5},
  [391] = {.lex_state = 25, .external_lex_state = 8},
  [392] = {.lex_state = 25, .external_lex_state = 8},
  [393] = {.lex_state = 25, .external_lex_state = 8},
  [394] = {.lex_state = 25, .external_lex_state = 8},
  [395] = {.lex_state = 25, .external_lex_state = 8},
  [396] = {.lex_state = 25, .external_lex_state = 8},
  [397] = {.lex_state = 25, .external_lex_state = 8},
  [398] = {.lex_state = 25, .external_lex_state = 8},
  [399] = {.lex_state = 25, .external_lex_state = 8},
  [400] = {.lex_state = 25, .external_lex_state = 8},
  [401] = {.lex_state = 25, .external_lex_state = 8},
  [402] = {.lex_state = 25, .external_lex_state = 8},
  [403] = {.lex_state = 25, .external_lex_state = 8},
  [404] = {.lex_state = 25, .external_lex_state = 8},
  [405] = {.lex_state = 25, .external_lex_state = 8},
  [406] = {.lex_state = 25, .external_lex_state = 8},
  [407] = {.lex_state = 25, .external_lex_state = 8},
  [408] = {.lex_state = 25, .external_lex_state = 8},
  [409] = {.lex_state = 25, .external_lex_state = 8},
  [410] = {.lex_state = 25, .external_lex_state = 8},
  [411] = {.lex_state = 25, .external_lex_state = 8},
  [412] = {.lex_state = 25, .external_lex_state = 8},
  [413] = {.lex_state = 25, .external_lex_state = 8},
  [414] = {.lex_state = 25, .external_lex_state = 8},
  [415] = {.lex_state = 9, .external_lex_state = 9},
  [416] = {.lex_state = 25, .external_lex_state = 8},
  [417] = {.lex_state = 9, .external_lex_state = 5},
  [418] = {.lex_state = 25, .external_lex_state = 8},
  [419] = {.lex_state = 25, .external_lex_state = 8},
  [420] = {.lex_state = 25, .external_lex_state = 8},
  [421] = {.lex_state = 25, .external_lex_state = 8},
  [422] = {.lex_state = 9, .external_lex_state = 5},
  [423] = {.lex_state = 9, .external_lex_state = 9},
  [424] = {.lex_state = 9, .external_lex_state = 5},
  [425] = {.lex_state = 25, .external_lex_state = 8},
  [426] = {.lex_state = 25, .external_lex_state = 8},
  [427] = {.lex_state = 25, .external_lex_state = 8},
  [428] = {.lex_state = 25, .external_lex_state = 8},
  [429] = {.lex_state = 25, .external_lex_state = 8},
  [430] = {.lex_state = 25, .external_lex_state = 8},
  [431] = {.lex_state = 25, .external_lex_state = 8},
  [432] = {.lex_state = 25, .external_lex_state = 8},
  [433] = {.lex_state = 25, .external_lex_state = 8},
  [434] = {.lex_state = 25, .external_lex_state = 8},
  [435] = {.lex_state = 25, .external_lex_state = 8},
  [436] = {.lex_state = 25, .external_lex_state = 8},
  [437] = {.lex_state = 25, .external_lex_state = 8},
  [438] = {.lex_state = 9, .external_lex_state = 5},
  [439] = {.lex_state = 25, .external_lex_state = 8},
  [440] = {.lex_state = 25, .external_lex_state = 8},
  [441] = {.lex_state = 25, .external_lex_state = 8},
  [442] = {.lex_state = 25, .external_lex_state = 8},
  [443] = {.lex_state = 25, .external_lex_state = 8},
  [444] = {.lex_state = 25, .external_lex_state = 8},
  [445] = {.lex_state = 25, .external_lex_state = 8},
  [446] = {.lex_state = 25, .external_lex_state = 8},
  [447] = {.lex_state = 25, .external_lex_state = 8},
  [448] = {.lex_state = 9, .external_lex_state = 5},
  [449] = {.lex_state = 9, .external_lex_state = 5},
  [450] = {.lex_state = 9, .external_lex_state = 5},
  [451] = {.lex_state = 9, .external_lex_state = 5},
  [452] = {.lex_state = 9, .external_lex_state = 5},
  [453] = {.lex_state = 9, .external_lex_state = 5},
  [454] = {.lex_state = 25, .external_lex_state = 8},
  [455] = {.lex_state = 25, .external_lex_state = 8},
  [456] = {.lex_state = 25, .external_lex_state = 8},
  [457] = {.lex_state = 9, .external_lex_state = 5},
  [458] = {.lex_state = 25, .external_lex_state = 8},
  [459] = {.lex_state = 9, .external_lex_state = 5},
  [460] = {.lex_state = 25, .external_lex_state = 8},
  [461] = {.lex_state = 25, .external_lex_state = 8},
  [462] = {.lex_state = 25, .external_lex_state = 8},
  [463] = {.lex_state = 25, .external_lex_state = 8},
  [464] = {.lex_state = 25, .external_lex_state = 8},
  [465] = {.lex_state = 25, .external_lex_state = 8},
  [466] = {.lex_state = 25, .external_lex_state = 8},
  [467] = {.lex_state = 25, .external_lex_state = 8},
  [468] = {.lex_state = 25, .external_lex_state = 8},
  [469] = {.lex_state = 25, .external_lex_state = 8},
  [470] = {.lex_state = 25, .external_lex_state = 8},
  [471] = {.lex_state = 25, .external_lex_state = 8},
  [472] = {.lex_state = 25, .external_lex_state = 8},
  [473] = {.lex_state = 9, .external_lex_state = 5},
  [474] = {.lex_state = 9, .external_lex_state = 5},
  [475] = {.lex_state = 25, .external_lex_state = 8},
  [476] = {.lex_state = 25, .external_lex_state = 8},
  [477] = {.lex_state = 25, .external_lex_state = 8},
  [478] = {.lex_state = 25, .external_lex_state = 8},
  [479] = {.lex_state = 9, .external_lex_state = 5},
  [480] = {.lex_state = 9, .external_lex_state = 5},
  [481] = {.lex_state = 25, .external_lex_state = 8},
  [482] = {.lex_state = 25, .external_lex_state = 8},
  [483] = {.lex_state = 25, .external_lex_state = 8},
  [484] = {.lex_state = 25, .external_lex_state = 8},
  [485] = {.lex_state = 25, .external_lex_state = 8},
  [486] = {.lex_state = 25, .external_lex_state = 8},
  [487] = {.lex_state = 25, .external_lex_state = 8},
  [488] = {.lex_state = 25, .external_lex_state = 8},
  [489] = {.lex_state = 25, .external_lex_state = 8},
  [490] = {.lex_state = 25, .external_lex_state = 8},
  [491] = {.lex_state = 25, .external_lex_state = 8},
  [492] = {.lex_state = 25, .external_lex_state = 8},
  [493] = {.lex_state = 25, .external_lex_state = 8},
  [494] = {.lex_state = 25, .external_lex_state = 8},
  [495] = {.lex_state = 25, .external_lex_state = 8},
  [496] = {.lex_state = 25, .external_lex_state = 8},
  [497] = {.lex_state = 25, .external_lex_state = 8},
  [498] = {.lex_state = 25, .external_lex_state = 8},
  [499] = {.lex_state = 25, .external_lex_state = 8},
  [500] = {.lex_state = 25, .external_lex_state = 8},
  [501] = {.lex_state = 25, .external_lex_state = 8},
  [502] = {.lex_state = 25, .external_lex_state = 8},
  [503] = {.lex_state = 25, .external_lex_state = 8},
  [504] = {.lex_state = 25, .external_lex_state = 8},
  [505] = {.lex_state = 25, .external_lex_state = 8},
  [506] = {.lex_state = 25, .external_lex_state = 8},
  [507] = {.lex_state = 25, .external_lex_state = 8},
  [508] = {.lex_state = 25, .external_lex_state = 8},
  [509] = {.lex_state = 25, .external_lex_state = 8},
  [510] = {.lex_state = 25, .external_lex_state = 8},
  [511] = {.lex_state = 25, .external_lex_state = 8},
  [512] = {.lex_state = 25, .external_lex_state = 8},
  [513] = {.lex_state = 25, .external_lex_state = 8},
  [514] = {.lex_state = 25, .external_lex_state = 8},
  [515] = {.lex_state = 25, .external_lex_state = 8},
  [516] = {.lex_state = 25, .external_lex_state = 8},
  [517] = {.lex_state = 25, .external_lex_state = 8},
  [518] = {.lex_state = 25, .external_lex_state = 8},
  [519] = {.lex_state = 25, .external_lex_state = 8},
  [520] = {.lex_state = 25, .external_lex_state = 8},
  [521] = {.lex_state = 25, .external_lex_state = 8},
  [522] = {.lex_state = 25, .external_lex_state = 8},
  [523] = {.lex_state = 25, .external_lex_state = 8},
  [524] = {.lex_state = 25, .external_lex_state = 8},
  [525] = {.lex_state = 29, .external_lex_state = 10},
  [526] = {.lex_state = 25, .external_lex_state = 8},
  [527] = {.lex_state = 25, .external_lex_state = 8},
  [528] = {.lex_state = 25, .external_lex_state = 8},
  [529] = {.lex_state = 25, .external_lex_state = 8},
  [530] = {.lex_state = 25, .external_lex_state = 8},
  [531] = {.lex_state = 25, .external_lex_state = 8},
  [532] = {.lex_state = 25, .external_lex_state = 8},
  [533] = {.lex_state = 25, .external_lex_state = 8},
  [534] = {.lex_state = 25, .external_lex_state = 8},
  [535] = {.lex_state = 25, .external_lex_state = 8},
  [536] = {.lex_state = 25, .external_lex_state = 8},
  [537] = {.lex_state = 25, .external_lex_state = 8},
  [538] = {.lex_state = 25, .external_lex_state = 8},
  [539] = {.lex_state = 25, .external_lex_state = 8},
  [540] = {.lex_state = 25, .external_lex_state = 8},
  [541] = {.lex_state = 25, .external_lex_state = 8},
  [542] = {.lex_state = 25, .external_lex_state = 8},
  [543] = {.lex_state = 25, .external_lex_state = 8},
  [544] = {.lex_state = 25, .external_lex_state = 8},
  [545] = {.lex_state = 25, .external_lex_state = 8},
  [546] = {.lex_state = 29, .external_lex_state = 10},
  [547] = {.lex_state = 25, .external_lex_state = 8},
  [548] = {.lex_state = 31, .external_lex_state = 10},
  [549] = {.lex_state = 25, .external_lex_state = 8},
  [550] = {.lex_state = 25, .external_lex_state = 8},
  [551] = {.lex_state = 25, .external_lex_state = 8},
  [552] = {.lex_state = 25, .external_lex_state = 8},
  [553] = {.lex_state = 25, .external_lex_state = 8},
  [554] = {.lex_state = 25, .external_lex_state = 8},
  [555] = {.lex_state = 25, .external_lex_state = 8},
  [556] = {.lex_state = 25, .external_lex_state = 8},
  [557] = {.lex_state = 25, .external_lex_state = 8},
  [558] = {.lex_state = 25, .external_lex_state = 8},
  [559] = {.lex_state = 25, .external_lex_state = 8},
  [560] = {.lex_state = 31, .external_lex_state = 10},
  [561] = {.lex_state = 25, .external_lex_state = 8},
  [562] = {.lex_state = 25, .external_lex_state = 8},
  [563] = {.lex_state = 25, .external_lex_state = 8},
  [564] = {.lex_state = 25, .external_lex_state = 8},
  [565] = {.lex_state = 25, .external_lex_state = 8},
  [566] = {.lex_state = 25, .external_lex_state = 8},
  [567] = {.lex_state = 25, .external_lex_state = 8},
  [568] = {.lex_state = 25, .external_lex_state = 8},
  [569] = {.lex_state = 25, .external_lex_state = 8},
  [570] = {.lex_state = 25, .external_lex_state = 8},
  [571] = {.lex_state = 25, .external_lex_state = 8},
  [572] = {.lex_state = 29, .external_lex_state = 10},
  [573] = {.lex_state = 25, .external_lex_state = 8},
  [574] = {.lex_state = 25, .external_lex_state = 8},
  [575] = {.lex_state = 25, .external_lex_state = 8},
  [576] = {.lex_state = 25, .external_lex_state = 8},
  [577] = {.lex_state = 25, .external_lex_state = 8},
  [578] = {.lex_state = 25, .external_lex_state = 8},
  [579] = {.lex_state = 25, .external_lex_state = 8},
  [580] = {.lex_state = 29, .external_lex_state = 10},
  [581] = {.lex_state = 25, .external_lex_state = 8},
  [582] = {.lex_state = 25, .external_lex_state = 8},
  [583] = {.lex_state = 29, .external_lex_state = 10},
  [584] = {.lex_state = 25, .external_lex_state = 8},
  [585] = {.lex_state = 25, .external_lex_state = 8},
  [586] = {.lex_state = 25, .external_lex_state = 8},
  [587] = {.lex_state = 25, .external_lex_state = 8},
  [588] = {.lex_state = 25, .external_lex_state = 8},
  [589] = {.lex_state = 25, .external_lex_state = 8},
  [590] = {.lex_state = 25, .external_lex_state = 8},
  [591] = {.lex_state = 25, .external_lex_state = 8},
  [592] = {.lex_state = 25, .external_lex_state = 8},
  [593] = {.lex_state = 29, .external_lex_state = 10},
  [594] = {.lex_state = 25, .external_lex_state = 8},
  [595] = {.lex_state = 25, .external_lex_state = 8},
  [596] = {.lex_state = 25, .external_lex_state = 8},
  [597] = {.lex_state = 25, .external_lex_state = 8},
  [598] = {.lex_state = 25, .external_lex_state = 8},
  [599] = {.lex_state = 25, .external_lex_state = 8},
  [600] = {.lex_state = 25, .external_lex_state = 8},
  [601] = {.lex_state = 25, .external_lex_state = 8},
  [602] = {.lex_state = 25, .external_lex_state = 8},
  [603] = {.lex_state = 25, .external_lex_state = 8},
  [604] = {.lex_state = 25, .external_lex_state = 8},
  [605] = {.lex_state = 25, .external_lex_state = 8},
  [606] = {.lex_state = 25, .external_lex_state = 8},
  [607] = {.lex_state = 25, .external_lex_state = 8},
  [608] = {.lex_state = 25, .external_lex_state = 8},
  [609] = {.lex_state = 25, .external_lex_state = 8},
  [610] = {.lex_state = 25, .external_lex_state = 8},
  [611] = {.lex_state = 25, .external_lex_state = 8},
  [612] = {.lex_state = 25, .external_lex_state = 8},
  [613] = {.lex_state = 25, .external_lex_state = 8},
  [614] = {.lex_state = 25, .external_lex_state = 8},
  [615] = {.lex_state = 25, .external_lex_state = 8},
  [616] = {.lex_state = 25, .external_lex_state = 8},
  [617] = {.lex_state = 25, .external_lex_state = 8},
  [618] = {.lex_state = 25, .external_lex_state = 8},
  [619] = {.lex_state = 25, .external_lex_state = 8},
  [620] = {.lex_state = 25, .external_lex_state = 8},
  [621] = {.lex_state = 25, .external_lex_state = 8},
  [622] = {.lex_state = 25, .external_lex_state = 8},
  [623] = {.lex_state = 25, .external_lex_state = 8},
  [624] = {.lex_state = 25, .external_lex_state = 8},
  [625] = {.lex_state = 25, .external_lex_state = 8},
  [626] = {.lex_state = 25, .external_lex_state = 8},
  [627] = {.lex_state = 25, .external_lex_state = 8},
  [628] = {.lex_state = 25, .external_lex_state = 8},
  [629] = {.lex_state = 25, .external_lex_state = 8},
  [630] = {.lex_state = 25, .external_lex_state = 8},
  [631] = {.lex_state = 25, .external_lex_state = 8},
  [632] = {.lex_state = 25, .external_lex_state = 8},
  [633] = {.lex_state = 25, .external_lex_state = 8},
  [634] = {.lex_state = 25, .external_lex_state = 8},
  [635] = {.lex_state = 25, .external_lex_state = 8},
  [636] = {.lex_state = 25, .external_lex_state = 8},
  [637] = {.lex_state = 25, .external_lex_state = 8},
  [638] = {.lex_state = 25, .external_lex_state = 8},
  [639] = {.lex_state = 25, .external_lex_state = 8},
  [640] = {.lex_state = 25, .external_lex_state = 8},
  [641] = {.lex_state = 29, .external_lex_state = 10},
  [642] = {.lex_state = 25, .external_lex_state = 8},
  [643] = {.lex_state = 25, .external_lex_state = 8},
  [644] = {.lex_state = 25, .external_lex_state = 8},
  [645] = {.lex_state = 25, .external_lex_state = 8},
  [646] = {.lex_state = 25, .external_lex_state = 8},
  [647] = {.lex_state = 25, .external_lex_state = 8},
  [648] = {.lex_state = 25, .external_lex_state = 8},
  [649] = {.lex_state = 25, .external_lex_state = 8},
  [650] = {.lex_state = 25, .external_lex_state = 8},
  [651] = {.lex_state = 25, .external_lex_state = 8},
  [652] = {.lex_state = 25, .external_lex_state = 8},
  [653] = {.lex_state = 25, .external_lex_state = 8},
  [654] = {.lex_state = 25, .external_lex_state = 8},
  [655] = {.lex_state = 25, .external_lex_state = 8},
  [656] = {.lex_state = 25, .external_lex_state = 8},
  [657] = {.lex_state = 25, .external_lex_state = 8},
  [658] = {.lex_state = 25, .external_lex_state = 8},
  [659] = {.lex_state = 25, .external_lex_state = 8},
  [660] = {.lex_state = 25, .external_lex_state = 8},
  [661] = {.lex_state = 25, .external_lex_state = 8},
  [662] = {.lex_state = 25, .external_lex_state = 8},
  [663] = {.lex_state = 25, .external_lex_state = 8},
  [664] = {.lex_state = 25, .external_lex_state = 8},
  [665] = {.lex_state = 25, .external_lex_state = 8},
  [666] = {.lex_state = 25, .external_lex_state = 8},
  [667] = {.lex_state = 25, .external_lex_state = 8},
  [668] = {.lex_state = 25, .external_lex_state = 8},
  [669] = {.lex_state = 25, .external_lex_state = 8},
  [670] = {.lex_state = 25, .external_lex_state = 8},
  [671] = {.lex_state = 25, .external_lex_state = 8},
  [672] = {.lex_state = 25, .external_lex_state = 8},
  [673] = {.lex_state = 29, .external_lex_state = 10},
  [674] = {.lex_state = 29, .external_lex_state = 10},
  [675] = {.lex_state = 29, .external_lex_state = 10},
  [676] = {.lex_state = 29, .external_lex_state = 10},
  [677] = {.lex_state = 29, .external_lex_state = 10},
  [678] = {.lex_state = 29, .external_lex_state = 10},
  [679] = {.lex_state = 25, .external_lex_state = 8},
  [680] = {.lex_state = 29, .external_lex_state = 10},
  [681] = {.lex_state = 29, .external_lex_state = 10},
  [682] = {.lex_state = 29, .external_lex_state = 10},
  [683] = {.lex_state = 25, .external_lex_state = 8},
  [684] = {.lex_state = 29, .external_lex_state = 10},
  [685] = {.lex_state = 25, .external_lex_state = 8},
  [686] = {.lex_state = 25, .external_lex_state = 8},
  [687] = {.lex_state = 25, .external_lex_state = 8},
  [688] = {.lex_state = 25, .external_lex_state = 8},
  [689] = {.lex_state = 25, .external_lex_state = 8},
  [690] = {.lex_state = 25, .external_lex_state = 8},
  [691] = {.lex_state = 29, .external_lex_state = 10},
  [692] = {.lex_state = 25, .external_lex_state = 8},
  [693] = {.lex_state = 29, .external_lex_state = 10},
  [694] = {.lex_state = 29, .external_lex_state = 10},
  [695] = {.lex_state = 25, .external_lex_state = 8},
  [696] = {.lex_state = 25, .external_lex_state = 8},
  [697] = {.lex_state = 25, .external_lex_state = 8},
  [698] = {.lex_state = 25, .external_lex_state = 8},
  [699] = {.lex_state = 25, .external_lex_state = 8},
  [700] = {.lex_state = 25, .external_lex_state = 8},
  [701] = {.lex_state = 25, .external_lex_state = 8},
  [702] = {.lex_state = 25, .external_lex_state = 8},
  [703] = {.lex_state = 25, .external_lex_state = 8},
  [704] = {.lex_state = 25, .external_lex_state = 8},
  [705] = {.lex_state = 25, .external_lex_state = 8},
  [706] = {.lex_state = 29, .external_lex_state = 10},
  [707] = {.lex_state = 25, .external_lex_state = 8},
  [708] = {.lex_state = 25, .external_lex_state = 8},
  [709] = {.lex_state = 25, .external_lex_state = 8},
  [710] = {.lex_state = 29, .external_lex_state = 10},
  [711] = {.lex_state = 25, .external_lex_state = 8},
  [712] = {.lex_state = 29, .external_lex_state = 10},
  [713] = {.lex_state = 25, .external_lex_state = 8},
  [714] = {.lex_state = 25, .external_lex_state = 8},
  [715] = {.lex_state = 25, .external_lex_state = 8},
  [716] = {.lex_state = 25, .external_lex_state = 8},
  [717] = {.lex_state = 25, .external_lex_state = 8},
  [718] = {.lex_state = 25, .external_lex_state = 8},
  [719] = {.lex_state = 25, .external_lex_state = 8},
  [720] = {.lex_state = 25, .external_lex_state = 8},
  [721] = {.lex_state = 25, .external_lex_state = 8},
  [722] = {.lex_state = 25, .external_lex_state = 8},
  [723] = {.lex_state = 31, .external_lex_state = 10},
  [724] = {.lex_state = 25, .external_lex_state = 8},
  [725] = {.lex_state = 25, .external_lex_state = 8},
  [726] = {.lex_state = 25, .external_lex_state = 8},
  [727] = {.lex_state = 25, .external_lex_state = 8},
  [728] = {.lex_state = 25, .external_lex_state = 8},
  [729] = {.lex_state = 25, .external_lex_state = 8},
  [730] = {.lex_state = 25, .external_lex_state = 8},
  [731] = {.lex_state = 25, .external_lex_state = 8},
  [732] = {.lex_state = 25, .external_lex_state = 8},
  [733] = {.lex_state = 25, .external_lex_state = 8},
  [734] = {.lex_state = 25, .external_lex_state = 8},
  [735] = {.lex_state = 25, .external_lex_state = 8},
  [736] = {.lex_state = 25, .external_lex_state = 8},
  [737] = {.lex_state = 25, .external_lex_state = 8},
  [738] = {.lex_state = 25, .external_lex_state = 8},
  [739] = {.lex_state = 29, .external_lex_state = 10},
  [740] = {.lex_state = 25, .external_lex_state = 8},
  [741] = {.lex_state = 29, .external_lex_state = 10},
  [742] = {.lex_state = 5, .external_lex_state = 10},
  [743] = {.lex_state = 5, .external_lex_state = 10},
  [744] = {.lex_state = 5, .external_lex_state = 10},
  [745] = {.lex_state = 29, .external_lex_state = 10},
  [746] = {.lex_state = 29, .external_lex_state = 10},
  [747] = {.lex_state = 29, .external_lex_state = 10},
  [748] = {.lex_state = 5, .external_lex_state = 10},
  [749] = {.lex_state = 29, .external_lex_state = 10},
  [750] = {.lex_state = 7, .external_lex_state = 10},
  [751] = {.lex_state = 29, .external_lex_state = 10},
  [752] = {.lex_state = 29, .external_lex_state = 10},
  [753] = {.lex_state = 29, .external_lex_state = 10},
  [754] = {.lex_state = 5, .external_lex_state = 10},
  [755] = {.lex_state = 5, .external_lex_state = 10},
  [756] = {.lex_state = 29, .external_lex_state = 10},
  [757] = {.lex_state = 29, .external_lex_state = 10},
  [758] = {.lex_state = 5, .external_lex_state = 10},
  [759] = {.lex_state = 29, .external_lex_state = 10},
  [760] = {.lex_state = 5, .external_lex_state = 10},
  [761] = {.lex_state = 29, .external_lex_state = 10},
  [762] = {.lex_state = 5, .external_lex_state = 10},
  [763] = {.lex_state = 29, .external_lex_state = 10},
  [764] = {.lex_state = 5, .external_lex_state = 10},
  [765] = {.lex_state = 29, .external_lex_state = 10},
  [766] = {.lex_state = 29, .external_lex_state = 10},
  [767] = {.lex_state = 5, .external_lex_state = 10},
  [768] = {.lex_state = 29, .external_lex_state = 10},
  [769] = {.lex_state = 5, .external_lex_state = 10},
  [770] = {.lex_state = 7, .external_lex_state = 10},
  [771] = {.lex_state = 5, .external_lex_state = 10},
  [772] = {.lex_state = 5, .external_lex_state = 10},
  [773] = {.lex_state = 5, .external_lex_state = 10},
  [774] = {.lex_state = 5, .external_lex_state = 10},
  [775] = {.lex_state = 5, .external_lex_state = 10},
  [776] = {.lex_state = 5, .external_lex_state = 10},
  [777] = {.lex_state = 5, .external_lex_state = 10},
  [778] = {.lex_state = 29, .external_lex_state = 10},
  [779] = {.lex_state = 29, .external_lex_state = 10},
  [780] = {.lex_state = 5, .external_lex_state = 10},
  [781] = {.lex_state = 29, .external_lex_state = 10},
  [782] = {.lex_state = 7, .external_lex_state = 10},
  [783] = {.lex_state = 5, .external_lex_state = 10},
  [784] = {.lex_state = 5, .external_lex_state = 10},
  [785] = {.lex_state = 5, .external_lex_state = 10},
  [786] = {.lex_state = 29, .external_lex_state = 10},
  [787] = {.lex_state = 29, .external_lex_state = 10},
  [788] = {.lex_state = 29, .external_lex_state = 10},
  [789] = {.lex_state = 5, .external_lex_state = 10},
  [790] = {.lex_state = 5, .external_lex_state = 10},
  [791] = {.lex_state = 5, .external_lex_state = 10},
  [792] = {.lex_state = 5, .external_lex_state = 10},
  [793] = {.lex_state = 5, .external_lex_state = 10},
  [794] = {.lex_state = 5, .external_lex_state = 10},
  [795] = {.lex_state = 5, .external_lex_state = 10},
  [796] = {.lex_state = 5, .external_lex_state = 10},
  [797] = {.lex_state = 5, .external_lex_state = 10},
  [798] = {.lex_state = 29, .external_lex_state = 10},
  [799] = {.lex_state = 29, .external_lex_state = 10},
  [800] = {.lex_state = 25, .external_lex_state = 8},
  [801] = {.lex_state = 5, .external_lex_state = 10},
  [802] = {.lex_state = 5, .external_lex_state = 10},
  [803] = {.lex_state = 5, .external_lex_state = 10},
  [804] = {.lex_state = 5, .external_lex_state = 10},
  [805] = {.lex_state = 5, .external_lex_state = 10},
  [806] = {.lex_state = 5, .external_lex_state = 10},
  [807] = {.lex_state = 5, .external_lex_state = 10},
  [808] = {.lex_state = 5, .external_lex_state = 10},
  [809] = {.lex_state = 5, .external_lex_state = 10},
  [810] = {.lex_state = 31, .external_lex_state = 10},
  [811] = {.lex_state = 5, .external_lex_state = 10},
  [812] = {.lex_state = 5, .external_lex_state = 10},
  [813] = {.lex_state = 5, .external_lex_state = 10},
  [814] = {.lex_state = 5, .external_lex_state = 10},
  [815] = {.lex_state = 5, .external_lex_state = 10},
  [816] = {.lex_state = 5, .external_lex_state = 10},
  [817] = {.lex_state = 5, .external_lex_state = 10},
  [818] = {.lex_state = 10, .external_lex_state = 10},
  [819] = {.lex_state = 6, .external_lex_state = 10},
  [820] = {.lex_state = 6, .external_lex_state = 10},
  [821] = {.lex_state = 6, .external_lex_state = 10},
  [822] = {.lex_state = 6, .external_lex_state = 10},
  [823] = {.lex_state = 6, .external_lex_state = 10},
  [824] = {.lex_state = 6, .external_lex_state = 10},
  [825] = {.lex_state = 30, .external_lex_state = 10},
  [826] = {.lex_state = 6, .external_lex_state = 10},
  [827] = {.lex_state = 6, .external_lex_state = 10},
  [828] = {.lex_state = 6, .external_lex_state = 10},
  [829] = {.lex_state = 6, .external_lex_state = 10},
  [830] = {.lex_state = 6, .external_lex_state = 10},
  [831] = {.lex_state = 6, .external_lex_state = 10},
  [832] = {.lex_state = 6, .external_lex_state = 10},
  [833] = {.lex_state = 6, .external_lex_state = 10},
  [834] = {.lex_state = 6, .external_lex_state = 10},
  [835] = {.lex_state = 6, .external_lex_state = 10},
  [836] = {.lex_state = 6, .external_lex_state = 10},
  [837] = {.lex_state = 6, .external_lex_state = 10},
  [838] = {.lex_state = 6, .external_lex_state = 10},
  [839] = {.lex_state = 6, .external_lex_state = 10},
  [840] = {.lex_state = 6, .external_lex_state = 10},
  [841] = {.lex_state = 29, .external_lex_state = 10},
  [842] = {.lex_state = 29, .external_lex_state = 10},
  [843] = {.lex_state = 30, .external_lex_state = 10},
  [844] = {.lex_state = 30, .external_lex_state = 10},
  [845] = {.lex_state = 30, .external_lex_state = 10},
  [846] = {.lex_state = 10, .external_lex_state = 10},
  [847] = {.lex_state = 30, .external_lex_state = 10},
  [848] = {.lex_state = 30, .external_lex_state = 10},
  [849] = {.lex_state = 30, .external_lex_state = 10},
  [850] = {.lex_state = 30, .external_lex_state = 10},
  [851] = {.lex_state = 30, .external_lex_state = 10},
  [852] = {.lex_state = 30, .external_lex_state = 10},
  [853] = {.lex_state = 30, .external_lex_state = 10},
  [854] = {.lex_state = 30, .external_lex_state = 10},
  [855] = {.lex_state = 30, .external_lex_state = 10},
  [856] = {.lex_state = 30, .external_lex_state = 10},
  [857] = {.lex_state = 30, .external_lex_state = 10},
  [858] = {.lex_state = 30, .external_lex_state = 10},
  [859] = {.lex_state = 30, .external_lex_state = 10},
  [860] = {.lex_state = 30, .external_lex_state = 10},
  [861] = {.lex_state = 30, .external_lex_state = 10},
  [862] = {.lex_state = 30, .external_lex_state = 10},
  [863] = {.lex_state = 30, .external_lex_state = 10},
  [864] = {.lex_state = 30, .external_lex_state = 10},
  [865] = {.lex_state = 30, .external_lex_state = 10},
  [866] = {.lex_state = 30, .external_lex_state = 10},
  [867] = {.lex_state = 34, .external_lex_state = 10},
  [868] = {.lex_state = 34, .external_lex_state = 10},
  [869] = {.lex_state = 34, .external_lex_state = 10},
  [870] = {.lex_state = 6, .external_lex_state = 10},
  [871] = {.lex_state = 6, .external_lex_state = 10},
  [872] = {.lex_state = 6, .external_lex_state = 10},
  [873] = {.lex_state = 10, .external_lex_state = 10},
  [874] = {.lex_state = 30, .external_lex_state = 10},
  [875] = {.lex_state = 6, .external_lex_state = 10},
  [876] = {.lex_state = 6, .external_lex_state = 10},
  [877] = {.lex_state = 6, .external_lex_state = 10},
  [878] = {.lex_state = 30, .external_lex_state = 10},
  [879] = {.lex_state = 30, .external_lex_state = 10},
  [880] = {.lex_state = 6, .external_lex_state = 10},
  [881] = {.lex_state = 6, .external_lex_state = 10},
  [882] = {.lex_state = 6, .external_lex_state = 10},
  [883] = {.lex_state = 30, .external_lex_state = 10},
  [884] = {.lex_state = 30, .external_lex_state = 10},
  [885] = {.lex_state = 30, .external_lex_state = 10},
  [886] = {.lex_state = 30, .external_lex_state = 10},
  [887] = {.lex_state = 30, .external_lex_state = 10},
  [888] = {.lex_state = 30, .external_lex_state = 10},
  [889] = {.lex_state = 30, .external_lex_state = 10},
  [890] = {.lex_state = 30, .external_lex_state = 10},
  [891] = {.lex_state = 30, .external_lex_state = 10},
  [892] = {.lex_state = 30, .external_lex_state = 10},
  [893] = {.lex_state = 30, .external_lex_state = 10},
  [894] = {.lex_state = 6, .external_lex_state = 10},
  [895] = {.lex_state = 30, .external_lex_state = 10},
  [896] = {.lex_state = 6, .external_lex_state = 10},
  [897] = {.lex_state = 30, .external_lex_state = 10},
  [898] = {.lex_state = 6, .external_lex_state = 10},
  [899] = {.lex_state = 6, .external_lex_state = 10},
  [900] = {.lex_state = 6, .external_lex_state = 10},
  [901] = {.lex_state = 6, .external_lex_state = 10},
  [902] = {.lex_state = 30, .external_lex_state = 10},
  [903] = {.lex_state = 30, .external_lex_state = 10},
  [904] = {.lex_state = 30, .external_lex_state = 10},
  [905] = {.lex_state = 30, .external_lex_state = 10},
  [906] = {.lex_state = 30, .external_lex_state = 10},
  [907] = {.lex_state = 30, .external_lex_state = 10},
  [908] = {.lex_state = 30, .external_lex_state = 10},
  [909] = {.lex_state = 6, .external_lex_state = 10},
  [910] = {.lex_state = 30, .external_lex_state = 10},
  [911] = {.lex_state = 6, .external_lex_state = 10},
  [912] = {.lex_state = 6, .external_lex_state = 10},
  [913] = {.lex_state = 6, .external_lex_state = 10},
  [914] = {.lex_state = 6, .external_lex_state = 10},
  [915] = {.lex_state = 6, .external_lex_state = 10},
  [916] = {.lex_state = 6, .external_lex_state = 10},
  [917] = {.lex_state = 6, .external_lex_state = 10},
  [918] = {.lex_state = 6, .external_lex_state = 10},
  [919] = {.lex_state = 6, .external_lex_state = 10},
  [920] = {.lex_state = 6, .external_lex_state = 10},
  [921] = {.lex_state = 30, .external_lex_state = 10},
  [922] = {.lex_state = 6, .external_lex_state = 10},
  [923] = {.lex_state = 30, .external_lex_state = 10},
  [924] = {.lex_state = 26, .external_lex_state = 7},
  [925] = {.lex_state = 26, .external_lex_state = 7},
  [926] = {.lex_state = 26, .external_lex_state = 7},
  [927] = {.lex_state = 2, .external_lex_state = 7},
  [928] = {.lex_state = 26, .external_lex_state = 7},
  [929] = {.lex_state = 26, .external_lex_state = 7},
  [930] = {.lex_state = 26, .external_lex_state = 7},
  [931] = {.lex_state = 2, .external_lex_state = 7},
  [932] = {.lex_state = 2, .external_lex_state = 7},
  [933] = {.lex_state = 2, .external_lex_state = 7},
  [934] = {.lex_state = 2, .external_lex_state = 7},
  [935] = {.lex_state = 26, .external_lex_state = 7},
  [936] = {.lex_state = 8, .external_lex_state = 10},
  [937] = {.lex_state = 26, .external_lex_state = 7},
  [938] = {.lex_state = 26, .external_lex_state = 7},
  [939] = {.lex_state = 26, .external_lex_state = 7},
  [940] = {.lex_state = 26, .external_lex_state = 7},
  [941] = {.lex_state = 8, .external_lex_state = 10},
  [942] = {.lex_state = 26, .external_lex_state = 7},
  [943] = {.lex_state = 26, .external_lex_state = 7},
  [944] = {.lex_state = 8, .external_lex_state = 10},
  [945] = {.lex_state = 26, .external_lex_state = 7},
  [946] = {.lex_state = 4, .external_lex_state = 10},
  [947] = {.lex_state = 4, .external_lex_state = 10},
  [948] = {.lex_state = 4, .external_lex_state = 10},
  [949] = {.lex_state = 4, .external_lex_state = 10},
  [950] = {.lex_state = 4, .external_lex_state = 10},
  [951] = {.lex_state = 4, .external_lex_state = 10},
  [952] = {.lex_state = 46},
  [953] = {.lex_state = 4, .external_lex_state = 10},
  [954] = {.lex_state = 4, .external_lex_state = 10},
  [955] = {.lex_state = 4, .external_lex_state = 10},
  [956] = {.lex_state = 4, .external_lex_state = 10},
  [957] = {.lex_state = 4, .external_lex_state = 10},
  [958] = {.lex_state = 4, .external_lex_state = 10},
  [959] = {.lex_state = 25, .external_lex_state = 8},
  [960] = {.lex_state = 4, .external_lex_state = 10},
  [961] = {.lex_state = 4, .external_lex_state = 10},
  [962] = {.lex_state = 4, .external_lex_state = 10},
  [963] = {.lex_state = 2, .external_lex_state = 11},
  [964] = {.lex_state = 32, .external_lex_state = 10},
  [965] = {.lex_state = 27, .external_lex_state = 10},
  [966] = {.lex_state = 27, .external_lex_state = 10},
  [967] = {.lex_state = 26, .external_lex_state = 11},
  [968] = {.lex_state = 27, .external_lex_state = 10},
  [969] = {.lex_state = 25, .external_lex_state = 8},
  [970] = {.lex_state = 26, .external_lex_state = 11},
  [971] = {.lex_state = 27, .external_lex_state = 10},
  [972] = {.lex_state = 2, .external_lex_state = 11},
  [973] = {.lex_state = 27, .external_lex_state = 10},
  [974] = {.lex_state = 27, .external_lex_state = 10},
  [975] = {.lex_state = 26, .external_lex_state = 11},
  [976] = {.lex_state = 4, .external_lex_state = 10},
  [977] = {.lex_state = 4, .external_lex_state = 10},
  [978] = {.lex_state = 4, .external_lex_state = 10},
  [979] = {.lex_state = 27, .external_lex_state = 10},
  [980] = {.lex_state = 2, .external_lex_state = 11},
  [981] = {.lex_state = 27, .external_lex_state = 10},
  [982] = {.lex_state = 4, .external_lex_state = 10},
  [983] = {.lex_state = 4, .external_lex_state = 10},
  [984] = {.lex_state = 27, .external_lex_state = 10},
  [985] = {.lex_state = 4, .external_lex_state = 10},
  [986] = {.lex_state = 4, .external_lex_state = 10},
  [987] = {.lex_state = 4, .external_lex_state = 10},
  [988] = {.lex_state = 27, .external_lex_state = 10},
  [989] = {.lex_state = 27, .external_lex_state = 10},
  [990] = {.lex_state = 27, .external_lex_state = 10},
  [991] = {.lex_state = 27, .external_lex_state = 10},
  [992] = {.lex_state = 27, .external_lex_state = 10},
  [993] = {.lex_state = 4, .external_lex_state = 10},
  [994] = {.lex_state = 32, .external_lex_state = 10},
  [995] = {.lex_state = 27, .external_lex_state = 10},
  [996] = {.lex_state = 27, .external_lex_state = 10},
  [997] = {.lex_state = 4, .external_lex_state = 10},
  [998] = {.lex_state = 27, .external_lex_state = 10},
  [999] = {.lex_state = 27, .external_lex_state = 10},
  [1000] = {.lex_state = 4, .external_lex_state = 10},
  [1001] = {.lex_state = 4, .external_lex_state = 10},
  [1002] = {.lex_state = 27, .external_lex_state = 10},
  [1003] = {.lex_state = 27, .external_lex_state = 10},
  [1004] = {.lex_state = 26, .external_lex_state = 11},
  [1005] = {.lex_state = 27, .external_lex_state = 10},
  [1006] = {.lex_state = 4, .external_lex_state = 10},
  [1007] = {.lex_state = 32, .external_lex_state = 10},
  [1008] = {.lex_state = 27, .external_lex_state = 10},
  [1009] = {.lex_state = 25, .external_lex_state = 8},
  [1010] = {.lex_state = 27, .external_lex_state = 10},
  [1011] = {.lex_state = 27, .external_lex_state = 10},
  [1012] = {.lex_state = 27, .external_lex_state = 10},
  [1013] = {.lex_state = 27, .external_lex_state = 10},
  [1014] = {.lex_state = 25, .external_lex_state = 8},
  [1015] = {.lex_state = 27, .external_lex_state = 10},
  [1016] = {.lex_state = 2, .external_lex_state = 11},
  [1017] = {.lex_state = 25, .external_lex_state = 8},
  [1018] = {.lex_state = 4, .external_lex_state = 10},
  [1019] = {.lex_state = 26, .external_lex_state = 11},
  [1020] = {.lex_state = 4, .external_lex_state = 10},
  [1021] = {.lex_state = 4, .external_lex_state = 10},
  [1022] = {.lex_state = 4, .external_lex_state = 10},
  [1023] = {.lex_state = 4, .external_lex_state = 10},
  [1024] = {.lex_state = 4, .external_lex_state = 10},
  [1025] = {.lex_state = 4, .external_lex_state = 10},
  [1026] = {.lex_state = 4, .external_lex_state = 10},
  [1027] = {.lex_state = 27, .external_lex_state = 10},
  [1028] = {.lex_state = 4, .external_lex_state = 10},
  [1029] = {.lex_state = 4, .external_lex_state = 10},
  [1030] = {.lex_state = 27, .external_lex_state = 10},
  [1031] = {.lex_state = 27, .external_lex_state = 10},
  [1032] = {.lex_state = 27, .external_lex_state = 10},
  [1033] = {.lex_state = 26, .external_lex_state = 12},
  [1034] = {.lex_state = 26, .external_lex_state = 12},
  [1035] = {.lex_state = 26, .external_lex_state = 12},
  [1036] = {.lex_state = 2, .external_lex_state = 12},
  [1037] = {.lex_state = 26, .external_lex_state = 12},
  [1038] = {.lex_state = 26, .external_lex_state = 12},
  [1039] = {.lex_state = 26, .external_lex_state = 12},
  [1040] = {.lex_state = 144, .external_lex_state = 2},
  [1041] = {.lex_state = 26, .external_lex_state = 12},
  [1042] = {.lex_state = 26, .external_lex_state = 12},
  [1043] = {.lex_state = 2, .external_lex_state = 12},
  [1044] = {.lex_state = 26, .external_lex_state = 12},
  [1045] = {.lex_state = 27, .external_lex_state = 10},
  [1046] = {.lex_state = 26, .external_lex_state = 12},
  [1047] = {.lex_state = 2, .external_lex_state = 12},
  [1048] = {.lex_state = 27, .external_lex_state = 10},
  [1049] = {.lex_state = 26, .external_lex_state = 12},
  [1050] = {.lex_state = 144, .external_lex_state = 2},
  [1051] = {.lex_state = 26, .external_lex_state = 11},
  [1052] = {.lex_state = 26, .external_lex_state = 12},
  [1053] = {.lex_state = 26, .external_lex_state = 13},
  [1054] = {.lex_state = 26, .external_lex_state = 12},
  [1055] = {.lex_state = 2, .external_lex_state = 12},
  [1056] = {.lex_state = 26, .external_lex_state = 12},
  [1057] = {.lex_state = 27, .external_lex_state = 10},
  [1058] = {.lex_state = 2, .external_lex_state = 12},
  [1059] = {.lex_state = 2, .external_lex_state = 7},
  [1060] = {.lex_state = 2, .external_lex_state = 12},
  [1061] = {.lex_state = 2, .external_lex_state = 12},
  [1062] = {.lex_state = 2, .external_lex_state = 7},
  [1063] = {.lex_state = 27, .external_lex_state = 10},
  [1064] = {.lex_state = 2, .external_lex_state = 12},
  [1065] = {.lex_state = 25, .external_lex_state = 8},
  [1066] = {.lex_state = 26, .external_lex_state = 12},
  [1067] = {.lex_state = 2, .external_lex_state = 12},
  [1068] = {.lex_state = 26, .external_lex_state = 12},
  [1069] = {.lex_state = 144, .external_lex_state = 2},
  [1070] = {.lex_state = 26, .external_lex_state = 12},
  [1071] = {.lex_state = 26, .external_lex_state = 12},
  [1072] = {.lex_state = 144, .external_lex_state = 2},
  [1073] = {.lex_state = 26, .external_lex_state = 13},
  [1074] = {.lex_state = 27, .external_lex_state = 10},
  [1075] = {.lex_state = 2, .external_lex_state = 12},
  [1076] = {.lex_state = 2, .external_lex_state = 7},
  [1077] = {.lex_state = 2, .external_lex_state = 11},
  [1078] = {.lex_state = 26, .external_lex_state = 12},
  [1079] = {.lex_state = 2, .external_lex_state = 13},
  [1080] = {.lex_state = 2, .external_lex_state = 12},
  [1081] = {.lex_state = 2, .external_lex_state = 7},
  [1082] = {.lex_state = 27, .external_lex_state = 10},
  [1083] = {.lex_state = 27, .external_lex_state = 10},
  [1084] = {.lex_state = 25, .external_lex_state = 8},
  [1085] = {.lex_state = 28, .external_lex_state = 10},
  [1086] = {.lex_state = 27, .external_lex_state = 10},
  [1087] = {.lex_state = 27, .external_lex_state = 10},
  [1088] = {.lex_state = 27, .external_lex_state = 10},
  [1089] = {.lex_state = 144, .external_lex_state = 2},
  [1090] = {.lex_state = 2, .external_lex_state = 12},
  [1091] = {.lex_state = 144, .external_lex_state = 2},
  [1092] = {.lex_state = 25, .external_lex_state = 8},
  [1093] = {.lex_state = 27, .external_lex_state = 10},
  [1094] = {.lex_state = 27, .external_lex_state = 10},
  [1095] = {.lex_state = 26, .external_lex_state = 12},
  [1096] = {.lex_state = 27, .external_lex_state = 10},
  [1097] = {.lex_state = 26, .external_lex_state = 12},
  [1098] = {.lex_state = 26, .external_lex_state = 12},
  [1099] = {.lex_state = 26, .external_lex_state = 12},
  [1100] = {.lex_state = 2, .external_lex_state = 13},
  [1101] = {.lex_state = 144, .external_lex_state = 2},
  [1102] = {.lex_state = 27, .external_lex_state = 10},
  [1103] = {.lex_state = 26, .external_lex_state = 12},
  [1104] = {.lex_state = 27, .external_lex_state = 10},
  [1105] = {.lex_state = 27, .external_lex_state = 10},
  [1106] = {.lex_state = 2, .external_lex_state = 11},
  [1107] = {.lex_state = 2, .external_lex_state = 12},
  [1108] = {.lex_state = 2, .external_lex_state = 12},
  [1109] = {.lex_state = 26, .external_lex_state = 12},
  [1110] = {.lex_state = 2, .external_lex_state = 12},
  [1111] = {.lex_state = 144, .external_lex_state = 2},
  [1112] = {.lex_state = 144, .external_lex_state = 2},
  [1113] = {.lex_state = 28, .external_lex_state = 10},
  [1114] = {.lex_state = 144, .external_lex_state = 2},
  [1115] = {.lex_state = 144, .external_lex_state = 2},
  [1116] = {.lex_state = 144, .external_lex_state = 2},
  [1117] = {.lex_state = 144, .external_lex_state = 2},
  [1118] = {.lex_state = 144, .external_lex_state = 2},
  [1119] = {.lex_state = 27, .external_lex_state = 10},
  [1120] = {.lex_state = 27, .external_lex_state = 10},
  [1121] = {.lex_state = 27, .external_lex_state = 10},
  [1122] = {.lex_state = 2, .external_lex_state = 12},
  [1123] = {.lex_state = 144, .external_lex_state = 2},
  [1124] = {.lex_state = 144, .external_lex_state = 2},
  [1125] = {.lex_state = 2, .external_lex_state = 12},
  [1126] = {.lex_state = 2, .external_lex_state = 12},
  [1127] = {.lex_state = 2, .external_lex_state = 12},
  [1128] = {.lex_state = 2, .external_lex_state = 12},
  [1129] = {.lex_state = 2, .external_lex_state = 12},
  [1130] = {.lex_state = 2, .external_lex_state = 12},
  [1131] = {.lex_state = 27, .external_lex_state = 10},
  [1132] = {.lex_state = 27, .external_lex_state = 10},
  [1133] = {.lex_state = 2, .external_lex_state = 12},
  [1134] = {.lex_state = 25, .external_lex_state = 8},
  [1135] = {.lex_state = 27, .external_lex_state = 10},
  [1136] = {.lex_state = 27, .external_lex_state = 10},
  [1137] = {.lex_state = 3, .external_lex_state = 11},
  [1138] = {.lex_state = 27, .external_lex_state = 10},
  [1139] = {.lex_state = 3, .external_lex_state = 12},
  [1140] = {.lex_state = 3, .external_lex_state = 12},
  [1141] = {.lex_state = 26, .external_lex_state = 12},
  [1142] = {.lex_state = 27, .external_lex_state = 10},
  [1143] = {.lex_state = 28, .external_lex_state = 10},
  [1144] = {.lex_state = 27, .external_lex_state = 10},
  [1145] = {.lex_state = 28, .external_lex_state = 10},
  [1146] = {.lex_state = 27, .external_lex_state = 10},
  [1147] = {.lex_state = 28, .external_lex_state = 10},
  [1148] = {.lex_state = 27, .external_lex_state = 10},
  [1149] = {.lex_state = 3, .external_lex_state = 12},
  [1150] = {.lex_state = 27, .external_lex_state = 10},
  [1151] = {.lex_state = 144, .external_lex_state = 2},
  [1152] = {.lex_state = 26, .external_lex_state = 12},
  [1153] = {.lex_state = 28, .external_lex_state = 10},
  [1154] = {.lex_state = 28, .external_lex_state = 10},
  [1155] = {.lex_state = 28, .external_lex_state = 10},
  [1156] = {.lex_state = 144, .external_lex_state = 2},
  [1157] = {.lex_state = 3, .external_lex_state = 12},
  [1158] = {.lex_state = 28, .external_lex_state = 10},
  [1159] = {.lex_state = 28, .external_lex_state = 10},
  [1160] = {.lex_state = 3, .external_lex_state = 12},
  [1161] = {.lex_state = 2, .external_lex_state = 13},
  [1162] = {.lex_state = 28, .external_lex_state = 10},
  [1163] = {.lex_state = 3, .external_lex_state = 12},
  [1164] = {.lex_state = 28, .external_lex_state = 10},
  [1165] = {.lex_state = 27, .external_lex_state = 10},
  [1166] = {.lex_state = 3, .external_lex_state = 12},
  [1167] = {.lex_state = 27, .external_lex_state = 10},
  [1168] = {.lex_state = 27, .external_lex_state = 10},
  [1169] = {.lex_state = 28, .external_lex_state = 10},
  [1170] = {.lex_state = 3, .external_lex_state = 12},
  [1171] = {.lex_state = 27, .external_lex_state = 10},
  [1172] = {.lex_state = 3, .external_lex_state = 11},
  [1173] = {.lex_state = 26, .external_lex_state = 12},
  [1174] = {.lex_state = 27, .external_lex_state = 10},
  [1175] = {.lex_state = 27, .external_lex_state = 10},
  [1176] = {.lex_state = 27, .external_lex_state = 10},
  [1177] = {.lex_state = 26, .external_lex_state = 12},
  [1178] = {.lex_state = 27, .external_lex_state = 10},
  [1179] = {.lex_state = 26, .external_lex_state = 13},
  [1180] = {.lex_state = 26, .external_lex_state = 12},
  [1181] = {.lex_state = 27, .external_lex_state = 10},
  [1182] = {.lex_state = 27, .external_lex_state = 10},
  [1183] = {.lex_state = 27, .external_lex_state = 10},
  [1184] = {.lex_state = 28, .external_lex_state = 10},
  [1185] = {.lex_state = 27, .external_lex_state = 10},
  [1186] = {.lex_state = 27, .external_lex_state = 10},
  [1187] = {.lex_state = 27, .external_lex_state = 10},
  [1188] = {.lex_state = 28, .external_lex_state = 10},
  [1189] = {.lex_state = 28, .external_lex_state = 10},
  [1190] = {.lex_state = 27, .external_lex_state = 10},
  [1191] = {.lex_state = 26, .external_lex_state = 12},
  [1192] = {.lex_state = 27, .external_lex_state = 10},
  [1193] = {.lex_state = 28, .external_lex_state = 10},
  [1194] = {.lex_state = 28, .external_lex_state = 10},
  [1195] = {.lex_state = 28, .external_lex_state = 10},
  [1196] = {.lex_state = 3, .external_lex_state = 12},
  [1197] = {.lex_state = 28, .external_lex_state = 10},
  [1198] = {.lex_state = 26, .external_lex_state = 12},
  [1199] = {.lex_state = 33, .external_lex_state = 10},
  [1200] = {.lex_state = 26, .external_lex_state = 12},
  [1201] = {.lex_state = 26, .external_lex_state = 12},
  [1202] = {.lex_state = 26, .external_lex_state = 12},
  [1203] = {.lex_state = 26, .external_lex_state = 12},
  [1204] = {.lex_state = 25, .external_lex_state = 8},
  [1205] = {.lex_state = 26, .external_lex_state = 12},
  [1206] = {.lex_state = 26, .external_lex_state = 12},
  [1207] = {.lex_state = 144, .external_lex_state = 2},
  [1208] = {.lex_state = 3, .external_lex_state = 12},
  [1209] = {.lex_state = 27, .external_lex_state = 10},
  [1210] = {.lex_state = 26, .external_lex_state = 12},
  [1211] = {.lex_state = 27, .external_lex_state = 10},
  [1212] = {.lex_state = 26, .external_lex_state = 12},
  [1213] = {.lex_state = 27, .external_lex_state = 10},
  [1214] = {.lex_state = 26, .external_lex_state = 12},
  [1215] = {.lex_state = 26, .external_lex_state = 12},
  [1216] = {.lex_state = 26, .external_lex_state = 12},
  [1217] = {.lex_state = 27, .external_lex_state = 10},
  [1218] = {.lex_state = 26, .external_lex_state = 11},
  [1219] = {.lex_state = 3, .external_lex_state = 12},
  [1220] = {.lex_state = 3, .external_lex_state = 12},
  [1221] = {.lex_state = 27, .external_lex_state = 10},
  [1222] = {.lex_state = 27, .external_lex_state = 10},
  [1223] = {.lex_state = 25, .external_lex_state = 8},
  [1224] = {.lex_state = 27, .external_lex_state = 10},
  [1225] = {.lex_state = 27, .external_lex_state = 10},
  [1226] = {.lex_state = 27, .external_lex_state = 10},
  [1227] = {.lex_state = 27, .external_lex_state = 10},
  [1228] = {.lex_state = 3, .external_lex_state = 12},
  [1229] = {.lex_state = 26, .external_lex_state = 13},
  [1230] = {.lex_state = 27, .external_lex_state = 10},
  [1231] = {.lex_state = 27, .external_lex_state = 10},
  [1232] = {.lex_state = 28, .external_lex_state = 10},
  [1233] = {.lex_state = 26, .external_lex_state = 12},
  [1234] = {.lex_state = 27, .external_lex_state = 10},
  [1235] = {.lex_state = 2, .external_lex_state = 13},
  [1236] = {.lex_state = 3, .external_lex_state = 12},
  [1237] = {.lex_state = 26, .external_lex_state = 11},
  [1238] = {.lex_state = 26, .external_lex_state = 12},
  [1239] = {.lex_state = 3, .external_lex_state = 12},
  [1240] = {.lex_state = 26, .external_lex_state = 12},
  [1241] = {.lex_state = 27, .external_lex_state = 10},
  [1242] = {.lex_state = 27, .external_lex_state = 10},
  [1243] = {.lex_state = 26, .external_lex_state = 12},
  [1244] = {.lex_state = 33, .external_lex_state = 10},
  [1245] = {.lex_state = 3, .external_lex_state = 12},
  [1246] = {.lex_state = 27, .external_lex_state = 10},
  [1247] = {.lex_state = 28, .external_lex_state = 10},
  [1248] = {.lex_state = 3, .external_lex_state = 12},
  [1249] = {.lex_state = 27, .external_lex_state = 10},
  [1250] = {.lex_state = 27, .external_lex_state = 10},
  [1251] = {.lex_state = 3, .external_lex_state = 12},
  [1252] = {.lex_state = 27, .external_lex_state = 10},
  [1253] = {.lex_state = 27, .external_lex_state = 10},
  [1254] = {.lex_state = 27, .external_lex_state = 10},
  [1255] = {.lex_state = 28, .external_lex_state = 10},
  [1256] = {.lex_state = 28, .external_lex_state = 10},
  [1257] = {.lex_state = 27, .external_lex_state = 10},
  [1258] = {.lex_state = 27, .external_lex_state = 10},
  [1259] = {.lex_state = 28, .external_lex_state = 10},
  [1260] = {.lex_state = 33, .external_lex_state = 10},
  [1261] = {.lex_state = 26, .external_lex_state = 12},
  [1262] = {.lex_state = 3, .external_lex_state = 12},
  [1263] = {.lex_state = 144, .external_lex_state = 2},
  [1264] = {.lex_state = 27, .external_lex_state = 10},
  [1265] = {.lex_state = 28, .external_lex_state = 10},
  [1266] = {.lex_state = 3, .external_lex_state = 12},
  [1267] = {.lex_state = 3, .external_lex_state = 10},
  [1268] = {.lex_state = 26, .external_lex_state = 11},
  [1269] = {.lex_state = 3, .external_lex_state = 10},
  [1270] = {.lex_state = 3, .external_lex_state = 10},
  [1271] = {.lex_state = 3, .external_lex_state = 12},
  [1272] = {.lex_state = 25, .external_lex_state = 8},
  [1273] = {.lex_state = 28, .external_lex_state = 10},
  [1274] = {.lex_state = 28, .external_lex_state = 10},
  [1275] = {.lex_state = 28, .external_lex_state = 10},
  [1276] = {.lex_state = 28, .external_lex_state = 10},
  [1277] = {.lex_state = 28, .external_lex_state = 10},
  [1278] = {.lex_state = 28, .external_lex_state = 10},
  [1279] = {.lex_state = 28, .external_lex_state = 10},
  [1280] = {.lex_state = 28, .external_lex_state = 10},
  [1281] = {.lex_state = 28, .external_lex_state = 10},
  [1282] = {.lex_state = 28, .external_lex_state = 10},
  [1283] = {.lex_state = 28, .external_lex_state = 10},
  [1284] = {.lex_state = 28, .external_lex_state = 10},
  [1285] = {.lex_state = 2, .external_lex_state = 13},
  [1286] = {.lex_state = 28, .external_lex_state = 10},
  [1287] = {.lex_state = 28, .external_lex_state = 10},
  [1288] = {.lex_state = 26, .external_lex_state = 12},
  [1289] = {.lex_state = 3, .external_lex_state = 12},
  [1290] = {.lex_state = 3, .external_lex_state = 12},
  [1291] = {.lex_state = 3, .external_lex_state = 10},
  [1292] = {.lex_state = 3, .external_lex_state = 10},
  [1293] = {.lex_state = 28, .external_lex_state = 10},
  [1294] = {.lex_state = 3, .external_lex_state = 10},
  [1295] = {.lex_state = 26, .external_lex_state = 13},
  [1296] = {.lex_state = 3, .external_lex_state = 12},
  [1297] = {.lex_state = 28, .external_lex_state = 10},
  [1298] = {.lex_state = 3, .external_lex_state = 12},
  [1299] = {.lex_state = 26, .external_lex_state = 11},
  [1300] = {.lex_state = 3, .external_lex_state = 10},
  [1301] = {.lex_state = 3, .external_lex_state = 11},
  [1302] = {.lex_state = 3, .external_lex_state = 10},
  [1303] = {.lex_state = 3, .external_lex_state = 10},
  [1304] = {.lex_state = 3, .external_lex_state = 11},
  [1305] = {.lex_state = 3, .external_lex_state = 12},
  [1306] = {.lex_state = 26, .external_lex_state = 12},
  [1307] = {.lex_state = 3, .external_lex_state = 12},
  [1308] = {.lex_state = 28, .external_lex_state = 10},
  [1309] = {.lex_state = 28, .external_lex_state = 10},
  [1310] = {.lex_state = 28, .external_lex_state = 10},
  [1311] = {.lex_state = 28, .external_lex_state = 10},
  [1312] = {.lex_state = 3, .external_lex_state = 10},
  [1313] = {.lex_state = 3, .external_lex_state = 12},
  [1314] = {.lex_state = 3, .external_lex_state = 10},
  [1315] = {.lex_state = 28, .external_lex_state = 10},
  [1316] = {.lex_state = 3, .external_lex_state = 10},
  [1317] = {.lex_state = 3, .external_lex_state = 10},
  [1318] = {.lex_state = 3, .external_lex_state = 10},
  [1319] = {.lex_state = 3, .external_lex_state = 10},
  [1320] = {.lex_state = 25, .external_lex_state = 8},
  [1321] = {.lex_state = 3, .external_lex_state = 10},
  [1322] = {.lex_state = 3, .external_lex_state = 10},
  [1323] = {.lex_state = 3, .external_lex_state = 10},
  [1324] = {.lex_state = 3, .external_lex_state = 10},
  [1325] = {.lex_state = 28, .external_lex_state = 10},
  [1326] = {.lex_state = 28, .external_lex_state = 10},
  [1327] = {.lex_state = 3, .external_lex_state = 10},
  [1328] = {.lex_state = 32, .external_lex_state = 12},
  [1329] = {.lex_state = 32, .external_lex_state = 12},
  [1330] = {.lex_state = 3, .external_lex_state = 10},
  [1331] = {.lex_state = 3, .external_lex_state = 10},
  [1332] = {.lex_state = 3, .external_lex_state = 12},
  [1333] = {.lex_state = 144, .external_lex_state = 2},
  [1334] = {.lex_state = 3, .external_lex_state = 10},
  [1335] = {.lex_state = 3, .external_lex_state = 12},
  [1336] = {.lex_state = 3, .external_lex_state = 12},
  [1337] = {.lex_state = 3, .external_lex_state = 10},
  [1338] = {.lex_state = 3, .external_lex_state = 10},
  [1339] = {.lex_state = 3, .external_lex_state = 12},
  [1340] = {.lex_state = 3, .external_lex_state = 12},
  [1341] = {.lex_state = 26, .external_lex_state = 12},
  [1342] = {.lex_state = 32, .external_lex_state = 12},
  [1343] = {.lex_state = 3, .external_lex_state = 12},
  [1344] = {.lex_state = 9, .external_lex_state = 12},
  [1345] = {.lex_state = 9, .external_lex_state = 12},
  [1346] = {.lex_state = 3, .external_lex_state = 12},
  [1347] = {.lex_state = 3, .external_lex_state = 10},
  [1348] = {.lex_state = 3, .external_lex_state = 12},
  [1349] = {.lex_state = 3, .external_lex_state = 10},
  [1350] = {.lex_state = 9, .external_lex_state = 12},
  [1351] = {.lex_state = 3, .external_lex_state = 10},
  [1352] = {.lex_state = 3, .external_lex_state = 10},
  [1353] = {.lex_state = 3, .external_lex_state = 12},
  [1354] = {.lex_state = 3, .external_lex_state = 10},
  [1355] = {.lex_state = 26, .external_lex_state = 11},
  [1356] = {.lex_state = 3, .external_lex_state = 10},
  [1357] = {.lex_state = 3, .external_lex_state = 12},
  [1358] = {.lex_state = 26, .external_lex_state = 12},
  [1359] = {.lex_state = 3, .external_lex_state = 10},
  [1360] = {.lex_state = 26, .external_lex_state = 12},
  [1361] = {.lex_state = 26, .external_lex_state = 12},
  [1362] = {.lex_state = 26, .external_lex_state = 12},
  [1363] = {.lex_state = 3, .external_lex_state = 10},
  [1364] = {.lex_state = 3, .external_lex_state = 10},
  [1365] = {.lex_state = 3, .external_lex_state = 10},
  [1366] = {.lex_state = 3, .external_lex_state = 10},
  [1367] = {.lex_state = 27, .external_lex_state = 10},
  [1368] = {.lex_state = 3, .external_lex_state = 10},
  [1369] = {.lex_state = 27, .external_lex_state = 10},
  [1370] = {.lex_state = 26, .external_lex_state = 12},
  [1371] = {.lex_state = 3, .external_lex_state = 12},
  [1372] = {.lex_state = 26, .external_lex_state = 12},
  [1373] = {.lex_state = 3, .external_lex_state = 12},
  [1374] = {.lex_state = 3, .external_lex_state = 12},
  [1375] = {.lex_state = 26, .external_lex_state = 12},
  [1376] = {.lex_state = 26, .external_lex_state = 12},
  [1377] = {.lex_state = 3, .external_lex_state = 12},
  [1378] = {.lex_state = 3, .external_lex_state = 12},
  [1379] = {.lex_state = 144, .external_lex_state = 2},
  [1380] = {.lex_state = 27, .external_lex_state = 10},
  [1381] = {.lex_state = 27, .external_lex_state = 10},
  [1382] = {.lex_state = 27, .external_lex_state = 10},
  [1383] = {.lex_state = 26, .external_lex_state = 12},
  [1384] = {.lex_state = 144, .external_lex_state = 2},
  [1385] = {.lex_state = 27, .external_lex_state = 10},
  [1386] = {.lex_state = 144, .external_lex_state = 2},
  [1387] = {.lex_state = 27, .external_lex_state = 10},
  [1388] = {.lex_state = 144, .external_lex_state = 2},
  [1389] = {.lex_state = 144, .external_lex_state = 2},
  [1390] = {.lex_state = 27, .external_lex_state = 10},
  [1391] = {.lex_state = 27, .external_lex_state = 10},
  [1392] = {.lex_state = 3, .external_lex_state = 12},
  [1393] = {.lex_state = 26, .external_lex_state = 12},
  [1394] = {.lex_state = 3, .external_lex_state = 12},
  [1395] = {.lex_state = 26, .external_lex_state = 12},
  [1396] = {.lex_state = 26, .external_lex_state = 12},
  [1397] = {.lex_state = 3, .external_lex_state = 12},
  [1398] = {.lex_state = 3, .external_lex_state = 10},
  [1399] = {.lex_state = 26, .external_lex_state = 12},
  [1400] = {.lex_state = 26, .external_lex_state = 12},
  [1401] = {.lex_state = 26, .external_lex_state = 12},
  [1402] = {.lex_state = 26, .external_lex_state = 12},
  [1403] = {.lex_state = 26, .external_lex_state = 12},
  [1404] = {.lex_state = 26, .external_lex_state = 12},
  [1405] = {.lex_state = 26, .external_lex_state = 12},
  [1406] = {.lex_state = 26, .external_lex_state = 12},
  [1407] = {.lex_state = 26, .external_lex_state = 12},
  [1408] = {.lex_state = 26, .external_lex_state = 12},
  [1409] = {.lex_state = 26, .external_lex_state = 12},
  [1410] = {.lex_state = 26, .external_lex_state = 12},
  [1411] = {.lex_state = 26, .external_lex_state = 12},
  [1412] = {.lex_state = 26, .external_lex_state = 12},
  [1413] = {.lex_state = 26, .external_lex_state = 12},
  [1414] = {.lex_state = 26, .external_lex_state = 12},
  [1415] = {.lex_state = 26, .external_lex_state = 12},
  [1416] = {.lex_state = 26, .external_lex_state = 12},
  [1417] = {.lex_state = 26, .external_lex_state = 12},
  [1418] = {.lex_state = 27, .external_lex_state = 10},
  [1419] = {.lex_state = 3, .external_lex_state = 12},
  [1420] = {.lex_state = 3, .external_lex_state = 12},
  [1421] = {.lex_state = 3, .external_lex_state = 12},
  [1422] = {.lex_state = 26, .external_lex_state = 12},
  [1423] = {.lex_state = 26, .external_lex_state = 12},
  [1424] = {.lex_state = 144, .external_lex_state = 2},
  [1425] = {.lex_state = 144, .external_lex_state = 2},
  [1426] = {.lex_state = 26, .external_lex_state = 12},
  [1427] = {.lex_state = 26, .external_lex_state = 12},
  [1428] = {.lex_state = 144, .external_lex_state = 2},
  [1429] = {.lex_state = 144, .external_lex_state = 2},
  [1430] = {.lex_state = 26, .external_lex_state = 12},
  [1431] = {.lex_state = 3, .external_lex_state = 12},
  [1432] = {.lex_state = 144, .external_lex_state = 2},
  [1433] = {.lex_state = 144, .external_lex_state = 2},
  [1434] = {.lex_state = 144, .external_lex_state = 2},
  [1435] = {.lex_state = 26, .external_lex_state = 12},
  [1436] = {.lex_state = 144, .external_lex_state = 2},
  [1437] = {.lex_state = 144, .external_lex_state = 2},
  [1438] = {.lex_state = 144, .external_lex_state = 2},
  [1439] = {.lex_state = 144, .external_lex_state = 2},
  [1440] = {.lex_state = 144, .external_lex_state = 2},
  [1441] = {.lex_state = 144, .external_lex_state = 2},
  [1442] = {.lex_state = 144, .external_lex_state = 2},
  [1443] = {.lex_state = 144, .external_lex_state = 2},
  [1444] = {.lex_state = 31},
  [1445] = {.lex_state = 144, .external_lex_state = 2},
  [1446] = {.lex_state = 144, .external_lex_state = 2},
  [1447] = {.lex_state = 144, .external_lex_state = 2},
  [1448] = {.lex_state = 144, .external_lex_state = 2},
  [1449] = {.lex_state = 144, .external_lex_state = 2},
  [1450] = {.lex_state = 3, .external_lex_state = 12},
  [1451] = {.lex_state = 144, .external_lex_state = 2},
  [1452] = {.lex_state = 144, .external_lex_state = 2},
  [1453] = {.lex_state = 144, .external_lex_state = 2},
  [1454] = {.lex_state = 26, .external_lex_state = 12},
  [1455] = {.lex_state = 144, .external_lex_state = 2},
  [1456] = {.lex_state = 144, .external_lex_state = 2},
  [1457] = {.lex_state = 144, .external_lex_state = 2},
  [1458] = {.lex_state = 144, .external_lex_state = 2},
  [1459] = {.lex_state = 144, .external_lex_state = 2},
  [1460] = {.lex_state = 144, .external_lex_state = 2},
  [1461] = {.lex_state = 144, .external_lex_state = 2},
  [1462] = {.lex_state = 144, .external_lex_state = 2},
  [1463] = {.lex_state = 144, .external_lex_state = 2},
  [1464] = {.lex_state = 144, .external_lex_state = 2},
  [1465] = {.lex_state = 144, .external_lex_state = 2},
  [1466] = {.lex_state = 144, .external_lex_state = 2},
  [1467] = {.lex_state = 144, .external_lex_state = 2},
  [1468] = {.lex_state = 144, .external_lex_state = 2},
  [1469] = {.lex_state = 144, .external_lex_state = 2},
  [1470] = {.lex_state = 144, .external_lex_state = 2},
  [1471] = {.lex_state = 144, .external_lex_state = 2},
  [1472] = {.lex_state = 144, .external_lex_state = 2},
  [1473] = {.lex_state = 144, .external_lex_state = 2},
  [1474] = {.lex_state = 144, .external_lex_state = 2},
  [1475] = {.lex_state = 144, .external_lex_state = 2},
  [1476] = {.lex_state = 144, .external_lex_state = 2},
  [1477] = {.lex_state = 144, .external_lex_state = 2},
  [1478] = {.lex_state = 144, .external_lex_state = 2},
  [1479] = {.lex_state = 144, .external_lex_state = 2},
  [1480] = {.lex_state = 144, .external_lex_state = 2},
  [1481] = {.lex_state = 144, .external_lex_state = 2},
  [1482] = {.lex_state = 144, .external_lex_state = 2},
  [1483] = {.lex_state = 144, .external_lex_state = 2},
  [1484] = {.lex_state = 144, .external_lex_state = 2},
  [1485] = {.lex_state = 144, .external_lex_state = 2},
  [1486] = {.lex_state = 144, .external_lex_state = 2},
  [1487] = {.lex_state = 144, .external_lex_state = 2},
  [1488] = {.lex_state = 144, .external_lex_state = 2},
  [1489] = {.lex_state = 26, .external_lex_state = 12},
  [1490] = {.lex_state = 144, .external_lex_state = 2},
  [1491] = {.lex_state = 144, .external_lex_state = 2},
  [1492] = {.lex_state = 144, .external_lex_state = 2},
  [1493] = {.lex_state = 144, .external_lex_state = 2},
  [1494] = {.lex_state = 144, .external_lex_state = 2},
  [1495] = {.lex_state = 144, .external_lex_state = 2},
  [1496] = {.lex_state = 144, .external_lex_state = 2},
  [1497] = {.lex_state = 144, .external_lex_state = 2},
  [1498] = {.lex_state = 144, .external_lex_state = 2},
  [1499] = {.lex_state = 3, .external_lex_state = 12},
  [1500] = {.lex_state = 144, .external_lex_state = 2},
  [1501] = {.lex_state = 26, .external_lex_state = 12},
  [1502] = {.lex_state = 144, .external_lex_state = 2},
  [1503] = {.lex_state = 144, .external_lex_state = 2},
  [1504] = {.lex_state = 144, .external_lex_state = 2},
  [1505] = {.lex_state = 144, .external_lex_state = 2},
  [1506] = {.lex_state = 144, .external_lex_state = 2},
  [1507] = {.lex_state = 144, .external_lex_state = 2},
  [1508] = {.lex_state = 144, .external_lex_state = 2},
  [1509] = {.lex_state = 144, .external_lex_state = 2},
  [1510] = {.lex_state = 25, .external_lex_state = 8},
  [1511] = {.lex_state = 144, .external_lex_state = 2},
  [1512] = {.lex_state = 31},
  [1513] = {.lex_state = 31},
  [1514] = {.lex_state = 26, .external_lex_state = 12},
  [1515] = {.lex_state = 31},
  [1516] = {.lex_state = 48, .external_lex_state = 2},
  [1517] = {.lex_state = 31},
  [1518] = {.lex_state = 31},
  [1519] = {.lex_state = 144, .external_lex_state = 2},
  [1520] = {.lex_state = 31},
  [1521] = {.lex_state = 31},
  [1522] = {.lex_state = 42},
  [1523] = {.lex_state = 42},
  [1524] = {.lex_state = 31},
  [1525] = {.lex_state = 42},
  [1526] = {.lex_state = 42},
  [1527] = {.lex_state = 42},
  [1528] = {.lex_state = 42},
  [1529] = {.lex_state = 7, .external_lex_state = 14},
  [1530] = {.lex_state = 32},
  [1531] = {.lex_state = 32},
  [1532] = {.lex_state = 32},
  [1533] = {.lex_state = 32},
  [1534] = {.lex_state = 32},
  [1535] = {.lex_state = 32},
  [1536] = {.lex_state = 32},
  [1537] = {.lex_state = 32},
  [1538] = {.lex_state = 2},
  [1539] = {.lex_state = 42},
  [1540] = {.lex_state = 42},
  [1541] = {.lex_state = 42},
  [1542] = {.lex_state = 42},
  [1543] = {.lex_state = 42},
  [1544] = {.lex_state = 42},
  [1545] = {.lex_state = 42},
  [1546] = {.lex_state = 2},
  [1547] = {.lex_state = 2},
  [1548] = {.lex_state = 2},
  [1549] = {.lex_state = 42},
  [1550] = {.lex_state = 2},
  [1551] = {.lex_state = 2},
  [1552] = {.lex_state = 42},
  [1553] = {.lex_state = 42},
  [1554] = {.lex_state = 2},
  [1555] = {.lex_state = 42},
  [1556] = {.lex_state = 2},
  [1557] = {.lex_state = 2},
  [1558] = {.lex_state = 32},
  [1559] = {.lex_state = 2},
  [1560] = {.lex_state = 2},
  [1561] = {.lex_state = 32},
  [1562] = {.lex_state = 32},
  [1563] = {.lex_state = 32},
  [1564] = {.lex_state = 2},
  [1565] = {.lex_state = 31},
  [1566] = {.lex_state = 31},
  [1567] = {.lex_state = 32},
  [1568] = {.lex_state = 2},
  [1569] = {.lex_state = 32},
  [1570] = {.lex_state = 2},
  [1571] = {.lex_state = 32},
  [1572] = {.lex_state = 2},
  [1573] = {.lex_state = 32},
  [1574] = {.lex_state = 42},
  [1575] = {.lex_state = 2},
  [1576] = {.lex_state = 2},
  [1577] = {.lex_state = 42},
  [1578] = {.lex_state = 42},
  [1579] = {.lex_state = 2},
  [1580] = {.lex_state = 29},
  [1581] = {.lex_state = 42},
  [1582] = {.lex_state = 42},
  [1583] = {.lex_state = 42},
  [1584] = {.lex_state = 42},
  [1585] = {.lex_state = 29},
  [1586] = {.lex_state = 42},
  [1587] = {.lex_state = 29},
  [1588] = {.lex_state = 42},
  [1589] = {.lex_state = 42},
  [1590] = {.lex_state = 42},
  [1591] = {.lex_state = 2},
  [1592] = {.lex_state = 42},
  [1593] = {.lex_state = 29},
  [1594] = {.lex_state = 29},
  [1595] = {.lex_state = 29},
  [1596] = {.lex_state = 29},
  [1597] = {.lex_state = 29},
  [1598] = {.lex_state = 42},
  [1599] = {.lex_state = 42},
  [1600] = {.lex_state = 42},
  [1601] = {.lex_state = 29},
  [1602] = {.lex_state = 42},
  [1603] = {.lex_state = 29},
  [1604] = {.lex_state = 2},
  [1605] = {.lex_state = 29},
  [1606] = {.lex_state = 42},
  [1607] = {.lex_state = 29},
  [1608] = {.lex_state = 42},
  [1609] = {.lex_state = 29},
  [1610] = {.lex_state = 42},
  [1611] = {.lex_state = 29},
  [1612] = {.lex_state = 42},
  [1613] = {.lex_state = 42},
  [1614] = {.lex_state = 42},
  [1615] = {.lex_state = 29},
  [1616] = {.lex_state = 42},
  [1617] = {.lex_state = 29},
  [1618] = {.lex_state = 42},
  [1619] = {.lex_state = 42},
  [1620] = {.lex_state = 42},
  [1621] = {.lex_state = 42},
  [1622] = {.lex_state = 42},
  [1623] = {.lex_state = 42},
  [1624] = {.lex_state = 42},
  [1625] = {.lex_state = 42},
  [1626] = {.lex_state = 42},
  [1627] = {.lex_state = 42},
  [1628] = {.lex_state = 42},
  [1629] = {.lex_state = 42},
  [1630] = {.lex_state = 42},
  [1631] = {.lex_state = 42},
  [1632] = {.lex_state = 42},
  [1633] = {.lex_state = 42},
  [1634] = {.lex_state = 42},
  [1635] = {.lex_state = 42},
  [1636] = {.lex_state = 42},
  [1637] = {.lex_state = 42},
  [1638] = {.lex_state = 42},
  [1639] = {.lex_state = 42},
  [1640] = {.lex_state = 42},
  [1641] = {.lex_state = 31},
  [1642] = {.lex_state = 42},
  [1643] = {.lex_state = 42},
  [1644] = {.lex_state = 42},
  [1645] = {.lex_state = 42},
  [1646] = {.lex_state = 2},
  [1647] = {.lex_state = 42},
  [1648] = {.lex_state = 42},
  [1649] = {.lex_state = 42},
  [1650] = {.lex_state = 2},
  [1651] = {.lex_state = 42},
  [1652] = {.lex_state = 29},
  [1653] = {.lex_state = 29},
  [1654] = {.lex_state = 2},
  [1655] = {.lex_state = 29},
  [1656] = {.lex_state = 29},
  [1657] = {.lex_state = 42},
  [1658] = {.lex_state = 32},
  [1659] = {.lex_state = 26},
  [1660] = {.lex_state = 26, .external_lex_state = 15},
  [1661] = {.lex_state = 42},
  [1662] = {.lex_state = 26},
  [1663] = {.lex_state = 10},
  [1664] = {.lex_state = 26},
  [1665] = {.lex_state = 26},
  [1666] = {.lex_state = 10},
  [1667] = {.lex_state = 42},
  [1668] = {.lex_state = 32},
  [1669] = {.lex_state = 42},
  [1670] = {.lex_state = 42},
  [1671] = {.lex_state = 42},
  [1672] = {.lex_state = 42},
  [1673] = {.lex_state = 42},
  [1674] = {.lex_state = 42},
  [1675] = {.lex_state = 42},
  [1676] = {.lex_state = 42},
  [1677] = {.lex_state = 35, .external_lex_state = 16},
  [1678] = {.lex_state = 42},
  [1679] = {.lex_state = 8},
  [1680] = {.lex_state = 42},
  [1681] = {.lex_state = 42},
  [1682] = {.lex_state = 42},
  [1683] = {.lex_state = 42},
  [1684] = {.lex_state = 42},
  [1685] = {.lex_state = 35, .external_lex_state = 16},
  [1686] = {.lex_state = 26},
  [1687] = {.lex_state = 12},
  [1688] = {.lex_state = 12},
  [1689] = {.lex_state = 12},
  [1690] = {.lex_state = 12},
  [1691] = {.lex_state = 12},
  [1692] = {.lex_state = 12},
  [1693] = {.lex_state = 12},
  [1694] = {.lex_state = 12},
  [1695] = {.lex_state = 12},
  [1696] = {.lex_state = 26, .external_lex_state = 15},
  [1697] = {.lex_state = 12},
  [1698] = {.lex_state = 12},
  [1699] = {.lex_state = 12},
  [1700] = {.lex_state = 11},
  [1701] = {.lex_state = 41, .external_lex_state = 17},
  [1702] = {.lex_state = 11},
  [1703] = {.lex_state = 41, .external_lex_state = 17},
  [1704] = {.lex_state = 12},
  [1705] = {.lex_state = 11},
  [1706] = {.lex_state = 42},
  [1707] = {.lex_state = 41, .external_lex_state = 17},
  [1708] = {.lex_state = 41, .external_lex_state = 17},
  [1709] = {.lex_state = 41, .external_lex_state = 17},
  [1710] = {.lex_state = 41, .external_lex_state = 17},
  [1711] = {.lex_state = 11},
  [1712] = {.lex_state = 11},
  [1713] = {.lex_state = 41, .external_lex_state = 17},
  [1714] = {.lex_state = 11},
  [1715] = {.lex_state = 11},
  [1716] = {.lex_state = 11},
  [1717] = {.lex_state = 41, .external_lex_state = 17},
  [1718] = {.lex_state = 41, .external_lex_state = 17},
  [1719] = {.lex_state = 11},
  [1720] = {.lex_state = 41, .external_lex_state = 17},
  [1721] = {.lex_state = 26},
  [1722] = {.lex_state = 31},
  [1723] = {.lex_state = 144},
  [1724] = {.lex_state = 42},
  [1725] = {.lex_state = 11},
  [1726] = {.lex_state = 32},
  [1727] = {.lex_state = 12},
  [1728] = {.lex_state = 11},
  [1729] = {.lex_state = 41, .external_lex_state = 17},
  [1730] = {.lex_state = 41, .external_lex_state = 17},
  [1731] = {.lex_state = 41, .external_lex_state = 17},
  [1732] = {.lex_state = 11},
  [1733] = {.lex_state = 11},
  [1734] = {.lex_state = 41, .external_lex_state = 17},
  [1735] = {.lex_state = 41, .external_lex_state = 17},
  [1736] = {.lex_state = 42},
  [1737] = {.lex_state = 11},
  [1738] = {.lex_state = 144},
  [1739] = {.lex_state = 41, .external_lex_state = 17},
  [1740] = {.lex_state = 41, .external_lex_state = 17},
  [1741] = {.lex_state = 12},
  [1742] = {.lex_state = 42},
  [1743] = {.lex_state = 31},
  [1744] = {.lex_state = 16},
  [1745] = {.lex_state = 11},
  [1746] = {.lex_state = 11},
  [1747] = {.lex_state = 26},
  [1748] = {.lex_state = 41, .external_lex_state = 17},
  [1749] = {.lex_state = 11},
  [1750] = {.lex_state = 42},
  [1751] = {.lex_state = 41, .external_lex_state = 17},
  [1752] = {.lex_state = 26},
  [1753] = {.lex_state = 12},
  [1754] = {.lex_state = 41, .external_lex_state = 17},
  [1755] = {.lex_state = 11},
  [1756] = {.lex_state = 11},
  [1757] = {.lex_state = 12},
  [1758] = {.lex_state = 41, .external_lex_state = 17},
  [1759] = {.lex_state = 41, .external_lex_state = 17},
  [1760] = {.lex_state = 41, .external_lex_state = 17},
  [1761] = {.lex_state = 11},
  [1762] = {.lex_state = 41, .external_lex_state = 17},
  [1763] = {.lex_state = 41, .external_lex_state = 17},
  [1764] = {.lex_state = 26},
  [1765] = {.lex_state = 26},
  [1766] = {.lex_state = 144},
  [1767] = {.lex_state = 32},
  [1768] = {.lex_state = 26},
  [1769] = {.lex_state = 26},
  [1770] = {.lex_state = 26},
  [1771] = {.lex_state = 26},
  [1772] = {.lex_state = 26},
  [1773] = {.lex_state = 144},
  [1774] = {.lex_state = 26},
  [1775] = {.lex_state = 26},
  [1776] = {.lex_state = 26},
  [1777] = {.lex_state = 8},
  [1778] = {.lex_state = 26},
  [1779] = {.lex_state = 49},
  [1780] = {.lex_state = 26},
  [1781] = {.lex_state = 26},
  [1782] = {.lex_state = 31},
  [1783] = {.lex_state = 31},
  [1784] = {.lex_state = 26},
  [1785] = {.lex_state = 31},
  [1786] = {.lex_state = 26},
  [1787] = {.lex_state = 26},
  [1788] = {.lex_state = 26},
  [1789] = {.lex_state = 26},
  [1790] = {.lex_state = 26},
  [1791] = {.lex_state = 26},
  [1792] = {.lex_state = 26},
  [1793] = {.lex_state = 8},
  [1794] = {.lex_state = 26},
  [1795] = {.lex_state = 26},
  [1796] = {.lex_state = 144},
  [1797] = {.lex_state = 26},
  [1798] = {.lex_state = 26},
  [1799] = {.lex_state = 26},
  [1800] = {.lex_state = 26},
  [1801] = {.lex_state = 49},
  [1802] = {.lex_state = 26},
  [1803] = {.lex_state = 26},
  [1804] = {.lex_state = 26},
  [1805] = {.lex_state = 26},
  [1806] = {.lex_state = 26},
  [1807] = {.lex_state = 26},
  [1808] = {.lex_state = 26},
  [1809] = {.lex_state = 8},
  [1810] = {.lex_state = 12},
  [1811] = {.lex_state = 26},
  [1812] = {.lex_state = 8},
  [1813] = {.lex_state = 31},
  [1814] = {.lex_state = 144},
  [1815] = {.lex_state = 47, .external_lex_state = 16},
  [1816] = {.lex_state = 144},
  [1817] = {.lex_state = 11},
  [1818] = {.lex_state = 26},
  [1819] = {.lex_state = 144},
  [1820] = {.lex_state = 144},
  [1821] = {.lex_state = 144},
  [1822] = {.lex_state = 32},
  [1823] = {.lex_state = 26, .external_lex_state = 16},
  [1824] = {.lex_state = 11},
  [1825] = {.lex_state = 144},
  [1826] = {.lex_state = 144},
  [1827] = {.lex_state = 26},
  [1828] = {.lex_state = 26},
  [1829] = {.lex_state = 144},
  [1830] = {.lex_state = 26},
  [1831] = {.lex_state = 31},
  [1832] = {.lex_state = 26},
  [1833] = {.lex_state = 26},
  [1834] = {.lex_state = 26},
  [1835] = {.lex_state = 31},
  [1836] = {.lex_state = 26},
  [1837] = {.lex_state = 26},
  [1838] = {.lex_state = 26},
  [1839] = {.lex_state = 32},
  [1840] = {.lex_state = 26},
  [1841] = {.lex_state = 41, .external_lex_state = 17},
  [1842] = {.lex_state = 35, .external_lex_state = 16},
  [1843] = {.lex_state = 26},
  [1844] = {.lex_state = 31},
  [1845] = {.lex_state = 26},
  [1846] = {.lex_state = 11},
  [1847] = {.lex_state = 144},
  [1848] = {.lex_state = 26},
  [1849] = {.lex_state = 144},
  [1850] = {.lex_state = 26},
  [1851] = {.lex_state = 41, .external_lex_state = 17},
  [1852] = {.lex_state = 26},
  [1853] = {.lex_state = 26},
  [1854] = {.lex_state = 144},
  [1855] = {.lex_state = 31},
  [1856] = {.lex_state = 47, .external_lex_state = 16},
  [1857] = {.lex_state = 144},
  [1858] = {.lex_state = 144},
  [1859] = {.lex_state = 144},
  [1860] = {.lex_state = 11},
  [1861] = {.lex_state = 144},
  [1862] = {.lex_state = 144},
  [1863] = {.lex_state = 144},
  [1864] = {.lex_state = 144},
  [1865] = {.lex_state = 11},
  [1866] = {.lex_state = 11},
  [1867] = {.lex_state = 26},
  [1868] = {.lex_state = 31},
  [1869] = {.lex_state = 26},
  [1870] = {.lex_state = 26},
  [1871] = {.lex_state = 26},
  [1872] = {.lex_state = 26},
  [1873] = {.lex_state = 26},
  [1874] = {.lex_state = 26},
  [1875] = {.lex_state = 26},
  [1876] = {.lex_state = 26},
  [1877] = {.lex_state = 26},
  [1878] = {.lex_state = 26},
  [1879] = {.lex_state = 26},
  [1880] = {.lex_state = 144},
  [1881] = {.lex_state = 26},
  [1882] = {.lex_state = 144},
  [1883] = {.lex_state = 26},
  [1884] = {.lex_state = 144},
  [1885] = {.lex_state = 47, .external_lex_state = 16},
  [1886] = {.lex_state = 144},
  [1887] = {.lex_state = 26},
  [1888] = {.lex_state = 144},
  [1889] = {.lex_state = 26},
  [1890] = {.lex_state = 26},
  [1891] = {.lex_state = 26},
  [1892] = {.lex_state = 26},
  [1893] = {.lex_state = 26},
  [1894] = {.lex_state = 26},
  [1895] = {.lex_state = 26},
  [1896] = {.lex_state = 144},
  [1897] = {.lex_state = 26},
  [1898] = {.lex_state = 26},
  [1899] = {.lex_state = 26},
  [1900] = {.lex_state = 26},
  [1901] = {.lex_state = 144},
  [1902] = {.lex_state = 26},
  [1903] = {.lex_state = 144},
  [1904] = {.lex_state = 144},
  [1905] = {.lex_state = 144},
  [1906] = {.lex_state = 31},
  [1907] = {.lex_state = 11},
  [1908] = {.lex_state = 31},
  [1909] = {.lex_state = 31},
  [1910] = {.lex_state = 26},
  [1911] = {.lex_state = 26},
  [1912] = {.lex_state = 31},
  [1913] = {.lex_state = 31},
  [1914] = {.lex_state = 31},
  [1915] = {.lex_state = 11},
  [1916] = {.lex_state = 11},
  [1917] = {.lex_state = 144},
  [1918] = {.lex_state = 26},
  [1919] = {.lex_state = 31},
  [1920] = {.lex_state = 31},
  [1921] = {.lex_state = 144},
  [1922] = {.lex_state = 26},
  [1923] = {.lex_state = 144},
  [1924] = {.lex_state = 26},
  [1925] = {.lex_state = 144},
  [1926] = {.lex_state = 26},
  [1927] = {.lex_state = 31},
  [1928] = {.lex_state = 144},
  [1929] = {.lex_state = 144},
  [1930] = {.lex_state = 31},
  [1931] = {.lex_state = 31},
  [1932] = {.lex_state = 31},
  [1933] = {.lex_state = 31},
  [1934] = {.lex_state = 31},
  [1935] = {.lex_state = 31},
  [1936] = {.lex_state = 26},
  [1937] = {.lex_state = 16},
  [1938] = {.lex_state = 144},
  [1939] = {.lex_state = 144},
  [1940] = {.lex_state = 31},
  [1941] = {.lex_state = 31},
  [1942] = {.lex_state = 31},
  [1943] = {.lex_state = 31},
  [1944] = {.lex_state = 31},
  [1945] = {.lex_state = 16},
  [1946] = {.lex_state = 26},
  [1947] = {.lex_state = 26},
  [1948] = {.lex_state = 36},
  [1949] = {.lex_state = 36},
  [1950] = {.lex_state = 36},
  [1951] = {.lex_state = 26, .external_lex_state = 16},
  [1952] = {.lex_state = 144},
  [1953] = {.lex_state = 144},
  [1954] = {.lex_state = 144},
  [1955] = {.lex_state = 31},
  [1956] = {.lex_state = 26},
  [1957] = {.lex_state = 36},
  [1958] = {.lex_state = 32},
  [1959] = {.lex_state = 144},
  [1960] = {.lex_state = 36},
  [1961] = {.lex_state = 31},
  [1962] = {.lex_state = 26},
  [1963] = {.lex_state = 31},
  [1964] = {.lex_state = 144},
  [1965] = {.lex_state = 31},
  [1966] = {.lex_state = 144},
  [1967] = {.lex_state = 26},
  [1968] = {.lex_state = 144},
  [1969] = {.lex_state = 36},
  [1970] = {.lex_state = 26},
  [1971] = {.lex_state = 144},
  [1972] = {.lex_state = 26},
  [1973] = {.lex_state = 26},
  [1974] = {.lex_state = 26},
  [1975] = {.lex_state = 31},
  [1976] = {.lex_state = 26},
  [1977] = {.lex_state = 26},
  [1978] = {.lex_state = 31},
  [1979] = {.lex_state = 26},
  [1980] = {.lex_state = 31},
  [1981] = {.lex_state = 144},
  [1982] = {.lex_state = 144},
  [1983] = {.lex_state = 36},
  [1984] = {.lex_state = 31},
  [1985] = {.lex_state = 31},
  [1986] = {.lex_state = 144},
  [1987] = {.lex_state = 36},
  [1988] = {.lex_state = 31},
  [1989] = {.lex_state = 26},
  [1990] = {.lex_state = 144},
  [1991] = {.lex_state = 8},
  [1992] = {.lex_state = 26},
  [1993] = {.lex_state = 36},
  [1994] = {.lex_state = 26},
  [1995] = {.lex_state = 26},
  [1996] = {.lex_state = 26},
  [1997] = {.lex_state = 144},
  [1998] = {.lex_state = 8},
  [1999] = {.lex_state = 26},
  [2000] = {.lex_state = 26},
  [2001] = {.lex_state = 26},
  [2002] = {.lex_state = 144},
  [2003] = {.lex_state = 26, .external_lex_state = 16},
  [2004] = {.lex_state = 144},
  [2005] = {.lex_state = 144},
  [2006] = {.lex_state = 26},
  [2007] = {.lex_state = 144},
  [2008] = {.lex_state = 26},
  [2009] = {.lex_state = 144},
  [2010] = {.lex_state = 26},
  [2011] = {.lex_state = 36},
  [2012] = {.lex_state = 36},
  [2013] = {.lex_state = 144},
  [2014] = {.lex_state = 31},
  [2015] = {.lex_state = 144},
  [2016] = {.lex_state = 31},
  [2017] = {.lex_state = 144},
  [2018] = {.lex_state = 36},
  [2019] = {.lex_state = 36},
  [2020] = {.lex_state = 144},
  [2021] = {.lex_state = 49},
  [2022] = {.lex_state = 36},
  [2023] = {.lex_state = 144},
  [2024] = {.lex_state = 144},
  [2025] = {.lex_state = 26},
  [2026] = {.lex_state = 26},
  [2027] = {.lex_state = 36},
  [2028] = {.lex_state = 36},
  [2029] = {.lex_state = 144},
  [2030] = {.lex_state = 144},
  [2031] = {.lex_state = 36},
  [2032] = {.lex_state = 26},
  [2033] = {.lex_state = 26},
  [2034] = {.lex_state = 144},
  [2035] = {.lex_state = 144},
  [2036] = {.lex_state = 26},
  [2037] = {.lex_state = 144},
  [2038] = {.lex_state = 26},
  [2039] = {.lex_state = 26},
  [2040] = {.lex_state = 144},
  [2041] = {.lex_state = 31},
  [2042] = {.lex_state = 31},
  [2043] = {.lex_state = 26},
  [2044] = {.lex_state = 144},
  [2045] = {.lex_state = 26},
  [2046] = {.lex_state = 26},
  [2047] = {.lex_state = 26},
  [2048] = {.lex_state = 26},
  [2049] = {.lex_state = 144},
  [2050] = {.lex_state = 3},
  [2051] = {.lex_state = 26},
  [2052] = {.lex_state = 26},
  [2053] = {.lex_state = 26},
  [2054] = {.lex_state = 26},
  [2055] = {.lex_state = 26},
  [2056] = {.lex_state = 26},
  [2057] = {.lex_state = 26},
  [2058] = {.lex_state = 26},
  [2059] = {.lex_state = 26},
  [2060] = {.lex_state = 26},
  [2061] = {.lex_state = 26},
  [2062] = {.lex_state = 26},
  [2063] = {.lex_state = 26},
  [2064] = {.lex_state = 26},
  [2065] = {.lex_state = 26},
  [2066] = {.lex_state = 26},
  [2067] = {.lex_state = 26},
  [2068] = {.lex_state = 144},
  [2069] = {.lex_state = 26},
  [2070] = {.lex_state = 26},
  [2071] = {.lex_state = 144},
  [2072] = {.lex_state = 144},
  [2073] = {.lex_state = 31},
  [2074] = {.lex_state = 31},
  [2075] = {.lex_state = 26},
  [2076] = {.lex_state = 26},
  [2077] = {.lex_state = 26},
  [2078] = {.lex_state = 26},
  [2079] = {.lex_state = 31},
  [2080] = {.lex_state = 26},
  [2081] = {.lex_state = 26},
  [2082] = {.lex_state = 26},
  [2083] = {.lex_state = 26},
  [2084] = {.lex_state = 26},
  [2085] = {.lex_state = 26},
  [2086] = {.lex_state = 26},
  [2087] = {.lex_state = 26},
  [2088] = {.lex_state = 26},
  [2089] = {.lex_state = 26},
  [2090] = {.lex_state = 26},
  [2091] = {.lex_state = 26},
  [2092] = {.lex_state = 31},
  [2093] = {.lex_state = 31},
  [2094] = {.lex_state = 144},
  [2095] = {.lex_state = 26},
  [2096] = {.lex_state = 144},
  [2097] = {.lex_state = 26},
  [2098] = {.lex_state = 144},
  [2099] = {.lex_state = 26},
  [2100] = {.lex_state = 26},
  [2101] = {.lex_state = 26},
  [2102] = {.lex_state = 26},
  [2103] = {.lex_state = 26},
  [2104] = {.lex_state = 26},
  [2105] = {.lex_state = 26},
  [2106] = {.lex_state = 26},
  [2107] = {.lex_state = 31},
  [2108] = {.lex_state = 31},
  [2109] = {.lex_state = 144},
  [2110] = {.lex_state = 26},
  [2111] = {.lex_state = 144},
  [2112] = {.lex_state = 26},
  [2113] = {.lex_state = 26},
  [2114] = {.lex_state = 26},
  [2115] = {.lex_state = 26},
  [2116] = {.lex_state = 26},
  [2117] = {.lex_state = 26},
  [2118] = {.lex_state = 26},
  [2119] = {.lex_state = 26},
  [2120] = {.lex_state = 31},
  [2121] = {.lex_state = 26},
  [2122] = {.lex_state = 26},
  [2123] = {.lex_state = 26},
  [2124] = {.lex_state = 26},
  [2125] = {.lex_state = 26},
  [2126] = {.lex_state = 26},
  [2127] = {.lex_state = 26},
  [2128] = {.lex_state = 26},
  [2129] = {.lex_state = 26},
  [2130] = {.lex_state = 26},
  [2131] = {.lex_state = 26},
  [2132] = {.lex_state = 31},
  [2133] = {.lex_state = 144},
  [2134] = {.lex_state = 26},
  [2135] = {.lex_state = 26},
  [2136] = {.lex_state = 26},
  [2137] = {.lex_state = 26},
  [2138] = {.lex_state = 26},
  [2139] = {.lex_state = 26},
  [2140] = {.lex_state = 26},
  [2141] = {.lex_state = 26},
  [2142] = {.lex_state = 26},
  [2143] = {.lex_state = 31},
  [2144] = {.lex_state = 26},
  [2145] = {.lex_state = 8},
  [2146] = {.lex_state = 26},
  [2147] = {.lex_state = 144},
  [2148] = {.lex_state = 26},
  [2149] = {.lex_state = 26},
  [2150] = {.lex_state = 26},
  [2151] = {.lex_state = 26},
  [2152] = {.lex_state = 26},
  [2153] = {.lex_state = 26},
  [2154] = {.lex_state = 26},
  [2155] = {.lex_state = 26},
  [2156] = {.lex_state = 26},
  [2157] = {.lex_state = 26},
  [2158] = {.lex_state = 26},
  [2159] = {.lex_state = 31},
  [2160] = {.lex_state = 26},
  [2161] = {.lex_state = 26},
  [2162] = {.lex_state = 31},
  [2163] = {.lex_state = 26},
  [2164] = {.lex_state = 31},
  [2165] = {.lex_state = 26},
  [2166] = {.lex_state = 26},
  [2167] = {.lex_state = 26},
  [2168] = {.lex_state = 26},
  [2169] = {.lex_state = 26},
  [2170] = {.lex_state = 26},
  [2171] = {.lex_state = 31},
  [2172] = {.lex_state = 144},
  [2173] = {.lex_state = 144},
  [2174] = {.lex_state = 31},
  [2175] = {.lex_state = 26},
  [2176] = {.lex_state = 26},
  [2177] = {.lex_state = 26},
  [2178] = {.lex_state = 144},
  [2179] = {.lex_state = 26},
  [2180] = {.lex_state = 26},
  [2181] = {.lex_state = 144},
  [2182] = {.lex_state = 144},
  [2183] = {.lex_state = 26},
  [2184] = {.lex_state = 26},
  [2185] = {.lex_state = 26},
  [2186] = {.lex_state = 26},
  [2187] = {.lex_state = 31},
  [2188] = {.lex_state = 26},
  [2189] = {.lex_state = 26},
  [2190] = {.lex_state = 144},
  [2191] = {.lex_state = 144},
  [2192] = {.lex_state = 26},
  [2193] = {.lex_state = 26},
  [2194] = {.lex_state = 31},
  [2195] = {.lex_state = 31},
  [2196] = {.lex_state = 3},
  [2197] = {.lex_state = 26},
  [2198] = {.lex_state = 31},
  [2199] = {.lex_state = 26},
  [2200] = {.lex_state = 31},
  [2201] = {.lex_state = 144},
  [2202] = {.lex_state = 26},
  [2203] = {.lex_state = 144},
  [2204] = {.lex_state = 26},
  [2205] = {.lex_state = 26},
  [2206] = {.lex_state = 144},
  [2207] = {.lex_state = 26},
  [2208] = {.lex_state = 144},
  [2209] = {.lex_state = 26},
  [2210] = {.lex_state = 144},
  [2211] = {.lex_state = 26},
  [2212] = {.lex_state = 26},
  [2213] = {.lex_state = 144},
  [2214] = {.lex_state = 31},
  [2215] = {.lex_state = 26},
  [2216] = {.lex_state = 26},
  [2217] = {.lex_state = 26},
  [2218] = {.lex_state = 48},
  [2219] = {.lex_state = 26},
  [2220] = {.lex_state = 26},
  [2221] = {.lex_state = 144},
  [2222] = {.lex_state = 144},
  [2223] = {.lex_state = 144},
  [2224] = {.lex_state = 26},
  [2225] = {.lex_state = 144},
  [2226] = {.lex_state = 144},
  [2227] = {.lex_state = 31},
  [2228] = {.lex_state = 26},
  [2229] = {.lex_state = 26},
  [2230] = {.lex_state = 31},
  [2231] = {.lex_state = 144},
  [2232] = {.lex_state = 11},
  [2233] = {.lex_state = 11},
  [2234] = {.lex_state = 26},
  [2235] = {.lex_state = 26},
  [2236] = {.lex_state = 26},
  [2237] = {.lex_state = 144},
  [2238] = {.lex_state = 26},
  [2239] = {.lex_state = 144},
  [2240] = {.lex_state = 144},
  [2241] = {.lex_state = 26},
  [2242] = {.lex_state = 144},
  [2243] = {.lex_state = 144},
  [2244] = {.lex_state = 144},
  [2245] = {.lex_state = 144},
  [2246] = {.lex_state = 77},
  [2247] = {.lex_state = 144},
  [2248] = {.lex_state = 26},
  [2249] = {.lex_state = 78},
  [2250] = {.lex_state = 26},
  [2251] = {.lex_state = 26},
  [2252] = {.lex_state = 26},
  [2253] = {.lex_state = 2, .external_lex_state = 16},
  [2254] = {.lex_state = 26},
  [2255] = {.lex_state = 144},
  [2256] = {.lex_state = 48},
  [2257] = {.lex_state = 3},
  [2258] = {.lex_state = 144, .external_lex_state = 10},
  [2259] = {.lex_state = 144},
  [2260] = {.lex_state = 3},
  [2261] = {.lex_state = 26},
  [2262] = {.lex_state = 26},
  [2263] = {.lex_state = 26},
  [2264] = {.lex_state = 144},
  [2265] = {.lex_state = 144},
  [2266] = {.lex_state = 48},
  [2267] = {.lex_state = 144},
  [2268] = {.lex_state = 144},
  [2269] = {.lex_state = 144},
  [2270] = {.lex_state = 144},
  [2271] = {.lex_state = 26},
  [2272] = {.lex_state = 26},
  [2273] = {.lex_state = 144},
  [2274] = {.lex_state = 144},
  [2275] = {.lex_state = 77},
  [2276] = {.lex_state = 26},
  [2277] = {.lex_state = 26},
  [2278] = {.lex_state = 78},
  [2279] = {.lex_state = 144},
  [2280] = {.lex_state = 144},
  [2281] = {.lex_state = 31},
  [2282] = {.lex_state = 144, .external_lex_state = 10},
  [2283] = {.lex_state = 31},
  [2284] = {.lex_state = 144},
  [2285] = {.lex_state = 144},
  [2286] = {.lex_state = 26},
  [2287] = {.lex_state = 78},
  [2288] = {.lex_state = 144},
  [2289] = {.lex_state = 3},
  [2290] = {.lex_state = 26},
  [2291] = {.lex_state = 78},
  [2292] = {.lex_state = 144, .external_lex_state = 10},
  [2293] = {.lex_state = 144},
  [2294] = {.lex_state = 144},
  [2295] = {.lex_state = 78},
  [2296] = {.lex_state = 144},
  [2297] = {.lex_state = 78},
  [2298] = {.lex_state = 144},
  [2299] = {.lex_state = 78},
  [2300] = {.lex_state = 78},
  [2301] = {.lex_state = 26},
  [2302] = {.lex_state = 26},
  [2303] = {.lex_state = 144},
  [2304] = {.lex_state = 144},
  [2305] = {.lex_state = 26},
  [2306] = {.lex_state = 144},
  [2307] = {.lex_state = 77},
  [2308] = {.lex_state = 144},
  [2309] = {.lex_state = 26},
  [2310] = {.lex_state = 26},
  [2311] = {.lex_state = 26},
  [2312] = {.lex_state = 26},
  [2313] = {.lex_state = 144},
  [2314] = {.lex_state = 144},
  [2315] = {.lex_state = 31},
  [2316] = {.lex_state = 144},
  [2317] = {.lex_state = 26},
  [2318] = {.lex_state = 144},
  [2319] = {.lex_state = 26},
  [2320] = {.lex_state = 26},
  [2321] = {.lex_state = 26},
  [2322] = {.lex_state = 31},
  [2323] = {.lex_state = 26},
  [2324] = {.lex_state = 26},
  [2325] = {.lex_state = 26},
  [2326] = {.lex_state = 26},
  [2327] = {.lex_state = 26},
  [2328] = {.lex_state = 144},
  [2329] = {.lex_state = 144},
  [2330] = {.lex_state = 144},
  [2331] = {.lex_state = 48},
  [2332] = {.lex_state = 26},
  [2333] = {.lex_state = 144},
  [2334] = {.lex_state = 144},
  [2335] = {.lex_state = 2, .external_lex_state = 16},
  [2336] = {.lex_state = 144},
  [2337] = {.lex_state = 26},
  [2338] = {.lex_state = 26},
  [2339] = {.lex_state = 26},
  [2340] = {.lex_state = 26},
  [2341] = {.lex_state = 26},
  [2342] = {.lex_state = 2, .external_lex_state = 16},
  [2343] = {.lex_state = 144},
  [2344] = {.lex_state = 144},
  [2345] = {.lex_state = 26},
  [2346] = {.lex_state = 31},
  [2347] = {.lex_state = 144, .external_lex_state = 10},
  [2348] = {.lex_state = 26},
  [2349] = {.lex_state = 3},
  [2350] = {.lex_state = 26},
  [2351] = {.lex_state = 31},
  [2352] = {.lex_state = 144},
  [2353] = {.lex_state = 144},
  [2354] = {.lex_state = 3},
  [2355] = {.lex_state = 3},
  [2356] = {.lex_state = 26},
  [2357] = {.lex_state = 26},
  [2358] = {.lex_state = 26},
  [2359] = {.lex_state = 3},
  [2360] = {.lex_state = 144},
  [2361] = {.lex_state = 144},
  [2362] = {.lex_state = 26},
  [2363] = {.lex_state = 144},
  [2364] = {.lex_state = 31},
  [2365] = {.lex_state = 144},
  [2366] = {.lex_state = 31},
  [2367] = {.lex_state = 0, .external_lex_state = 15},
  [2368] = {.lex_state = 144},
  [2369] = {.lex_state = 31},
  [2370] = {.lex_state = 31},
  [2371] = {.lex_state = 144},
  [2372] = {.lex_state = 29},
  [2373] = {.lex_state = 144},
  [2374] = {.lex_state = 0, .external_lex_state = 18},
  [2375] = {.lex_state = 31},
  [2376] = {.lex_state = 3},
  [2377] = {.lex_state = 31},
  [2378] = {.lex_state = 144},
  [2379] = {.lex_state = 144},
  [2380] = {.lex_state = 26},
  [2381] = {.lex_state = 144},
  [2382] = {.lex_state = 26},
  [2383] = {.lex_state = 31},
  [2384] = {.lex_state = 144},
  [2385] = {.lex_state = 0, .external_lex_state = 15},
  [2386] = {.lex_state = 0, .external_lex_state = 15},
  [2387] = {.lex_state = 31},
  [2388] = {.lex_state = 144},
  [2389] = {.lex_state = 144},
  [2390] = {.lex_state = 0, .external_lex_state = 19},
  [2391] = {.lex_state = 31},
  [2392] = {.lex_state = 0, .external_lex_state = 19},
  [2393] = {.lex_state = 31},
  [2394] = {.lex_state = 31},
  [2395] = {.lex_state = 31},
  [2396] = {.lex_state = 144},
  [2397] = {.lex_state = 31},
  [2398] = {.lex_state = 144},
  [2399] = {.lex_state = 26},
  [2400] = {.lex_state = 0},
  [2401] = {.lex_state = 144},
  [2402] = {.lex_state = 144},
  [2403] = {.lex_state = 31},
  [2404] = {.lex_state = 31},
  [2405] = {.lex_state = 144},
  [2406] = {.lex_state = 26},
  [2407] = {.lex_state = 144},
  [2408] = {.lex_state = 26},
  [2409] = {.lex_state = 31},
  [2410] = {.lex_state = 144},
  [2411] = {.lex_state = 0, .external_lex_state = 18},
  [2412] = {.lex_state = 144},
  [2413] = {.lex_state = 144},
  [2414] = {.lex_state = 31},
  [2415] = {.lex_state = 26},
  [2416] = {.lex_state = 144},
  [2417] = {.lex_state = 0, .external_lex_state = 15},
  [2418] = {.lex_state = 31},
  [2419] = {.lex_state = 31},
  [2420] = {.lex_state = 144},
  [2421] = {.lex_state = 144},
  [2422] = {.lex_state = 0, .external_lex_state = 15},
  [2423] = {.lex_state = 31},
  [2424] = {.lex_state = 144},
  [2425] = {.lex_state = 31},
  [2426] = {.lex_state = 31},
  [2427] = {.lex_state = 144},
  [2428] = {.lex_state = 0, .external_lex_state = 18},
  [2429] = {.lex_state = 31},
  [2430] = {.lex_state = 144},
  [2431] = {.lex_state = 31},
  [2432] = {.lex_state = 144},
  [2433] = {.lex_state = 31},
  [2434] = {.lex_state = 31},
  [2435] = {.lex_state = 144},
  [2436] = {.lex_state = 0, .external_lex_state = 19},
  [2437] = {.lex_state = 31},
  [2438] = {.lex_state = 0, .external_lex_state = 19},
  [2439] = {.lex_state = 0, .external_lex_state = 19},
  [2440] = {.lex_state = 31},
  [2441] = {.lex_state = 26},
  [2442] = {.lex_state = 26},
  [2443] = {.lex_state = 0, .external_lex_state = 19},
  [2444] = {.lex_state = 144},
  [2445] = {.lex_state = 0, .external_lex_state = 19},
  [2446] = {.lex_state = 144},
  [2447] = {.lex_state = 144},
  [2448] = {.lex_state = 31},
  [2449] = {.lex_state = 0, .external_lex_state = 18},
  [2450] = {.lex_state = 144},
};

static const uint16_t ts_parse_table[LARGE_STATE_COUNT][SYMBOL_COUNT] = {
  [STATE(0)] = {
    [ts_builtin_sym_end] = ACTIONS(1),
    [sym_identifier] = ACTIONS(1),
    [anon_sym_RPAREN] = ACTIONS(1),
    [anon_sym_LPAREN] = ACTIONS(1),
    [anon_sym_LBRACE] = ACTIONS(1),
    [anon_sym_RBRACE] = ACTIONS(1),
    [aux_sym_subroutine_block_token1] = ACTIONS(1),
    [aux_sym_if_block_token1] = ACTIONS(1),
    [aux_sym_elif_block_token1] = ACTIONS(1),
    [aux_sym_while_block_token1] = ACTIONS(1),
    [aux_sym__repeat_block_pre_condition_format_token1] = ACTIONS(1),
    [anon_sym_EQ] = ACTIONS(1),
    [anon_sym_PLUS] = ACTIONS(1),
    [anon_sym_DASH] = ACTIONS(1),
    [anon_sym_TILDE] = ACTIONS(1),
    [anon_sym_BANG] = ACTIONS(1),
    [anon_sym_STAR] = ACTIONS(1),
    [anon_sym_SLASH] = ACTIONS(1),
    [anon_sym_PERCENT] = ACTIONS(1),
    [anon_sym_PIPE] = ACTIONS(1),
    [anon_sym_CARET] = ACTIONS(1),
    [anon_sym_GT] = ACTIONS(1),
    [anon_sym_LT] = ACTIONS(1),
    [anon_sym_AMP] = ACTIONS(1),
    [anon_sym_COLON] = ACTIONS(1),
    [aux_sym_parameter_declaration_token1] = ACTIONS(1),
    [aux_sym_parameter_declaration_token2] = ACTIONS(1),
    [aux_sym_parameter_declaration_token3] = ACTIONS(1),
    [aux_sym_subroutine_call_expression_token1] = ACTIONS(1),
    [aux_sym_macro_definition_command_token1] = ACTIONS(1),
    [aux_sym_macro_definition_command_token2] = ACTIONS(1),
    [aux_sym_macro_definition_command_token3] = ACTIONS(1),
    [aux_sym__host_command_with_default_format_token1] = ACTIONS(1),
    [anon_sym_DOT] = ACTIONS(1),
    [anon_sym_COMMA] = ACTIONS(1),
    [aux_sym__host_command_argument_list_default_format_token1] = ACTIONS(1),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(1),
    [aux_sym__hll_non_default_format_var_command_token2] = ACTIONS(1),
    [aux_sym__hll_non_default_format_var_command_token3] = ACTIONS(1),
    [aux_sym__hll_non_default_format_var_command_token4] = ACTIONS(1),
    [aux_sym__hll_non_default_format_var_command_token5] = ACTIONS(1),
    [aux_sym__var_command_with_non_hll_format_token2] = ACTIONS(1),
    [aux_sym__var_command_with_non_hll_format_token3] = ACTIONS(1),
    [aux_sym__hll_var_definition_command_expression_token1] = ACTIONS(1),
    [aux_sym__hll_var_definition_command_expression_token2] = ACTIONS(1),
    [anon_sym_QMARK] = ACTIONS(1),
    [anon_sym_BSLASH] = ACTIONS(1),
    [anon_sym_LBRACK] = ACTIONS(1),
    [anon_sym_RBRACK] = ACTIONS(1),
    [anon_sym_sizeof] = ACTIONS(1),
    [anon_sym_SQUOTE] = ACTIONS(1),
    [aux_sym_hll_char_literal_token1] = ACTIONS(1),
    [anon_sym_DQUOTE] = ACTIONS(1),
    [anon_sym_const] = ACTIONS(1),
    [anon_sym_volatile] = ACTIONS(1),
    [anon_sym_struct] = ACTIONS(1),
    [anon_sym_union] = ACTIONS(1),
    [anon_sym_enum] = ACTIONS(1),
    [anon_sym_signed] = ACTIONS(1),
    [anon_sym_unsigned] = ACTIONS(1),
    [anon_sym_long] = ACTIONS(1),
    [anon_sym_short] = ACTIONS(1),
    [sym_hll_primitive_type] = ACTIONS(1),
    [aux_sym_character_token2] = ACTIONS(1),
    [sym__blank_line] = ACTIONS(1),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(1),
    [sym_label_identifier] = ACTIONS(1),
    [sym__and_operator_pre_hook] = ACTIONS(1),
    [sym__decimal_number] = ACTIONS(1),
    [sym__decimal_number_pre_hook] = ACTIONS(1),
    [sym_hll_number_literal] = ACTIONS(1),
    [sym__hll_number_literal_pre_hook] = ACTIONS(1),
    [sym_path] = ACTIONS(1),
    [sym__ampersand_char] = ACTIONS(1),
  },
  [STATE(1)] = {
    [sym_script] = STATE(2400),
    [sym_block] = STATE(248),
    [sym__statement] = STATE(248),
    [sym__non_labeled_statement] = STATE(248),
    [sym_labeled_expression] = STATE(248),
    [sym_subroutine_block] = STATE(248),
    [sym_if_block] = STATE(248),
    [sym_while_block] = STATE(248),
    [sym_repeat_block] = STATE(248),
    [sym__repeat_block_pre_condition_format] = STATE(1432),
    [sym__repeat_block_post_condition_format] = STATE(1469),
    [sym_macro_assignment_expression] = STATE(248),
    [sym__label] = STATE(295),
    [sym_macro_definition] = STATE(248),
    [sym_parameter_declaration] = STATE(248),
    [sym_subroutine_call_expression] = STATE(248),
    [sym_macro] = STATE(2059),
    [sym_recursive_macro_expansion] = STATE(1333),
    [sym_macro_definition_command] = STATE(2082),
    [sym_command_expression] = STATE(248),
    [sym__host_command] = STATE(2308),
    [sym__host_command_with_default_format] = STATE(2340),
    [sym__other_command] = STATE(2344),
    [sym__command_identifier] = STATE(2020),
    [sym__var_command] = STATE(2360),
    [sym__hll_var_command] = STATE(2298),
    [sym__hll_default_format_var_command] = STATE(2243),
    [sym__hll_non_default_format_var_command] = STATE(2285),
    [sym__non_hll_var_command] = STATE(2314),
    [sym__hll_var_definition_command] = STATE(2336),
    [sym__hll_var_command_with_default_format] = STATE(1981),
    [sym__var_command_with_non_hll_format] = STATE(1982),
    [sym__hll_var_definition_command_expression] = STATE(2271),
    [sym__hll_var_if_command] = STATE(2272),
    [aux_sym_script_repeat1] = STATE(248),
    [aux_sym_block_repeat1] = STATE(304),
    [ts_builtin_sym_end] = ACTIONS(5),
    [sym_identifier] = ACTIONS(7),
    [aux_sym_block_token1] = ACTIONS(9),
    [aux_sym_subroutine_block_token1] = ACTIONS(11),
    [aux_sym_if_block_token1] = ACTIONS(13),
    [aux_sym_while_block_token1] = ACTIONS(15),
    [aux_sym_while_block_token2] = ACTIONS(17),
    [aux_sym__repeat_block_pre_condition_format_token1] = ACTIONS(19),
    [anon_sym_AMP_AMP] = ACTIONS(21),
    [anon_sym_AMP] = ACTIONS(23),
    [aux_sym_macro_definition_token1] = ACTIONS(25),
    [aux_sym_parameter_declaration_token1] = ACTIONS(27),
    [aux_sym_parameter_declaration_token2] = ACTIONS(27),
    [aux_sym_parameter_declaration_token3] = ACTIONS(29),
    [aux_sym_subroutine_call_expression_token1] = ACTIONS(31),
    [aux_sym_macro_definition_command_token1] = ACTIONS(33),
    [aux_sym_macro_definition_command_token2] = ACTIONS(33),
    [aux_sym_macro_definition_command_token3] = ACTIONS(33),
    [aux_sym__host_command_with_default_format_token1] = ACTIONS(35),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(37),
    [sym_comment] = ACTIONS(39),
    [sym__blank_line] = ACTIONS(39),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(41),
    [sym_label_identifier] = ACTIONS(43),
  },
  [STATE(2)] = {
    [sym__expression] = STATE(1435),
    [sym__parenthesized_expression] = STATE(1435),
    [sym__path_expression] = STATE(1435),
    [sym_unary_expression] = STATE(1435),
    [sym__unary_expression] = STATE(1399),
    [sym__prefix_postfix_expression] = STATE(1400),
    [sym_binary_expression] = STATE(1435),
    [sym__binary_expression] = STATE(1404),
    [sym__and_expression] = STATE(1406),
    [sym_assignment_expression] = STATE(1435),
    [sym_macro] = STATE(341),
    [sym_call_expression] = STATE(364),
    [sym__function_identifier] = STATE(2354),
    [sym__hll_var_call_expression_function] = STATE(2355),
    [sym__hll_var_call_expression] = STATE(345),
    [sym_trace32_hll_variable] = STATE(1412),
    [sym__literal] = STATE(1435),
    [sym__address_expression] = STATE(363),
    [sym_memory_space] = STATE(225),
    [sym_address] = STATE(1435),
    [sym__parenthesized_address_expression] = STATE(363),
    [sym__address_binary_expression] = STATE(354),
    [sym_integer] = STATE(365),
    [sym_bitmask] = STATE(1435),
    [sym_string] = STATE(1435),
    [sym_character] = STATE(1435),
    [sym_symbol] = STATE(1435),
    [sym__special_command_operator] = STATE(1435),
    [sym__file_dialog] = STATE(1417),
    [aux_sym__path_expression_repeat1] = STATE(1218),
    [aux_sym__path_expression_repeat2] = STATE(1053),
    [sym_identifier] = ACTIONS(45),
    [anon_sym_LPAREN] = ACTIONS(48),
    [anon_sym_LBRACE] = ACTIONS(51),
    [aux_sym_subroutine_block_token1] = ACTIONS(53),
    [aux_sym_if_block_token1] = ACTIONS(53),
    [aux_sym_while_block_token1] = ACTIONS(53),
    [aux_sym_while_block_token2] = ACTIONS(55),
    [aux_sym__repeat_block_pre_condition_format_token1] = ACTIONS(53),
    [anon_sym_EQ] = ACTIONS(53),
    [anon_sym_PLUS] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(57),
    [anon_sym_TILDE] = ACTIONS(60),
    [anon_sym_BANG] = ACTIONS(62),
    [anon_sym_PLUS_PLUS] = ACTIONS(64),
    [anon_sym_DASH_DASH] = ACTIONS(64),
    [anon_sym_CARET_CARET] = ACTIONS(55),
    [anon_sym_PIPE_PIPE] = ACTIONS(55),
    [anon_sym_STAR] = ACTIONS(67),
    [anon_sym_SLASH] = ACTIONS(53),
    [anon_sym_PERCENT] = ACTIONS(55),
    [anon_sym_PIPE] = ACTIONS(53),
    [anon_sym_CARET] = ACTIONS(53),
    [anon_sym_EQ_EQ] = ACTIONS(55),
    [anon_sym_BANG_EQ] = ACTIONS(55),
    [anon_sym_GT] = ACTIONS(53),
    [anon_sym_GT_EQ] = ACTIONS(55),
    [anon_sym_LT_EQ] = ACTIONS(55),
    [anon_sym_LT] = ACTIONS(53),
    [anon_sym_LT_LT] = ACTIONS(55),
    [anon_sym_GT_GT] = ACTIONS(55),
    [anon_sym_DOT_DOT] = ACTIONS(55),
    [anon_sym_AMP_AMP] = ACTIONS(55),
    [anon_sym_AMP] = ACTIONS(70),
    [aux_sym_macro_definition_token1] = ACTIONS(53),
    [aux_sym_parameter_declaration_token1] = ACTIONS(53),
    [aux_sym_parameter_declaration_token2] = ACTIONS(53),
    [aux_sym_parameter_declaration_token3] = ACTIONS(53),
    [aux_sym_subroutine_call_expression_token1] = ACTIONS(53),
    [aux_sym_macro_definition_command_token1] = ACTIONS(53),
    [aux_sym_macro_definition_command_token2] = ACTIONS(53),
    [aux_sym_macro_definition_command_token3] = ACTIONS(53),
    [aux_sym__host_command_with_default_format_token1] = ACTIONS(53),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(73),
    [anon_sym_BSLASH] = ACTIONS(76),
    [anon_sym_SQUOTE] = ACTIONS(78),
    [anon_sym_DQUOTE] = ACTIONS(80),
    [sym_access_class] = ACTIONS(82),
    [aux_sym_integer_token1] = ACTIONS(84),
    [aux_sym_integer_token2] = ACTIONS(84),
    [sym_float] = ACTIONS(86),
    [aux_sym_bitmask_token1] = ACTIONS(88),
    [aux_sym_bitmask_token2] = ACTIONS(88),
    [aux_sym_symbol_token1] = ACTIONS(90),
    [aux_sym_symbol_token2] = ACTIONS(92),
    [sym__composed_name] = ACTIONS(94),
    [sym_time] = ACTIONS(86),
    [sym_frequency] = ACTIONS(86),
    [sym_percentage] = ACTIONS(94),
    [sym_file_handle] = ACTIONS(94),
    [sym_comment] = ACTIONS(55),
    [sym__blank_line] = ACTIONS(55),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(53),
    [sym_label_identifier] = ACTIONS(55),
    [sym__and_operator_pre_hook] = ACTIONS(55),
    [sym__decimal_number_pre_hook] = ACTIONS(96),
    [sym_path] = ACTIONS(98),
  },
  [STATE(3)] = {
    [sym__expression] = STATE(388),
    [sym__parenthesized_expression] = STATE(388),
    [sym__path_expression] = STATE(388),
    [sym_unary_expression] = STATE(388),
    [sym__unary_expression] = STATE(450),
    [sym__prefix_postfix_expression] = STATE(451),
    [sym_binary_expression] = STATE(388),
    [sym__binary_expression] = STATE(452),
    [sym__and_expression] = STATE(453),
    [sym_assignment_expression] = STATE(388),
    [sym_macro] = STATE(328),
    [sym_call_expression] = STATE(347),
    [sym__function_identifier] = STATE(2354),
    [sym__hll_var_call_expression_function] = STATE(2355),
    [sym__hll_var_call_expression] = STATE(345),
    [sym_trace32_hll_variable] = STATE(457),
    [sym__literal] = STATE(388),
    [sym__address_expression] = STATE(1575),
    [sym_memory_space] = STATE(224),
    [sym_address] = STATE(388),
    [sym__parenthesized_address_expression] = STATE(1575),
    [sym__address_binary_expression] = STATE(1550),
    [sym_integer] = STATE(350),
    [sym_bitmask] = STATE(388),
    [sym_string] = STATE(388),
    [sym_character] = STATE(388),
    [sym_symbol] = STATE(388),
    [sym__special_command_operator] = STATE(388),
    [sym__file_dialog] = STATE(459),
    [aux_sym__path_expression_repeat1] = STATE(371),
    [aux_sym__path_expression_repeat2] = STATE(388),
    [sym_identifier] = ACTIONS(100),
    [anon_sym_LPAREN] = ACTIONS(102),
    [anon_sym_LBRACE] = ACTIONS(104),
    [aux_sym_subroutine_block_token1] = ACTIONS(106),
    [aux_sym_if_block_token1] = ACTIONS(106),
    [aux_sym_while_block_token1] = ACTIONS(106),
    [aux_sym_while_block_token2] = ACTIONS(108),
    [aux_sym__repeat_block_pre_condition_format_token1] = ACTIONS(106),
    [anon_sym_EQ] = ACTIONS(106),
    [anon_sym_PLUS] = ACTIONS(110),
    [anon_sym_DASH] = ACTIONS(110),
    [anon_sym_TILDE] = ACTIONS(112),
    [anon_sym_BANG] = ACTIONS(110),
    [anon_sym_PLUS_PLUS] = ACTIONS(114),
    [anon_sym_DASH_DASH] = ACTIONS(114),
    [anon_sym_CARET_CARET] = ACTIONS(108),
    [anon_sym_PIPE_PIPE] = ACTIONS(108),
    [anon_sym_STAR] = ACTIONS(116),
    [anon_sym_SLASH] = ACTIONS(106),
    [anon_sym_PERCENT] = ACTIONS(108),
    [anon_sym_PIPE] = ACTIONS(106),
    [anon_sym_CARET] = ACTIONS(106),
    [anon_sym_EQ_EQ] = ACTIONS(108),
    [anon_sym_BANG_EQ] = ACTIONS(108),
    [anon_sym_GT] = ACTIONS(106),
    [anon_sym_GT_EQ] = ACTIONS(108),
    [anon_sym_LT_EQ] = ACTIONS(108),
    [anon_sym_LT] = ACTIONS(106),
    [anon_sym_LT_LT] = ACTIONS(108),
    [anon_sym_GT_GT] = ACTIONS(108),
    [anon_sym_DOT_DOT] = ACTIONS(108),
    [anon_sym_AMP_AMP] = ACTIONS(108),
    [anon_sym_AMP] = ACTIONS(118),
    [aux_sym_macro_definition_token1] = ACTIONS(106),
    [aux_sym_parameter_declaration_token1] = ACTIONS(106),
    [aux_sym_parameter_declaration_token2] = ACTIONS(106),
    [aux_sym_parameter_declaration_token3] = ACTIONS(106),
    [aux_sym_subroutine_call_expression_token1] = ACTIONS(106),
    [aux_sym_macro_definition_command_token1] = ACTIONS(106),
    [aux_sym_macro_definition_command_token2] = ACTIONS(106),
    [aux_sym_macro_definition_command_token3] = ACTIONS(106),
    [aux_sym__host_command_with_default_format_token1] = ACTIONS(106),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(120),
    [anon_sym_BSLASH] = ACTIONS(122),
    [anon_sym_SQUOTE] = ACTIONS(124),
    [anon_sym_DQUOTE] = ACTIONS(126),
    [sym_access_class] = ACTIONS(128),
    [aux_sym_integer_token1] = ACTIONS(84),
    [aux_sym_integer_token2] = ACTIONS(84),
    [sym_float] = ACTIONS(130),
    [aux_sym_bitmask_token1] = ACTIONS(132),
    [aux_sym_bitmask_token2] = ACTIONS(132),
    [aux_sym_symbol_token1] = ACTIONS(134),
    [aux_sym_symbol_token2] = ACTIONS(136),
    [sym__composed_name] = ACTIONS(138),
    [sym_time] = ACTIONS(130),
    [sym_frequency] = ACTIONS(130),
    [sym_percentage] = ACTIONS(138),
    [sym_file_handle] = ACTIONS(138),
    [sym_comment] = ACTIONS(108),
    [sym__blank_line] = ACTIONS(108),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(106),
    [sym_label_identifier] = ACTIONS(108),
    [sym__and_operator_pre_hook] = ACTIONS(108),
    [sym__decimal_number_pre_hook] = ACTIONS(96),
    [sym_path] = ACTIONS(138),
  },
  [STATE(4)] = {
    [sym__expression] = STATE(1501),
    [sym__parenthesized_expression] = STATE(1501),
    [sym__path_expression] = STATE(1501),
    [sym_unary_expression] = STATE(1501),
    [sym__unary_expression] = STATE(1399),
    [sym__prefix_postfix_expression] = STATE(1400),
    [sym_binary_expression] = STATE(1501),
    [sym__binary_expression] = STATE(1404),
    [sym__and_expression] = STATE(1406),
    [sym_assignment_expression] = STATE(1501),
    [sym_macro] = STATE(972),
    [sym_call_expression] = STATE(1108),
    [sym__function_identifier] = STATE(2349),
    [sym__hll_var_call_expression_function] = STATE(2359),
    [sym__hll_var_call_expression] = STATE(1061),
    [sym_trace32_hll_variable] = STATE(1412),
    [sym__literal] = STATE(1501),
    [sym__address_expression] = STATE(1043),
    [sym_memory_space] = STATE(198),
    [sym_address] = STATE(1501),
    [sym__parenthesized_address_expression] = STATE(1043),
    [sym__address_binary_expression] = STATE(1107),
    [sym_integer] = STATE(1110),
    [sym_bitmask] = STATE(1501),
    [sym_string] = STATE(1501),
    [sym_character] = STATE(1501),
    [sym_symbol] = STATE(1501),
    [sym__special_command_operator] = STATE(1501),
    [sym__file_dialog] = STATE(1417),
    [aux_sym__path_expression_repeat1] = STATE(1218),
    [aux_sym__path_expression_repeat2] = STATE(1053),
    [sym_identifier] = ACTIONS(140),
    [anon_sym_LPAREN] = ACTIONS(142),
    [anon_sym_LBRACE] = ACTIONS(145),
    [anon_sym_EQ] = ACTIONS(53),
    [anon_sym_PLUS] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(57),
    [anon_sym_TILDE] = ACTIONS(60),
    [anon_sym_BANG] = ACTIONS(62),
    [anon_sym_PLUS_PLUS] = ACTIONS(64),
    [anon_sym_DASH_DASH] = ACTIONS(64),
    [anon_sym_CARET_CARET] = ACTIONS(55),
    [anon_sym_PIPE_PIPE] = ACTIONS(55),
    [anon_sym_STAR] = ACTIONS(67),
    [anon_sym_SLASH] = ACTIONS(53),
    [anon_sym_PERCENT] = ACTIONS(55),
    [anon_sym_PIPE] = ACTIONS(53),
    [anon_sym_CARET] = ACTIONS(53),
    [anon_sym_EQ_EQ] = ACTIONS(55),
    [anon_sym_BANG_EQ] = ACTIONS(55),
    [anon_sym_GT] = ACTIONS(53),
    [anon_sym_GT_EQ] = ACTIONS(55),
    [anon_sym_LT_EQ] = ACTIONS(55),
    [anon_sym_LT] = ACTIONS(53),
    [anon_sym_LT_LT] = ACTIONS(55),
    [anon_sym_GT_GT] = ACTIONS(55),
    [anon_sym_DOT_DOT] = ACTIONS(55),
    [anon_sym_AMP] = ACTIONS(147),
    [anon_sym_COMMA] = ACTIONS(55),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(120),
    [anon_sym_BSLASH] = ACTIONS(76),
    [anon_sym_SQUOTE] = ACTIONS(78),
    [anon_sym_DQUOTE] = ACTIONS(80),
    [sym_access_class] = ACTIONS(82),
    [aux_sym_integer_token1] = ACTIONS(149),
    [aux_sym_integer_token2] = ACTIONS(149),
    [sym_float] = ACTIONS(151),
    [aux_sym_bitmask_token1] = ACTIONS(88),
    [aux_sym_bitmask_token2] = ACTIONS(88),
    [aux_sym_symbol_token1] = ACTIONS(90),
    [aux_sym_symbol_token2] = ACTIONS(92),
    [sym__composed_name] = ACTIONS(153),
    [sym_time] = ACTIONS(151),
    [sym_frequency] = ACTIONS(151),
    [sym_percentage] = ACTIONS(153),
    [sym_file_handle] = ACTIONS(153),
    [sym_comment] = ACTIONS(55),
    [sym__blank_line] = ACTIONS(55),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(53),
    [sym__and_operator_pre_hook] = ACTIONS(55),
    [sym__decimal_number_pre_hook] = ACTIONS(155),
    [sym_path] = ACTIONS(98),
  },
  [STATE(5)] = {
    [sym__expression] = STATE(1210),
    [sym__parenthesized_expression] = STATE(1210),
    [sym__path_expression] = STATE(1210),
    [sym_unary_expression] = STATE(1210),
    [sym__unary_expression] = STATE(1399),
    [sym__prefix_postfix_expression] = STATE(1400),
    [sym_binary_expression] = STATE(1210),
    [sym__binary_expression] = STATE(1404),
    [sym__and_expression] = STATE(1406),
    [sym_assignment_expression] = STATE(1210),
    [sym_macro] = STATE(970),
    [sym_call_expression] = STATE(1097),
    [sym__function_identifier] = STATE(2257),
    [sym__hll_var_call_expression_function] = STATE(2260),
    [sym__hll_var_call_expression] = STATE(1049),
    [sym_trace32_hll_variable] = STATE(1412),
    [sym__literal] = STATE(1210),
    [sym__address_expression] = STATE(1575),
    [sym_memory_space] = STATE(236),
    [sym_address] = STATE(1210),
    [sym__parenthesized_address_expression] = STATE(1575),
    [sym__address_binary_expression] = STATE(1550),
    [sym_integer] = STATE(1098),
    [sym_bitmask] = STATE(1210),
    [sym_string] = STATE(1210),
    [sym_character] = STATE(1210),
    [sym_symbol] = STATE(1210),
    [sym__special_command_operator] = STATE(1210),
    [sym__file_dialog] = STATE(1417),
    [aux_sym__path_expression_repeat1] = STATE(1218),
    [aux_sym__path_expression_repeat2] = STATE(1053),
    [sym_identifier] = ACTIONS(140),
    [anon_sym_RPAREN] = ACTIONS(108),
    [anon_sym_LPAREN] = ACTIONS(157),
    [anon_sym_LBRACE] = ACTIONS(159),
    [anon_sym_RBRACE] = ACTIONS(108),
    [anon_sym_EQ] = ACTIONS(106),
    [anon_sym_PLUS] = ACTIONS(161),
    [anon_sym_DASH] = ACTIONS(161),
    [anon_sym_TILDE] = ACTIONS(163),
    [anon_sym_BANG] = ACTIONS(161),
    [anon_sym_PLUS_PLUS] = ACTIONS(165),
    [anon_sym_DASH_DASH] = ACTIONS(165),
    [anon_sym_CARET_CARET] = ACTIONS(108),
    [anon_sym_PIPE_PIPE] = ACTIONS(108),
    [anon_sym_STAR] = ACTIONS(167),
    [anon_sym_SLASH] = ACTIONS(108),
    [anon_sym_PERCENT] = ACTIONS(108),
    [anon_sym_PIPE] = ACTIONS(106),
    [anon_sym_CARET] = ACTIONS(106),
    [anon_sym_EQ_EQ] = ACTIONS(108),
    [anon_sym_BANG_EQ] = ACTIONS(108),
    [anon_sym_GT] = ACTIONS(106),
    [anon_sym_GT_EQ] = ACTIONS(108),
    [anon_sym_LT_EQ] = ACTIONS(108),
    [anon_sym_LT] = ACTIONS(106),
    [anon_sym_LT_LT] = ACTIONS(108),
    [anon_sym_GT_GT] = ACTIONS(108),
    [anon_sym_DOT_DOT] = ACTIONS(108),
    [anon_sym_AMP] = ACTIONS(169),
    [anon_sym_COMMA] = ACTIONS(108),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(120),
    [anon_sym_BSLASH] = ACTIONS(76),
    [anon_sym_SQUOTE] = ACTIONS(78),
    [anon_sym_DQUOTE] = ACTIONS(80),
    [sym_access_class] = ACTIONS(82),
    [aux_sym_integer_token1] = ACTIONS(171),
    [aux_sym_integer_token2] = ACTIONS(171),
    [sym_float] = ACTIONS(173),
    [aux_sym_bitmask_token1] = ACTIONS(88),
    [aux_sym_bitmask_token2] = ACTIONS(88),
    [aux_sym_symbol_token1] = ACTIONS(90),
    [aux_sym_symbol_token2] = ACTIONS(92),
    [sym__composed_name] = ACTIONS(175),
    [sym_time] = ACTIONS(173),
    [sym_frequency] = ACTIONS(173),
    [sym_percentage] = ACTIONS(175),
    [sym_file_handle] = ACTIONS(175),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(108),
    [sym__and_operator_pre_hook] = ACTIONS(108),
    [sym__decimal_number_pre_hook] = ACTIONS(177),
    [sym_path] = ACTIONS(98),
  },
  [STATE(6)] = {
    [sym__expression] = STATE(1166),
    [sym__parenthesized_expression] = STATE(1166),
    [sym__path_expression] = STATE(1166),
    [sym_unary_expression] = STATE(1166),
    [sym__unary_expression] = STATE(1378),
    [sym__prefix_postfix_expression] = STATE(1392),
    [sym_binary_expression] = STATE(1166),
    [sym__binary_expression] = STATE(1394),
    [sym__and_expression] = STATE(1371),
    [sym_assignment_expression] = STATE(1166),
    [sym_macro] = STATE(980),
    [sym_call_expression] = STATE(1060),
    [sym__function_identifier] = STATE(2349),
    [sym__hll_var_call_expression_function] = STATE(2359),
    [sym__hll_var_call_expression] = STATE(1061),
    [sym_trace32_hll_variable] = STATE(1377),
    [sym__literal] = STATE(1166),
    [sym__address_expression] = STATE(1575),
    [sym_memory_space] = STATE(228),
    [sym_address] = STATE(1166),
    [sym__parenthesized_address_expression] = STATE(1575),
    [sym__address_binary_expression] = STATE(1550),
    [sym_integer] = STATE(1080),
    [sym_bitmask] = STATE(1166),
    [sym_string] = STATE(1166),
    [sym_character] = STATE(1166),
    [sym_symbol] = STATE(1166),
    [sym__special_command_operator] = STATE(1166),
    [sym__file_dialog] = STATE(1374),
    [aux_sym__path_expression_repeat1] = STATE(1172),
    [aux_sym__path_expression_repeat2] = STATE(1100),
    [sym_identifier] = ACTIONS(179),
    [anon_sym_LPAREN] = ACTIONS(181),
    [anon_sym_LBRACE] = ACTIONS(183),
    [anon_sym_EQ] = ACTIONS(106),
    [anon_sym_PLUS] = ACTIONS(185),
    [anon_sym_DASH] = ACTIONS(185),
    [anon_sym_TILDE] = ACTIONS(187),
    [anon_sym_BANG] = ACTIONS(185),
    [anon_sym_PLUS_PLUS] = ACTIONS(189),
    [anon_sym_DASH_DASH] = ACTIONS(189),
    [anon_sym_CARET_CARET] = ACTIONS(108),
    [anon_sym_PIPE_PIPE] = ACTIONS(108),
    [anon_sym_STAR] = ACTIONS(191),
    [anon_sym_SLASH] = ACTIONS(106),
    [anon_sym_PERCENT] = ACTIONS(108),
    [anon_sym_PIPE] = ACTIONS(106),
    [anon_sym_CARET] = ACTIONS(106),
    [anon_sym_EQ_EQ] = ACTIONS(108),
    [anon_sym_BANG_EQ] = ACTIONS(108),
    [anon_sym_GT] = ACTIONS(106),
    [anon_sym_GT_EQ] = ACTIONS(108),
    [anon_sym_LT_EQ] = ACTIONS(108),
    [anon_sym_LT] = ACTIONS(106),
    [anon_sym_LT_LT] = ACTIONS(108),
    [anon_sym_GT_GT] = ACTIONS(108),
    [anon_sym_DOT_DOT] = ACTIONS(108),
    [anon_sym_AMP] = ACTIONS(147),
    [anon_sym_COMMA] = ACTIONS(108),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(120),
    [anon_sym_BSLASH] = ACTIONS(193),
    [anon_sym_SQUOTE] = ACTIONS(195),
    [anon_sym_DQUOTE] = ACTIONS(197),
    [sym_access_class] = ACTIONS(199),
    [aux_sym_integer_token1] = ACTIONS(149),
    [aux_sym_integer_token2] = ACTIONS(149),
    [sym_float] = ACTIONS(201),
    [aux_sym_bitmask_token1] = ACTIONS(203),
    [aux_sym_bitmask_token2] = ACTIONS(203),
    [aux_sym_symbol_token1] = ACTIONS(205),
    [aux_sym_symbol_token2] = ACTIONS(207),
    [sym__composed_name] = ACTIONS(209),
    [sym_time] = ACTIONS(201),
    [sym_frequency] = ACTIONS(201),
    [sym_percentage] = ACTIONS(209),
    [sym_file_handle] = ACTIONS(209),
    [sym_comment] = ACTIONS(108),
    [sym__blank_line] = ACTIONS(108),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(106),
    [sym__and_operator_pre_hook] = ACTIONS(108),
    [sym__decimal_number_pre_hook] = ACTIONS(155),
    [sym_path] = ACTIONS(211),
  },
  [STATE(7)] = {
    [sym__expression] = STATE(1454),
    [sym__parenthesized_expression] = STATE(1454),
    [sym__path_expression] = STATE(1454),
    [sym_unary_expression] = STATE(1454),
    [sym__unary_expression] = STATE(1399),
    [sym__prefix_postfix_expression] = STATE(1400),
    [sym_binary_expression] = STATE(1454),
    [sym__binary_expression] = STATE(1404),
    [sym__and_expression] = STATE(1406),
    [sym_assignment_expression] = STATE(1454),
    [sym_macro] = STATE(967),
    [sym_call_expression] = STATE(1034),
    [sym__function_identifier] = STATE(2257),
    [sym__hll_var_call_expression_function] = STATE(2260),
    [sym__hll_var_call_expression] = STATE(1049),
    [sym_trace32_hll_variable] = STATE(1412),
    [sym__literal] = STATE(1454),
    [sym__address_expression] = STATE(1056),
    [sym_memory_space] = STATE(238),
    [sym_address] = STATE(1454),
    [sym__parenthesized_address_expression] = STATE(1056),
    [sym__address_binary_expression] = STATE(1109),
    [sym_integer] = STATE(1035),
    [sym_bitmask] = STATE(1454),
    [sym_string] = STATE(1454),
    [sym_character] = STATE(1454),
    [sym_symbol] = STATE(1454),
    [sym__special_command_operator] = STATE(1454),
    [sym__file_dialog] = STATE(1417),
    [aux_sym__path_expression_repeat1] = STATE(1218),
    [aux_sym__path_expression_repeat2] = STATE(1053),
    [sym_identifier] = ACTIONS(140),
    [anon_sym_RPAREN] = ACTIONS(55),
    [anon_sym_LPAREN] = ACTIONS(213),
    [anon_sym_LBRACE] = ACTIONS(216),
    [anon_sym_RBRACE] = ACTIONS(55),
    [anon_sym_EQ] = ACTIONS(53),
    [anon_sym_PLUS] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(57),
    [anon_sym_TILDE] = ACTIONS(60),
    [anon_sym_BANG] = ACTIONS(62),
    [anon_sym_PLUS_PLUS] = ACTIONS(64),
    [anon_sym_DASH_DASH] = ACTIONS(64),
    [anon_sym_CARET_CARET] = ACTIONS(55),
    [anon_sym_PIPE_PIPE] = ACTIONS(55),
    [anon_sym_STAR] = ACTIONS(67),
    [anon_sym_SLASH] = ACTIONS(55),
    [anon_sym_PERCENT] = ACTIONS(55),
    [anon_sym_PIPE] = ACTIONS(53),
    [anon_sym_CARET] = ACTIONS(53),
    [anon_sym_EQ_EQ] = ACTIONS(55),
    [anon_sym_BANG_EQ] = ACTIONS(55),
    [anon_sym_GT] = ACTIONS(53),
    [anon_sym_GT_EQ] = ACTIONS(55),
    [anon_sym_LT_EQ] = ACTIONS(55),
    [anon_sym_LT] = ACTIONS(53),
    [anon_sym_LT_LT] = ACTIONS(55),
    [anon_sym_GT_GT] = ACTIONS(55),
    [anon_sym_DOT_DOT] = ACTIONS(55),
    [anon_sym_AMP] = ACTIONS(169),
    [anon_sym_COMMA] = ACTIONS(55),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(120),
    [anon_sym_BSLASH] = ACTIONS(76),
    [anon_sym_SQUOTE] = ACTIONS(78),
    [anon_sym_DQUOTE] = ACTIONS(80),
    [sym_access_class] = ACTIONS(82),
    [aux_sym_integer_token1] = ACTIONS(171),
    [aux_sym_integer_token2] = ACTIONS(171),
    [sym_float] = ACTIONS(218),
    [aux_sym_bitmask_token1] = ACTIONS(88),
    [aux_sym_bitmask_token2] = ACTIONS(88),
    [aux_sym_symbol_token1] = ACTIONS(90),
    [aux_sym_symbol_token2] = ACTIONS(92),
    [sym__composed_name] = ACTIONS(220),
    [sym_time] = ACTIONS(218),
    [sym_frequency] = ACTIONS(218),
    [sym_percentage] = ACTIONS(220),
    [sym_file_handle] = ACTIONS(220),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(55),
    [sym__and_operator_pre_hook] = ACTIONS(55),
    [sym__decimal_number_pre_hook] = ACTIONS(177),
    [sym_path] = ACTIONS(98),
  },
  [STATE(8)] = {
    [sym__expression] = STATE(1411),
    [sym__parenthesized_expression] = STATE(1411),
    [sym__path_expression] = STATE(1411),
    [sym_unary_expression] = STATE(1411),
    [sym__unary_expression] = STATE(1399),
    [sym__prefix_postfix_expression] = STATE(1400),
    [sym_binary_expression] = STATE(1411),
    [sym__binary_expression] = STATE(1404),
    [sym__and_expression] = STATE(1406),
    [sym_assignment_expression] = STATE(1411),
    [sym_macro] = STATE(975),
    [sym_call_expression] = STATE(1046),
    [sym__function_identifier] = STATE(2257),
    [sym__hll_var_call_expression_function] = STATE(2260),
    [sym__hll_var_call_expression] = STATE(1049),
    [sym_trace32_hll_variable] = STATE(1412),
    [sym__literal] = STATE(1411),
    [sym__address_expression] = STATE(1575),
    [sym_memory_space] = STATE(236),
    [sym_address] = STATE(1411),
    [sym__parenthesized_address_expression] = STATE(1575),
    [sym__address_binary_expression] = STATE(1550),
    [sym_integer] = STATE(1052),
    [sym_bitmask] = STATE(1411),
    [sym_string] = STATE(1411),
    [sym_character] = STATE(1411),
    [sym_symbol] = STATE(1411),
    [sym__special_command_operator] = STATE(1411),
    [sym__file_dialog] = STATE(1417),
    [aux_sym__path_expression_repeat1] = STATE(1218),
    [aux_sym__path_expression_repeat2] = STATE(1053),
    [sym_identifier] = ACTIONS(140),
    [anon_sym_LPAREN] = ACTIONS(157),
    [anon_sym_LBRACE] = ACTIONS(159),
    [anon_sym_EQ] = ACTIONS(106),
    [anon_sym_PLUS] = ACTIONS(62),
    [anon_sym_DASH] = ACTIONS(62),
    [anon_sym_TILDE] = ACTIONS(60),
    [anon_sym_BANG] = ACTIONS(62),
    [anon_sym_PLUS_PLUS] = ACTIONS(222),
    [anon_sym_DASH_DASH] = ACTIONS(222),
    [anon_sym_CARET_CARET] = ACTIONS(108),
    [anon_sym_PIPE_PIPE] = ACTIONS(108),
    [anon_sym_STAR] = ACTIONS(167),
    [anon_sym_SLASH] = ACTIONS(108),
    [anon_sym_PERCENT] = ACTIONS(108),
    [anon_sym_PIPE] = ACTIONS(106),
    [anon_sym_CARET] = ACTIONS(106),
    [anon_sym_EQ_EQ] = ACTIONS(108),
    [anon_sym_BANG_EQ] = ACTIONS(108),
    [anon_sym_GT] = ACTIONS(106),
    [anon_sym_GT_EQ] = ACTIONS(108),
    [anon_sym_LT_EQ] = ACTIONS(108),
    [anon_sym_LT] = ACTIONS(106),
    [anon_sym_LT_LT] = ACTIONS(108),
    [anon_sym_GT_GT] = ACTIONS(108),
    [anon_sym_DOT_DOT] = ACTIONS(108),
    [anon_sym_AMP] = ACTIONS(169),
    [anon_sym_COMMA] = ACTIONS(108),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(120),
    [anon_sym_BSLASH] = ACTIONS(76),
    [anon_sym_SQUOTE] = ACTIONS(78),
    [anon_sym_DQUOTE] = ACTIONS(80),
    [sym_access_class] = ACTIONS(82),
    [aux_sym_integer_token1] = ACTIONS(171),
    [aux_sym_integer_token2] = ACTIONS(171),
    [sym_float] = ACTIONS(224),
    [aux_sym_bitmask_token1] = ACTIONS(88),
    [aux_sym_bitmask_token2] = ACTIONS(88),
    [aux_sym_symbol_token1] = ACTIONS(90),
    [aux_sym_symbol_token2] = ACTIONS(92),
    [sym__composed_name] = ACTIONS(226),
    [sym_time] = ACTIONS(224),
    [sym_frequency] = ACTIONS(224),
    [sym_percentage] = ACTIONS(226),
    [sym_file_handle] = ACTIONS(226),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(108),
    [sym__and_operator_pre_hook] = ACTIONS(108),
    [sym__decimal_number_pre_hook] = ACTIONS(177),
    [sym_path] = ACTIONS(98),
  },
  [STATE(9)] = {
    [sym__statement] = STATE(1474),
    [sym__non_labeled_statement] = STATE(1474),
    [sym_labeled_expression] = STATE(1474),
    [sym_subroutine_block] = STATE(1474),
    [sym_if_block] = STATE(1474),
    [sym_while_block] = STATE(1474),
    [sym_repeat_block] = STATE(1474),
    [sym__repeat_block_pre_condition_format] = STATE(1432),
    [sym__repeat_block_post_condition_format] = STATE(1469),
    [sym_macro_assignment_expression] = STATE(1474),
    [sym__label] = STATE(295),
    [sym_macro_definition] = STATE(1474),
    [sym_parameter_declaration] = STATE(1474),
    [sym_subroutine_call_expression] = STATE(1474),
    [sym_macro] = STATE(2059),
    [sym_recursive_macro_expansion] = STATE(1333),
    [sym_macro_definition_command] = STATE(2082),
    [sym_command_expression] = STATE(1474),
    [sym__host_command] = STATE(2308),
    [sym__host_command_with_default_format] = STATE(2340),
    [sym__other_command] = STATE(2344),
    [sym__command_identifier] = STATE(2020),
    [sym_argument_list] = STATE(348),
    [sym__var_command] = STATE(2360),
    [sym__hll_var_command] = STATE(2298),
    [sym__hll_default_format_var_command] = STATE(2243),
    [sym__hll_non_default_format_var_command] = STATE(2285),
    [sym__non_hll_var_command] = STATE(2314),
    [sym__hll_var_definition_command] = STATE(2336),
    [sym__hll_var_command_with_default_format] = STATE(1981),
    [sym__var_command_with_non_hll_format] = STATE(1982),
    [sym__hll_var_definition_command_expression] = STATE(2271),
    [sym__hll_var_if_command] = STATE(2272),
    [aux_sym_block_repeat1] = STATE(306),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(228),
    [aux_sym_subroutine_block_token1] = ACTIONS(11),
    [aux_sym_if_block_token1] = ACTIONS(13),
    [aux_sym_while_block_token1] = ACTIONS(15),
    [aux_sym_while_block_token2] = ACTIONS(17),
    [aux_sym__repeat_block_pre_condition_format_token1] = ACTIONS(19),
    [anon_sym_EQ] = ACTIONS(230),
    [anon_sym_PLUS] = ACTIONS(232),
    [anon_sym_DASH] = ACTIONS(232),
    [anon_sym_PLUS_PLUS] = ACTIONS(234),
    [anon_sym_DASH_DASH] = ACTIONS(234),
    [anon_sym_CARET_CARET] = ACTIONS(236),
    [anon_sym_PIPE_PIPE] = ACTIONS(238),
    [anon_sym_STAR] = ACTIONS(240),
    [anon_sym_SLASH] = ACTIONS(242),
    [anon_sym_PERCENT] = ACTIONS(240),
    [anon_sym_PIPE] = ACTIONS(244),
    [anon_sym_CARET] = ACTIONS(246),
    [anon_sym_EQ_EQ] = ACTIONS(248),
    [anon_sym_BANG_EQ] = ACTIONS(248),
    [anon_sym_GT] = ACTIONS(250),
    [anon_sym_GT_EQ] = ACTIONS(248),
    [anon_sym_LT_EQ] = ACTIONS(248),
    [anon_sym_LT] = ACTIONS(250),
    [anon_sym_LT_LT] = ACTIONS(252),
    [anon_sym_GT_GT] = ACTIONS(252),
    [anon_sym_DOT_DOT] = ACTIONS(254),
    [anon_sym_AMP_AMP] = ACTIONS(21),
    [anon_sym_AMP] = ACTIONS(23),
    [aux_sym_macro_definition_token1] = ACTIONS(25),
    [aux_sym_parameter_declaration_token1] = ACTIONS(27),
    [aux_sym_parameter_declaration_token2] = ACTIONS(27),
    [aux_sym_parameter_declaration_token3] = ACTIONS(29),
    [aux_sym_subroutine_call_expression_token1] = ACTIONS(31),
    [aux_sym_macro_definition_command_token1] = ACTIONS(33),
    [aux_sym_macro_definition_command_token2] = ACTIONS(33),
    [aux_sym_macro_definition_command_token3] = ACTIONS(33),
    [aux_sym__host_command_with_default_format_token1] = ACTIONS(35),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(37),
    [sym_comment] = ACTIONS(256),
    [sym__blank_line] = ACTIONS(256),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(258),
    [sym_label_identifier] = ACTIONS(43),
    [sym__and_operator_pre_hook] = ACTIONS(260),
  },
  [STATE(10)] = {
    [sym__statement] = STATE(1474),
    [sym__non_labeled_statement] = STATE(1474),
    [sym_labeled_expression] = STATE(1474),
    [sym_subroutine_block] = STATE(1474),
    [sym_if_block] = STATE(1474),
    [sym_while_block] = STATE(1474),
    [sym_repeat_block] = STATE(1474),
    [sym__repeat_block_pre_condition_format] = STATE(1432),
    [sym__repeat_block_post_condition_format] = STATE(1469),
    [sym_macro_assignment_expression] = STATE(1474),
    [sym__label] = STATE(294),
    [sym_macro_definition] = STATE(1474),
    [sym_parameter_declaration] = STATE(1474),
    [sym_subroutine_call_expression] = STATE(1474),
    [sym_macro] = STATE(2059),
    [sym_recursive_macro_expansion] = STATE(1333),
    [sym_macro_definition_command] = STATE(2082),
    [sym_command_expression] = STATE(1474),
    [sym__host_command] = STATE(2308),
    [sym__host_command_with_default_format] = STATE(2340),
    [sym__other_command] = STATE(2344),
    [sym__command_identifier] = STATE(2020),
    [sym_argument_list] = STATE(348),
    [sym__var_command] = STATE(2360),
    [sym__hll_var_command] = STATE(2298),
    [sym__hll_default_format_var_command] = STATE(2243),
    [sym__hll_non_default_format_var_command] = STATE(2285),
    [sym__non_hll_var_command] = STATE(2314),
    [sym__hll_var_definition_command] = STATE(2336),
    [sym__hll_var_command_with_default_format] = STATE(1981),
    [sym__var_command_with_non_hll_format] = STATE(1982),
    [sym__hll_var_definition_command_expression] = STATE(2271),
    [sym__hll_var_if_command] = STATE(2312),
    [aux_sym_block_repeat1] = STATE(303),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(228),
    [aux_sym_subroutine_block_token1] = ACTIONS(11),
    [aux_sym_if_block_token1] = ACTIONS(262),
    [aux_sym_while_block_token1] = ACTIONS(264),
    [aux_sym_while_block_token2] = ACTIONS(266),
    [aux_sym__repeat_block_pre_condition_format_token1] = ACTIONS(268),
    [anon_sym_EQ] = ACTIONS(230),
    [anon_sym_PLUS] = ACTIONS(232),
    [anon_sym_DASH] = ACTIONS(232),
    [anon_sym_PLUS_PLUS] = ACTIONS(234),
    [anon_sym_DASH_DASH] = ACTIONS(234),
    [anon_sym_CARET_CARET] = ACTIONS(236),
    [anon_sym_PIPE_PIPE] = ACTIONS(238),
    [anon_sym_STAR] = ACTIONS(240),
    [anon_sym_SLASH] = ACTIONS(242),
    [anon_sym_PERCENT] = ACTIONS(240),
    [anon_sym_PIPE] = ACTIONS(244),
    [anon_sym_CARET] = ACTIONS(246),
    [anon_sym_EQ_EQ] = ACTIONS(248),
    [anon_sym_BANG_EQ] = ACTIONS(248),
    [anon_sym_GT] = ACTIONS(250),
    [anon_sym_GT_EQ] = ACTIONS(248),
    [anon_sym_LT_EQ] = ACTIONS(248),
    [anon_sym_LT] = ACTIONS(250),
    [anon_sym_LT_LT] = ACTIONS(252),
    [anon_sym_GT_GT] = ACTIONS(252),
    [anon_sym_DOT_DOT] = ACTIONS(254),
    [anon_sym_AMP_AMP] = ACTIONS(270),
    [anon_sym_AMP] = ACTIONS(23),
    [aux_sym_macro_definition_token1] = ACTIONS(25),
    [aux_sym_parameter_declaration_token1] = ACTIONS(27),
    [aux_sym_parameter_declaration_token2] = ACTIONS(27),
    [aux_sym_parameter_declaration_token3] = ACTIONS(29),
    [aux_sym_subroutine_call_expression_token1] = ACTIONS(31),
    [aux_sym_macro_definition_command_token1] = ACTIONS(33),
    [aux_sym_macro_definition_command_token2] = ACTIONS(33),
    [aux_sym_macro_definition_command_token3] = ACTIONS(33),
    [aux_sym__host_command_with_default_format_token1] = ACTIONS(35),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(37),
    [sym_comment] = ACTIONS(272),
    [sym__blank_line] = ACTIONS(272),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(274),
    [sym_label_identifier] = ACTIONS(43),
    [sym__and_operator_pre_hook] = ACTIONS(260),
  },
  [STATE(11)] = {
    [sym__statement] = STATE(1474),
    [sym__non_labeled_statement] = STATE(1474),
    [sym_labeled_expression] = STATE(1474),
    [sym_subroutine_block] = STATE(1474),
    [sym_if_block] = STATE(1474),
    [sym_while_block] = STATE(1474),
    [sym_repeat_block] = STATE(1474),
    [sym__repeat_block_pre_condition_format] = STATE(1432),
    [sym__repeat_block_post_condition_format] = STATE(1469),
    [sym_macro_assignment_expression] = STATE(1474),
    [sym__label] = STATE(296),
    [sym_macro_definition] = STATE(1474),
    [sym_parameter_declaration] = STATE(1474),
    [sym_subroutine_call_expression] = STATE(1474),
    [sym_macro] = STATE(2059),
    [sym_recursive_macro_expansion] = STATE(1333),
    [sym_macro_definition_command] = STATE(2082),
    [sym_command_expression] = STATE(1474),
    [sym__host_command] = STATE(2308),
    [sym__host_command_with_default_format] = STATE(2340),
    [sym__other_command] = STATE(2344),
    [sym__command_identifier] = STATE(2020),
    [sym_argument_list] = STATE(348),
    [sym__var_command] = STATE(2360),
    [sym__hll_var_command] = STATE(2298),
    [sym__hll_default_format_var_command] = STATE(2243),
    [sym__hll_non_default_format_var_command] = STATE(2285),
    [sym__non_hll_var_command] = STATE(2314),
    [sym__hll_var_definition_command] = STATE(2336),
    [sym__hll_var_command_with_default_format] = STATE(1981),
    [sym__var_command_with_non_hll_format] = STATE(1982),
    [sym__hll_var_definition_command_expression] = STATE(2271),
    [sym__hll_var_if_command] = STATE(2325),
    [aux_sym_block_repeat1] = STATE(305),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(228),
    [aux_sym_subroutine_block_token1] = ACTIONS(11),
    [aux_sym_if_block_token1] = ACTIONS(276),
    [aux_sym_while_block_token1] = ACTIONS(278),
    [aux_sym_while_block_token2] = ACTIONS(280),
    [aux_sym__repeat_block_pre_condition_format_token1] = ACTIONS(282),
    [anon_sym_EQ] = ACTIONS(230),
    [anon_sym_PLUS] = ACTIONS(232),
    [anon_sym_DASH] = ACTIONS(232),
    [anon_sym_PLUS_PLUS] = ACTIONS(234),
    [anon_sym_DASH_DASH] = ACTIONS(234),
    [anon_sym_CARET_CARET] = ACTIONS(236),
    [anon_sym_PIPE_PIPE] = ACTIONS(238),
    [anon_sym_STAR] = ACTIONS(240),
    [anon_sym_SLASH] = ACTIONS(242),
    [anon_sym_PERCENT] = ACTIONS(240),
    [anon_sym_PIPE] = ACTIONS(244),
    [anon_sym_CARET] = ACTIONS(246),
    [anon_sym_EQ_EQ] = ACTIONS(248),
    [anon_sym_BANG_EQ] = ACTIONS(248),
    [anon_sym_GT] = ACTIONS(250),
    [anon_sym_GT_EQ] = ACTIONS(248),
    [anon_sym_LT_EQ] = ACTIONS(248),
    [anon_sym_LT] = ACTIONS(250),
    [anon_sym_LT_LT] = ACTIONS(252),
    [anon_sym_GT_GT] = ACTIONS(252),
    [anon_sym_DOT_DOT] = ACTIONS(254),
    [anon_sym_AMP_AMP] = ACTIONS(21),
    [anon_sym_AMP] = ACTIONS(23),
    [aux_sym_macro_definition_token1] = ACTIONS(25),
    [aux_sym_parameter_declaration_token1] = ACTIONS(27),
    [aux_sym_parameter_declaration_token2] = ACTIONS(27),
    [aux_sym_parameter_declaration_token3] = ACTIONS(29),
    [aux_sym_subroutine_call_expression_token1] = ACTIONS(31),
    [aux_sym_macro_definition_command_token1] = ACTIONS(33),
    [aux_sym_macro_definition_command_token2] = ACTIONS(33),
    [aux_sym_macro_definition_command_token3] = ACTIONS(33),
    [aux_sym__host_command_with_default_format_token1] = ACTIONS(35),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(37),
    [sym_comment] = ACTIONS(284),
    [sym__blank_line] = ACTIONS(284),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(286),
    [sym_label_identifier] = ACTIONS(43),
    [sym__and_operator_pre_hook] = ACTIONS(260),
  },
  [STATE(12)] = {
    [sym__statement] = STATE(1474),
    [sym__non_labeled_statement] = STATE(1474),
    [sym_labeled_expression] = STATE(1474),
    [sym_subroutine_block] = STATE(1474),
    [sym_if_block] = STATE(1474),
    [sym_while_block] = STATE(1474),
    [sym_repeat_block] = STATE(1474),
    [sym__repeat_block_pre_condition_format] = STATE(1432),
    [sym__repeat_block_post_condition_format] = STATE(1469),
    [sym_macro_assignment_expression] = STATE(1474),
    [sym__label] = STATE(297),
    [sym_macro_definition] = STATE(1474),
    [sym_parameter_declaration] = STATE(1474),
    [sym_subroutine_call_expression] = STATE(1474),
    [sym_macro] = STATE(2059),
    [sym_recursive_macro_expansion] = STATE(1333),
    [sym_macro_definition_command] = STATE(2082),
    [sym_command_expression] = STATE(1474),
    [sym__host_command] = STATE(2308),
    [sym__host_command_with_default_format] = STATE(2340),
    [sym__other_command] = STATE(2344),
    [sym__command_identifier] = STATE(2020),
    [sym_argument_list] = STATE(348),
    [sym__var_command] = STATE(2360),
    [sym__hll_var_command] = STATE(2298),
    [sym__hll_default_format_var_command] = STATE(2243),
    [sym__hll_non_default_format_var_command] = STATE(2285),
    [sym__non_hll_var_command] = STATE(2314),
    [sym__hll_var_definition_command] = STATE(2336),
    [sym__hll_var_command_with_default_format] = STATE(1981),
    [sym__var_command_with_non_hll_format] = STATE(1982),
    [sym__hll_var_definition_command_expression] = STATE(2271),
    [sym__hll_var_if_command] = STATE(2327),
    [aux_sym_block_repeat1] = STATE(302),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(228),
    [aux_sym_subroutine_block_token1] = ACTIONS(11),
    [aux_sym_if_block_token1] = ACTIONS(288),
    [aux_sym_while_block_token1] = ACTIONS(290),
    [aux_sym_while_block_token2] = ACTIONS(292),
    [aux_sym__repeat_block_pre_condition_format_token1] = ACTIONS(294),
    [anon_sym_EQ] = ACTIONS(230),
    [anon_sym_PLUS] = ACTIONS(232),
    [anon_sym_DASH] = ACTIONS(232),
    [anon_sym_PLUS_PLUS] = ACTIONS(234),
    [anon_sym_DASH_DASH] = ACTIONS(234),
    [anon_sym_CARET_CARET] = ACTIONS(236),
    [anon_sym_PIPE_PIPE] = ACTIONS(238),
    [anon_sym_STAR] = ACTIONS(240),
    [anon_sym_SLASH] = ACTIONS(242),
    [anon_sym_PERCENT] = ACTIONS(240),
    [anon_sym_PIPE] = ACTIONS(244),
    [anon_sym_CARET] = ACTIONS(246),
    [anon_sym_EQ_EQ] = ACTIONS(248),
    [anon_sym_BANG_EQ] = ACTIONS(248),
    [anon_sym_GT] = ACTIONS(250),
    [anon_sym_GT_EQ] = ACTIONS(248),
    [anon_sym_LT_EQ] = ACTIONS(248),
    [anon_sym_LT] = ACTIONS(250),
    [anon_sym_LT_LT] = ACTIONS(252),
    [anon_sym_GT_GT] = ACTIONS(252),
    [anon_sym_DOT_DOT] = ACTIONS(254),
    [anon_sym_AMP_AMP] = ACTIONS(270),
    [anon_sym_AMP] = ACTIONS(23),
    [aux_sym_macro_definition_token1] = ACTIONS(25),
    [aux_sym_parameter_declaration_token1] = ACTIONS(27),
    [aux_sym_parameter_declaration_token2] = ACTIONS(27),
    [aux_sym_parameter_declaration_token3] = ACTIONS(29),
    [aux_sym_subroutine_call_expression_token1] = ACTIONS(31),
    [aux_sym_macro_definition_command_token1] = ACTIONS(33),
    [aux_sym_macro_definition_command_token2] = ACTIONS(33),
    [aux_sym_macro_definition_command_token3] = ACTIONS(33),
    [aux_sym__host_command_with_default_format_token1] = ACTIONS(35),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(37),
    [sym_comment] = ACTIONS(296),
    [sym__blank_line] = ACTIONS(296),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(298),
    [sym_label_identifier] = ACTIONS(43),
    [sym__and_operator_pre_hook] = ACTIONS(260),
  },
  [STATE(13)] = {
    [sym_trace32_hll_variable] = STATE(781),
    [sym__hll_expression] = STATE(593),
    [sym_hll_call_expression] = STATE(778),
    [sym_hll_field_expression] = STATE(778),
    [sym_hll_subscript_expression] = STATE(778),
    [sym_hll_cast_expression] = STATE(593),
    [sym_hll_sizeof_expression] = STATE(593),
    [sym_hll_pointer_expression] = STATE(778),
    [sym_hll_update_expression] = STATE(593),
    [sym_hll_unary_expression] = STATE(593),
    [sym_hll_binary_expression] = STATE(593),
    [sym_hll_assignment_expression] = STATE(593),
    [sym__hll_assignment_left_expression] = STATE(1601),
    [sym_hll_conditional_expression] = STATE(593),
    [sym_hll_char_literal] = STATE(593),
    [sym_hll_string_literal] = STATE(593),
    [sym_hll_parenthesized_expression] = STATE(778),
    [sym_symbol] = STATE(593),
    [sym_identifier] = ACTIONS(300),
    [anon_sym_RPAREN] = ACTIONS(302),
    [anon_sym_LPAREN] = ACTIONS(304),
    [anon_sym_EQ] = ACTIONS(306),
    [anon_sym_PLUS] = ACTIONS(308),
    [anon_sym_DASH] = ACTIONS(308),
    [anon_sym_TILDE] = ACTIONS(310),
    [anon_sym_BANG] = ACTIONS(308),
    [anon_sym_PLUS_PLUS] = ACTIONS(312),
    [anon_sym_DASH_DASH] = ACTIONS(312),
    [anon_sym_PIPE_PIPE] = ACTIONS(302),
    [anon_sym_STAR] = ACTIONS(314),
    [anon_sym_SLASH] = ACTIONS(306),
    [anon_sym_PERCENT] = ACTIONS(306),
    [anon_sym_PIPE] = ACTIONS(306),
    [anon_sym_CARET] = ACTIONS(306),
    [anon_sym_EQ_EQ] = ACTIONS(302),
    [anon_sym_BANG_EQ] = ACTIONS(302),
    [anon_sym_GT] = ACTIONS(306),
    [anon_sym_GT_EQ] = ACTIONS(302),
    [anon_sym_LT_EQ] = ACTIONS(302),
    [anon_sym_LT] = ACTIONS(306),
    [anon_sym_LT_LT] = ACTIONS(306),
    [anon_sym_GT_GT] = ACTIONS(306),
    [anon_sym_DOT_DOT] = ACTIONS(302),
    [anon_sym_AMP_AMP] = ACTIONS(302),
    [anon_sym_AMP] = ACTIONS(314),
    [anon_sym_COLON] = ACTIONS(302),
    [anon_sym_DOT] = ACTIONS(306),
    [anon_sym_COMMA] = ACTIONS(302),
    [anon_sym_QMARK] = ACTIONS(302),
    [anon_sym_BSLASH] = ACTIONS(316),
    [anon_sym_DASH_GT] = ACTIONS(302),
    [anon_sym_LBRACK] = ACTIONS(302),
    [anon_sym_RBRACK] = ACTIONS(302),
    [anon_sym_sizeof] = ACTIONS(318),
    [anon_sym_STAR_EQ] = ACTIONS(302),
    [anon_sym_SLASH_EQ] = ACTIONS(302),
    [anon_sym_PERCENT_EQ] = ACTIONS(302),
    [anon_sym_PLUS_EQ] = ACTIONS(302),
    [anon_sym_DASH_EQ] = ACTIONS(302),
    [anon_sym_LT_LT_EQ] = ACTIONS(302),
    [anon_sym_GT_GT_EQ] = ACTIONS(302),
    [anon_sym_AMP_EQ] = ACTIONS(302),
    [anon_sym_CARET_EQ] = ACTIONS(302),
    [anon_sym_PIPE_EQ] = ACTIONS(302),
    [anon_sym_L_SQUOTE] = ACTIONS(320),
    [anon_sym_u_SQUOTE] = ACTIONS(320),
    [anon_sym_U_SQUOTE] = ACTIONS(320),
    [anon_sym_u8_SQUOTE] = ACTIONS(320),
    [anon_sym_SQUOTE] = ACTIONS(320),
    [anon_sym_L_DQUOTE] = ACTIONS(322),
    [anon_sym_u_DQUOTE] = ACTIONS(322),
    [anon_sym_U_DQUOTE] = ACTIONS(322),
    [anon_sym_u8_DQUOTE] = ACTIONS(322),
    [anon_sym_DQUOTE] = ACTIONS(322),
    [aux_sym_symbol_token1] = ACTIONS(324),
    [aux_sym_symbol_token2] = ACTIONS(326),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(302),
    [sym__hll_number_literal_pre_hook] = ACTIONS(328),
  },
  [STATE(14)] = {
    [sym_trace32_hll_variable] = STATE(781),
    [sym__hll_expression] = STATE(583),
    [sym_hll_call_expression] = STATE(778),
    [sym_hll_field_expression] = STATE(778),
    [sym_hll_subscript_expression] = STATE(778),
    [sym_hll_cast_expression] = STATE(583),
    [sym_hll_sizeof_expression] = STATE(583),
    [sym_hll_pointer_expression] = STATE(778),
    [sym_hll_update_expression] = STATE(583),
    [sym_hll_unary_expression] = STATE(583),
    [sym_hll_binary_expression] = STATE(583),
    [sym_hll_assignment_expression] = STATE(583),
    [sym__hll_assignment_left_expression] = STATE(1601),
    [sym_hll_conditional_expression] = STATE(583),
    [sym_hll_char_literal] = STATE(583),
    [sym_hll_string_literal] = STATE(583),
    [sym_hll_parenthesized_expression] = STATE(778),
    [sym_symbol] = STATE(583),
    [sym_identifier] = ACTIONS(300),
    [anon_sym_RPAREN] = ACTIONS(330),
    [anon_sym_LPAREN] = ACTIONS(304),
    [anon_sym_EQ] = ACTIONS(332),
    [anon_sym_PLUS] = ACTIONS(308),
    [anon_sym_DASH] = ACTIONS(308),
    [anon_sym_TILDE] = ACTIONS(310),
    [anon_sym_BANG] = ACTIONS(308),
    [anon_sym_PLUS_PLUS] = ACTIONS(312),
    [anon_sym_DASH_DASH] = ACTIONS(312),
    [anon_sym_PIPE_PIPE] = ACTIONS(330),
    [anon_sym_STAR] = ACTIONS(314),
    [anon_sym_SLASH] = ACTIONS(332),
    [anon_sym_PERCENT] = ACTIONS(332),
    [anon_sym_PIPE] = ACTIONS(332),
    [anon_sym_CARET] = ACTIONS(332),
    [anon_sym_EQ_EQ] = ACTIONS(330),
    [anon_sym_BANG_EQ] = ACTIONS(330),
    [anon_sym_GT] = ACTIONS(332),
    [anon_sym_GT_EQ] = ACTIONS(330),
    [anon_sym_LT_EQ] = ACTIONS(330),
    [anon_sym_LT] = ACTIONS(332),
    [anon_sym_LT_LT] = ACTIONS(332),
    [anon_sym_GT_GT] = ACTIONS(332),
    [anon_sym_DOT_DOT] = ACTIONS(330),
    [anon_sym_AMP_AMP] = ACTIONS(330),
    [anon_sym_AMP] = ACTIONS(314),
    [anon_sym_COLON] = ACTIONS(330),
    [anon_sym_DOT] = ACTIONS(332),
    [anon_sym_COMMA] = ACTIONS(330),
    [anon_sym_QMARK] = ACTIONS(330),
    [anon_sym_BSLASH] = ACTIONS(316),
    [anon_sym_DASH_GT] = ACTIONS(330),
    [anon_sym_LBRACK] = ACTIONS(330),
    [anon_sym_RBRACK] = ACTIONS(330),
    [anon_sym_sizeof] = ACTIONS(318),
    [anon_sym_STAR_EQ] = ACTIONS(330),
    [anon_sym_SLASH_EQ] = ACTIONS(330),
    [anon_sym_PERCENT_EQ] = ACTIONS(330),
    [anon_sym_PLUS_EQ] = ACTIONS(330),
    [anon_sym_DASH_EQ] = ACTIONS(330),
    [anon_sym_LT_LT_EQ] = ACTIONS(330),
    [anon_sym_GT_GT_EQ] = ACTIONS(330),
    [anon_sym_AMP_EQ] = ACTIONS(330),
    [anon_sym_CARET_EQ] = ACTIONS(330),
    [anon_sym_PIPE_EQ] = ACTIONS(330),
    [anon_sym_L_SQUOTE] = ACTIONS(320),
    [anon_sym_u_SQUOTE] = ACTIONS(320),
    [anon_sym_U_SQUOTE] = ACTIONS(320),
    [anon_sym_u8_SQUOTE] = ACTIONS(320),
    [anon_sym_SQUOTE] = ACTIONS(320),
    [anon_sym_L_DQUOTE] = ACTIONS(322),
    [anon_sym_u_DQUOTE] = ACTIONS(322),
    [anon_sym_U_DQUOTE] = ACTIONS(322),
    [anon_sym_u8_DQUOTE] = ACTIONS(322),
    [anon_sym_DQUOTE] = ACTIONS(322),
    [aux_sym_symbol_token1] = ACTIONS(324),
    [aux_sym_symbol_token2] = ACTIONS(326),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(330),
    [sym__hll_number_literal_pre_hook] = ACTIONS(328),
  },
  [STATE(15)] = {
    [sym_trace32_hll_variable] = STATE(781),
    [sym__hll_expression] = STATE(580),
    [sym_hll_call_expression] = STATE(778),
    [sym_hll_field_expression] = STATE(778),
    [sym_hll_subscript_expression] = STATE(778),
    [sym_hll_cast_expression] = STATE(580),
    [sym_hll_sizeof_expression] = STATE(580),
    [sym_hll_pointer_expression] = STATE(778),
    [sym_hll_update_expression] = STATE(580),
    [sym_hll_unary_expression] = STATE(580),
    [sym_hll_binary_expression] = STATE(580),
    [sym_hll_assignment_expression] = STATE(580),
    [sym__hll_assignment_left_expression] = STATE(1601),
    [sym_hll_conditional_expression] = STATE(580),
    [sym_hll_char_literal] = STATE(580),
    [sym_hll_string_literal] = STATE(580),
    [sym_hll_parenthesized_expression] = STATE(778),
    [sym_symbol] = STATE(580),
    [sym_identifier] = ACTIONS(300),
    [anon_sym_RPAREN] = ACTIONS(334),
    [anon_sym_LPAREN] = ACTIONS(304),
    [anon_sym_EQ] = ACTIONS(336),
    [anon_sym_PLUS] = ACTIONS(308),
    [anon_sym_DASH] = ACTIONS(308),
    [anon_sym_TILDE] = ACTIONS(310),
    [anon_sym_BANG] = ACTIONS(308),
    [anon_sym_PLUS_PLUS] = ACTIONS(312),
    [anon_sym_DASH_DASH] = ACTIONS(312),
    [anon_sym_PIPE_PIPE] = ACTIONS(334),
    [anon_sym_STAR] = ACTIONS(314),
    [anon_sym_SLASH] = ACTIONS(336),
    [anon_sym_PERCENT] = ACTIONS(336),
    [anon_sym_PIPE] = ACTIONS(336),
    [anon_sym_CARET] = ACTIONS(336),
    [anon_sym_EQ_EQ] = ACTIONS(334),
    [anon_sym_BANG_EQ] = ACTIONS(334),
    [anon_sym_GT] = ACTIONS(336),
    [anon_sym_GT_EQ] = ACTIONS(334),
    [anon_sym_LT_EQ] = ACTIONS(334),
    [anon_sym_LT] = ACTIONS(336),
    [anon_sym_LT_LT] = ACTIONS(336),
    [anon_sym_GT_GT] = ACTIONS(336),
    [anon_sym_DOT_DOT] = ACTIONS(334),
    [anon_sym_AMP_AMP] = ACTIONS(334),
    [anon_sym_AMP] = ACTIONS(314),
    [anon_sym_COLON] = ACTIONS(334),
    [anon_sym_DOT] = ACTIONS(336),
    [anon_sym_COMMA] = ACTIONS(334),
    [anon_sym_QMARK] = ACTIONS(334),
    [anon_sym_BSLASH] = ACTIONS(316),
    [anon_sym_DASH_GT] = ACTIONS(334),
    [anon_sym_LBRACK] = ACTIONS(334),
    [anon_sym_RBRACK] = ACTIONS(334),
    [anon_sym_sizeof] = ACTIONS(318),
    [anon_sym_STAR_EQ] = ACTIONS(334),
    [anon_sym_SLASH_EQ] = ACTIONS(334),
    [anon_sym_PERCENT_EQ] = ACTIONS(334),
    [anon_sym_PLUS_EQ] = ACTIONS(334),
    [anon_sym_DASH_EQ] = ACTIONS(334),
    [anon_sym_LT_LT_EQ] = ACTIONS(334),
    [anon_sym_GT_GT_EQ] = ACTIONS(334),
    [anon_sym_AMP_EQ] = ACTIONS(334),
    [anon_sym_CARET_EQ] = ACTIONS(334),
    [anon_sym_PIPE_EQ] = ACTIONS(334),
    [anon_sym_L_SQUOTE] = ACTIONS(320),
    [anon_sym_u_SQUOTE] = ACTIONS(320),
    [anon_sym_U_SQUOTE] = ACTIONS(320),
    [anon_sym_u8_SQUOTE] = ACTIONS(320),
    [anon_sym_SQUOTE] = ACTIONS(320),
    [anon_sym_L_DQUOTE] = ACTIONS(322),
    [anon_sym_u_DQUOTE] = ACTIONS(322),
    [anon_sym_U_DQUOTE] = ACTIONS(322),
    [anon_sym_u8_DQUOTE] = ACTIONS(322),
    [anon_sym_DQUOTE] = ACTIONS(322),
    [aux_sym_symbol_token1] = ACTIONS(324),
    [aux_sym_symbol_token2] = ACTIONS(326),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(334),
    [sym__hll_number_literal_pre_hook] = ACTIONS(328),
  },
  [STATE(16)] = {
    [sym_trace32_hll_variable] = STATE(781),
    [sym__hll_expression] = STATE(546),
    [sym_hll_call_expression] = STATE(778),
    [sym_hll_field_expression] = STATE(778),
    [sym_hll_subscript_expression] = STATE(778),
    [sym_hll_cast_expression] = STATE(546),
    [sym_hll_sizeof_expression] = STATE(546),
    [sym_hll_pointer_expression] = STATE(778),
    [sym_hll_update_expression] = STATE(546),
    [sym_hll_unary_expression] = STATE(546),
    [sym_hll_binary_expression] = STATE(546),
    [sym_hll_assignment_expression] = STATE(546),
    [sym__hll_assignment_left_expression] = STATE(1601),
    [sym_hll_conditional_expression] = STATE(546),
    [sym_hll_char_literal] = STATE(546),
    [sym_hll_string_literal] = STATE(546),
    [sym_hll_parenthesized_expression] = STATE(778),
    [sym_symbol] = STATE(546),
    [sym_identifier] = ACTIONS(300),
    [anon_sym_RPAREN] = ACTIONS(338),
    [anon_sym_LPAREN] = ACTIONS(304),
    [anon_sym_EQ] = ACTIONS(340),
    [anon_sym_PLUS] = ACTIONS(308),
    [anon_sym_DASH] = ACTIONS(308),
    [anon_sym_TILDE] = ACTIONS(310),
    [anon_sym_BANG] = ACTIONS(308),
    [anon_sym_PLUS_PLUS] = ACTIONS(312),
    [anon_sym_DASH_DASH] = ACTIONS(312),
    [anon_sym_PIPE_PIPE] = ACTIONS(338),
    [anon_sym_STAR] = ACTIONS(314),
    [anon_sym_SLASH] = ACTIONS(340),
    [anon_sym_PERCENT] = ACTIONS(340),
    [anon_sym_PIPE] = ACTIONS(340),
    [anon_sym_CARET] = ACTIONS(340),
    [anon_sym_EQ_EQ] = ACTIONS(338),
    [anon_sym_BANG_EQ] = ACTIONS(338),
    [anon_sym_GT] = ACTIONS(340),
    [anon_sym_GT_EQ] = ACTIONS(338),
    [anon_sym_LT_EQ] = ACTIONS(338),
    [anon_sym_LT] = ACTIONS(340),
    [anon_sym_LT_LT] = ACTIONS(340),
    [anon_sym_GT_GT] = ACTIONS(340),
    [anon_sym_DOT_DOT] = ACTIONS(338),
    [anon_sym_AMP_AMP] = ACTIONS(338),
    [anon_sym_AMP] = ACTIONS(314),
    [anon_sym_COLON] = ACTIONS(338),
    [anon_sym_DOT] = ACTIONS(340),
    [anon_sym_COMMA] = ACTIONS(338),
    [anon_sym_QMARK] = ACTIONS(338),
    [anon_sym_BSLASH] = ACTIONS(316),
    [anon_sym_DASH_GT] = ACTIONS(338),
    [anon_sym_LBRACK] = ACTIONS(338),
    [anon_sym_RBRACK] = ACTIONS(338),
    [anon_sym_sizeof] = ACTIONS(318),
    [anon_sym_STAR_EQ] = ACTIONS(338),
    [anon_sym_SLASH_EQ] = ACTIONS(338),
    [anon_sym_PERCENT_EQ] = ACTIONS(338),
    [anon_sym_PLUS_EQ] = ACTIONS(338),
    [anon_sym_DASH_EQ] = ACTIONS(338),
    [anon_sym_LT_LT_EQ] = ACTIONS(338),
    [anon_sym_GT_GT_EQ] = ACTIONS(338),
    [anon_sym_AMP_EQ] = ACTIONS(338),
    [anon_sym_CARET_EQ] = ACTIONS(338),
    [anon_sym_PIPE_EQ] = ACTIONS(338),
    [anon_sym_L_SQUOTE] = ACTIONS(320),
    [anon_sym_u_SQUOTE] = ACTIONS(320),
    [anon_sym_U_SQUOTE] = ACTIONS(320),
    [anon_sym_u8_SQUOTE] = ACTIONS(320),
    [anon_sym_SQUOTE] = ACTIONS(320),
    [anon_sym_L_DQUOTE] = ACTIONS(322),
    [anon_sym_u_DQUOTE] = ACTIONS(322),
    [anon_sym_U_DQUOTE] = ACTIONS(322),
    [anon_sym_u8_DQUOTE] = ACTIONS(322),
    [anon_sym_DQUOTE] = ACTIONS(322),
    [aux_sym_symbol_token1] = ACTIONS(324),
    [aux_sym_symbol_token2] = ACTIONS(326),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(338),
    [sym__hll_number_literal_pre_hook] = ACTIONS(328),
  },
  [STATE(17)] = {
    [sym_trace32_hll_variable] = STATE(807),
    [sym__hll_expression] = STATE(769),
    [sym_hll_call_expression] = STATE(806),
    [sym_hll_field_expression] = STATE(806),
    [sym_hll_subscript_expression] = STATE(806),
    [sym_hll_cast_expression] = STATE(769),
    [sym_hll_sizeof_expression] = STATE(769),
    [sym_hll_pointer_expression] = STATE(806),
    [sym_hll_update_expression] = STATE(769),
    [sym_hll_unary_expression] = STATE(769),
    [sym_hll_binary_expression] = STATE(769),
    [sym_hll_assignment_expression] = STATE(769),
    [sym__hll_assignment_left_expression] = STATE(1593),
    [sym_hll_conditional_expression] = STATE(769),
    [sym_hll_char_literal] = STATE(769),
    [sym_hll_string_literal] = STATE(769),
    [sym_hll_parenthesized_expression] = STATE(806),
    [sym_symbol] = STATE(769),
    [sym_identifier] = ACTIONS(342),
    [anon_sym_LPAREN] = ACTIONS(344),
    [anon_sym_EQ] = ACTIONS(340),
    [anon_sym_PLUS] = ACTIONS(346),
    [anon_sym_DASH] = ACTIONS(346),
    [anon_sym_TILDE] = ACTIONS(348),
    [anon_sym_BANG] = ACTIONS(346),
    [anon_sym_PLUS_PLUS] = ACTIONS(350),
    [anon_sym_DASH_DASH] = ACTIONS(350),
    [anon_sym_PIPE_PIPE] = ACTIONS(338),
    [anon_sym_STAR] = ACTIONS(352),
    [anon_sym_SLASH] = ACTIONS(340),
    [anon_sym_PERCENT] = ACTIONS(340),
    [anon_sym_PIPE] = ACTIONS(340),
    [anon_sym_CARET] = ACTIONS(340),
    [anon_sym_EQ_EQ] = ACTIONS(338),
    [anon_sym_BANG_EQ] = ACTIONS(338),
    [anon_sym_GT] = ACTIONS(340),
    [anon_sym_GT_EQ] = ACTIONS(338),
    [anon_sym_LT_EQ] = ACTIONS(338),
    [anon_sym_LT] = ACTIONS(340),
    [anon_sym_LT_LT] = ACTIONS(340),
    [anon_sym_GT_GT] = ACTIONS(340),
    [anon_sym_AMP_AMP] = ACTIONS(338),
    [anon_sym_AMP] = ACTIONS(352),
    [anon_sym_DOT] = ACTIONS(338),
    [anon_sym_QMARK] = ACTIONS(338),
    [anon_sym_BSLASH] = ACTIONS(354),
    [anon_sym_DASH_GT] = ACTIONS(338),
    [anon_sym_LBRACK] = ACTIONS(338),
    [anon_sym_sizeof] = ACTIONS(356),
    [anon_sym_STAR_EQ] = ACTIONS(338),
    [anon_sym_SLASH_EQ] = ACTIONS(338),
    [anon_sym_PERCENT_EQ] = ACTIONS(338),
    [anon_sym_PLUS_EQ] = ACTIONS(338),
    [anon_sym_DASH_EQ] = ACTIONS(338),
    [anon_sym_LT_LT_EQ] = ACTIONS(338),
    [anon_sym_GT_GT_EQ] = ACTIONS(338),
    [anon_sym_AMP_EQ] = ACTIONS(338),
    [anon_sym_CARET_EQ] = ACTIONS(338),
    [anon_sym_PIPE_EQ] = ACTIONS(338),
    [anon_sym_L_SQUOTE] = ACTIONS(358),
    [anon_sym_u_SQUOTE] = ACTIONS(358),
    [anon_sym_U_SQUOTE] = ACTIONS(358),
    [anon_sym_u8_SQUOTE] = ACTIONS(358),
    [anon_sym_SQUOTE] = ACTIONS(358),
    [anon_sym_L_DQUOTE] = ACTIONS(360),
    [anon_sym_u_DQUOTE] = ACTIONS(360),
    [anon_sym_U_DQUOTE] = ACTIONS(360),
    [anon_sym_u8_DQUOTE] = ACTIONS(360),
    [anon_sym_DQUOTE] = ACTIONS(360),
    [aux_sym__hll_expression_separator_token1] = ACTIONS(338),
    [aux_sym__hll_expression_separator_token2] = ACTIONS(340),
    [aux_sym_symbol_token1] = ACTIONS(362),
    [aux_sym_symbol_token2] = ACTIONS(364),
    [sym_comment] = ACTIONS(338),
    [sym__blank_line] = ACTIONS(338),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(340),
    [sym__hll_number_literal_pre_hook] = ACTIONS(366),
  },
  [STATE(18)] = {
    [sym_trace32_hll_variable] = STATE(807),
    [sym__hll_expression] = STATE(776),
    [sym_hll_call_expression] = STATE(806),
    [sym_hll_field_expression] = STATE(806),
    [sym_hll_subscript_expression] = STATE(806),
    [sym_hll_cast_expression] = STATE(776),
    [sym_hll_sizeof_expression] = STATE(776),
    [sym_hll_pointer_expression] = STATE(806),
    [sym_hll_update_expression] = STATE(776),
    [sym_hll_unary_expression] = STATE(776),
    [sym_hll_binary_expression] = STATE(776),
    [sym_hll_assignment_expression] = STATE(776),
    [sym__hll_assignment_left_expression] = STATE(1593),
    [sym_hll_conditional_expression] = STATE(776),
    [sym_hll_char_literal] = STATE(776),
    [sym_hll_string_literal] = STATE(776),
    [sym_hll_parenthesized_expression] = STATE(806),
    [sym_symbol] = STATE(776),
    [sym_identifier] = ACTIONS(342),
    [anon_sym_LPAREN] = ACTIONS(344),
    [anon_sym_EQ] = ACTIONS(332),
    [anon_sym_PLUS] = ACTIONS(346),
    [anon_sym_DASH] = ACTIONS(346),
    [anon_sym_TILDE] = ACTIONS(348),
    [anon_sym_BANG] = ACTIONS(346),
    [anon_sym_PLUS_PLUS] = ACTIONS(350),
    [anon_sym_DASH_DASH] = ACTIONS(350),
    [anon_sym_PIPE_PIPE] = ACTIONS(330),
    [anon_sym_STAR] = ACTIONS(352),
    [anon_sym_SLASH] = ACTIONS(332),
    [anon_sym_PERCENT] = ACTIONS(332),
    [anon_sym_PIPE] = ACTIONS(332),
    [anon_sym_CARET] = ACTIONS(332),
    [anon_sym_EQ_EQ] = ACTIONS(330),
    [anon_sym_BANG_EQ] = ACTIONS(330),
    [anon_sym_GT] = ACTIONS(332),
    [anon_sym_GT_EQ] = ACTIONS(330),
    [anon_sym_LT_EQ] = ACTIONS(330),
    [anon_sym_LT] = ACTIONS(332),
    [anon_sym_LT_LT] = ACTIONS(332),
    [anon_sym_GT_GT] = ACTIONS(332),
    [anon_sym_AMP_AMP] = ACTIONS(330),
    [anon_sym_AMP] = ACTIONS(352),
    [anon_sym_DOT] = ACTIONS(330),
    [anon_sym_QMARK] = ACTIONS(330),
    [anon_sym_BSLASH] = ACTIONS(354),
    [anon_sym_DASH_GT] = ACTIONS(330),
    [anon_sym_LBRACK] = ACTIONS(330),
    [anon_sym_sizeof] = ACTIONS(356),
    [anon_sym_STAR_EQ] = ACTIONS(330),
    [anon_sym_SLASH_EQ] = ACTIONS(330),
    [anon_sym_PERCENT_EQ] = ACTIONS(330),
    [anon_sym_PLUS_EQ] = ACTIONS(330),
    [anon_sym_DASH_EQ] = ACTIONS(330),
    [anon_sym_LT_LT_EQ] = ACTIONS(330),
    [anon_sym_GT_GT_EQ] = ACTIONS(330),
    [anon_sym_AMP_EQ] = ACTIONS(330),
    [anon_sym_CARET_EQ] = ACTIONS(330),
    [anon_sym_PIPE_EQ] = ACTIONS(330),
    [anon_sym_L_SQUOTE] = ACTIONS(358),
    [anon_sym_u_SQUOTE] = ACTIONS(358),
    [anon_sym_U_SQUOTE] = ACTIONS(358),
    [anon_sym_u8_SQUOTE] = ACTIONS(358),
    [anon_sym_SQUOTE] = ACTIONS(358),
    [anon_sym_L_DQUOTE] = ACTIONS(360),
    [anon_sym_u_DQUOTE] = ACTIONS(360),
    [anon_sym_U_DQUOTE] = ACTIONS(360),
    [anon_sym_u8_DQUOTE] = ACTIONS(360),
    [anon_sym_DQUOTE] = ACTIONS(360),
    [aux_sym__hll_expression_separator_token1] = ACTIONS(330),
    [aux_sym__hll_expression_separator_token2] = ACTIONS(332),
    [aux_sym_symbol_token1] = ACTIONS(362),
    [aux_sym_symbol_token2] = ACTIONS(364),
    [sym_comment] = ACTIONS(330),
    [sym__blank_line] = ACTIONS(330),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(332),
    [sym__hll_number_literal_pre_hook] = ACTIONS(366),
  },
  [STATE(19)] = {
    [sym_trace32_hll_variable] = STATE(807),
    [sym__hll_expression] = STATE(780),
    [sym_hll_call_expression] = STATE(806),
    [sym_hll_field_expression] = STATE(806),
    [sym_hll_subscript_expression] = STATE(806),
    [sym_hll_cast_expression] = STATE(780),
    [sym_hll_sizeof_expression] = STATE(780),
    [sym_hll_pointer_expression] = STATE(806),
    [sym_hll_update_expression] = STATE(780),
    [sym_hll_unary_expression] = STATE(780),
    [sym_hll_binary_expression] = STATE(780),
    [sym_hll_assignment_expression] = STATE(780),
    [sym__hll_assignment_left_expression] = STATE(1593),
    [sym_hll_conditional_expression] = STATE(780),
    [sym_hll_char_literal] = STATE(780),
    [sym_hll_string_literal] = STATE(780),
    [sym_hll_parenthesized_expression] = STATE(806),
    [sym_symbol] = STATE(780),
    [sym_identifier] = ACTIONS(342),
    [anon_sym_LPAREN] = ACTIONS(344),
    [anon_sym_EQ] = ACTIONS(306),
    [anon_sym_PLUS] = ACTIONS(346),
    [anon_sym_DASH] = ACTIONS(346),
    [anon_sym_TILDE] = ACTIONS(348),
    [anon_sym_BANG] = ACTIONS(346),
    [anon_sym_PLUS_PLUS] = ACTIONS(350),
    [anon_sym_DASH_DASH] = ACTIONS(350),
    [anon_sym_PIPE_PIPE] = ACTIONS(302),
    [anon_sym_STAR] = ACTIONS(352),
    [anon_sym_SLASH] = ACTIONS(306),
    [anon_sym_PERCENT] = ACTIONS(306),
    [anon_sym_PIPE] = ACTIONS(306),
    [anon_sym_CARET] = ACTIONS(306),
    [anon_sym_EQ_EQ] = ACTIONS(302),
    [anon_sym_BANG_EQ] = ACTIONS(302),
    [anon_sym_GT] = ACTIONS(306),
    [anon_sym_GT_EQ] = ACTIONS(302),
    [anon_sym_LT_EQ] = ACTIONS(302),
    [anon_sym_LT] = ACTIONS(306),
    [anon_sym_LT_LT] = ACTIONS(306),
    [anon_sym_GT_GT] = ACTIONS(306),
    [anon_sym_AMP_AMP] = ACTIONS(302),
    [anon_sym_AMP] = ACTIONS(352),
    [anon_sym_DOT] = ACTIONS(302),
    [anon_sym_QMARK] = ACTIONS(302),
    [anon_sym_BSLASH] = ACTIONS(354),
    [anon_sym_DASH_GT] = ACTIONS(302),
    [anon_sym_LBRACK] = ACTIONS(302),
    [anon_sym_sizeof] = ACTIONS(356),
    [anon_sym_STAR_EQ] = ACTIONS(302),
    [anon_sym_SLASH_EQ] = ACTIONS(302),
    [anon_sym_PERCENT_EQ] = ACTIONS(302),
    [anon_sym_PLUS_EQ] = ACTIONS(302),
    [anon_sym_DASH_EQ] = ACTIONS(302),
    [anon_sym_LT_LT_EQ] = ACTIONS(302),
    [anon_sym_GT_GT_EQ] = ACTIONS(302),
    [anon_sym_AMP_EQ] = ACTIONS(302),
    [anon_sym_CARET_EQ] = ACTIONS(302),
    [anon_sym_PIPE_EQ] = ACTIONS(302),
    [anon_sym_L_SQUOTE] = ACTIONS(358),
    [anon_sym_u_SQUOTE] = ACTIONS(358),
    [anon_sym_U_SQUOTE] = ACTIONS(358),
    [anon_sym_u8_SQUOTE] = ACTIONS(358),
    [anon_sym_SQUOTE] = ACTIONS(358),
    [anon_sym_L_DQUOTE] = ACTIONS(360),
    [anon_sym_u_DQUOTE] = ACTIONS(360),
    [anon_sym_U_DQUOTE] = ACTIONS(360),
    [anon_sym_u8_DQUOTE] = ACTIONS(360),
    [anon_sym_DQUOTE] = ACTIONS(360),
    [aux_sym__hll_expression_separator_token1] = ACTIONS(302),
    [aux_sym__hll_expression_separator_token2] = ACTIONS(306),
    [aux_sym_symbol_token1] = ACTIONS(362),
    [aux_sym_symbol_token2] = ACTIONS(364),
    [sym_comment] = ACTIONS(302),
    [sym__blank_line] = ACTIONS(302),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(306),
    [sym__hll_number_literal_pre_hook] = ACTIONS(366),
  },
  [STATE(20)] = {
    [sym_trace32_hll_variable] = STATE(807),
    [sym__hll_expression] = STATE(775),
    [sym_hll_call_expression] = STATE(806),
    [sym_hll_field_expression] = STATE(806),
    [sym_hll_subscript_expression] = STATE(806),
    [sym_hll_cast_expression] = STATE(775),
    [sym_hll_sizeof_expression] = STATE(775),
    [sym_hll_pointer_expression] = STATE(806),
    [sym_hll_update_expression] = STATE(775),
    [sym_hll_unary_expression] = STATE(775),
    [sym_hll_binary_expression] = STATE(775),
    [sym_hll_assignment_expression] = STATE(775),
    [sym__hll_assignment_left_expression] = STATE(1593),
    [sym_hll_conditional_expression] = STATE(775),
    [sym_hll_char_literal] = STATE(775),
    [sym_hll_string_literal] = STATE(775),
    [sym_hll_parenthesized_expression] = STATE(806),
    [sym_symbol] = STATE(775),
    [sym_identifier] = ACTIONS(342),
    [anon_sym_LPAREN] = ACTIONS(344),
    [anon_sym_EQ] = ACTIONS(336),
    [anon_sym_PLUS] = ACTIONS(346),
    [anon_sym_DASH] = ACTIONS(346),
    [anon_sym_TILDE] = ACTIONS(348),
    [anon_sym_BANG] = ACTIONS(346),
    [anon_sym_PLUS_PLUS] = ACTIONS(350),
    [anon_sym_DASH_DASH] = ACTIONS(350),
    [anon_sym_PIPE_PIPE] = ACTIONS(334),
    [anon_sym_STAR] = ACTIONS(352),
    [anon_sym_SLASH] = ACTIONS(336),
    [anon_sym_PERCENT] = ACTIONS(336),
    [anon_sym_PIPE] = ACTIONS(336),
    [anon_sym_CARET] = ACTIONS(336),
    [anon_sym_EQ_EQ] = ACTIONS(334),
    [anon_sym_BANG_EQ] = ACTIONS(334),
    [anon_sym_GT] = ACTIONS(336),
    [anon_sym_GT_EQ] = ACTIONS(334),
    [anon_sym_LT_EQ] = ACTIONS(334),
    [anon_sym_LT] = ACTIONS(336),
    [anon_sym_LT_LT] = ACTIONS(336),
    [anon_sym_GT_GT] = ACTIONS(336),
    [anon_sym_AMP_AMP] = ACTIONS(334),
    [anon_sym_AMP] = ACTIONS(352),
    [anon_sym_DOT] = ACTIONS(334),
    [anon_sym_QMARK] = ACTIONS(334),
    [anon_sym_BSLASH] = ACTIONS(354),
    [anon_sym_DASH_GT] = ACTIONS(334),
    [anon_sym_LBRACK] = ACTIONS(334),
    [anon_sym_sizeof] = ACTIONS(356),
    [anon_sym_STAR_EQ] = ACTIONS(334),
    [anon_sym_SLASH_EQ] = ACTIONS(334),
    [anon_sym_PERCENT_EQ] = ACTIONS(334),
    [anon_sym_PLUS_EQ] = ACTIONS(334),
    [anon_sym_DASH_EQ] = ACTIONS(334),
    [anon_sym_LT_LT_EQ] = ACTIONS(334),
    [anon_sym_GT_GT_EQ] = ACTIONS(334),
    [anon_sym_AMP_EQ] = ACTIONS(334),
    [anon_sym_CARET_EQ] = ACTIONS(334),
    [anon_sym_PIPE_EQ] = ACTIONS(334),
    [anon_sym_L_SQUOTE] = ACTIONS(358),
    [anon_sym_u_SQUOTE] = ACTIONS(358),
    [anon_sym_U_SQUOTE] = ACTIONS(358),
    [anon_sym_u8_SQUOTE] = ACTIONS(358),
    [anon_sym_SQUOTE] = ACTIONS(358),
    [anon_sym_L_DQUOTE] = ACTIONS(360),
    [anon_sym_u_DQUOTE] = ACTIONS(360),
    [anon_sym_U_DQUOTE] = ACTIONS(360),
    [anon_sym_u8_DQUOTE] = ACTIONS(360),
    [anon_sym_DQUOTE] = ACTIONS(360),
    [aux_sym__hll_expression_separator_token1] = ACTIONS(334),
    [aux_sym__hll_expression_separator_token2] = ACTIONS(336),
    [aux_sym_symbol_token1] = ACTIONS(362),
    [aux_sym_symbol_token2] = ACTIONS(364),
    [sym_comment] = ACTIONS(334),
    [sym__blank_line] = ACTIONS(334),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(336),
    [sym__hll_number_literal_pre_hook] = ACTIONS(366),
  },
  [STATE(21)] = {
    [sym_trace32_hll_variable] = STATE(900),
    [sym__hll_expression] = STATE(822),
    [sym_hll_call_expression] = STATE(898),
    [sym_hll_field_expression] = STATE(898),
    [sym_hll_subscript_expression] = STATE(898),
    [sym_hll_cast_expression] = STATE(822),
    [sym_hll_sizeof_expression] = STATE(822),
    [sym_hll_pointer_expression] = STATE(898),
    [sym_hll_update_expression] = STATE(822),
    [sym_hll_unary_expression] = STATE(822),
    [sym_hll_binary_expression] = STATE(822),
    [sym_hll_assignment_expression] = STATE(822),
    [sym__hll_assignment_left_expression] = STATE(1580),
    [sym_hll_conditional_expression] = STATE(822),
    [sym_hll_char_literal] = STATE(822),
    [sym_hll_string_literal] = STATE(822),
    [sym_hll_parenthesized_expression] = STATE(898),
    [sym_symbol] = STATE(822),
    [sym_identifier] = ACTIONS(368),
    [anon_sym_LPAREN] = ACTIONS(370),
    [anon_sym_EQ] = ACTIONS(336),
    [anon_sym_PLUS] = ACTIONS(372),
    [anon_sym_DASH] = ACTIONS(372),
    [anon_sym_TILDE] = ACTIONS(374),
    [anon_sym_BANG] = ACTIONS(372),
    [anon_sym_PLUS_PLUS] = ACTIONS(376),
    [anon_sym_DASH_DASH] = ACTIONS(376),
    [anon_sym_PIPE_PIPE] = ACTIONS(334),
    [anon_sym_STAR] = ACTIONS(378),
    [anon_sym_SLASH] = ACTIONS(336),
    [anon_sym_PERCENT] = ACTIONS(336),
    [anon_sym_PIPE] = ACTIONS(336),
    [anon_sym_CARET] = ACTIONS(336),
    [anon_sym_EQ_EQ] = ACTIONS(334),
    [anon_sym_BANG_EQ] = ACTIONS(334),
    [anon_sym_GT] = ACTIONS(336),
    [anon_sym_GT_EQ] = ACTIONS(334),
    [anon_sym_LT_EQ] = ACTIONS(334),
    [anon_sym_LT] = ACTIONS(336),
    [anon_sym_LT_LT] = ACTIONS(336),
    [anon_sym_GT_GT] = ACTIONS(336),
    [anon_sym_AMP_AMP] = ACTIONS(334),
    [anon_sym_AMP] = ACTIONS(378),
    [anon_sym_DOT] = ACTIONS(334),
    [anon_sym_QMARK] = ACTIONS(334),
    [anon_sym_BSLASH] = ACTIONS(380),
    [anon_sym_DASH_GT] = ACTIONS(334),
    [anon_sym_LBRACK] = ACTIONS(334),
    [anon_sym_sizeof] = ACTIONS(382),
    [anon_sym_STAR_EQ] = ACTIONS(334),
    [anon_sym_SLASH_EQ] = ACTIONS(334),
    [anon_sym_PERCENT_EQ] = ACTIONS(334),
    [anon_sym_PLUS_EQ] = ACTIONS(334),
    [anon_sym_DASH_EQ] = ACTIONS(334),
    [anon_sym_LT_LT_EQ] = ACTIONS(334),
    [anon_sym_GT_GT_EQ] = ACTIONS(334),
    [anon_sym_AMP_EQ] = ACTIONS(334),
    [anon_sym_CARET_EQ] = ACTIONS(334),
    [anon_sym_PIPE_EQ] = ACTIONS(334),
    [anon_sym_L_SQUOTE] = ACTIONS(384),
    [anon_sym_u_SQUOTE] = ACTIONS(384),
    [anon_sym_U_SQUOTE] = ACTIONS(384),
    [anon_sym_u8_SQUOTE] = ACTIONS(384),
    [anon_sym_SQUOTE] = ACTIONS(384),
    [anon_sym_L_DQUOTE] = ACTIONS(386),
    [anon_sym_u_DQUOTE] = ACTIONS(386),
    [anon_sym_U_DQUOTE] = ACTIONS(386),
    [anon_sym_u8_DQUOTE] = ACTIONS(386),
    [anon_sym_DQUOTE] = ACTIONS(386),
    [aux_sym_symbol_token1] = ACTIONS(388),
    [aux_sym_symbol_token2] = ACTIONS(390),
    [sym_comment] = ACTIONS(334),
    [sym__blank_line] = ACTIONS(334),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(336),
    [sym__hll_number_literal_pre_hook] = ACTIONS(392),
  },
  [STATE(22)] = {
    [sym_trace32_hll_variable] = STATE(900),
    [sym__hll_expression] = STATE(821),
    [sym_hll_call_expression] = STATE(898),
    [sym_hll_field_expression] = STATE(898),
    [sym_hll_subscript_expression] = STATE(898),
    [sym_hll_cast_expression] = STATE(821),
    [sym_hll_sizeof_expression] = STATE(821),
    [sym_hll_pointer_expression] = STATE(898),
    [sym_hll_update_expression] = STATE(821),
    [sym_hll_unary_expression] = STATE(821),
    [sym_hll_binary_expression] = STATE(821),
    [sym_hll_assignment_expression] = STATE(821),
    [sym__hll_assignment_left_expression] = STATE(1580),
    [sym_hll_conditional_expression] = STATE(821),
    [sym_hll_char_literal] = STATE(821),
    [sym_hll_string_literal] = STATE(821),
    [sym_hll_parenthesized_expression] = STATE(898),
    [sym_symbol] = STATE(821),
    [sym_identifier] = ACTIONS(368),
    [anon_sym_LPAREN] = ACTIONS(370),
    [anon_sym_EQ] = ACTIONS(340),
    [anon_sym_PLUS] = ACTIONS(372),
    [anon_sym_DASH] = ACTIONS(372),
    [anon_sym_TILDE] = ACTIONS(374),
    [anon_sym_BANG] = ACTIONS(372),
    [anon_sym_PLUS_PLUS] = ACTIONS(376),
    [anon_sym_DASH_DASH] = ACTIONS(376),
    [anon_sym_PIPE_PIPE] = ACTIONS(338),
    [anon_sym_STAR] = ACTIONS(378),
    [anon_sym_SLASH] = ACTIONS(340),
    [anon_sym_PERCENT] = ACTIONS(340),
    [anon_sym_PIPE] = ACTIONS(340),
    [anon_sym_CARET] = ACTIONS(340),
    [anon_sym_EQ_EQ] = ACTIONS(338),
    [anon_sym_BANG_EQ] = ACTIONS(338),
    [anon_sym_GT] = ACTIONS(340),
    [anon_sym_GT_EQ] = ACTIONS(338),
    [anon_sym_LT_EQ] = ACTIONS(338),
    [anon_sym_LT] = ACTIONS(340),
    [anon_sym_LT_LT] = ACTIONS(340),
    [anon_sym_GT_GT] = ACTIONS(340),
    [anon_sym_AMP_AMP] = ACTIONS(338),
    [anon_sym_AMP] = ACTIONS(378),
    [anon_sym_DOT] = ACTIONS(338),
    [anon_sym_QMARK] = ACTIONS(338),
    [anon_sym_BSLASH] = ACTIONS(380),
    [anon_sym_DASH_GT] = ACTIONS(338),
    [anon_sym_LBRACK] = ACTIONS(338),
    [anon_sym_sizeof] = ACTIONS(382),
    [anon_sym_STAR_EQ] = ACTIONS(338),
    [anon_sym_SLASH_EQ] = ACTIONS(338),
    [anon_sym_PERCENT_EQ] = ACTIONS(338),
    [anon_sym_PLUS_EQ] = ACTIONS(338),
    [anon_sym_DASH_EQ] = ACTIONS(338),
    [anon_sym_LT_LT_EQ] = ACTIONS(338),
    [anon_sym_GT_GT_EQ] = ACTIONS(338),
    [anon_sym_AMP_EQ] = ACTIONS(338),
    [anon_sym_CARET_EQ] = ACTIONS(338),
    [anon_sym_PIPE_EQ] = ACTIONS(338),
    [anon_sym_L_SQUOTE] = ACTIONS(384),
    [anon_sym_u_SQUOTE] = ACTIONS(384),
    [anon_sym_U_SQUOTE] = ACTIONS(384),
    [anon_sym_u8_SQUOTE] = ACTIONS(384),
    [anon_sym_SQUOTE] = ACTIONS(384),
    [anon_sym_L_DQUOTE] = ACTIONS(386),
    [anon_sym_u_DQUOTE] = ACTIONS(386),
    [anon_sym_U_DQUOTE] = ACTIONS(386),
    [anon_sym_u8_DQUOTE] = ACTIONS(386),
    [anon_sym_DQUOTE] = ACTIONS(386),
    [aux_sym_symbol_token1] = ACTIONS(388),
    [aux_sym_symbol_token2] = ACTIONS(390),
    [sym_comment] = ACTIONS(338),
    [sym__blank_line] = ACTIONS(338),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(340),
    [sym__hll_number_literal_pre_hook] = ACTIONS(392),
  },
  [STATE(23)] = {
    [sym_trace32_hll_variable] = STATE(900),
    [sym__hll_expression] = STATE(823),
    [sym_hll_call_expression] = STATE(898),
    [sym_hll_field_expression] = STATE(898),
    [sym_hll_subscript_expression] = STATE(898),
    [sym_hll_cast_expression] = STATE(823),
    [sym_hll_sizeof_expression] = STATE(823),
    [sym_hll_pointer_expression] = STATE(898),
    [sym_hll_update_expression] = STATE(823),
    [sym_hll_unary_expression] = STATE(823),
    [sym_hll_binary_expression] = STATE(823),
    [sym_hll_assignment_expression] = STATE(823),
    [sym__hll_assignment_left_expression] = STATE(1580),
    [sym_hll_conditional_expression] = STATE(823),
    [sym_hll_char_literal] = STATE(823),
    [sym_hll_string_literal] = STATE(823),
    [sym_hll_parenthesized_expression] = STATE(898),
    [sym_symbol] = STATE(823),
    [sym_identifier] = ACTIONS(368),
    [anon_sym_LPAREN] = ACTIONS(370),
    [anon_sym_EQ] = ACTIONS(332),
    [anon_sym_PLUS] = ACTIONS(372),
    [anon_sym_DASH] = ACTIONS(372),
    [anon_sym_TILDE] = ACTIONS(374),
    [anon_sym_BANG] = ACTIONS(372),
    [anon_sym_PLUS_PLUS] = ACTIONS(376),
    [anon_sym_DASH_DASH] = ACTIONS(376),
    [anon_sym_PIPE_PIPE] = ACTIONS(330),
    [anon_sym_STAR] = ACTIONS(378),
    [anon_sym_SLASH] = ACTIONS(332),
    [anon_sym_PERCENT] = ACTIONS(332),
    [anon_sym_PIPE] = ACTIONS(332),
    [anon_sym_CARET] = ACTIONS(332),
    [anon_sym_EQ_EQ] = ACTIONS(330),
    [anon_sym_BANG_EQ] = ACTIONS(330),
    [anon_sym_GT] = ACTIONS(332),
    [anon_sym_GT_EQ] = ACTIONS(330),
    [anon_sym_LT_EQ] = ACTIONS(330),
    [anon_sym_LT] = ACTIONS(332),
    [anon_sym_LT_LT] = ACTIONS(332),
    [anon_sym_GT_GT] = ACTIONS(332),
    [anon_sym_AMP_AMP] = ACTIONS(330),
    [anon_sym_AMP] = ACTIONS(378),
    [anon_sym_DOT] = ACTIONS(330),
    [anon_sym_QMARK] = ACTIONS(330),
    [anon_sym_BSLASH] = ACTIONS(380),
    [anon_sym_DASH_GT] = ACTIONS(330),
    [anon_sym_LBRACK] = ACTIONS(330),
    [anon_sym_sizeof] = ACTIONS(382),
    [anon_sym_STAR_EQ] = ACTIONS(330),
    [anon_sym_SLASH_EQ] = ACTIONS(330),
    [anon_sym_PERCENT_EQ] = ACTIONS(330),
    [anon_sym_PLUS_EQ] = ACTIONS(330),
    [anon_sym_DASH_EQ] = ACTIONS(330),
    [anon_sym_LT_LT_EQ] = ACTIONS(330),
    [anon_sym_GT_GT_EQ] = ACTIONS(330),
    [anon_sym_AMP_EQ] = ACTIONS(330),
    [anon_sym_CARET_EQ] = ACTIONS(330),
    [anon_sym_PIPE_EQ] = ACTIONS(330),
    [anon_sym_L_SQUOTE] = ACTIONS(384),
    [anon_sym_u_SQUOTE] = ACTIONS(384),
    [anon_sym_U_SQUOTE] = ACTIONS(384),
    [anon_sym_u8_SQUOTE] = ACTIONS(384),
    [anon_sym_SQUOTE] = ACTIONS(384),
    [anon_sym_L_DQUOTE] = ACTIONS(386),
    [anon_sym_u_DQUOTE] = ACTIONS(386),
    [anon_sym_U_DQUOTE] = ACTIONS(386),
    [anon_sym_u8_DQUOTE] = ACTIONS(386),
    [anon_sym_DQUOTE] = ACTIONS(386),
    [aux_sym_symbol_token1] = ACTIONS(388),
    [aux_sym_symbol_token2] = ACTIONS(390),
    [sym_comment] = ACTIONS(330),
    [sym__blank_line] = ACTIONS(330),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(332),
    [sym__hll_number_literal_pre_hook] = ACTIONS(392),
  },
  [STATE(24)] = {
    [sym_trace32_hll_variable] = STATE(900),
    [sym__hll_expression] = STATE(824),
    [sym_hll_call_expression] = STATE(898),
    [sym_hll_field_expression] = STATE(898),
    [sym_hll_subscript_expression] = STATE(898),
    [sym_hll_cast_expression] = STATE(824),
    [sym_hll_sizeof_expression] = STATE(824),
    [sym_hll_pointer_expression] = STATE(898),
    [sym_hll_update_expression] = STATE(824),
    [sym_hll_unary_expression] = STATE(824),
    [sym_hll_binary_expression] = STATE(824),
    [sym_hll_assignment_expression] = STATE(824),
    [sym__hll_assignment_left_expression] = STATE(1580),
    [sym_hll_conditional_expression] = STATE(824),
    [sym_hll_char_literal] = STATE(824),
    [sym_hll_string_literal] = STATE(824),
    [sym_hll_parenthesized_expression] = STATE(898),
    [sym_symbol] = STATE(824),
    [sym_identifier] = ACTIONS(368),
    [anon_sym_LPAREN] = ACTIONS(370),
    [anon_sym_EQ] = ACTIONS(306),
    [anon_sym_PLUS] = ACTIONS(372),
    [anon_sym_DASH] = ACTIONS(372),
    [anon_sym_TILDE] = ACTIONS(374),
    [anon_sym_BANG] = ACTIONS(372),
    [anon_sym_PLUS_PLUS] = ACTIONS(376),
    [anon_sym_DASH_DASH] = ACTIONS(376),
    [anon_sym_PIPE_PIPE] = ACTIONS(302),
    [anon_sym_STAR] = ACTIONS(378),
    [anon_sym_SLASH] = ACTIONS(306),
    [anon_sym_PERCENT] = ACTIONS(306),
    [anon_sym_PIPE] = ACTIONS(306),
    [anon_sym_CARET] = ACTIONS(306),
    [anon_sym_EQ_EQ] = ACTIONS(302),
    [anon_sym_BANG_EQ] = ACTIONS(302),
    [anon_sym_GT] = ACTIONS(306),
    [anon_sym_GT_EQ] = ACTIONS(302),
    [anon_sym_LT_EQ] = ACTIONS(302),
    [anon_sym_LT] = ACTIONS(306),
    [anon_sym_LT_LT] = ACTIONS(306),
    [anon_sym_GT_GT] = ACTIONS(306),
    [anon_sym_AMP_AMP] = ACTIONS(302),
    [anon_sym_AMP] = ACTIONS(378),
    [anon_sym_DOT] = ACTIONS(302),
    [anon_sym_QMARK] = ACTIONS(302),
    [anon_sym_BSLASH] = ACTIONS(380),
    [anon_sym_DASH_GT] = ACTIONS(302),
    [anon_sym_LBRACK] = ACTIONS(302),
    [anon_sym_sizeof] = ACTIONS(382),
    [anon_sym_STAR_EQ] = ACTIONS(302),
    [anon_sym_SLASH_EQ] = ACTIONS(302),
    [anon_sym_PERCENT_EQ] = ACTIONS(302),
    [anon_sym_PLUS_EQ] = ACTIONS(302),
    [anon_sym_DASH_EQ] = ACTIONS(302),
    [anon_sym_LT_LT_EQ] = ACTIONS(302),
    [anon_sym_GT_GT_EQ] = ACTIONS(302),
    [anon_sym_AMP_EQ] = ACTIONS(302),
    [anon_sym_CARET_EQ] = ACTIONS(302),
    [anon_sym_PIPE_EQ] = ACTIONS(302),
    [anon_sym_L_SQUOTE] = ACTIONS(384),
    [anon_sym_u_SQUOTE] = ACTIONS(384),
    [anon_sym_U_SQUOTE] = ACTIONS(384),
    [anon_sym_u8_SQUOTE] = ACTIONS(384),
    [anon_sym_SQUOTE] = ACTIONS(384),
    [anon_sym_L_DQUOTE] = ACTIONS(386),
    [anon_sym_u_DQUOTE] = ACTIONS(386),
    [anon_sym_U_DQUOTE] = ACTIONS(386),
    [anon_sym_u8_DQUOTE] = ACTIONS(386),
    [anon_sym_DQUOTE] = ACTIONS(386),
    [aux_sym_symbol_token1] = ACTIONS(388),
    [aux_sym_symbol_token2] = ACTIONS(390),
    [sym_comment] = ACTIONS(302),
    [sym__blank_line] = ACTIONS(302),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(306),
    [sym__hll_number_literal_pre_hook] = ACTIONS(392),
  },
  [STATE(25)] = {
    [sym_trace32_hll_variable] = STATE(893),
    [sym__hll_expression] = STATE(848),
    [sym_hll_call_expression] = STATE(892),
    [sym_hll_field_expression] = STATE(892),
    [sym_hll_subscript_expression] = STATE(892),
    [sym_hll_cast_expression] = STATE(848),
    [sym_hll_sizeof_expression] = STATE(848),
    [sym_hll_pointer_expression] = STATE(892),
    [sym_hll_update_expression] = STATE(848),
    [sym_hll_unary_expression] = STATE(848),
    [sym_hll_binary_expression] = STATE(848),
    [sym_hll_assignment_expression] = STATE(848),
    [sym__hll_assignment_left_expression] = STATE(1615),
    [sym_hll_conditional_expression] = STATE(848),
    [sym_hll_char_literal] = STATE(848),
    [sym_hll_string_literal] = STATE(848),
    [sym_hll_parenthesized_expression] = STATE(892),
    [sym_symbol] = STATE(848),
    [sym_identifier] = ACTIONS(394),
    [anon_sym_LPAREN] = ACTIONS(396),
    [anon_sym_EQ] = ACTIONS(340),
    [anon_sym_PLUS] = ACTIONS(398),
    [anon_sym_DASH] = ACTIONS(398),
    [anon_sym_TILDE] = ACTIONS(400),
    [anon_sym_BANG] = ACTIONS(398),
    [anon_sym_PLUS_PLUS] = ACTIONS(402),
    [anon_sym_DASH_DASH] = ACTIONS(402),
    [anon_sym_PIPE_PIPE] = ACTIONS(338),
    [anon_sym_STAR] = ACTIONS(404),
    [anon_sym_SLASH] = ACTIONS(340),
    [anon_sym_PERCENT] = ACTIONS(340),
    [anon_sym_PIPE] = ACTIONS(340),
    [anon_sym_CARET] = ACTIONS(340),
    [anon_sym_EQ_EQ] = ACTIONS(338),
    [anon_sym_BANG_EQ] = ACTIONS(338),
    [anon_sym_GT] = ACTIONS(340),
    [anon_sym_GT_EQ] = ACTIONS(338),
    [anon_sym_LT_EQ] = ACTIONS(338),
    [anon_sym_LT] = ACTIONS(340),
    [anon_sym_LT_LT] = ACTIONS(340),
    [anon_sym_GT_GT] = ACTIONS(340),
    [anon_sym_AMP_AMP] = ACTIONS(338),
    [anon_sym_AMP] = ACTIONS(404),
    [anon_sym_DOT] = ACTIONS(338),
    [anon_sym_QMARK] = ACTIONS(338),
    [anon_sym_BSLASH] = ACTIONS(406),
    [anon_sym_DASH_GT] = ACTIONS(338),
    [anon_sym_LBRACK] = ACTIONS(338),
    [anon_sym_sizeof] = ACTIONS(408),
    [anon_sym_STAR_EQ] = ACTIONS(338),
    [anon_sym_SLASH_EQ] = ACTIONS(338),
    [anon_sym_PERCENT_EQ] = ACTIONS(338),
    [anon_sym_PLUS_EQ] = ACTIONS(338),
    [anon_sym_DASH_EQ] = ACTIONS(338),
    [anon_sym_LT_LT_EQ] = ACTIONS(338),
    [anon_sym_GT_GT_EQ] = ACTIONS(338),
    [anon_sym_AMP_EQ] = ACTIONS(338),
    [anon_sym_CARET_EQ] = ACTIONS(338),
    [anon_sym_PIPE_EQ] = ACTIONS(338),
    [anon_sym_L_SQUOTE] = ACTIONS(410),
    [anon_sym_u_SQUOTE] = ACTIONS(410),
    [anon_sym_U_SQUOTE] = ACTIONS(410),
    [anon_sym_u8_SQUOTE] = ACTIONS(410),
    [anon_sym_SQUOTE] = ACTIONS(410),
    [anon_sym_L_DQUOTE] = ACTIONS(412),
    [anon_sym_u_DQUOTE] = ACTIONS(412),
    [anon_sym_U_DQUOTE] = ACTIONS(412),
    [anon_sym_u8_DQUOTE] = ACTIONS(412),
    [anon_sym_DQUOTE] = ACTIONS(412),
    [aux_sym__hll_expression_separator_token1] = ACTIONS(338),
    [aux_sym__hll_expression_separator_token2] = ACTIONS(338),
    [aux_sym_symbol_token1] = ACTIONS(414),
    [aux_sym_symbol_token2] = ACTIONS(416),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(340),
    [sym__hll_number_literal_pre_hook] = ACTIONS(418),
  },
  [STATE(26)] = {
    [sym_trace32_hll_variable] = STATE(893),
    [sym__hll_expression] = STATE(850),
    [sym_hll_call_expression] = STATE(892),
    [sym_hll_field_expression] = STATE(892),
    [sym_hll_subscript_expression] = STATE(892),
    [sym_hll_cast_expression] = STATE(850),
    [sym_hll_sizeof_expression] = STATE(850),
    [sym_hll_pointer_expression] = STATE(892),
    [sym_hll_update_expression] = STATE(850),
    [sym_hll_unary_expression] = STATE(850),
    [sym_hll_binary_expression] = STATE(850),
    [sym_hll_assignment_expression] = STATE(850),
    [sym__hll_assignment_left_expression] = STATE(1615),
    [sym_hll_conditional_expression] = STATE(850),
    [sym_hll_char_literal] = STATE(850),
    [sym_hll_string_literal] = STATE(850),
    [sym_hll_parenthesized_expression] = STATE(892),
    [sym_symbol] = STATE(850),
    [sym_identifier] = ACTIONS(394),
    [anon_sym_LPAREN] = ACTIONS(396),
    [anon_sym_EQ] = ACTIONS(332),
    [anon_sym_PLUS] = ACTIONS(398),
    [anon_sym_DASH] = ACTIONS(398),
    [anon_sym_TILDE] = ACTIONS(400),
    [anon_sym_BANG] = ACTIONS(398),
    [anon_sym_PLUS_PLUS] = ACTIONS(402),
    [anon_sym_DASH_DASH] = ACTIONS(402),
    [anon_sym_PIPE_PIPE] = ACTIONS(330),
    [anon_sym_STAR] = ACTIONS(404),
    [anon_sym_SLASH] = ACTIONS(332),
    [anon_sym_PERCENT] = ACTIONS(332),
    [anon_sym_PIPE] = ACTIONS(332),
    [anon_sym_CARET] = ACTIONS(332),
    [anon_sym_EQ_EQ] = ACTIONS(330),
    [anon_sym_BANG_EQ] = ACTIONS(330),
    [anon_sym_GT] = ACTIONS(332),
    [anon_sym_GT_EQ] = ACTIONS(330),
    [anon_sym_LT_EQ] = ACTIONS(330),
    [anon_sym_LT] = ACTIONS(332),
    [anon_sym_LT_LT] = ACTIONS(332),
    [anon_sym_GT_GT] = ACTIONS(332),
    [anon_sym_AMP_AMP] = ACTIONS(330),
    [anon_sym_AMP] = ACTIONS(404),
    [anon_sym_DOT] = ACTIONS(330),
    [anon_sym_QMARK] = ACTIONS(330),
    [anon_sym_BSLASH] = ACTIONS(406),
    [anon_sym_DASH_GT] = ACTIONS(330),
    [anon_sym_LBRACK] = ACTIONS(330),
    [anon_sym_sizeof] = ACTIONS(408),
    [anon_sym_STAR_EQ] = ACTIONS(330),
    [anon_sym_SLASH_EQ] = ACTIONS(330),
    [anon_sym_PERCENT_EQ] = ACTIONS(330),
    [anon_sym_PLUS_EQ] = ACTIONS(330),
    [anon_sym_DASH_EQ] = ACTIONS(330),
    [anon_sym_LT_LT_EQ] = ACTIONS(330),
    [anon_sym_GT_GT_EQ] = ACTIONS(330),
    [anon_sym_AMP_EQ] = ACTIONS(330),
    [anon_sym_CARET_EQ] = ACTIONS(330),
    [anon_sym_PIPE_EQ] = ACTIONS(330),
    [anon_sym_L_SQUOTE] = ACTIONS(410),
    [anon_sym_u_SQUOTE] = ACTIONS(410),
    [anon_sym_U_SQUOTE] = ACTIONS(410),
    [anon_sym_u8_SQUOTE] = ACTIONS(410),
    [anon_sym_SQUOTE] = ACTIONS(410),
    [anon_sym_L_DQUOTE] = ACTIONS(412),
    [anon_sym_u_DQUOTE] = ACTIONS(412),
    [anon_sym_U_DQUOTE] = ACTIONS(412),
    [anon_sym_u8_DQUOTE] = ACTIONS(412),
    [anon_sym_DQUOTE] = ACTIONS(412),
    [aux_sym__hll_expression_separator_token1] = ACTIONS(330),
    [aux_sym__hll_expression_separator_token2] = ACTIONS(330),
    [aux_sym_symbol_token1] = ACTIONS(414),
    [aux_sym_symbol_token2] = ACTIONS(416),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(332),
    [sym__hll_number_literal_pre_hook] = ACTIONS(418),
  },
  [STATE(27)] = {
    [sym_trace32_hll_variable] = STATE(893),
    [sym__hll_expression] = STATE(849),
    [sym_hll_call_expression] = STATE(892),
    [sym_hll_field_expression] = STATE(892),
    [sym_hll_subscript_expression] = STATE(892),
    [sym_hll_cast_expression] = STATE(849),
    [sym_hll_sizeof_expression] = STATE(849),
    [sym_hll_pointer_expression] = STATE(892),
    [sym_hll_update_expression] = STATE(849),
    [sym_hll_unary_expression] = STATE(849),
    [sym_hll_binary_expression] = STATE(849),
    [sym_hll_assignment_expression] = STATE(849),
    [sym__hll_assignment_left_expression] = STATE(1615),
    [sym_hll_conditional_expression] = STATE(849),
    [sym_hll_char_literal] = STATE(849),
    [sym_hll_string_literal] = STATE(849),
    [sym_hll_parenthesized_expression] = STATE(892),
    [sym_symbol] = STATE(849),
    [sym_identifier] = ACTIONS(394),
    [anon_sym_LPAREN] = ACTIONS(396),
    [anon_sym_EQ] = ACTIONS(336),
    [anon_sym_PLUS] = ACTIONS(398),
    [anon_sym_DASH] = ACTIONS(398),
    [anon_sym_TILDE] = ACTIONS(400),
    [anon_sym_BANG] = ACTIONS(398),
    [anon_sym_PLUS_PLUS] = ACTIONS(402),
    [anon_sym_DASH_DASH] = ACTIONS(402),
    [anon_sym_PIPE_PIPE] = ACTIONS(334),
    [anon_sym_STAR] = ACTIONS(404),
    [anon_sym_SLASH] = ACTIONS(336),
    [anon_sym_PERCENT] = ACTIONS(336),
    [anon_sym_PIPE] = ACTIONS(336),
    [anon_sym_CARET] = ACTIONS(336),
    [anon_sym_EQ_EQ] = ACTIONS(334),
    [anon_sym_BANG_EQ] = ACTIONS(334),
    [anon_sym_GT] = ACTIONS(336),
    [anon_sym_GT_EQ] = ACTIONS(334),
    [anon_sym_LT_EQ] = ACTIONS(334),
    [anon_sym_LT] = ACTIONS(336),
    [anon_sym_LT_LT] = ACTIONS(336),
    [anon_sym_GT_GT] = ACTIONS(336),
    [anon_sym_AMP_AMP] = ACTIONS(334),
    [anon_sym_AMP] = ACTIONS(404),
    [anon_sym_DOT] = ACTIONS(334),
    [anon_sym_QMARK] = ACTIONS(334),
    [anon_sym_BSLASH] = ACTIONS(406),
    [anon_sym_DASH_GT] = ACTIONS(334),
    [anon_sym_LBRACK] = ACTIONS(334),
    [anon_sym_sizeof] = ACTIONS(408),
    [anon_sym_STAR_EQ] = ACTIONS(334),
    [anon_sym_SLASH_EQ] = ACTIONS(334),
    [anon_sym_PERCENT_EQ] = ACTIONS(334),
    [anon_sym_PLUS_EQ] = ACTIONS(334),
    [anon_sym_DASH_EQ] = ACTIONS(334),
    [anon_sym_LT_LT_EQ] = ACTIONS(334),
    [anon_sym_GT_GT_EQ] = ACTIONS(334),
    [anon_sym_AMP_EQ] = ACTIONS(334),
    [anon_sym_CARET_EQ] = ACTIONS(334),
    [anon_sym_PIPE_EQ] = ACTIONS(334),
    [anon_sym_L_SQUOTE] = ACTIONS(410),
    [anon_sym_u_SQUOTE] = ACTIONS(410),
    [anon_sym_U_SQUOTE] = ACTIONS(410),
    [anon_sym_u8_SQUOTE] = ACTIONS(410),
    [anon_sym_SQUOTE] = ACTIONS(410),
    [anon_sym_L_DQUOTE] = ACTIONS(412),
    [anon_sym_u_DQUOTE] = ACTIONS(412),
    [anon_sym_U_DQUOTE] = ACTIONS(412),
    [anon_sym_u8_DQUOTE] = ACTIONS(412),
    [anon_sym_DQUOTE] = ACTIONS(412),
    [aux_sym__hll_expression_separator_token1] = ACTIONS(334),
    [aux_sym__hll_expression_separator_token2] = ACTIONS(334),
    [aux_sym_symbol_token1] = ACTIONS(414),
    [aux_sym_symbol_token2] = ACTIONS(416),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(336),
    [sym__hll_number_literal_pre_hook] = ACTIONS(418),
  },
  [STATE(28)] = {
    [sym_trace32_hll_variable] = STATE(893),
    [sym__hll_expression] = STATE(851),
    [sym_hll_call_expression] = STATE(892),
    [sym_hll_field_expression] = STATE(892),
    [sym_hll_subscript_expression] = STATE(892),
    [sym_hll_cast_expression] = STATE(851),
    [sym_hll_sizeof_expression] = STATE(851),
    [sym_hll_pointer_expression] = STATE(892),
    [sym_hll_update_expression] = STATE(851),
    [sym_hll_unary_expression] = STATE(851),
    [sym_hll_binary_expression] = STATE(851),
    [sym_hll_assignment_expression] = STATE(851),
    [sym__hll_assignment_left_expression] = STATE(1615),
    [sym_hll_conditional_expression] = STATE(851),
    [sym_hll_char_literal] = STATE(851),
    [sym_hll_string_literal] = STATE(851),
    [sym_hll_parenthesized_expression] = STATE(892),
    [sym_symbol] = STATE(851),
    [sym_identifier] = ACTIONS(394),
    [anon_sym_LPAREN] = ACTIONS(396),
    [anon_sym_EQ] = ACTIONS(306),
    [anon_sym_PLUS] = ACTIONS(398),
    [anon_sym_DASH] = ACTIONS(398),
    [anon_sym_TILDE] = ACTIONS(400),
    [anon_sym_BANG] = ACTIONS(398),
    [anon_sym_PLUS_PLUS] = ACTIONS(402),
    [anon_sym_DASH_DASH] = ACTIONS(402),
    [anon_sym_PIPE_PIPE] = ACTIONS(302),
    [anon_sym_STAR] = ACTIONS(404),
    [anon_sym_SLASH] = ACTIONS(306),
    [anon_sym_PERCENT] = ACTIONS(306),
    [anon_sym_PIPE] = ACTIONS(306),
    [anon_sym_CARET] = ACTIONS(306),
    [anon_sym_EQ_EQ] = ACTIONS(302),
    [anon_sym_BANG_EQ] = ACTIONS(302),
    [anon_sym_GT] = ACTIONS(306),
    [anon_sym_GT_EQ] = ACTIONS(302),
    [anon_sym_LT_EQ] = ACTIONS(302),
    [anon_sym_LT] = ACTIONS(306),
    [anon_sym_LT_LT] = ACTIONS(306),
    [anon_sym_GT_GT] = ACTIONS(306),
    [anon_sym_AMP_AMP] = ACTIONS(302),
    [anon_sym_AMP] = ACTIONS(404),
    [anon_sym_DOT] = ACTIONS(302),
    [anon_sym_QMARK] = ACTIONS(302),
    [anon_sym_BSLASH] = ACTIONS(406),
    [anon_sym_DASH_GT] = ACTIONS(302),
    [anon_sym_LBRACK] = ACTIONS(302),
    [anon_sym_sizeof] = ACTIONS(408),
    [anon_sym_STAR_EQ] = ACTIONS(302),
    [anon_sym_SLASH_EQ] = ACTIONS(302),
    [anon_sym_PERCENT_EQ] = ACTIONS(302),
    [anon_sym_PLUS_EQ] = ACTIONS(302),
    [anon_sym_DASH_EQ] = ACTIONS(302),
    [anon_sym_LT_LT_EQ] = ACTIONS(302),
    [anon_sym_GT_GT_EQ] = ACTIONS(302),
    [anon_sym_AMP_EQ] = ACTIONS(302),
    [anon_sym_CARET_EQ] = ACTIONS(302),
    [anon_sym_PIPE_EQ] = ACTIONS(302),
    [anon_sym_L_SQUOTE] = ACTIONS(410),
    [anon_sym_u_SQUOTE] = ACTIONS(410),
    [anon_sym_U_SQUOTE] = ACTIONS(410),
    [anon_sym_u8_SQUOTE] = ACTIONS(410),
    [anon_sym_SQUOTE] = ACTIONS(410),
    [anon_sym_L_DQUOTE] = ACTIONS(412),
    [anon_sym_u_DQUOTE] = ACTIONS(412),
    [anon_sym_U_DQUOTE] = ACTIONS(412),
    [anon_sym_u8_DQUOTE] = ACTIONS(412),
    [anon_sym_DQUOTE] = ACTIONS(412),
    [aux_sym__hll_expression_separator_token1] = ACTIONS(302),
    [aux_sym__hll_expression_separator_token2] = ACTIONS(302),
    [aux_sym_symbol_token1] = ACTIONS(414),
    [aux_sym_symbol_token2] = ACTIONS(416),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(306),
    [sym__hll_number_literal_pre_hook] = ACTIONS(418),
  },
  [STATE(29)] = {
    [sym__expression] = STATE(1139),
    [sym__parenthesized_expression] = STATE(1139),
    [sym__path_expression] = STATE(1139),
    [sym_unary_expression] = STATE(1139),
    [sym__unary_expression] = STATE(1378),
    [sym__prefix_postfix_expression] = STATE(1392),
    [sym_binary_expression] = STATE(1139),
    [sym__binary_expression] = STATE(1394),
    [sym__and_expression] = STATE(1371),
    [sym_assignment_expression] = STATE(1139),
    [sym_macro] = STATE(980),
    [sym__command_arguments] = STATE(2293),
    [sym__command_argument] = STATE(1921),
    [sym_option_expression] = STATE(1923),
    [sym_format_expression] = STATE(1921),
    [sym_call_expression] = STATE(1060),
    [sym__function_identifier] = STATE(2349),
    [sym__hll_var_call_expression_function] = STATE(2359),
    [sym__hll_var_call_expression] = STATE(1061),
    [sym_trace32_hll_variable] = STATE(1377),
    [sym__literal] = STATE(1139),
    [sym__address_expression] = STATE(1575),
    [sym_memory_space] = STATE(228),
    [sym_address] = STATE(1139),
    [sym__parenthesized_address_expression] = STATE(1575),
    [sym__address_binary_expression] = STATE(1550),
    [sym_integer] = STATE(1080),
    [sym_bitmask] = STATE(1139),
    [sym_string] = STATE(1139),
    [sym_character] = STATE(1139),
    [sym_symbol] = STATE(1139),
    [sym__special_command_operator] = STATE(1139),
    [sym__file_dialog] = STATE(1374),
    [aux_sym_block_repeat1] = STATE(927),
    [aux_sym__path_expression_repeat1] = STATE(1172),
    [aux_sym__path_expression_repeat2] = STATE(1100),
    [aux_sym__command_arguments_repeat1] = STATE(56),
    [aux_sym__command_arguments_repeat2] = STATE(2203),
    [sym_identifier] = ACTIONS(179),
    [anon_sym_LPAREN] = ACTIONS(181),
    [anon_sym_LBRACE] = ACTIONS(183),
    [anon_sym_PLUS] = ACTIONS(185),
    [anon_sym_DASH] = ACTIONS(185),
    [anon_sym_TILDE] = ACTIONS(187),
    [anon_sym_BANG] = ACTIONS(187),
    [anon_sym_PLUS_PLUS] = ACTIONS(189),
    [anon_sym_DASH_DASH] = ACTIONS(189),
    [anon_sym_STAR] = ACTIONS(191),
    [anon_sym_SLASH] = ACTIONS(420),
    [anon_sym_PERCENT] = ACTIONS(422),
    [anon_sym_AMP] = ACTIONS(147),
    [anon_sym_COMMA] = ACTIONS(424),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(120),
    [anon_sym_BSLASH] = ACTIONS(193),
    [anon_sym_SQUOTE] = ACTIONS(195),
    [anon_sym_DQUOTE] = ACTIONS(197),
    [sym_access_class] = ACTIONS(199),
    [aux_sym_integer_token1] = ACTIONS(149),
    [aux_sym_integer_token2] = ACTIONS(149),
    [sym_float] = ACTIONS(426),
    [aux_sym_bitmask_token1] = ACTIONS(203),
    [aux_sym_bitmask_token2] = ACTIONS(203),
    [aux_sym_symbol_token1] = ACTIONS(205),
    [aux_sym_symbol_token2] = ACTIONS(207),
    [sym__composed_name] = ACTIONS(428),
    [sym_time] = ACTIONS(426),
    [sym_frequency] = ACTIONS(426),
    [sym_percentage] = ACTIONS(428),
    [sym_file_handle] = ACTIONS(428),
    [sym_comment] = ACTIONS(430),
    [sym__blank_line] = ACTIONS(430),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(432),
    [sym__decimal_number_pre_hook] = ACTIONS(155),
    [sym_path] = ACTIONS(211),
  },
  [STATE(30)] = {
    [sym__expression] = STATE(1139),
    [sym__parenthesized_expression] = STATE(1139),
    [sym__path_expression] = STATE(1139),
    [sym_unary_expression] = STATE(1139),
    [sym__unary_expression] = STATE(1378),
    [sym__prefix_postfix_expression] = STATE(1392),
    [sym_binary_expression] = STATE(1139),
    [sym__binary_expression] = STATE(1394),
    [sym__and_expression] = STATE(1371),
    [sym_assignment_expression] = STATE(1139),
    [sym_macro] = STATE(980),
    [sym__command_arguments] = STATE(2316),
    [sym__command_argument] = STATE(1921),
    [sym_option_expression] = STATE(1923),
    [sym_format_expression] = STATE(1921),
    [sym_call_expression] = STATE(1060),
    [sym__function_identifier] = STATE(2349),
    [sym__hll_var_call_expression_function] = STATE(2359),
    [sym__hll_var_call_expression] = STATE(1061),
    [sym_trace32_hll_variable] = STATE(1377),
    [sym__literal] = STATE(1139),
    [sym__address_expression] = STATE(1575),
    [sym_memory_space] = STATE(228),
    [sym_address] = STATE(1139),
    [sym__parenthesized_address_expression] = STATE(1575),
    [sym__address_binary_expression] = STATE(1550),
    [sym_integer] = STATE(1080),
    [sym_bitmask] = STATE(1139),
    [sym_string] = STATE(1139),
    [sym_character] = STATE(1139),
    [sym_symbol] = STATE(1139),
    [sym__special_command_operator] = STATE(1139),
    [sym__file_dialog] = STATE(1374),
    [aux_sym_block_repeat1] = STATE(935),
    [aux_sym__path_expression_repeat1] = STATE(1172),
    [aux_sym__path_expression_repeat2] = STATE(1100),
    [aux_sym__command_arguments_repeat1] = STATE(56),
    [aux_sym__command_arguments_repeat2] = STATE(2203),
    [sym_identifier] = ACTIONS(179),
    [anon_sym_LPAREN] = ACTIONS(181),
    [anon_sym_LBRACE] = ACTIONS(183),
    [anon_sym_PLUS] = ACTIONS(185),
    [anon_sym_DASH] = ACTIONS(185),
    [anon_sym_TILDE] = ACTIONS(187),
    [anon_sym_BANG] = ACTIONS(187),
    [anon_sym_PLUS_PLUS] = ACTIONS(189),
    [anon_sym_DASH_DASH] = ACTIONS(189),
    [anon_sym_STAR] = ACTIONS(191),
    [anon_sym_SLASH] = ACTIONS(434),
    [anon_sym_PERCENT] = ACTIONS(422),
    [anon_sym_AMP] = ACTIONS(147),
    [anon_sym_COMMA] = ACTIONS(424),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(120),
    [anon_sym_BSLASH] = ACTIONS(193),
    [anon_sym_SQUOTE] = ACTIONS(195),
    [anon_sym_DQUOTE] = ACTIONS(197),
    [sym_access_class] = ACTIONS(199),
    [aux_sym_integer_token1] = ACTIONS(149),
    [aux_sym_integer_token2] = ACTIONS(149),
    [sym_float] = ACTIONS(426),
    [aux_sym_bitmask_token1] = ACTIONS(203),
    [aux_sym_bitmask_token2] = ACTIONS(203),
    [aux_sym_symbol_token1] = ACTIONS(205),
    [aux_sym_symbol_token2] = ACTIONS(207),
    [sym__composed_name] = ACTIONS(428),
    [sym_time] = ACTIONS(426),
    [sym_frequency] = ACTIONS(426),
    [sym_percentage] = ACTIONS(428),
    [sym_file_handle] = ACTIONS(428),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(436),
    [sym__decimal_number_pre_hook] = ACTIONS(155),
    [sym_path] = ACTIONS(211),
  },
  [STATE(31)] = {
    [sym__expression] = STATE(1139),
    [sym__parenthesized_expression] = STATE(1139),
    [sym__path_expression] = STATE(1139),
    [sym_unary_expression] = STATE(1139),
    [sym__unary_expression] = STATE(1378),
    [sym__prefix_postfix_expression] = STATE(1392),
    [sym_binary_expression] = STATE(1139),
    [sym__binary_expression] = STATE(1394),
    [sym__and_expression] = STATE(1371),
    [sym_assignment_expression] = STATE(1139),
    [sym_macro] = STATE(980),
    [sym__command_arguments] = STATE(2330),
    [sym__command_argument] = STATE(1921),
    [sym_option_expression] = STATE(1923),
    [sym_format_expression] = STATE(1921),
    [sym_call_expression] = STATE(1060),
    [sym__function_identifier] = STATE(2349),
    [sym__hll_var_call_expression_function] = STATE(2359),
    [sym__hll_var_call_expression] = STATE(1061),
    [sym_trace32_hll_variable] = STATE(1377),
    [sym__literal] = STATE(1139),
    [sym__address_expression] = STATE(1575),
    [sym_memory_space] = STATE(228),
    [sym_address] = STATE(1139),
    [sym__parenthesized_address_expression] = STATE(1575),
    [sym__address_binary_expression] = STATE(1550),
    [sym_integer] = STATE(1080),
    [sym_bitmask] = STATE(1139),
    [sym_string] = STATE(1139),
    [sym_character] = STATE(1139),
    [sym_symbol] = STATE(1139),
    [sym__special_command_operator] = STATE(1139),
    [sym__file_dialog] = STATE(1374),
    [aux_sym_block_repeat1] = STATE(935),
    [aux_sym__path_expression_repeat1] = STATE(1172),
    [aux_sym__path_expression_repeat2] = STATE(1100),
    [aux_sym__command_arguments_repeat1] = STATE(56),
    [aux_sym__command_arguments_repeat2] = STATE(2203),
    [sym_identifier] = ACTIONS(179),
    [anon_sym_LPAREN] = ACTIONS(181),
    [anon_sym_LBRACE] = ACTIONS(183),
    [anon_sym_PLUS] = ACTIONS(185),
    [anon_sym_DASH] = ACTIONS(185),
    [anon_sym_TILDE] = ACTIONS(187),
    [anon_sym_BANG] = ACTIONS(187),
    [anon_sym_PLUS_PLUS] = ACTIONS(189),
    [anon_sym_DASH_DASH] = ACTIONS(189),
    [anon_sym_STAR] = ACTIONS(191),
    [anon_sym_SLASH] = ACTIONS(434),
    [anon_sym_PERCENT] = ACTIONS(422),
    [anon_sym_AMP] = ACTIONS(147),
    [anon_sym_COMMA] = ACTIONS(424),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(120),
    [anon_sym_BSLASH] = ACTIONS(193),
    [anon_sym_SQUOTE] = ACTIONS(195),
    [anon_sym_DQUOTE] = ACTIONS(197),
    [sym_access_class] = ACTIONS(199),
    [aux_sym_integer_token1] = ACTIONS(149),
    [aux_sym_integer_token2] = ACTIONS(149),
    [sym_float] = ACTIONS(426),
    [aux_sym_bitmask_token1] = ACTIONS(203),
    [aux_sym_bitmask_token2] = ACTIONS(203),
    [aux_sym_symbol_token1] = ACTIONS(205),
    [aux_sym_symbol_token2] = ACTIONS(207),
    [sym__composed_name] = ACTIONS(428),
    [sym_time] = ACTIONS(426),
    [sym_frequency] = ACTIONS(426),
    [sym_percentage] = ACTIONS(428),
    [sym_file_handle] = ACTIONS(428),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(436),
    [sym__decimal_number_pre_hook] = ACTIONS(155),
    [sym_path] = ACTIONS(211),
  },
  [STATE(32)] = {
    [sym_trace32_hll_variable] = STATE(799),
    [sym__hll_expression] = STATE(1102),
    [sym_hll_call_expression] = STATE(798),
    [sym_hll_field_expression] = STATE(798),
    [sym_hll_subscript_expression] = STATE(798),
    [sym_hll_cast_expression] = STATE(1102),
    [sym_hll_sizeof_expression] = STATE(1102),
    [sym_hll_pointer_expression] = STATE(798),
    [sym_hll_comma_expression] = STATE(2051),
    [sym_hll_update_expression] = STATE(1102),
    [sym_hll_unary_expression] = STATE(1102),
    [sym_hll_binary_expression] = STATE(1102),
    [sym_hll_assignment_expression] = STATE(1102),
    [sym__hll_assignment_left_expression] = STATE(1652),
    [sym_hll_conditional_expression] = STATE(1102),
    [sym_hll_char_literal] = STATE(1102),
    [sym_hll_string_literal] = STATE(1102),
    [sym_hll_parenthesized_expression] = STATE(798),
    [sym_hll_type_descriptor] = STATE(2123),
    [sym_hll_type_qualifier] = STATE(1518),
    [sym__hll_type_specifier] = STATE(1534),
    [sym_hll_struct_specifier] = STATE(1534),
    [sym_hll_union_specifier] = STATE(1534),
    [sym_hll_enum_specifier] = STATE(1534),
    [sym_hll_sized_type_specifier] = STATE(1534),
    [sym__hll_type_identifier] = STATE(1534),
    [sym_symbol] = STATE(1102),
    [aux_sym_block_repeat1] = STATE(74),
    [aux_sym_hll_type_descriptor_repeat1] = STATE(1518),
    [aux_sym_hll_sized_type_specifier_repeat1] = STATE(1743),
    [sym_identifier] = ACTIONS(438),
    [anon_sym_LPAREN] = ACTIONS(440),
    [anon_sym_PLUS] = ACTIONS(442),
    [anon_sym_DASH] = ACTIONS(442),
    [anon_sym_TILDE] = ACTIONS(444),
    [anon_sym_BANG] = ACTIONS(444),
    [anon_sym_PLUS_PLUS] = ACTIONS(446),
    [anon_sym_DASH_DASH] = ACTIONS(446),
    [anon_sym_STAR] = ACTIONS(448),
    [anon_sym_AMP] = ACTIONS(448),
    [anon_sym_BSLASH] = ACTIONS(450),
    [anon_sym_sizeof] = ACTIONS(452),
    [anon_sym_L_SQUOTE] = ACTIONS(454),
    [anon_sym_u_SQUOTE] = ACTIONS(454),
    [anon_sym_U_SQUOTE] = ACTIONS(454),
    [anon_sym_u8_SQUOTE] = ACTIONS(454),
    [anon_sym_SQUOTE] = ACTIONS(454),
    [anon_sym_L_DQUOTE] = ACTIONS(456),
    [anon_sym_u_DQUOTE] = ACTIONS(456),
    [anon_sym_U_DQUOTE] = ACTIONS(456),
    [anon_sym_u8_DQUOTE] = ACTIONS(456),
    [anon_sym_DQUOTE] = ACTIONS(456),
    [anon_sym_const] = ACTIONS(458),
    [anon_sym_volatile] = ACTIONS(458),
    [anon_sym_struct] = ACTIONS(460),
    [anon_sym_union] = ACTIONS(462),
    [anon_sym_enum] = ACTIONS(464),
    [anon_sym_signed] = ACTIONS(466),
    [anon_sym_unsigned] = ACTIONS(466),
    [anon_sym_long] = ACTIONS(466),
    [anon_sym_short] = ACTIONS(466),
    [sym_hll_primitive_type] = ACTIONS(468),
    [aux_sym_symbol_token1] = ACTIONS(470),
    [aux_sym_symbol_token2] = ACTIONS(472),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(474),
    [sym__hll_number_literal_pre_hook] = ACTIONS(476),
  },
  [STATE(33)] = {
    [sym__expression] = STATE(1383),
    [sym__parenthesized_expression] = STATE(1383),
    [sym__path_expression] = STATE(1383),
    [sym_unary_expression] = STATE(1383),
    [sym__unary_expression] = STATE(1399),
    [sym__prefix_postfix_expression] = STATE(1400),
    [sym_binary_expression] = STATE(1383),
    [sym__binary_expression] = STATE(1404),
    [sym__and_expression] = STATE(1406),
    [sym_assignment_expression] = STATE(1383),
    [sym_macro] = STATE(975),
    [sym__command_argument] = STATE(2127),
    [sym_format_expression] = STATE(2127),
    [sym_call_expression] = STATE(1046),
    [sym__function_identifier] = STATE(2257),
    [sym__hll_var_call_expression_function] = STATE(2260),
    [sym__hll_var_call_expression] = STATE(1049),
    [sym_trace32_hll_variable] = STATE(1412),
    [sym__literal] = STATE(1383),
    [sym__address_expression] = STATE(1575),
    [sym_memory_space] = STATE(236),
    [sym_address] = STATE(1383),
    [sym__parenthesized_address_expression] = STATE(1575),
    [sym__address_binary_expression] = STATE(1550),
    [sym_integer] = STATE(1052),
    [sym_bitmask] = STATE(1383),
    [sym_string] = STATE(1383),
    [sym_character] = STATE(1383),
    [sym_symbol] = STATE(1383),
    [sym__special_command_operator] = STATE(1383),
    [sym__file_dialog] = STATE(1417),
    [aux_sym__path_expression_repeat1] = STATE(1218),
    [aux_sym__path_expression_repeat2] = STATE(1053),
    [aux_sym__command_arguments_repeat1] = STATE(33),
    [sym_identifier] = ACTIONS(478),
    [anon_sym_LPAREN] = ACTIONS(481),
    [anon_sym_LBRACE] = ACTIONS(484),
    [anon_sym_PLUS] = ACTIONS(487),
    [anon_sym_DASH] = ACTIONS(487),
    [anon_sym_TILDE] = ACTIONS(490),
    [anon_sym_BANG] = ACTIONS(490),
    [anon_sym_PLUS_PLUS] = ACTIONS(493),
    [anon_sym_DASH_DASH] = ACTIONS(493),
    [anon_sym_STAR] = ACTIONS(496),
    [anon_sym_PERCENT] = ACTIONS(499),
    [anon_sym_AMP] = ACTIONS(502),
    [anon_sym_COMMA] = ACTIONS(505),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(508),
    [anon_sym_BSLASH] = ACTIONS(511),
    [anon_sym_SQUOTE] = ACTIONS(514),
    [anon_sym_DQUOTE] = ACTIONS(517),
    [sym_access_class] = ACTIONS(520),
    [aux_sym_integer_token1] = ACTIONS(523),
    [aux_sym_integer_token2] = ACTIONS(523),
    [sym_float] = ACTIONS(526),
    [aux_sym_bitmask_token1] = ACTIONS(529),
    [aux_sym_bitmask_token2] = ACTIONS(529),
    [aux_sym_symbol_token1] = ACTIONS(532),
    [aux_sym_symbol_token2] = ACTIONS(535),
    [sym__composed_name] = ACTIONS(538),
    [sym_time] = ACTIONS(526),
    [sym_frequency] = ACTIONS(526),
    [sym_percentage] = ACTIONS(538),
    [sym_file_handle] = ACTIONS(538),
    [sym__line_continuation] = ACTIONS(3),
    [sym__decimal_number_pre_hook] = ACTIONS(541),
    [sym_path] = ACTIONS(544),
  },
  [STATE(34)] = {
    [sym_trace32_hll_variable] = STATE(799),
    [sym__hll_expression] = STATE(971),
    [sym_hll_call_expression] = STATE(798),
    [sym_hll_field_expression] = STATE(798),
    [sym_hll_subscript_expression] = STATE(798),
    [sym_hll_cast_expression] = STATE(971),
    [sym_hll_sizeof_expression] = STATE(971),
    [sym_hll_pointer_expression] = STATE(798),
    [sym_hll_update_expression] = STATE(971),
    [sym_hll_unary_expression] = STATE(971),
    [sym_hll_binary_expression] = STATE(971),
    [sym_hll_assignment_expression] = STATE(971),
    [sym__hll_assignment_left_expression] = STATE(1652),
    [sym_hll_conditional_expression] = STATE(971),
    [sym_hll_char_literal] = STATE(971),
    [sym_hll_string_literal] = STATE(971),
    [sym_hll_parenthesized_expression] = STATE(798),
    [sym_symbol] = STATE(971),
    [sym_identifier] = ACTIONS(547),
    [anon_sym_RPAREN] = ACTIONS(338),
    [anon_sym_LPAREN] = ACTIONS(440),
    [anon_sym_PLUS] = ACTIONS(442),
    [anon_sym_DASH] = ACTIONS(442),
    [anon_sym_TILDE] = ACTIONS(444),
    [anon_sym_BANG] = ACTIONS(442),
    [anon_sym_PLUS_PLUS] = ACTIONS(446),
    [anon_sym_DASH_DASH] = ACTIONS(446),
    [anon_sym_PIPE_PIPE] = ACTIONS(338),
    [anon_sym_STAR] = ACTIONS(448),
    [anon_sym_SLASH] = ACTIONS(338),
    [anon_sym_PERCENT] = ACTIONS(338),
    [anon_sym_PIPE] = ACTIONS(340),
    [anon_sym_CARET] = ACTIONS(338),
    [anon_sym_EQ_EQ] = ACTIONS(338),
    [anon_sym_BANG_EQ] = ACTIONS(338),
    [anon_sym_GT] = ACTIONS(340),
    [anon_sym_GT_EQ] = ACTIONS(338),
    [anon_sym_LT_EQ] = ACTIONS(338),
    [anon_sym_LT] = ACTIONS(340),
    [anon_sym_LT_LT] = ACTIONS(338),
    [anon_sym_GT_GT] = ACTIONS(338),
    [anon_sym_DOT_DOT] = ACTIONS(338),
    [anon_sym_AMP_AMP] = ACTIONS(338),
    [anon_sym_AMP] = ACTIONS(314),
    [anon_sym_DOT] = ACTIONS(340),
    [anon_sym_COMMA] = ACTIONS(338),
    [anon_sym_QMARK] = ACTIONS(338),
    [anon_sym_BSLASH] = ACTIONS(450),
    [anon_sym_DASH_GT] = ACTIONS(338),
    [anon_sym_LBRACK] = ACTIONS(338),
    [anon_sym_RBRACK] = ACTIONS(338),
    [anon_sym_sizeof] = ACTIONS(452),
    [anon_sym_L_SQUOTE] = ACTIONS(454),
    [anon_sym_u_SQUOTE] = ACTIONS(454),
    [anon_sym_U_SQUOTE] = ACTIONS(454),
    [anon_sym_u8_SQUOTE] = ACTIONS(454),
    [anon_sym_SQUOTE] = ACTIONS(454),
    [anon_sym_L_DQUOTE] = ACTIONS(456),
    [anon_sym_u_DQUOTE] = ACTIONS(456),
    [anon_sym_U_DQUOTE] = ACTIONS(456),
    [anon_sym_u8_DQUOTE] = ACTIONS(456),
    [anon_sym_DQUOTE] = ACTIONS(456),
    [aux_sym_symbol_token1] = ACTIONS(470),
    [aux_sym_symbol_token2] = ACTIONS(472),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(338),
    [sym__hll_number_literal_pre_hook] = ACTIONS(476),
  },
  [STATE(35)] = {
    [sym_trace32_hll_variable] = STATE(799),
    [sym__hll_expression] = STATE(1002),
    [sym_hll_call_expression] = STATE(798),
    [sym_hll_field_expression] = STATE(798),
    [sym_hll_subscript_expression] = STATE(798),
    [sym_hll_cast_expression] = STATE(1002),
    [sym_hll_sizeof_expression] = STATE(1002),
    [sym_hll_pointer_expression] = STATE(798),
    [sym_hll_update_expression] = STATE(1002),
    [sym_hll_unary_expression] = STATE(1002),
    [sym_hll_binary_expression] = STATE(1002),
    [sym_hll_assignment_expression] = STATE(1002),
    [sym__hll_assignment_left_expression] = STATE(1652),
    [sym_hll_conditional_expression] = STATE(1002),
    [sym_hll_char_literal] = STATE(1002),
    [sym_hll_string_literal] = STATE(1002),
    [sym_hll_parenthesized_expression] = STATE(798),
    [sym_symbol] = STATE(1002),
    [sym_identifier] = ACTIONS(547),
    [anon_sym_RPAREN] = ACTIONS(334),
    [anon_sym_LPAREN] = ACTIONS(440),
    [anon_sym_PLUS] = ACTIONS(442),
    [anon_sym_DASH] = ACTIONS(442),
    [anon_sym_TILDE] = ACTIONS(444),
    [anon_sym_BANG] = ACTIONS(442),
    [anon_sym_PLUS_PLUS] = ACTIONS(446),
    [anon_sym_DASH_DASH] = ACTIONS(446),
    [anon_sym_PIPE_PIPE] = ACTIONS(334),
    [anon_sym_STAR] = ACTIONS(448),
    [anon_sym_SLASH] = ACTIONS(334),
    [anon_sym_PERCENT] = ACTIONS(334),
    [anon_sym_PIPE] = ACTIONS(336),
    [anon_sym_CARET] = ACTIONS(334),
    [anon_sym_EQ_EQ] = ACTIONS(334),
    [anon_sym_BANG_EQ] = ACTIONS(334),
    [anon_sym_GT] = ACTIONS(336),
    [anon_sym_GT_EQ] = ACTIONS(334),
    [anon_sym_LT_EQ] = ACTIONS(334),
    [anon_sym_LT] = ACTIONS(336),
    [anon_sym_LT_LT] = ACTIONS(334),
    [anon_sym_GT_GT] = ACTIONS(334),
    [anon_sym_DOT_DOT] = ACTIONS(334),
    [anon_sym_AMP_AMP] = ACTIONS(334),
    [anon_sym_AMP] = ACTIONS(314),
    [anon_sym_DOT] = ACTIONS(336),
    [anon_sym_COMMA] = ACTIONS(334),
    [anon_sym_QMARK] = ACTIONS(334),
    [anon_sym_BSLASH] = ACTIONS(450),
    [anon_sym_DASH_GT] = ACTIONS(334),
    [anon_sym_LBRACK] = ACTIONS(334),
    [anon_sym_RBRACK] = ACTIONS(334),
    [anon_sym_sizeof] = ACTIONS(452),
    [anon_sym_L_SQUOTE] = ACTIONS(454),
    [anon_sym_u_SQUOTE] = ACTIONS(454),
    [anon_sym_U_SQUOTE] = ACTIONS(454),
    [anon_sym_u8_SQUOTE] = ACTIONS(454),
    [anon_sym_SQUOTE] = ACTIONS(454),
    [anon_sym_L_DQUOTE] = ACTIONS(456),
    [anon_sym_u_DQUOTE] = ACTIONS(456),
    [anon_sym_U_DQUOTE] = ACTIONS(456),
    [anon_sym_u8_DQUOTE] = ACTIONS(456),
    [anon_sym_DQUOTE] = ACTIONS(456),
    [aux_sym_symbol_token1] = ACTIONS(470),
    [aux_sym_symbol_token2] = ACTIONS(472),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(334),
    [sym__hll_number_literal_pre_hook] = ACTIONS(476),
  },
  [STATE(36)] = {
    [sym_trace32_hll_variable] = STATE(799),
    [sym__hll_expression] = STATE(988),
    [sym_hll_call_expression] = STATE(798),
    [sym_hll_field_expression] = STATE(798),
    [sym_hll_subscript_expression] = STATE(798),
    [sym_hll_cast_expression] = STATE(988),
    [sym_hll_sizeof_expression] = STATE(988),
    [sym_hll_pointer_expression] = STATE(798),
    [sym_hll_update_expression] = STATE(988),
    [sym_hll_unary_expression] = STATE(988),
    [sym_hll_binary_expression] = STATE(988),
    [sym_hll_assignment_expression] = STATE(988),
    [sym__hll_assignment_left_expression] = STATE(1652),
    [sym_hll_conditional_expression] = STATE(988),
    [sym_hll_char_literal] = STATE(988),
    [sym_hll_string_literal] = STATE(988),
    [sym_hll_parenthesized_expression] = STATE(798),
    [sym_symbol] = STATE(988),
    [sym_identifier] = ACTIONS(547),
    [anon_sym_RPAREN] = ACTIONS(330),
    [anon_sym_LPAREN] = ACTIONS(440),
    [anon_sym_PLUS] = ACTIONS(442),
    [anon_sym_DASH] = ACTIONS(442),
    [anon_sym_TILDE] = ACTIONS(444),
    [anon_sym_BANG] = ACTIONS(442),
    [anon_sym_PLUS_PLUS] = ACTIONS(446),
    [anon_sym_DASH_DASH] = ACTIONS(446),
    [anon_sym_PIPE_PIPE] = ACTIONS(330),
    [anon_sym_STAR] = ACTIONS(448),
    [anon_sym_SLASH] = ACTIONS(330),
    [anon_sym_PERCENT] = ACTIONS(330),
    [anon_sym_PIPE] = ACTIONS(332),
    [anon_sym_CARET] = ACTIONS(330),
    [anon_sym_EQ_EQ] = ACTIONS(330),
    [anon_sym_BANG_EQ] = ACTIONS(330),
    [anon_sym_GT] = ACTIONS(332),
    [anon_sym_GT_EQ] = ACTIONS(330),
    [anon_sym_LT_EQ] = ACTIONS(330),
    [anon_sym_LT] = ACTIONS(332),
    [anon_sym_LT_LT] = ACTIONS(330),
    [anon_sym_GT_GT] = ACTIONS(330),
    [anon_sym_DOT_DOT] = ACTIONS(330),
    [anon_sym_AMP_AMP] = ACTIONS(330),
    [anon_sym_AMP] = ACTIONS(314),
    [anon_sym_DOT] = ACTIONS(332),
    [anon_sym_COMMA] = ACTIONS(330),
    [anon_sym_QMARK] = ACTIONS(330),
    [anon_sym_BSLASH] = ACTIONS(450),
    [anon_sym_DASH_GT] = ACTIONS(330),
    [anon_sym_LBRACK] = ACTIONS(330),
    [anon_sym_RBRACK] = ACTIONS(330),
    [anon_sym_sizeof] = ACTIONS(452),
    [anon_sym_L_SQUOTE] = ACTIONS(454),
    [anon_sym_u_SQUOTE] = ACTIONS(454),
    [anon_sym_U_SQUOTE] = ACTIONS(454),
    [anon_sym_u8_SQUOTE] = ACTIONS(454),
    [anon_sym_SQUOTE] = ACTIONS(454),
    [anon_sym_L_DQUOTE] = ACTIONS(456),
    [anon_sym_u_DQUOTE] = ACTIONS(456),
    [anon_sym_U_DQUOTE] = ACTIONS(456),
    [anon_sym_u8_DQUOTE] = ACTIONS(456),
    [anon_sym_DQUOTE] = ACTIONS(456),
    [aux_sym_symbol_token1] = ACTIONS(470),
    [aux_sym_symbol_token2] = ACTIONS(472),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(330),
    [sym__hll_number_literal_pre_hook] = ACTIONS(476),
  },
  [STATE(37)] = {
    [sym_trace32_hll_variable] = STATE(799),
    [sym__hll_expression] = STATE(1030),
    [sym_hll_call_expression] = STATE(798),
    [sym_hll_field_expression] = STATE(798),
    [sym_hll_subscript_expression] = STATE(798),
    [sym_hll_cast_expression] = STATE(1030),
    [sym_hll_sizeof_expression] = STATE(1030),
    [sym_hll_pointer_expression] = STATE(798),
    [sym_hll_update_expression] = STATE(1030),
    [sym_hll_unary_expression] = STATE(1030),
    [sym_hll_binary_expression] = STATE(1030),
    [sym_hll_assignment_expression] = STATE(1030),
    [sym__hll_assignment_left_expression] = STATE(1652),
    [sym_hll_conditional_expression] = STATE(1030),
    [sym_hll_char_literal] = STATE(1030),
    [sym_hll_string_literal] = STATE(1030),
    [sym_hll_parenthesized_expression] = STATE(798),
    [sym_symbol] = STATE(1030),
    [sym_identifier] = ACTIONS(547),
    [anon_sym_RPAREN] = ACTIONS(302),
    [anon_sym_LPAREN] = ACTIONS(440),
    [anon_sym_PLUS] = ACTIONS(442),
    [anon_sym_DASH] = ACTIONS(442),
    [anon_sym_TILDE] = ACTIONS(444),
    [anon_sym_BANG] = ACTIONS(442),
    [anon_sym_PLUS_PLUS] = ACTIONS(446),
    [anon_sym_DASH_DASH] = ACTIONS(446),
    [anon_sym_PIPE_PIPE] = ACTIONS(302),
    [anon_sym_STAR] = ACTIONS(448),
    [anon_sym_SLASH] = ACTIONS(302),
    [anon_sym_PERCENT] = ACTIONS(302),
    [anon_sym_PIPE] = ACTIONS(306),
    [anon_sym_CARET] = ACTIONS(302),
    [anon_sym_EQ_EQ] = ACTIONS(302),
    [anon_sym_BANG_EQ] = ACTIONS(302),
    [anon_sym_GT] = ACTIONS(306),
    [anon_sym_GT_EQ] = ACTIONS(302),
    [anon_sym_LT_EQ] = ACTIONS(302),
    [anon_sym_LT] = ACTIONS(306),
    [anon_sym_LT_LT] = ACTIONS(302),
    [anon_sym_GT_GT] = ACTIONS(302),
    [anon_sym_DOT_DOT] = ACTIONS(302),
    [anon_sym_AMP_AMP] = ACTIONS(302),
    [anon_sym_AMP] = ACTIONS(314),
    [anon_sym_DOT] = ACTIONS(306),
    [anon_sym_COMMA] = ACTIONS(302),
    [anon_sym_QMARK] = ACTIONS(302),
    [anon_sym_BSLASH] = ACTIONS(450),
    [anon_sym_DASH_GT] = ACTIONS(302),
    [anon_sym_LBRACK] = ACTIONS(302),
    [anon_sym_RBRACK] = ACTIONS(302),
    [anon_sym_sizeof] = ACTIONS(452),
    [anon_sym_L_SQUOTE] = ACTIONS(454),
    [anon_sym_u_SQUOTE] = ACTIONS(454),
    [anon_sym_U_SQUOTE] = ACTIONS(454),
    [anon_sym_u8_SQUOTE] = ACTIONS(454),
    [anon_sym_SQUOTE] = ACTIONS(454),
    [anon_sym_L_DQUOTE] = ACTIONS(456),
    [anon_sym_u_DQUOTE] = ACTIONS(456),
    [anon_sym_U_DQUOTE] = ACTIONS(456),
    [anon_sym_u8_DQUOTE] = ACTIONS(456),
    [anon_sym_DQUOTE] = ACTIONS(456),
    [aux_sym_symbol_token1] = ACTIONS(470),
    [aux_sym_symbol_token2] = ACTIONS(472),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(302),
    [sym__hll_number_literal_pre_hook] = ACTIONS(476),
  },
  [STATE(38)] = {
    [sym_trace32_hll_variable] = STATE(799),
    [sym__hll_expression] = STATE(1057),
    [sym_hll_call_expression] = STATE(798),
    [sym_hll_field_expression] = STATE(798),
    [sym_hll_subscript_expression] = STATE(798),
    [sym_hll_cast_expression] = STATE(1057),
    [sym_hll_sizeof_expression] = STATE(1057),
    [sym_hll_pointer_expression] = STATE(798),
    [sym_hll_comma_expression] = STATE(2179),
    [sym_hll_update_expression] = STATE(1057),
    [sym_hll_unary_expression] = STATE(1057),
    [sym_hll_binary_expression] = STATE(1057),
    [sym_hll_assignment_expression] = STATE(1057),
    [sym__hll_assignment_left_expression] = STATE(1652),
    [sym_hll_conditional_expression] = STATE(1057),
    [sym_hll_char_literal] = STATE(1057),
    [sym_hll_string_literal] = STATE(1057),
    [sym_hll_parenthesized_expression] = STATE(798),
    [sym_hll_type_descriptor] = STATE(2078),
    [sym_hll_type_qualifier] = STATE(1518),
    [sym__hll_type_specifier] = STATE(1531),
    [sym_hll_struct_specifier] = STATE(1531),
    [sym_hll_union_specifier] = STATE(1531),
    [sym_hll_enum_specifier] = STATE(1531),
    [sym_hll_sized_type_specifier] = STATE(1531),
    [sym__hll_type_identifier] = STATE(1531),
    [sym_symbol] = STATE(1057),
    [aux_sym_block_repeat1] = STATE(500),
    [aux_sym_hll_type_descriptor_repeat1] = STATE(1518),
    [aux_sym_hll_sized_type_specifier_repeat1] = STATE(1743),
    [sym_identifier] = ACTIONS(438),
    [anon_sym_LPAREN] = ACTIONS(440),
    [anon_sym_PLUS] = ACTIONS(442),
    [anon_sym_DASH] = ACTIONS(442),
    [anon_sym_TILDE] = ACTIONS(444),
    [anon_sym_BANG] = ACTIONS(444),
    [anon_sym_PLUS_PLUS] = ACTIONS(446),
    [anon_sym_DASH_DASH] = ACTIONS(446),
    [anon_sym_STAR] = ACTIONS(448),
    [anon_sym_AMP] = ACTIONS(448),
    [anon_sym_BSLASH] = ACTIONS(450),
    [anon_sym_sizeof] = ACTIONS(452),
    [anon_sym_L_SQUOTE] = ACTIONS(454),
    [anon_sym_u_SQUOTE] = ACTIONS(454),
    [anon_sym_U_SQUOTE] = ACTIONS(454),
    [anon_sym_u8_SQUOTE] = ACTIONS(454),
    [anon_sym_SQUOTE] = ACTIONS(454),
    [anon_sym_L_DQUOTE] = ACTIONS(456),
    [anon_sym_u_DQUOTE] = ACTIONS(456),
    [anon_sym_U_DQUOTE] = ACTIONS(456),
    [anon_sym_u8_DQUOTE] = ACTIONS(456),
    [anon_sym_DQUOTE] = ACTIONS(456),
    [anon_sym_const] = ACTIONS(458),
    [anon_sym_volatile] = ACTIONS(458),
    [anon_sym_struct] = ACTIONS(460),
    [anon_sym_union] = ACTIONS(462),
    [anon_sym_enum] = ACTIONS(464),
    [anon_sym_signed] = ACTIONS(466),
    [anon_sym_unsigned] = ACTIONS(466),
    [anon_sym_long] = ACTIONS(466),
    [anon_sym_short] = ACTIONS(466),
    [sym_hll_primitive_type] = ACTIONS(549),
    [aux_sym_symbol_token1] = ACTIONS(470),
    [aux_sym_symbol_token2] = ACTIONS(472),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(551),
    [sym__hll_number_literal_pre_hook] = ACTIONS(476),
  },
  [STATE(39)] = {
    [sym_trace32_hll_variable] = STATE(799),
    [sym__hll_expression] = STATE(1082),
    [sym_hll_call_expression] = STATE(798),
    [sym_hll_field_expression] = STATE(798),
    [sym_hll_subscript_expression] = STATE(798),
    [sym_hll_cast_expression] = STATE(1082),
    [sym_hll_sizeof_expression] = STATE(1082),
    [sym_hll_pointer_expression] = STATE(798),
    [sym_hll_comma_expression] = STATE(2149),
    [sym_hll_update_expression] = STATE(1082),
    [sym_hll_unary_expression] = STATE(1082),
    [sym_hll_binary_expression] = STATE(1082),
    [sym_hll_assignment_expression] = STATE(1082),
    [sym__hll_assignment_left_expression] = STATE(1652),
    [sym_hll_conditional_expression] = STATE(1082),
    [sym_hll_char_literal] = STATE(1082),
    [sym_hll_string_literal] = STATE(1082),
    [sym_hll_parenthesized_expression] = STATE(798),
    [sym_hll_type_descriptor] = STATE(2150),
    [sym_hll_type_qualifier] = STATE(1518),
    [sym__hll_type_specifier] = STATE(1534),
    [sym_hll_struct_specifier] = STATE(1534),
    [sym_hll_union_specifier] = STATE(1534),
    [sym_hll_enum_specifier] = STATE(1534),
    [sym_hll_sized_type_specifier] = STATE(1534),
    [sym__hll_type_identifier] = STATE(1534),
    [sym_symbol] = STATE(1082),
    [aux_sym_block_repeat1] = STATE(40),
    [aux_sym_hll_type_descriptor_repeat1] = STATE(1518),
    [aux_sym_hll_sized_type_specifier_repeat1] = STATE(1743),
    [sym_identifier] = ACTIONS(438),
    [anon_sym_LPAREN] = ACTIONS(440),
    [anon_sym_PLUS] = ACTIONS(442),
    [anon_sym_DASH] = ACTIONS(442),
    [anon_sym_TILDE] = ACTIONS(444),
    [anon_sym_BANG] = ACTIONS(444),
    [anon_sym_PLUS_PLUS] = ACTIONS(446),
    [anon_sym_DASH_DASH] = ACTIONS(446),
    [anon_sym_STAR] = ACTIONS(448),
    [anon_sym_AMP] = ACTIONS(448),
    [anon_sym_BSLASH] = ACTIONS(450),
    [anon_sym_sizeof] = ACTIONS(452),
    [anon_sym_L_SQUOTE] = ACTIONS(454),
    [anon_sym_u_SQUOTE] = ACTIONS(454),
    [anon_sym_U_SQUOTE] = ACTIONS(454),
    [anon_sym_u8_SQUOTE] = ACTIONS(454),
    [anon_sym_SQUOTE] = ACTIONS(454),
    [anon_sym_L_DQUOTE] = ACTIONS(456),
    [anon_sym_u_DQUOTE] = ACTIONS(456),
    [anon_sym_U_DQUOTE] = ACTIONS(456),
    [anon_sym_u8_DQUOTE] = ACTIONS(456),
    [anon_sym_DQUOTE] = ACTIONS(456),
    [anon_sym_const] = ACTIONS(458),
    [anon_sym_volatile] = ACTIONS(458),
    [anon_sym_struct] = ACTIONS(460),
    [anon_sym_union] = ACTIONS(462),
    [anon_sym_enum] = ACTIONS(464),
    [anon_sym_signed] = ACTIONS(466),
    [anon_sym_unsigned] = ACTIONS(466),
    [anon_sym_long] = ACTIONS(466),
    [anon_sym_short] = ACTIONS(466),
    [sym_hll_primitive_type] = ACTIONS(468),
    [aux_sym_symbol_token1] = ACTIONS(470),
    [aux_sym_symbol_token2] = ACTIONS(472),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(553),
    [sym__hll_number_literal_pre_hook] = ACTIONS(476),
  },
  [STATE(40)] = {
    [sym_trace32_hll_variable] = STATE(799),
    [sym__hll_expression] = STATE(1057),
    [sym_hll_call_expression] = STATE(798),
    [sym_hll_field_expression] = STATE(798),
    [sym_hll_subscript_expression] = STATE(798),
    [sym_hll_cast_expression] = STATE(1057),
    [sym_hll_sizeof_expression] = STATE(1057),
    [sym_hll_pointer_expression] = STATE(798),
    [sym_hll_comma_expression] = STATE(2179),
    [sym_hll_update_expression] = STATE(1057),
    [sym_hll_unary_expression] = STATE(1057),
    [sym_hll_binary_expression] = STATE(1057),
    [sym_hll_assignment_expression] = STATE(1057),
    [sym__hll_assignment_left_expression] = STATE(1652),
    [sym_hll_conditional_expression] = STATE(1057),
    [sym_hll_char_literal] = STATE(1057),
    [sym_hll_string_literal] = STATE(1057),
    [sym_hll_parenthesized_expression] = STATE(798),
    [sym_hll_type_descriptor] = STATE(2180),
    [sym_hll_type_qualifier] = STATE(1518),
    [sym__hll_type_specifier] = STATE(1531),
    [sym_hll_struct_specifier] = STATE(1531),
    [sym_hll_union_specifier] = STATE(1531),
    [sym_hll_enum_specifier] = STATE(1531),
    [sym_hll_sized_type_specifier] = STATE(1531),
    [sym__hll_type_identifier] = STATE(1531),
    [sym_symbol] = STATE(1057),
    [aux_sym_block_repeat1] = STATE(500),
    [aux_sym_hll_type_descriptor_repeat1] = STATE(1518),
    [aux_sym_hll_sized_type_specifier_repeat1] = STATE(1743),
    [sym_identifier] = ACTIONS(438),
    [anon_sym_LPAREN] = ACTIONS(440),
    [anon_sym_PLUS] = ACTIONS(442),
    [anon_sym_DASH] = ACTIONS(442),
    [anon_sym_TILDE] = ACTIONS(444),
    [anon_sym_BANG] = ACTIONS(444),
    [anon_sym_PLUS_PLUS] = ACTIONS(446),
    [anon_sym_DASH_DASH] = ACTIONS(446),
    [anon_sym_STAR] = ACTIONS(448),
    [anon_sym_AMP] = ACTIONS(448),
    [anon_sym_BSLASH] = ACTIONS(450),
    [anon_sym_sizeof] = ACTIONS(452),
    [anon_sym_L_SQUOTE] = ACTIONS(454),
    [anon_sym_u_SQUOTE] = ACTIONS(454),
    [anon_sym_U_SQUOTE] = ACTIONS(454),
    [anon_sym_u8_SQUOTE] = ACTIONS(454),
    [anon_sym_SQUOTE] = ACTIONS(454),
    [anon_sym_L_DQUOTE] = ACTIONS(456),
    [anon_sym_u_DQUOTE] = ACTIONS(456),
    [anon_sym_U_DQUOTE] = ACTIONS(456),
    [anon_sym_u8_DQUOTE] = ACTIONS(456),
    [anon_sym_DQUOTE] = ACTIONS(456),
    [anon_sym_const] = ACTIONS(458),
    [anon_sym_volatile] = ACTIONS(458),
    [anon_sym_struct] = ACTIONS(460),
    [anon_sym_union] = ACTIONS(462),
    [anon_sym_enum] = ACTIONS(464),
    [anon_sym_signed] = ACTIONS(466),
    [anon_sym_unsigned] = ACTIONS(466),
    [anon_sym_long] = ACTIONS(466),
    [anon_sym_short] = ACTIONS(466),
    [sym_hll_primitive_type] = ACTIONS(549),
    [aux_sym_symbol_token1] = ACTIONS(470),
    [aux_sym_symbol_token2] = ACTIONS(472),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(551),
    [sym__hll_number_literal_pre_hook] = ACTIONS(476),
  },
  [STATE(41)] = {
    [sym_trace32_hll_variable] = STATE(799),
    [sym__hll_expression] = STATE(1082),
    [sym_hll_call_expression] = STATE(798),
    [sym_hll_field_expression] = STATE(798),
    [sym_hll_subscript_expression] = STATE(798),
    [sym_hll_cast_expression] = STATE(1082),
    [sym_hll_sizeof_expression] = STATE(1082),
    [sym_hll_pointer_expression] = STATE(798),
    [sym_hll_comma_expression] = STATE(2149),
    [sym_hll_update_expression] = STATE(1082),
    [sym_hll_unary_expression] = STATE(1082),
    [sym_hll_binary_expression] = STATE(1082),
    [sym_hll_assignment_expression] = STATE(1082),
    [sym__hll_assignment_left_expression] = STATE(1652),
    [sym_hll_conditional_expression] = STATE(1082),
    [sym_hll_char_literal] = STATE(1082),
    [sym_hll_string_literal] = STATE(1082),
    [sym_hll_parenthesized_expression] = STATE(798),
    [sym_hll_type_descriptor] = STATE(2189),
    [sym_hll_type_qualifier] = STATE(1518),
    [sym__hll_type_specifier] = STATE(1534),
    [sym_hll_struct_specifier] = STATE(1534),
    [sym_hll_union_specifier] = STATE(1534),
    [sym_hll_enum_specifier] = STATE(1534),
    [sym_hll_sized_type_specifier] = STATE(1534),
    [sym__hll_type_identifier] = STATE(1534),
    [sym_symbol] = STATE(1082),
    [aux_sym_block_repeat1] = STATE(38),
    [aux_sym_hll_type_descriptor_repeat1] = STATE(1518),
    [aux_sym_hll_sized_type_specifier_repeat1] = STATE(1743),
    [sym_identifier] = ACTIONS(438),
    [anon_sym_LPAREN] = ACTIONS(440),
    [anon_sym_PLUS] = ACTIONS(442),
    [anon_sym_DASH] = ACTIONS(442),
    [anon_sym_TILDE] = ACTIONS(444),
    [anon_sym_BANG] = ACTIONS(444),
    [anon_sym_PLUS_PLUS] = ACTIONS(446),
    [anon_sym_DASH_DASH] = ACTIONS(446),
    [anon_sym_STAR] = ACTIONS(448),
    [anon_sym_AMP] = ACTIONS(448),
    [anon_sym_BSLASH] = ACTIONS(450),
    [anon_sym_sizeof] = ACTIONS(452),
    [anon_sym_L_SQUOTE] = ACTIONS(454),
    [anon_sym_u_SQUOTE] = ACTIONS(454),
    [anon_sym_U_SQUOTE] = ACTIONS(454),
    [anon_sym_u8_SQUOTE] = ACTIONS(454),
    [anon_sym_SQUOTE] = ACTIONS(454),
    [anon_sym_L_DQUOTE] = ACTIONS(456),
    [anon_sym_u_DQUOTE] = ACTIONS(456),
    [anon_sym_U_DQUOTE] = ACTIONS(456),
    [anon_sym_u8_DQUOTE] = ACTIONS(456),
    [anon_sym_DQUOTE] = ACTIONS(456),
    [anon_sym_const] = ACTIONS(458),
    [anon_sym_volatile] = ACTIONS(458),
    [anon_sym_struct] = ACTIONS(460),
    [anon_sym_union] = ACTIONS(462),
    [anon_sym_enum] = ACTIONS(464),
    [anon_sym_signed] = ACTIONS(466),
    [anon_sym_unsigned] = ACTIONS(466),
    [anon_sym_long] = ACTIONS(466),
    [anon_sym_short] = ACTIONS(466),
    [sym_hll_primitive_type] = ACTIONS(468),
    [aux_sym_symbol_token1] = ACTIONS(470),
    [aux_sym_symbol_token2] = ACTIONS(472),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(555),
    [sym__hll_number_literal_pre_hook] = ACTIONS(476),
  },
  [STATE(42)] = {
    [sym_trace32_hll_variable] = STATE(799),
    [sym__hll_expression] = STATE(1083),
    [sym_hll_call_expression] = STATE(798),
    [sym_hll_field_expression] = STATE(798),
    [sym_hll_subscript_expression] = STATE(798),
    [sym_hll_cast_expression] = STATE(1083),
    [sym_hll_sizeof_expression] = STATE(1083),
    [sym_hll_pointer_expression] = STATE(798),
    [sym_hll_comma_expression] = STATE(2154),
    [sym_hll_update_expression] = STATE(1083),
    [sym_hll_unary_expression] = STATE(1083),
    [sym_hll_binary_expression] = STATE(1083),
    [sym_hll_assignment_expression] = STATE(1083),
    [sym__hll_assignment_left_expression] = STATE(1652),
    [sym_hll_conditional_expression] = STATE(1083),
    [sym_hll_char_literal] = STATE(1083),
    [sym_hll_string_literal] = STATE(1083),
    [sym_hll_parenthesized_expression] = STATE(798),
    [sym_hll_type_descriptor] = STATE(2087),
    [sym_hll_type_qualifier] = STATE(1518),
    [sym__hll_type_specifier] = STATE(1534),
    [sym_hll_struct_specifier] = STATE(1534),
    [sym_hll_union_specifier] = STATE(1534),
    [sym_hll_enum_specifier] = STATE(1534),
    [sym_hll_sized_type_specifier] = STATE(1534),
    [sym__hll_type_identifier] = STATE(1534),
    [sym_symbol] = STATE(1083),
    [aux_sym_block_repeat1] = STATE(43),
    [aux_sym_hll_type_descriptor_repeat1] = STATE(1518),
    [aux_sym_hll_sized_type_specifier_repeat1] = STATE(1743),
    [sym_identifier] = ACTIONS(438),
    [anon_sym_LPAREN] = ACTIONS(440),
    [anon_sym_PLUS] = ACTIONS(442),
    [anon_sym_DASH] = ACTIONS(442),
    [anon_sym_TILDE] = ACTIONS(444),
    [anon_sym_BANG] = ACTIONS(444),
    [anon_sym_PLUS_PLUS] = ACTIONS(446),
    [anon_sym_DASH_DASH] = ACTIONS(446),
    [anon_sym_STAR] = ACTIONS(448),
    [anon_sym_AMP] = ACTIONS(448),
    [anon_sym_BSLASH] = ACTIONS(450),
    [anon_sym_sizeof] = ACTIONS(452),
    [anon_sym_L_SQUOTE] = ACTIONS(454),
    [anon_sym_u_SQUOTE] = ACTIONS(454),
    [anon_sym_U_SQUOTE] = ACTIONS(454),
    [anon_sym_u8_SQUOTE] = ACTIONS(454),
    [anon_sym_SQUOTE] = ACTIONS(454),
    [anon_sym_L_DQUOTE] = ACTIONS(456),
    [anon_sym_u_DQUOTE] = ACTIONS(456),
    [anon_sym_U_DQUOTE] = ACTIONS(456),
    [anon_sym_u8_DQUOTE] = ACTIONS(456),
    [anon_sym_DQUOTE] = ACTIONS(456),
    [anon_sym_const] = ACTIONS(458),
    [anon_sym_volatile] = ACTIONS(458),
    [anon_sym_struct] = ACTIONS(460),
    [anon_sym_union] = ACTIONS(462),
    [anon_sym_enum] = ACTIONS(464),
    [anon_sym_signed] = ACTIONS(466),
    [anon_sym_unsigned] = ACTIONS(466),
    [anon_sym_long] = ACTIONS(466),
    [anon_sym_short] = ACTIONS(466),
    [sym_hll_primitive_type] = ACTIONS(468),
    [aux_sym_symbol_token1] = ACTIONS(470),
    [aux_sym_symbol_token2] = ACTIONS(472),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(557),
    [sym__hll_number_literal_pre_hook] = ACTIONS(476),
  },
  [STATE(43)] = {
    [sym_trace32_hll_variable] = STATE(799),
    [sym__hll_expression] = STATE(1086),
    [sym_hll_call_expression] = STATE(798),
    [sym_hll_field_expression] = STATE(798),
    [sym_hll_subscript_expression] = STATE(798),
    [sym_hll_cast_expression] = STATE(1086),
    [sym_hll_sizeof_expression] = STATE(1086),
    [sym_hll_pointer_expression] = STATE(798),
    [sym_hll_comma_expression] = STATE(2081),
    [sym_hll_update_expression] = STATE(1086),
    [sym_hll_unary_expression] = STATE(1086),
    [sym_hll_binary_expression] = STATE(1086),
    [sym_hll_assignment_expression] = STATE(1086),
    [sym__hll_assignment_left_expression] = STATE(1652),
    [sym_hll_conditional_expression] = STATE(1086),
    [sym_hll_char_literal] = STATE(1086),
    [sym_hll_string_literal] = STATE(1086),
    [sym_hll_parenthesized_expression] = STATE(798),
    [sym_hll_type_descriptor] = STATE(2175),
    [sym_hll_type_qualifier] = STATE(1518),
    [sym__hll_type_specifier] = STATE(1531),
    [sym_hll_struct_specifier] = STATE(1531),
    [sym_hll_union_specifier] = STATE(1531),
    [sym_hll_enum_specifier] = STATE(1531),
    [sym_hll_sized_type_specifier] = STATE(1531),
    [sym__hll_type_identifier] = STATE(1531),
    [sym_symbol] = STATE(1086),
    [aux_sym_block_repeat1] = STATE(500),
    [aux_sym_hll_type_descriptor_repeat1] = STATE(1518),
    [aux_sym_hll_sized_type_specifier_repeat1] = STATE(1743),
    [sym_identifier] = ACTIONS(438),
    [anon_sym_LPAREN] = ACTIONS(440),
    [anon_sym_PLUS] = ACTIONS(442),
    [anon_sym_DASH] = ACTIONS(442),
    [anon_sym_TILDE] = ACTIONS(444),
    [anon_sym_BANG] = ACTIONS(444),
    [anon_sym_PLUS_PLUS] = ACTIONS(446),
    [anon_sym_DASH_DASH] = ACTIONS(446),
    [anon_sym_STAR] = ACTIONS(448),
    [anon_sym_AMP] = ACTIONS(448),
    [anon_sym_BSLASH] = ACTIONS(450),
    [anon_sym_sizeof] = ACTIONS(452),
    [anon_sym_L_SQUOTE] = ACTIONS(454),
    [anon_sym_u_SQUOTE] = ACTIONS(454),
    [anon_sym_U_SQUOTE] = ACTIONS(454),
    [anon_sym_u8_SQUOTE] = ACTIONS(454),
    [anon_sym_SQUOTE] = ACTIONS(454),
    [anon_sym_L_DQUOTE] = ACTIONS(456),
    [anon_sym_u_DQUOTE] = ACTIONS(456),
    [anon_sym_U_DQUOTE] = ACTIONS(456),
    [anon_sym_u8_DQUOTE] = ACTIONS(456),
    [anon_sym_DQUOTE] = ACTIONS(456),
    [anon_sym_const] = ACTIONS(458),
    [anon_sym_volatile] = ACTIONS(458),
    [anon_sym_struct] = ACTIONS(460),
    [anon_sym_union] = ACTIONS(462),
    [anon_sym_enum] = ACTIONS(464),
    [anon_sym_signed] = ACTIONS(466),
    [anon_sym_unsigned] = ACTIONS(466),
    [anon_sym_long] = ACTIONS(466),
    [anon_sym_short] = ACTIONS(466),
    [sym_hll_primitive_type] = ACTIONS(549),
    [aux_sym_symbol_token1] = ACTIONS(470),
    [aux_sym_symbol_token2] = ACTIONS(472),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(551),
    [sym__hll_number_literal_pre_hook] = ACTIONS(476),
  },
  [STATE(44)] = {
    [sym_trace32_hll_variable] = STATE(812),
    [sym__hll_expression] = STATE(983),
    [sym_hll_call_expression] = STATE(811),
    [sym_hll_field_expression] = STATE(811),
    [sym_hll_subscript_expression] = STATE(811),
    [sym_hll_cast_expression] = STATE(983),
    [sym_hll_sizeof_expression] = STATE(983),
    [sym_hll_pointer_expression] = STATE(811),
    [sym_hll_update_expression] = STATE(983),
    [sym_hll_unary_expression] = STATE(983),
    [sym_hll_binary_expression] = STATE(983),
    [sym_hll_assignment_expression] = STATE(983),
    [sym__hll_assignment_left_expression] = STATE(1655),
    [sym_hll_conditional_expression] = STATE(983),
    [sym_hll_char_literal] = STATE(983),
    [sym_hll_string_literal] = STATE(983),
    [sym_hll_parenthesized_expression] = STATE(811),
    [sym_symbol] = STATE(983),
    [sym_identifier] = ACTIONS(559),
    [anon_sym_LPAREN] = ACTIONS(561),
    [anon_sym_PLUS] = ACTIONS(563),
    [anon_sym_DASH] = ACTIONS(563),
    [anon_sym_TILDE] = ACTIONS(565),
    [anon_sym_BANG] = ACTIONS(563),
    [anon_sym_PLUS_PLUS] = ACTIONS(567),
    [anon_sym_DASH_DASH] = ACTIONS(567),
    [anon_sym_PIPE_PIPE] = ACTIONS(338),
    [anon_sym_STAR] = ACTIONS(569),
    [anon_sym_SLASH] = ACTIONS(340),
    [anon_sym_PERCENT] = ACTIONS(338),
    [anon_sym_PIPE] = ACTIONS(340),
    [anon_sym_CARET] = ACTIONS(338),
    [anon_sym_EQ_EQ] = ACTIONS(338),
    [anon_sym_BANG_EQ] = ACTIONS(338),
    [anon_sym_GT] = ACTIONS(340),
    [anon_sym_GT_EQ] = ACTIONS(338),
    [anon_sym_LT_EQ] = ACTIONS(338),
    [anon_sym_LT] = ACTIONS(340),
    [anon_sym_LT_LT] = ACTIONS(338),
    [anon_sym_GT_GT] = ACTIONS(338),
    [anon_sym_AMP_AMP] = ACTIONS(338),
    [anon_sym_AMP] = ACTIONS(352),
    [anon_sym_DOT] = ACTIONS(338),
    [anon_sym_QMARK] = ACTIONS(338),
    [anon_sym_BSLASH] = ACTIONS(571),
    [anon_sym_DASH_GT] = ACTIONS(338),
    [anon_sym_LBRACK] = ACTIONS(338),
    [anon_sym_sizeof] = ACTIONS(573),
    [anon_sym_L_SQUOTE] = ACTIONS(575),
    [anon_sym_u_SQUOTE] = ACTIONS(575),
    [anon_sym_U_SQUOTE] = ACTIONS(575),
    [anon_sym_u8_SQUOTE] = ACTIONS(575),
    [anon_sym_SQUOTE] = ACTIONS(575),
    [anon_sym_L_DQUOTE] = ACTIONS(577),
    [anon_sym_u_DQUOTE] = ACTIONS(577),
    [anon_sym_U_DQUOTE] = ACTIONS(577),
    [anon_sym_u8_DQUOTE] = ACTIONS(577),
    [anon_sym_DQUOTE] = ACTIONS(577),
    [aux_sym__hll_expression_separator_token1] = ACTIONS(338),
    [aux_sym__hll_expression_separator_token2] = ACTIONS(340),
    [aux_sym_symbol_token1] = ACTIONS(579),
    [aux_sym_symbol_token2] = ACTIONS(581),
    [sym_comment] = ACTIONS(338),
    [sym__blank_line] = ACTIONS(338),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(340),
    [sym__hll_number_literal_pre_hook] = ACTIONS(583),
  },
  [STATE(45)] = {
    [sym_trace32_hll_variable] = STATE(799),
    [sym__hll_expression] = STATE(1093),
    [sym_hll_call_expression] = STATE(798),
    [sym_hll_field_expression] = STATE(798),
    [sym_hll_subscript_expression] = STATE(798),
    [sym_hll_cast_expression] = STATE(1093),
    [sym_hll_sizeof_expression] = STATE(1093),
    [sym_hll_pointer_expression] = STATE(798),
    [sym_hll_comma_expression] = STATE(2204),
    [sym_hll_update_expression] = STATE(1093),
    [sym_hll_unary_expression] = STATE(1093),
    [sym_hll_binary_expression] = STATE(1093),
    [sym_hll_assignment_expression] = STATE(1093),
    [sym__hll_assignment_left_expression] = STATE(1652),
    [sym_hll_conditional_expression] = STATE(1093),
    [sym_hll_char_literal] = STATE(1093),
    [sym_hll_string_literal] = STATE(1093),
    [sym_hll_parenthesized_expression] = STATE(798),
    [sym_hll_type_descriptor] = STATE(2224),
    [sym_hll_type_qualifier] = STATE(1518),
    [sym__hll_type_specifier] = STATE(1534),
    [sym_hll_struct_specifier] = STATE(1534),
    [sym_hll_union_specifier] = STATE(1534),
    [sym_hll_enum_specifier] = STATE(1534),
    [sym_hll_sized_type_specifier] = STATE(1534),
    [sym__hll_type_identifier] = STATE(1534),
    [sym_symbol] = STATE(1093),
    [aux_sym_block_repeat1] = STATE(46),
    [aux_sym_hll_type_descriptor_repeat1] = STATE(1518),
    [aux_sym_hll_sized_type_specifier_repeat1] = STATE(1743),
    [sym_identifier] = ACTIONS(438),
    [anon_sym_LPAREN] = ACTIONS(440),
    [anon_sym_PLUS] = ACTIONS(442),
    [anon_sym_DASH] = ACTIONS(442),
    [anon_sym_TILDE] = ACTIONS(444),
    [anon_sym_BANG] = ACTIONS(444),
    [anon_sym_PLUS_PLUS] = ACTIONS(446),
    [anon_sym_DASH_DASH] = ACTIONS(446),
    [anon_sym_STAR] = ACTIONS(448),
    [anon_sym_AMP] = ACTIONS(448),
    [anon_sym_BSLASH] = ACTIONS(450),
    [anon_sym_sizeof] = ACTIONS(452),
    [anon_sym_L_SQUOTE] = ACTIONS(454),
    [anon_sym_u_SQUOTE] = ACTIONS(454),
    [anon_sym_U_SQUOTE] = ACTIONS(454),
    [anon_sym_u8_SQUOTE] = ACTIONS(454),
    [anon_sym_SQUOTE] = ACTIONS(454),
    [anon_sym_L_DQUOTE] = ACTIONS(456),
    [anon_sym_u_DQUOTE] = ACTIONS(456),
    [anon_sym_U_DQUOTE] = ACTIONS(456),
    [anon_sym_u8_DQUOTE] = ACTIONS(456),
    [anon_sym_DQUOTE] = ACTIONS(456),
    [anon_sym_const] = ACTIONS(458),
    [anon_sym_volatile] = ACTIONS(458),
    [anon_sym_struct] = ACTIONS(460),
    [anon_sym_union] = ACTIONS(462),
    [anon_sym_enum] = ACTIONS(464),
    [anon_sym_signed] = ACTIONS(466),
    [anon_sym_unsigned] = ACTIONS(466),
    [anon_sym_long] = ACTIONS(466),
    [anon_sym_short] = ACTIONS(466),
    [sym_hll_primitive_type] = ACTIONS(468),
    [aux_sym_symbol_token1] = ACTIONS(470),
    [aux_sym_symbol_token2] = ACTIONS(472),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(585),
    [sym__hll_number_literal_pre_hook] = ACTIONS(476),
  },
  [STATE(46)] = {
    [sym_trace32_hll_variable] = STATE(799),
    [sym__hll_expression] = STATE(1094),
    [sym_hll_call_expression] = STATE(798),
    [sym_hll_field_expression] = STATE(798),
    [sym_hll_subscript_expression] = STATE(798),
    [sym_hll_cast_expression] = STATE(1094),
    [sym_hll_sizeof_expression] = STATE(1094),
    [sym_hll_pointer_expression] = STATE(798),
    [sym_hll_comma_expression] = STATE(2219),
    [sym_hll_update_expression] = STATE(1094),
    [sym_hll_unary_expression] = STATE(1094),
    [sym_hll_binary_expression] = STATE(1094),
    [sym_hll_assignment_expression] = STATE(1094),
    [sym__hll_assignment_left_expression] = STATE(1652),
    [sym_hll_conditional_expression] = STATE(1094),
    [sym_hll_char_literal] = STATE(1094),
    [sym_hll_string_literal] = STATE(1094),
    [sym_hll_parenthesized_expression] = STATE(798),
    [sym_hll_type_descriptor] = STATE(2238),
    [sym_hll_type_qualifier] = STATE(1518),
    [sym__hll_type_specifier] = STATE(1531),
    [sym_hll_struct_specifier] = STATE(1531),
    [sym_hll_union_specifier] = STATE(1531),
    [sym_hll_enum_specifier] = STATE(1531),
    [sym_hll_sized_type_specifier] = STATE(1531),
    [sym__hll_type_identifier] = STATE(1531),
    [sym_symbol] = STATE(1094),
    [aux_sym_block_repeat1] = STATE(500),
    [aux_sym_hll_type_descriptor_repeat1] = STATE(1518),
    [aux_sym_hll_sized_type_specifier_repeat1] = STATE(1743),
    [sym_identifier] = ACTIONS(438),
    [anon_sym_LPAREN] = ACTIONS(440),
    [anon_sym_PLUS] = ACTIONS(442),
    [anon_sym_DASH] = ACTIONS(442),
    [anon_sym_TILDE] = ACTIONS(444),
    [anon_sym_BANG] = ACTIONS(444),
    [anon_sym_PLUS_PLUS] = ACTIONS(446),
    [anon_sym_DASH_DASH] = ACTIONS(446),
    [anon_sym_STAR] = ACTIONS(448),
    [anon_sym_AMP] = ACTIONS(448),
    [anon_sym_BSLASH] = ACTIONS(450),
    [anon_sym_sizeof] = ACTIONS(452),
    [anon_sym_L_SQUOTE] = ACTIONS(454),
    [anon_sym_u_SQUOTE] = ACTIONS(454),
    [anon_sym_U_SQUOTE] = ACTIONS(454),
    [anon_sym_u8_SQUOTE] = ACTIONS(454),
    [anon_sym_SQUOTE] = ACTIONS(454),
    [anon_sym_L_DQUOTE] = ACTIONS(456),
    [anon_sym_u_DQUOTE] = ACTIONS(456),
    [anon_sym_U_DQUOTE] = ACTIONS(456),
    [anon_sym_u8_DQUOTE] = ACTIONS(456),
    [anon_sym_DQUOTE] = ACTIONS(456),
    [anon_sym_const] = ACTIONS(458),
    [anon_sym_volatile] = ACTIONS(458),
    [anon_sym_struct] = ACTIONS(460),
    [anon_sym_union] = ACTIONS(462),
    [anon_sym_enum] = ACTIONS(464),
    [anon_sym_signed] = ACTIONS(466),
    [anon_sym_unsigned] = ACTIONS(466),
    [anon_sym_long] = ACTIONS(466),
    [anon_sym_short] = ACTIONS(466),
    [sym_hll_primitive_type] = ACTIONS(549),
    [aux_sym_symbol_token1] = ACTIONS(470),
    [aux_sym_symbol_token2] = ACTIONS(472),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(551),
    [sym__hll_number_literal_pre_hook] = ACTIONS(476),
  },
  [STATE(47)] = {
    [sym_trace32_hll_variable] = STATE(799),
    [sym__hll_expression] = STATE(1102),
    [sym_hll_call_expression] = STATE(798),
    [sym_hll_field_expression] = STATE(798),
    [sym_hll_subscript_expression] = STATE(798),
    [sym_hll_cast_expression] = STATE(1102),
    [sym_hll_sizeof_expression] = STATE(1102),
    [sym_hll_pointer_expression] = STATE(798),
    [sym_hll_comma_expression] = STATE(2051),
    [sym_hll_update_expression] = STATE(1102),
    [sym_hll_unary_expression] = STATE(1102),
    [sym_hll_binary_expression] = STATE(1102),
    [sym_hll_assignment_expression] = STATE(1102),
    [sym__hll_assignment_left_expression] = STATE(1652),
    [sym_hll_conditional_expression] = STATE(1102),
    [sym_hll_char_literal] = STATE(1102),
    [sym_hll_string_literal] = STATE(1102),
    [sym_hll_parenthesized_expression] = STATE(798),
    [sym_hll_type_descriptor] = STATE(2033),
    [sym_hll_type_qualifier] = STATE(1518),
    [sym__hll_type_specifier] = STATE(1534),
    [sym_hll_struct_specifier] = STATE(1534),
    [sym_hll_union_specifier] = STATE(1534),
    [sym_hll_enum_specifier] = STATE(1534),
    [sym_hll_sized_type_specifier] = STATE(1534),
    [sym__hll_type_identifier] = STATE(1534),
    [sym_symbol] = STATE(1102),
    [aux_sym_block_repeat1] = STATE(48),
    [aux_sym_hll_type_descriptor_repeat1] = STATE(1518),
    [aux_sym_hll_sized_type_specifier_repeat1] = STATE(1743),
    [sym_identifier] = ACTIONS(438),
    [anon_sym_LPAREN] = ACTIONS(440),
    [anon_sym_PLUS] = ACTIONS(442),
    [anon_sym_DASH] = ACTIONS(442),
    [anon_sym_TILDE] = ACTIONS(444),
    [anon_sym_BANG] = ACTIONS(444),
    [anon_sym_PLUS_PLUS] = ACTIONS(446),
    [anon_sym_DASH_DASH] = ACTIONS(446),
    [anon_sym_STAR] = ACTIONS(448),
    [anon_sym_AMP] = ACTIONS(448),
    [anon_sym_BSLASH] = ACTIONS(450),
    [anon_sym_sizeof] = ACTIONS(452),
    [anon_sym_L_SQUOTE] = ACTIONS(454),
    [anon_sym_u_SQUOTE] = ACTIONS(454),
    [anon_sym_U_SQUOTE] = ACTIONS(454),
    [anon_sym_u8_SQUOTE] = ACTIONS(454),
    [anon_sym_SQUOTE] = ACTIONS(454),
    [anon_sym_L_DQUOTE] = ACTIONS(456),
    [anon_sym_u_DQUOTE] = ACTIONS(456),
    [anon_sym_U_DQUOTE] = ACTIONS(456),
    [anon_sym_u8_DQUOTE] = ACTIONS(456),
    [anon_sym_DQUOTE] = ACTIONS(456),
    [anon_sym_const] = ACTIONS(458),
    [anon_sym_volatile] = ACTIONS(458),
    [anon_sym_struct] = ACTIONS(460),
    [anon_sym_union] = ACTIONS(462),
    [anon_sym_enum] = ACTIONS(464),
    [anon_sym_signed] = ACTIONS(466),
    [anon_sym_unsigned] = ACTIONS(466),
    [anon_sym_long] = ACTIONS(466),
    [anon_sym_short] = ACTIONS(466),
    [sym_hll_primitive_type] = ACTIONS(468),
    [aux_sym_symbol_token1] = ACTIONS(470),
    [aux_sym_symbol_token2] = ACTIONS(472),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(587),
    [sym__hll_number_literal_pre_hook] = ACTIONS(476),
  },
  [STATE(48)] = {
    [sym_trace32_hll_variable] = STATE(799),
    [sym__hll_expression] = STATE(1104),
    [sym_hll_call_expression] = STATE(798),
    [sym_hll_field_expression] = STATE(798),
    [sym_hll_subscript_expression] = STATE(798),
    [sym_hll_cast_expression] = STATE(1104),
    [sym_hll_sizeof_expression] = STATE(1104),
    [sym_hll_pointer_expression] = STATE(798),
    [sym_hll_comma_expression] = STATE(2060),
    [sym_hll_update_expression] = STATE(1104),
    [sym_hll_unary_expression] = STATE(1104),
    [sym_hll_binary_expression] = STATE(1104),
    [sym_hll_assignment_expression] = STATE(1104),
    [sym__hll_assignment_left_expression] = STATE(1652),
    [sym_hll_conditional_expression] = STATE(1104),
    [sym_hll_char_literal] = STATE(1104),
    [sym_hll_string_literal] = STATE(1104),
    [sym_hll_parenthesized_expression] = STATE(798),
    [sym_hll_type_descriptor] = STATE(2130),
    [sym_hll_type_qualifier] = STATE(1518),
    [sym__hll_type_specifier] = STATE(1531),
    [sym_hll_struct_specifier] = STATE(1531),
    [sym_hll_union_specifier] = STATE(1531),
    [sym_hll_enum_specifier] = STATE(1531),
    [sym_hll_sized_type_specifier] = STATE(1531),
    [sym__hll_type_identifier] = STATE(1531),
    [sym_symbol] = STATE(1104),
    [aux_sym_block_repeat1] = STATE(500),
    [aux_sym_hll_type_descriptor_repeat1] = STATE(1518),
    [aux_sym_hll_sized_type_specifier_repeat1] = STATE(1743),
    [sym_identifier] = ACTIONS(438),
    [anon_sym_LPAREN] = ACTIONS(440),
    [anon_sym_PLUS] = ACTIONS(442),
    [anon_sym_DASH] = ACTIONS(442),
    [anon_sym_TILDE] = ACTIONS(444),
    [anon_sym_BANG] = ACTIONS(444),
    [anon_sym_PLUS_PLUS] = ACTIONS(446),
    [anon_sym_DASH_DASH] = ACTIONS(446),
    [anon_sym_STAR] = ACTIONS(448),
    [anon_sym_AMP] = ACTIONS(448),
    [anon_sym_BSLASH] = ACTIONS(450),
    [anon_sym_sizeof] = ACTIONS(452),
    [anon_sym_L_SQUOTE] = ACTIONS(454),
    [anon_sym_u_SQUOTE] = ACTIONS(454),
    [anon_sym_U_SQUOTE] = ACTIONS(454),
    [anon_sym_u8_SQUOTE] = ACTIONS(454),
    [anon_sym_SQUOTE] = ACTIONS(454),
    [anon_sym_L_DQUOTE] = ACTIONS(456),
    [anon_sym_u_DQUOTE] = ACTIONS(456),
    [anon_sym_U_DQUOTE] = ACTIONS(456),
    [anon_sym_u8_DQUOTE] = ACTIONS(456),
    [anon_sym_DQUOTE] = ACTIONS(456),
    [anon_sym_const] = ACTIONS(458),
    [anon_sym_volatile] = ACTIONS(458),
    [anon_sym_struct] = ACTIONS(460),
    [anon_sym_union] = ACTIONS(462),
    [anon_sym_enum] = ACTIONS(464),
    [anon_sym_signed] = ACTIONS(466),
    [anon_sym_unsigned] = ACTIONS(466),
    [anon_sym_long] = ACTIONS(466),
    [anon_sym_short] = ACTIONS(466),
    [sym_hll_primitive_type] = ACTIONS(549),
    [aux_sym_symbol_token1] = ACTIONS(470),
    [aux_sym_symbol_token2] = ACTIONS(472),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(551),
    [sym__hll_number_literal_pre_hook] = ACTIONS(476),
  },
  [STATE(49)] = {
    [sym_trace32_hll_variable] = STATE(799),
    [sym__hll_expression] = STATE(1083),
    [sym_hll_call_expression] = STATE(798),
    [sym_hll_field_expression] = STATE(798),
    [sym_hll_subscript_expression] = STATE(798),
    [sym_hll_cast_expression] = STATE(1083),
    [sym_hll_sizeof_expression] = STATE(1083),
    [sym_hll_pointer_expression] = STATE(798),
    [sym_hll_comma_expression] = STATE(2154),
    [sym_hll_update_expression] = STATE(1083),
    [sym_hll_unary_expression] = STATE(1083),
    [sym_hll_binary_expression] = STATE(1083),
    [sym_hll_assignment_expression] = STATE(1083),
    [sym__hll_assignment_left_expression] = STATE(1652),
    [sym_hll_conditional_expression] = STATE(1083),
    [sym_hll_char_literal] = STATE(1083),
    [sym_hll_string_literal] = STATE(1083),
    [sym_hll_parenthesized_expression] = STATE(798),
    [sym_hll_type_descriptor] = STATE(2161),
    [sym_hll_type_qualifier] = STATE(1518),
    [sym__hll_type_specifier] = STATE(1534),
    [sym_hll_struct_specifier] = STATE(1534),
    [sym_hll_union_specifier] = STATE(1534),
    [sym_hll_enum_specifier] = STATE(1534),
    [sym_hll_sized_type_specifier] = STATE(1534),
    [sym__hll_type_identifier] = STATE(1534),
    [sym_symbol] = STATE(1083),
    [aux_sym_block_repeat1] = STATE(50),
    [aux_sym_hll_type_descriptor_repeat1] = STATE(1518),
    [aux_sym_hll_sized_type_specifier_repeat1] = STATE(1743),
    [sym_identifier] = ACTIONS(438),
    [anon_sym_LPAREN] = ACTIONS(440),
    [anon_sym_PLUS] = ACTIONS(442),
    [anon_sym_DASH] = ACTIONS(442),
    [anon_sym_TILDE] = ACTIONS(444),
    [anon_sym_BANG] = ACTIONS(444),
    [anon_sym_PLUS_PLUS] = ACTIONS(446),
    [anon_sym_DASH_DASH] = ACTIONS(446),
    [anon_sym_STAR] = ACTIONS(448),
    [anon_sym_AMP] = ACTIONS(448),
    [anon_sym_BSLASH] = ACTIONS(450),
    [anon_sym_sizeof] = ACTIONS(452),
    [anon_sym_L_SQUOTE] = ACTIONS(454),
    [anon_sym_u_SQUOTE] = ACTIONS(454),
    [anon_sym_U_SQUOTE] = ACTIONS(454),
    [anon_sym_u8_SQUOTE] = ACTIONS(454),
    [anon_sym_SQUOTE] = ACTIONS(454),
    [anon_sym_L_DQUOTE] = ACTIONS(456),
    [anon_sym_u_DQUOTE] = ACTIONS(456),
    [anon_sym_U_DQUOTE] = ACTIONS(456),
    [anon_sym_u8_DQUOTE] = ACTIONS(456),
    [anon_sym_DQUOTE] = ACTIONS(456),
    [anon_sym_const] = ACTIONS(458),
    [anon_sym_volatile] = ACTIONS(458),
    [anon_sym_struct] = ACTIONS(460),
    [anon_sym_union] = ACTIONS(462),
    [anon_sym_enum] = ACTIONS(464),
    [anon_sym_signed] = ACTIONS(466),
    [anon_sym_unsigned] = ACTIONS(466),
    [anon_sym_long] = ACTIONS(466),
    [anon_sym_short] = ACTIONS(466),
    [sym_hll_primitive_type] = ACTIONS(468),
    [aux_sym_symbol_token1] = ACTIONS(470),
    [aux_sym_symbol_token2] = ACTIONS(472),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(589),
    [sym__hll_number_literal_pre_hook] = ACTIONS(476),
  },
  [STATE(50)] = {
    [sym_trace32_hll_variable] = STATE(799),
    [sym__hll_expression] = STATE(1086),
    [sym_hll_call_expression] = STATE(798),
    [sym_hll_field_expression] = STATE(798),
    [sym_hll_subscript_expression] = STATE(798),
    [sym_hll_cast_expression] = STATE(1086),
    [sym_hll_sizeof_expression] = STATE(1086),
    [sym_hll_pointer_expression] = STATE(798),
    [sym_hll_comma_expression] = STATE(2081),
    [sym_hll_update_expression] = STATE(1086),
    [sym_hll_unary_expression] = STATE(1086),
    [sym_hll_binary_expression] = STATE(1086),
    [sym_hll_assignment_expression] = STATE(1086),
    [sym__hll_assignment_left_expression] = STATE(1652),
    [sym_hll_conditional_expression] = STATE(1086),
    [sym_hll_char_literal] = STATE(1086),
    [sym_hll_string_literal] = STATE(1086),
    [sym_hll_parenthesized_expression] = STATE(798),
    [sym_hll_type_descriptor] = STATE(2083),
    [sym_hll_type_qualifier] = STATE(1518),
    [sym__hll_type_specifier] = STATE(1531),
    [sym_hll_struct_specifier] = STATE(1531),
    [sym_hll_union_specifier] = STATE(1531),
    [sym_hll_enum_specifier] = STATE(1531),
    [sym_hll_sized_type_specifier] = STATE(1531),
    [sym__hll_type_identifier] = STATE(1531),
    [sym_symbol] = STATE(1086),
    [aux_sym_block_repeat1] = STATE(500),
    [aux_sym_hll_type_descriptor_repeat1] = STATE(1518),
    [aux_sym_hll_sized_type_specifier_repeat1] = STATE(1743),
    [sym_identifier] = ACTIONS(438),
    [anon_sym_LPAREN] = ACTIONS(440),
    [anon_sym_PLUS] = ACTIONS(442),
    [anon_sym_DASH] = ACTIONS(442),
    [anon_sym_TILDE] = ACTIONS(444),
    [anon_sym_BANG] = ACTIONS(444),
    [anon_sym_PLUS_PLUS] = ACTIONS(446),
    [anon_sym_DASH_DASH] = ACTIONS(446),
    [anon_sym_STAR] = ACTIONS(448),
    [anon_sym_AMP] = ACTIONS(448),
    [anon_sym_BSLASH] = ACTIONS(450),
    [anon_sym_sizeof] = ACTIONS(452),
    [anon_sym_L_SQUOTE] = ACTIONS(454),
    [anon_sym_u_SQUOTE] = ACTIONS(454),
    [anon_sym_U_SQUOTE] = ACTIONS(454),
    [anon_sym_u8_SQUOTE] = ACTIONS(454),
    [anon_sym_SQUOTE] = ACTIONS(454),
    [anon_sym_L_DQUOTE] = ACTIONS(456),
    [anon_sym_u_DQUOTE] = ACTIONS(456),
    [anon_sym_U_DQUOTE] = ACTIONS(456),
    [anon_sym_u8_DQUOTE] = ACTIONS(456),
    [anon_sym_DQUOTE] = ACTIONS(456),
    [anon_sym_const] = ACTIONS(458),
    [anon_sym_volatile] = ACTIONS(458),
    [anon_sym_struct] = ACTIONS(460),
    [anon_sym_union] = ACTIONS(462),
    [anon_sym_enum] = ACTIONS(464),
    [anon_sym_signed] = ACTIONS(466),
    [anon_sym_unsigned] = ACTIONS(466),
    [anon_sym_long] = ACTIONS(466),
    [anon_sym_short] = ACTIONS(466),
    [sym_hll_primitive_type] = ACTIONS(549),
    [aux_sym_symbol_token1] = ACTIONS(470),
    [aux_sym_symbol_token2] = ACTIONS(472),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(551),
    [sym__hll_number_literal_pre_hook] = ACTIONS(476),
  },
  [STATE(51)] = {
    [sym_trace32_hll_variable] = STATE(799),
    [sym__hll_expression] = STATE(1082),
    [sym_hll_call_expression] = STATE(798),
    [sym_hll_field_expression] = STATE(798),
    [sym_hll_subscript_expression] = STATE(798),
    [sym_hll_cast_expression] = STATE(1082),
    [sym_hll_sizeof_expression] = STATE(1082),
    [sym_hll_pointer_expression] = STATE(798),
    [sym_hll_comma_expression] = STATE(2149),
    [sym_hll_update_expression] = STATE(1082),
    [sym_hll_unary_expression] = STATE(1082),
    [sym_hll_binary_expression] = STATE(1082),
    [sym_hll_assignment_expression] = STATE(1082),
    [sym__hll_assignment_left_expression] = STATE(1652),
    [sym_hll_conditional_expression] = STATE(1082),
    [sym_hll_char_literal] = STATE(1082),
    [sym_hll_string_literal] = STATE(1082),
    [sym_hll_parenthesized_expression] = STATE(798),
    [sym_hll_type_descriptor] = STATE(2062),
    [sym_hll_type_qualifier] = STATE(1518),
    [sym__hll_type_specifier] = STATE(1534),
    [sym_hll_struct_specifier] = STATE(1534),
    [sym_hll_union_specifier] = STATE(1534),
    [sym_hll_enum_specifier] = STATE(1534),
    [sym_hll_sized_type_specifier] = STATE(1534),
    [sym__hll_type_identifier] = STATE(1534),
    [sym_symbol] = STATE(1082),
    [aux_sym_block_repeat1] = STATE(52),
    [aux_sym_hll_type_descriptor_repeat1] = STATE(1518),
    [aux_sym_hll_sized_type_specifier_repeat1] = STATE(1743),
    [sym_identifier] = ACTIONS(438),
    [anon_sym_LPAREN] = ACTIONS(440),
    [anon_sym_PLUS] = ACTIONS(442),
    [anon_sym_DASH] = ACTIONS(442),
    [anon_sym_TILDE] = ACTIONS(444),
    [anon_sym_BANG] = ACTIONS(444),
    [anon_sym_PLUS_PLUS] = ACTIONS(446),
    [anon_sym_DASH_DASH] = ACTIONS(446),
    [anon_sym_STAR] = ACTIONS(448),
    [anon_sym_AMP] = ACTIONS(448),
    [anon_sym_BSLASH] = ACTIONS(450),
    [anon_sym_sizeof] = ACTIONS(452),
    [anon_sym_L_SQUOTE] = ACTIONS(454),
    [anon_sym_u_SQUOTE] = ACTIONS(454),
    [anon_sym_U_SQUOTE] = ACTIONS(454),
    [anon_sym_u8_SQUOTE] = ACTIONS(454),
    [anon_sym_SQUOTE] = ACTIONS(454),
    [anon_sym_L_DQUOTE] = ACTIONS(456),
    [anon_sym_u_DQUOTE] = ACTIONS(456),
    [anon_sym_U_DQUOTE] = ACTIONS(456),
    [anon_sym_u8_DQUOTE] = ACTIONS(456),
    [anon_sym_DQUOTE] = ACTIONS(456),
    [anon_sym_const] = ACTIONS(458),
    [anon_sym_volatile] = ACTIONS(458),
    [anon_sym_struct] = ACTIONS(460),
    [anon_sym_union] = ACTIONS(462),
    [anon_sym_enum] = ACTIONS(464),
    [anon_sym_signed] = ACTIONS(466),
    [anon_sym_unsigned] = ACTIONS(466),
    [anon_sym_long] = ACTIONS(466),
    [anon_sym_short] = ACTIONS(466),
    [sym_hll_primitive_type] = ACTIONS(468),
    [aux_sym_symbol_token1] = ACTIONS(470),
    [aux_sym_symbol_token2] = ACTIONS(472),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(591),
    [sym__hll_number_literal_pre_hook] = ACTIONS(476),
  },
  [STATE(52)] = {
    [sym_trace32_hll_variable] = STATE(799),
    [sym__hll_expression] = STATE(1057),
    [sym_hll_call_expression] = STATE(798),
    [sym_hll_field_expression] = STATE(798),
    [sym_hll_subscript_expression] = STATE(798),
    [sym_hll_cast_expression] = STATE(1057),
    [sym_hll_sizeof_expression] = STATE(1057),
    [sym_hll_pointer_expression] = STATE(798),
    [sym_hll_comma_expression] = STATE(2179),
    [sym_hll_update_expression] = STATE(1057),
    [sym_hll_unary_expression] = STATE(1057),
    [sym_hll_binary_expression] = STATE(1057),
    [sym_hll_assignment_expression] = STATE(1057),
    [sym__hll_assignment_left_expression] = STATE(1652),
    [sym_hll_conditional_expression] = STATE(1057),
    [sym_hll_char_literal] = STATE(1057),
    [sym_hll_string_literal] = STATE(1057),
    [sym_hll_parenthesized_expression] = STATE(798),
    [sym_hll_type_descriptor] = STATE(2067),
    [sym_hll_type_qualifier] = STATE(1518),
    [sym__hll_type_specifier] = STATE(1531),
    [sym_hll_struct_specifier] = STATE(1531),
    [sym_hll_union_specifier] = STATE(1531),
    [sym_hll_enum_specifier] = STATE(1531),
    [sym_hll_sized_type_specifier] = STATE(1531),
    [sym__hll_type_identifier] = STATE(1531),
    [sym_symbol] = STATE(1057),
    [aux_sym_block_repeat1] = STATE(500),
    [aux_sym_hll_type_descriptor_repeat1] = STATE(1518),
    [aux_sym_hll_sized_type_specifier_repeat1] = STATE(1743),
    [sym_identifier] = ACTIONS(438),
    [anon_sym_LPAREN] = ACTIONS(440),
    [anon_sym_PLUS] = ACTIONS(442),
    [anon_sym_DASH] = ACTIONS(442),
    [anon_sym_TILDE] = ACTIONS(444),
    [anon_sym_BANG] = ACTIONS(444),
    [anon_sym_PLUS_PLUS] = ACTIONS(446),
    [anon_sym_DASH_DASH] = ACTIONS(446),
    [anon_sym_STAR] = ACTIONS(448),
    [anon_sym_AMP] = ACTIONS(448),
    [anon_sym_BSLASH] = ACTIONS(450),
    [anon_sym_sizeof] = ACTIONS(452),
    [anon_sym_L_SQUOTE] = ACTIONS(454),
    [anon_sym_u_SQUOTE] = ACTIONS(454),
    [anon_sym_U_SQUOTE] = ACTIONS(454),
    [anon_sym_u8_SQUOTE] = ACTIONS(454),
    [anon_sym_SQUOTE] = ACTIONS(454),
    [anon_sym_L_DQUOTE] = ACTIONS(456),
    [anon_sym_u_DQUOTE] = ACTIONS(456),
    [anon_sym_U_DQUOTE] = ACTIONS(456),
    [anon_sym_u8_DQUOTE] = ACTIONS(456),
    [anon_sym_DQUOTE] = ACTIONS(456),
    [anon_sym_const] = ACTIONS(458),
    [anon_sym_volatile] = ACTIONS(458),
    [anon_sym_struct] = ACTIONS(460),
    [anon_sym_union] = ACTIONS(462),
    [anon_sym_enum] = ACTIONS(464),
    [anon_sym_signed] = ACTIONS(466),
    [anon_sym_unsigned] = ACTIONS(466),
    [anon_sym_long] = ACTIONS(466),
    [anon_sym_short] = ACTIONS(466),
    [sym_hll_primitive_type] = ACTIONS(549),
    [aux_sym_symbol_token1] = ACTIONS(470),
    [aux_sym_symbol_token2] = ACTIONS(472),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(551),
    [sym__hll_number_literal_pre_hook] = ACTIONS(476),
  },
  [STATE(53)] = {
    [sym_trace32_hll_variable] = STATE(799),
    [sym__hll_expression] = STATE(1083),
    [sym_hll_call_expression] = STATE(798),
    [sym_hll_field_expression] = STATE(798),
    [sym_hll_subscript_expression] = STATE(798),
    [sym_hll_cast_expression] = STATE(1083),
    [sym_hll_sizeof_expression] = STATE(1083),
    [sym_hll_pointer_expression] = STATE(798),
    [sym_hll_comma_expression] = STATE(2154),
    [sym_hll_update_expression] = STATE(1083),
    [sym_hll_unary_expression] = STATE(1083),
    [sym_hll_binary_expression] = STATE(1083),
    [sym_hll_assignment_expression] = STATE(1083),
    [sym__hll_assignment_left_expression] = STATE(1652),
    [sym_hll_conditional_expression] = STATE(1083),
    [sym_hll_char_literal] = STATE(1083),
    [sym_hll_string_literal] = STATE(1083),
    [sym_hll_parenthesized_expression] = STATE(798),
    [sym_hll_type_descriptor] = STATE(2086),
    [sym_hll_type_qualifier] = STATE(1518),
    [sym__hll_type_specifier] = STATE(1534),
    [sym_hll_struct_specifier] = STATE(1534),
    [sym_hll_union_specifier] = STATE(1534),
    [sym_hll_enum_specifier] = STATE(1534),
    [sym_hll_sized_type_specifier] = STATE(1534),
    [sym__hll_type_identifier] = STATE(1534),
    [sym_symbol] = STATE(1083),
    [aux_sym_block_repeat1] = STATE(54),
    [aux_sym_hll_type_descriptor_repeat1] = STATE(1518),
    [aux_sym_hll_sized_type_specifier_repeat1] = STATE(1743),
    [sym_identifier] = ACTIONS(438),
    [anon_sym_LPAREN] = ACTIONS(440),
    [anon_sym_PLUS] = ACTIONS(442),
    [anon_sym_DASH] = ACTIONS(442),
    [anon_sym_TILDE] = ACTIONS(444),
    [anon_sym_BANG] = ACTIONS(444),
    [anon_sym_PLUS_PLUS] = ACTIONS(446),
    [anon_sym_DASH_DASH] = ACTIONS(446),
    [anon_sym_STAR] = ACTIONS(448),
    [anon_sym_AMP] = ACTIONS(448),
    [anon_sym_BSLASH] = ACTIONS(450),
    [anon_sym_sizeof] = ACTIONS(452),
    [anon_sym_L_SQUOTE] = ACTIONS(454),
    [anon_sym_u_SQUOTE] = ACTIONS(454),
    [anon_sym_U_SQUOTE] = ACTIONS(454),
    [anon_sym_u8_SQUOTE] = ACTIONS(454),
    [anon_sym_SQUOTE] = ACTIONS(454),
    [anon_sym_L_DQUOTE] = ACTIONS(456),
    [anon_sym_u_DQUOTE] = ACTIONS(456),
    [anon_sym_U_DQUOTE] = ACTIONS(456),
    [anon_sym_u8_DQUOTE] = ACTIONS(456),
    [anon_sym_DQUOTE] = ACTIONS(456),
    [anon_sym_const] = ACTIONS(458),
    [anon_sym_volatile] = ACTIONS(458),
    [anon_sym_struct] = ACTIONS(460),
    [anon_sym_union] = ACTIONS(462),
    [anon_sym_enum] = ACTIONS(464),
    [anon_sym_signed] = ACTIONS(466),
    [anon_sym_unsigned] = ACTIONS(466),
    [anon_sym_long] = ACTIONS(466),
    [anon_sym_short] = ACTIONS(466),
    [sym_hll_primitive_type] = ACTIONS(468),
    [aux_sym_symbol_token1] = ACTIONS(470),
    [aux_sym_symbol_token2] = ACTIONS(472),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(593),
    [sym__hll_number_literal_pre_hook] = ACTIONS(476),
  },
  [STATE(54)] = {
    [sym_trace32_hll_variable] = STATE(799),
    [sym__hll_expression] = STATE(1086),
    [sym_hll_call_expression] = STATE(798),
    [sym_hll_field_expression] = STATE(798),
    [sym_hll_subscript_expression] = STATE(798),
    [sym_hll_cast_expression] = STATE(1086),
    [sym_hll_sizeof_expression] = STATE(1086),
    [sym_hll_pointer_expression] = STATE(798),
    [sym_hll_comma_expression] = STATE(2081),
    [sym_hll_update_expression] = STATE(1086),
    [sym_hll_unary_expression] = STATE(1086),
    [sym_hll_binary_expression] = STATE(1086),
    [sym_hll_assignment_expression] = STATE(1086),
    [sym__hll_assignment_left_expression] = STATE(1652),
    [sym_hll_conditional_expression] = STATE(1086),
    [sym_hll_char_literal] = STATE(1086),
    [sym_hll_string_literal] = STATE(1086),
    [sym_hll_parenthesized_expression] = STATE(798),
    [sym_hll_type_descriptor] = STATE(2090),
    [sym_hll_type_qualifier] = STATE(1518),
    [sym__hll_type_specifier] = STATE(1531),
    [sym_hll_struct_specifier] = STATE(1531),
    [sym_hll_union_specifier] = STATE(1531),
    [sym_hll_enum_specifier] = STATE(1531),
    [sym_hll_sized_type_specifier] = STATE(1531),
    [sym__hll_type_identifier] = STATE(1531),
    [sym_symbol] = STATE(1086),
    [aux_sym_block_repeat1] = STATE(500),
    [aux_sym_hll_type_descriptor_repeat1] = STATE(1518),
    [aux_sym_hll_sized_type_specifier_repeat1] = STATE(1743),
    [sym_identifier] = ACTIONS(438),
    [anon_sym_LPAREN] = ACTIONS(440),
    [anon_sym_PLUS] = ACTIONS(442),
    [anon_sym_DASH] = ACTIONS(442),
    [anon_sym_TILDE] = ACTIONS(444),
    [anon_sym_BANG] = ACTIONS(444),
    [anon_sym_PLUS_PLUS] = ACTIONS(446),
    [anon_sym_DASH_DASH] = ACTIONS(446),
    [anon_sym_STAR] = ACTIONS(448),
    [anon_sym_AMP] = ACTIONS(448),
    [anon_sym_BSLASH] = ACTIONS(450),
    [anon_sym_sizeof] = ACTIONS(452),
    [anon_sym_L_SQUOTE] = ACTIONS(454),
    [anon_sym_u_SQUOTE] = ACTIONS(454),
    [anon_sym_U_SQUOTE] = ACTIONS(454),
    [anon_sym_u8_SQUOTE] = ACTIONS(454),
    [anon_sym_SQUOTE] = ACTIONS(454),
    [anon_sym_L_DQUOTE] = ACTIONS(456),
    [anon_sym_u_DQUOTE] = ACTIONS(456),
    [anon_sym_U_DQUOTE] = ACTIONS(456),
    [anon_sym_u8_DQUOTE] = ACTIONS(456),
    [anon_sym_DQUOTE] = ACTIONS(456),
    [anon_sym_const] = ACTIONS(458),
    [anon_sym_volatile] = ACTIONS(458),
    [anon_sym_struct] = ACTIONS(460),
    [anon_sym_union] = ACTIONS(462),
    [anon_sym_enum] = ACTIONS(464),
    [anon_sym_signed] = ACTIONS(466),
    [anon_sym_unsigned] = ACTIONS(466),
    [anon_sym_long] = ACTIONS(466),
    [anon_sym_short] = ACTIONS(466),
    [sym_hll_primitive_type] = ACTIONS(549),
    [aux_sym_symbol_token1] = ACTIONS(470),
    [aux_sym_symbol_token2] = ACTIONS(472),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(551),
    [sym__hll_number_literal_pre_hook] = ACTIONS(476),
  },
  [STATE(55)] = {
    [sym_trace32_hll_variable] = STATE(799),
    [sym__hll_expression] = STATE(1093),
    [sym_hll_call_expression] = STATE(798),
    [sym_hll_field_expression] = STATE(798),
    [sym_hll_subscript_expression] = STATE(798),
    [sym_hll_cast_expression] = STATE(1093),
    [sym_hll_sizeof_expression] = STATE(1093),
    [sym_hll_pointer_expression] = STATE(798),
    [sym_hll_comma_expression] = STATE(2204),
    [sym_hll_update_expression] = STATE(1093),
    [sym_hll_unary_expression] = STATE(1093),
    [sym_hll_binary_expression] = STATE(1093),
    [sym_hll_assignment_expression] = STATE(1093),
    [sym__hll_assignment_left_expression] = STATE(1652),
    [sym_hll_conditional_expression] = STATE(1093),
    [sym_hll_char_literal] = STATE(1093),
    [sym_hll_string_literal] = STATE(1093),
    [sym_hll_parenthesized_expression] = STATE(798),
    [sym_hll_type_descriptor] = STATE(2101),
    [sym_hll_type_qualifier] = STATE(1518),
    [sym__hll_type_specifier] = STATE(1534),
    [sym_hll_struct_specifier] = STATE(1534),
    [sym_hll_union_specifier] = STATE(1534),
    [sym_hll_enum_specifier] = STATE(1534),
    [sym_hll_sized_type_specifier] = STATE(1534),
    [sym__hll_type_identifier] = STATE(1534),
    [sym_symbol] = STATE(1093),
    [aux_sym_block_repeat1] = STATE(81),
    [aux_sym_hll_type_descriptor_repeat1] = STATE(1518),
    [aux_sym_hll_sized_type_specifier_repeat1] = STATE(1743),
    [sym_identifier] = ACTIONS(438),
    [anon_sym_LPAREN] = ACTIONS(440),
    [anon_sym_PLUS] = ACTIONS(442),
    [anon_sym_DASH] = ACTIONS(442),
    [anon_sym_TILDE] = ACTIONS(444),
    [anon_sym_BANG] = ACTIONS(444),
    [anon_sym_PLUS_PLUS] = ACTIONS(446),
    [anon_sym_DASH_DASH] = ACTIONS(446),
    [anon_sym_STAR] = ACTIONS(448),
    [anon_sym_AMP] = ACTIONS(448),
    [anon_sym_BSLASH] = ACTIONS(450),
    [anon_sym_sizeof] = ACTIONS(452),
    [anon_sym_L_SQUOTE] = ACTIONS(454),
    [anon_sym_u_SQUOTE] = ACTIONS(454),
    [anon_sym_U_SQUOTE] = ACTIONS(454),
    [anon_sym_u8_SQUOTE] = ACTIONS(454),
    [anon_sym_SQUOTE] = ACTIONS(454),
    [anon_sym_L_DQUOTE] = ACTIONS(456),
    [anon_sym_u_DQUOTE] = ACTIONS(456),
    [anon_sym_U_DQUOTE] = ACTIONS(456),
    [anon_sym_u8_DQUOTE] = ACTIONS(456),
    [anon_sym_DQUOTE] = ACTIONS(456),
    [anon_sym_const] = ACTIONS(458),
    [anon_sym_volatile] = ACTIONS(458),
    [anon_sym_struct] = ACTIONS(460),
    [anon_sym_union] = ACTIONS(462),
    [anon_sym_enum] = ACTIONS(464),
    [anon_sym_signed] = ACTIONS(466),
    [anon_sym_unsigned] = ACTIONS(466),
    [anon_sym_long] = ACTIONS(466),
    [anon_sym_short] = ACTIONS(466),
    [sym_hll_primitive_type] = ACTIONS(468),
    [aux_sym_symbol_token1] = ACTIONS(470),
    [aux_sym_symbol_token2] = ACTIONS(472),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(595),
    [sym__hll_number_literal_pre_hook] = ACTIONS(476),
  },
  [STATE(56)] = {
    [sym__expression] = STATE(1139),
    [sym__parenthesized_expression] = STATE(1139),
    [sym__path_expression] = STATE(1139),
    [sym_unary_expression] = STATE(1139),
    [sym__unary_expression] = STATE(1378),
    [sym__prefix_postfix_expression] = STATE(1392),
    [sym_binary_expression] = STATE(1139),
    [sym__binary_expression] = STATE(1394),
    [sym__and_expression] = STATE(1371),
    [sym_assignment_expression] = STATE(1139),
    [sym_macro] = STATE(980),
    [sym__command_argument] = STATE(1826),
    [sym_format_expression] = STATE(1826),
    [sym_call_expression] = STATE(1060),
    [sym__function_identifier] = STATE(2349),
    [sym__hll_var_call_expression_function] = STATE(2359),
    [sym__hll_var_call_expression] = STATE(1061),
    [sym_trace32_hll_variable] = STATE(1377),
    [sym__literal] = STATE(1139),
    [sym__address_expression] = STATE(1575),
    [sym_memory_space] = STATE(228),
    [sym_address] = STATE(1139),
    [sym__parenthesized_address_expression] = STATE(1575),
    [sym__address_binary_expression] = STATE(1550),
    [sym_integer] = STATE(1080),
    [sym_bitmask] = STATE(1139),
    [sym_string] = STATE(1139),
    [sym_character] = STATE(1139),
    [sym_symbol] = STATE(1139),
    [sym__special_command_operator] = STATE(1139),
    [sym__file_dialog] = STATE(1374),
    [aux_sym__path_expression_repeat1] = STATE(1172),
    [aux_sym__path_expression_repeat2] = STATE(1100),
    [aux_sym__command_arguments_repeat1] = STATE(33),
    [sym_identifier] = ACTIONS(179),
    [anon_sym_LPAREN] = ACTIONS(181),
    [anon_sym_LBRACE] = ACTIONS(183),
    [anon_sym_PLUS] = ACTIONS(185),
    [anon_sym_DASH] = ACTIONS(185),
    [anon_sym_TILDE] = ACTIONS(187),
    [anon_sym_BANG] = ACTIONS(187),
    [anon_sym_PLUS_PLUS] = ACTIONS(189),
    [anon_sym_DASH_DASH] = ACTIONS(189),
    [anon_sym_STAR] = ACTIONS(191),
    [anon_sym_PERCENT] = ACTIONS(422),
    [anon_sym_AMP] = ACTIONS(147),
    [anon_sym_COMMA] = ACTIONS(597),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(120),
    [anon_sym_BSLASH] = ACTIONS(193),
    [anon_sym_SQUOTE] = ACTIONS(195),
    [anon_sym_DQUOTE] = ACTIONS(197),
    [sym_access_class] = ACTIONS(199),
    [aux_sym_integer_token1] = ACTIONS(149),
    [aux_sym_integer_token2] = ACTIONS(149),
    [sym_float] = ACTIONS(426),
    [aux_sym_bitmask_token1] = ACTIONS(203),
    [aux_sym_bitmask_token2] = ACTIONS(203),
    [aux_sym_symbol_token1] = ACTIONS(205),
    [aux_sym_symbol_token2] = ACTIONS(207),
    [sym__composed_name] = ACTIONS(428),
    [sym_time] = ACTIONS(426),
    [sym_frequency] = ACTIONS(426),
    [sym_percentage] = ACTIONS(428),
    [sym_file_handle] = ACTIONS(428),
    [sym__line_continuation] = ACTIONS(3),
    [sym__decimal_number_pre_hook] = ACTIONS(155),
    [sym_path] = ACTIONS(211),
  },
  [STATE(57)] = {
    [sym_trace32_hll_variable] = STATE(799),
    [sym__hll_expression] = STATE(1102),
    [sym_hll_call_expression] = STATE(798),
    [sym_hll_field_expression] = STATE(798),
    [sym_hll_subscript_expression] = STATE(798),
    [sym_hll_cast_expression] = STATE(1102),
    [sym_hll_sizeof_expression] = STATE(1102),
    [sym_hll_pointer_expression] = STATE(798),
    [sym_hll_comma_expression] = STATE(2051),
    [sym_hll_update_expression] = STATE(1102),
    [sym_hll_unary_expression] = STATE(1102),
    [sym_hll_binary_expression] = STATE(1102),
    [sym_hll_assignment_expression] = STATE(1102),
    [sym__hll_assignment_left_expression] = STATE(1652),
    [sym_hll_conditional_expression] = STATE(1102),
    [sym_hll_char_literal] = STATE(1102),
    [sym_hll_string_literal] = STATE(1102),
    [sym_hll_parenthesized_expression] = STATE(798),
    [sym_hll_type_descriptor] = STATE(2138),
    [sym_hll_type_qualifier] = STATE(1518),
    [sym__hll_type_specifier] = STATE(1534),
    [sym_hll_struct_specifier] = STATE(1534),
    [sym_hll_union_specifier] = STATE(1534),
    [sym_hll_enum_specifier] = STATE(1534),
    [sym_hll_sized_type_specifier] = STATE(1534),
    [sym__hll_type_identifier] = STATE(1534),
    [sym_symbol] = STATE(1102),
    [aux_sym_block_repeat1] = STATE(58),
    [aux_sym_hll_type_descriptor_repeat1] = STATE(1518),
    [aux_sym_hll_sized_type_specifier_repeat1] = STATE(1743),
    [sym_identifier] = ACTIONS(438),
    [anon_sym_LPAREN] = ACTIONS(440),
    [anon_sym_PLUS] = ACTIONS(442),
    [anon_sym_DASH] = ACTIONS(442),
    [anon_sym_TILDE] = ACTIONS(444),
    [anon_sym_BANG] = ACTIONS(444),
    [anon_sym_PLUS_PLUS] = ACTIONS(446),
    [anon_sym_DASH_DASH] = ACTIONS(446),
    [anon_sym_STAR] = ACTIONS(448),
    [anon_sym_AMP] = ACTIONS(448),
    [anon_sym_BSLASH] = ACTIONS(450),
    [anon_sym_sizeof] = ACTIONS(452),
    [anon_sym_L_SQUOTE] = ACTIONS(454),
    [anon_sym_u_SQUOTE] = ACTIONS(454),
    [anon_sym_U_SQUOTE] = ACTIONS(454),
    [anon_sym_u8_SQUOTE] = ACTIONS(454),
    [anon_sym_SQUOTE] = ACTIONS(454),
    [anon_sym_L_DQUOTE] = ACTIONS(456),
    [anon_sym_u_DQUOTE] = ACTIONS(456),
    [anon_sym_U_DQUOTE] = ACTIONS(456),
    [anon_sym_u8_DQUOTE] = ACTIONS(456),
    [anon_sym_DQUOTE] = ACTIONS(456),
    [anon_sym_const] = ACTIONS(458),
    [anon_sym_volatile] = ACTIONS(458),
    [anon_sym_struct] = ACTIONS(460),
    [anon_sym_union] = ACTIONS(462),
    [anon_sym_enum] = ACTIONS(464),
    [anon_sym_signed] = ACTIONS(466),
    [anon_sym_unsigned] = ACTIONS(466),
    [anon_sym_long] = ACTIONS(466),
    [anon_sym_short] = ACTIONS(466),
    [sym_hll_primitive_type] = ACTIONS(468),
    [aux_sym_symbol_token1] = ACTIONS(470),
    [aux_sym_symbol_token2] = ACTIONS(472),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(599),
    [sym__hll_number_literal_pre_hook] = ACTIONS(476),
  },
  [STATE(58)] = {
    [sym_trace32_hll_variable] = STATE(799),
    [sym__hll_expression] = STATE(1104),
    [sym_hll_call_expression] = STATE(798),
    [sym_hll_field_expression] = STATE(798),
    [sym_hll_subscript_expression] = STATE(798),
    [sym_hll_cast_expression] = STATE(1104),
    [sym_hll_sizeof_expression] = STATE(1104),
    [sym_hll_pointer_expression] = STATE(798),
    [sym_hll_comma_expression] = STATE(2060),
    [sym_hll_update_expression] = STATE(1104),
    [sym_hll_unary_expression] = STATE(1104),
    [sym_hll_binary_expression] = STATE(1104),
    [sym_hll_assignment_expression] = STATE(1104),
    [sym__hll_assignment_left_expression] = STATE(1652),
    [sym_hll_conditional_expression] = STATE(1104),
    [sym_hll_char_literal] = STATE(1104),
    [sym_hll_string_literal] = STATE(1104),
    [sym_hll_parenthesized_expression] = STATE(798),
    [sym_hll_type_descriptor] = STATE(2141),
    [sym_hll_type_qualifier] = STATE(1518),
    [sym__hll_type_specifier] = STATE(1531),
    [sym_hll_struct_specifier] = STATE(1531),
    [sym_hll_union_specifier] = STATE(1531),
    [sym_hll_enum_specifier] = STATE(1531),
    [sym_hll_sized_type_specifier] = STATE(1531),
    [sym__hll_type_identifier] = STATE(1531),
    [sym_symbol] = STATE(1104),
    [aux_sym_block_repeat1] = STATE(500),
    [aux_sym_hll_type_descriptor_repeat1] = STATE(1518),
    [aux_sym_hll_sized_type_specifier_repeat1] = STATE(1743),
    [sym_identifier] = ACTIONS(438),
    [anon_sym_LPAREN] = ACTIONS(440),
    [anon_sym_PLUS] = ACTIONS(442),
    [anon_sym_DASH] = ACTIONS(442),
    [anon_sym_TILDE] = ACTIONS(444),
    [anon_sym_BANG] = ACTIONS(444),
    [anon_sym_PLUS_PLUS] = ACTIONS(446),
    [anon_sym_DASH_DASH] = ACTIONS(446),
    [anon_sym_STAR] = ACTIONS(448),
    [anon_sym_AMP] = ACTIONS(448),
    [anon_sym_BSLASH] = ACTIONS(450),
    [anon_sym_sizeof] = ACTIONS(452),
    [anon_sym_L_SQUOTE] = ACTIONS(454),
    [anon_sym_u_SQUOTE] = ACTIONS(454),
    [anon_sym_U_SQUOTE] = ACTIONS(454),
    [anon_sym_u8_SQUOTE] = ACTIONS(454),
    [anon_sym_SQUOTE] = ACTIONS(454),
    [anon_sym_L_DQUOTE] = ACTIONS(456),
    [anon_sym_u_DQUOTE] = ACTIONS(456),
    [anon_sym_U_DQUOTE] = ACTIONS(456),
    [anon_sym_u8_DQUOTE] = ACTIONS(456),
    [anon_sym_DQUOTE] = ACTIONS(456),
    [anon_sym_const] = ACTIONS(458),
    [anon_sym_volatile] = ACTIONS(458),
    [anon_sym_struct] = ACTIONS(460),
    [anon_sym_union] = ACTIONS(462),
    [anon_sym_enum] = ACTIONS(464),
    [anon_sym_signed] = ACTIONS(466),
    [anon_sym_unsigned] = ACTIONS(466),
    [anon_sym_long] = ACTIONS(466),
    [anon_sym_short] = ACTIONS(466),
    [sym_hll_primitive_type] = ACTIONS(549),
    [aux_sym_symbol_token1] = ACTIONS(470),
    [aux_sym_symbol_token2] = ACTIONS(472),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(551),
    [sym__hll_number_literal_pre_hook] = ACTIONS(476),
  },
  [STATE(59)] = {
    [sym_trace32_hll_variable] = STATE(799),
    [sym__hll_expression] = STATE(1093),
    [sym_hll_call_expression] = STATE(798),
    [sym_hll_field_expression] = STATE(798),
    [sym_hll_subscript_expression] = STATE(798),
    [sym_hll_cast_expression] = STATE(1093),
    [sym_hll_sizeof_expression] = STATE(1093),
    [sym_hll_pointer_expression] = STATE(798),
    [sym_hll_comma_expression] = STATE(2204),
    [sym_hll_update_expression] = STATE(1093),
    [sym_hll_unary_expression] = STATE(1093),
    [sym_hll_binary_expression] = STATE(1093),
    [sym_hll_assignment_expression] = STATE(1093),
    [sym__hll_assignment_left_expression] = STATE(1652),
    [sym_hll_conditional_expression] = STATE(1093),
    [sym_hll_char_literal] = STATE(1093),
    [sym_hll_string_literal] = STATE(1093),
    [sym_hll_parenthesized_expression] = STATE(798),
    [sym_hll_type_descriptor] = STATE(2205),
    [sym_hll_type_qualifier] = STATE(1518),
    [sym__hll_type_specifier] = STATE(1534),
    [sym_hll_struct_specifier] = STATE(1534),
    [sym_hll_union_specifier] = STATE(1534),
    [sym_hll_enum_specifier] = STATE(1534),
    [sym_hll_sized_type_specifier] = STATE(1534),
    [sym__hll_type_identifier] = STATE(1534),
    [sym_symbol] = STATE(1093),
    [aux_sym_block_repeat1] = STATE(60),
    [aux_sym_hll_type_descriptor_repeat1] = STATE(1518),
    [aux_sym_hll_sized_type_specifier_repeat1] = STATE(1743),
    [sym_identifier] = ACTIONS(438),
    [anon_sym_LPAREN] = ACTIONS(440),
    [anon_sym_PLUS] = ACTIONS(442),
    [anon_sym_DASH] = ACTIONS(442),
    [anon_sym_TILDE] = ACTIONS(444),
    [anon_sym_BANG] = ACTIONS(444),
    [anon_sym_PLUS_PLUS] = ACTIONS(446),
    [anon_sym_DASH_DASH] = ACTIONS(446),
    [anon_sym_STAR] = ACTIONS(448),
    [anon_sym_AMP] = ACTIONS(448),
    [anon_sym_BSLASH] = ACTIONS(450),
    [anon_sym_sizeof] = ACTIONS(452),
    [anon_sym_L_SQUOTE] = ACTIONS(454),
    [anon_sym_u_SQUOTE] = ACTIONS(454),
    [anon_sym_U_SQUOTE] = ACTIONS(454),
    [anon_sym_u8_SQUOTE] = ACTIONS(454),
    [anon_sym_SQUOTE] = ACTIONS(454),
    [anon_sym_L_DQUOTE] = ACTIONS(456),
    [anon_sym_u_DQUOTE] = ACTIONS(456),
    [anon_sym_U_DQUOTE] = ACTIONS(456),
    [anon_sym_u8_DQUOTE] = ACTIONS(456),
    [anon_sym_DQUOTE] = ACTIONS(456),
    [anon_sym_const] = ACTIONS(458),
    [anon_sym_volatile] = ACTIONS(458),
    [anon_sym_struct] = ACTIONS(460),
    [anon_sym_union] = ACTIONS(462),
    [anon_sym_enum] = ACTIONS(464),
    [anon_sym_signed] = ACTIONS(466),
    [anon_sym_unsigned] = ACTIONS(466),
    [anon_sym_long] = ACTIONS(466),
    [anon_sym_short] = ACTIONS(466),
    [sym_hll_primitive_type] = ACTIONS(468),
    [aux_sym_symbol_token1] = ACTIONS(470),
    [aux_sym_symbol_token2] = ACTIONS(472),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(601),
    [sym__hll_number_literal_pre_hook] = ACTIONS(476),
  },
  [STATE(60)] = {
    [sym_trace32_hll_variable] = STATE(799),
    [sym__hll_expression] = STATE(1094),
    [sym_hll_call_expression] = STATE(798),
    [sym_hll_field_expression] = STATE(798),
    [sym_hll_subscript_expression] = STATE(798),
    [sym_hll_cast_expression] = STATE(1094),
    [sym_hll_sizeof_expression] = STATE(1094),
    [sym_hll_pointer_expression] = STATE(798),
    [sym_hll_comma_expression] = STATE(2219),
    [sym_hll_update_expression] = STATE(1094),
    [sym_hll_unary_expression] = STATE(1094),
    [sym_hll_binary_expression] = STATE(1094),
    [sym_hll_assignment_expression] = STATE(1094),
    [sym__hll_assignment_left_expression] = STATE(1652),
    [sym_hll_conditional_expression] = STATE(1094),
    [sym_hll_char_literal] = STATE(1094),
    [sym_hll_string_literal] = STATE(1094),
    [sym_hll_parenthesized_expression] = STATE(798),
    [sym_hll_type_descriptor] = STATE(2220),
    [sym_hll_type_qualifier] = STATE(1518),
    [sym__hll_type_specifier] = STATE(1531),
    [sym_hll_struct_specifier] = STATE(1531),
    [sym_hll_union_specifier] = STATE(1531),
    [sym_hll_enum_specifier] = STATE(1531),
    [sym_hll_sized_type_specifier] = STATE(1531),
    [sym__hll_type_identifier] = STATE(1531),
    [sym_symbol] = STATE(1094),
    [aux_sym_block_repeat1] = STATE(500),
    [aux_sym_hll_type_descriptor_repeat1] = STATE(1518),
    [aux_sym_hll_sized_type_specifier_repeat1] = STATE(1743),
    [sym_identifier] = ACTIONS(438),
    [anon_sym_LPAREN] = ACTIONS(440),
    [anon_sym_PLUS] = ACTIONS(442),
    [anon_sym_DASH] = ACTIONS(442),
    [anon_sym_TILDE] = ACTIONS(444),
    [anon_sym_BANG] = ACTIONS(444),
    [anon_sym_PLUS_PLUS] = ACTIONS(446),
    [anon_sym_DASH_DASH] = ACTIONS(446),
    [anon_sym_STAR] = ACTIONS(448),
    [anon_sym_AMP] = ACTIONS(448),
    [anon_sym_BSLASH] = ACTIONS(450),
    [anon_sym_sizeof] = ACTIONS(452),
    [anon_sym_L_SQUOTE] = ACTIONS(454),
    [anon_sym_u_SQUOTE] = ACTIONS(454),
    [anon_sym_U_SQUOTE] = ACTIONS(454),
    [anon_sym_u8_SQUOTE] = ACTIONS(454),
    [anon_sym_SQUOTE] = ACTIONS(454),
    [anon_sym_L_DQUOTE] = ACTIONS(456),
    [anon_sym_u_DQUOTE] = ACTIONS(456),
    [anon_sym_U_DQUOTE] = ACTIONS(456),
    [anon_sym_u8_DQUOTE] = ACTIONS(456),
    [anon_sym_DQUOTE] = ACTIONS(456),
    [anon_sym_const] = ACTIONS(458),
    [anon_sym_volatile] = ACTIONS(458),
    [anon_sym_struct] = ACTIONS(460),
    [anon_sym_union] = ACTIONS(462),
    [anon_sym_enum] = ACTIONS(464),
    [anon_sym_signed] = ACTIONS(466),
    [anon_sym_unsigned] = ACTIONS(466),
    [anon_sym_long] = ACTIONS(466),
    [anon_sym_short] = ACTIONS(466),
    [sym_hll_primitive_type] = ACTIONS(549),
    [aux_sym_symbol_token1] = ACTIONS(470),
    [aux_sym_symbol_token2] = ACTIONS(472),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(551),
    [sym__hll_number_literal_pre_hook] = ACTIONS(476),
  },
  [STATE(61)] = {
    [sym_trace32_hll_variable] = STATE(799),
    [sym__hll_expression] = STATE(1093),
    [sym_hll_call_expression] = STATE(798),
    [sym_hll_field_expression] = STATE(798),
    [sym_hll_subscript_expression] = STATE(798),
    [sym_hll_cast_expression] = STATE(1093),
    [sym_hll_sizeof_expression] = STATE(1093),
    [sym_hll_pointer_expression] = STATE(798),
    [sym_hll_comma_expression] = STATE(2204),
    [sym_hll_update_expression] = STATE(1093),
    [sym_hll_unary_expression] = STATE(1093),
    [sym_hll_binary_expression] = STATE(1093),
    [sym_hll_assignment_expression] = STATE(1093),
    [sym__hll_assignment_left_expression] = STATE(1652),
    [sym_hll_conditional_expression] = STATE(1093),
    [sym_hll_char_literal] = STATE(1093),
    [sym_hll_string_literal] = STATE(1093),
    [sym_hll_parenthesized_expression] = STATE(798),
    [sym_hll_type_descriptor] = STATE(2114),
    [sym_hll_type_qualifier] = STATE(1518),
    [sym__hll_type_specifier] = STATE(1534),
    [sym_hll_struct_specifier] = STATE(1534),
    [sym_hll_union_specifier] = STATE(1534),
    [sym_hll_enum_specifier] = STATE(1534),
    [sym_hll_sized_type_specifier] = STATE(1534),
    [sym__hll_type_identifier] = STATE(1534),
    [sym_symbol] = STATE(1093),
    [aux_sym_block_repeat1] = STATE(62),
    [aux_sym_hll_type_descriptor_repeat1] = STATE(1518),
    [aux_sym_hll_sized_type_specifier_repeat1] = STATE(1743),
    [sym_identifier] = ACTIONS(438),
    [anon_sym_LPAREN] = ACTIONS(440),
    [anon_sym_PLUS] = ACTIONS(442),
    [anon_sym_DASH] = ACTIONS(442),
    [anon_sym_TILDE] = ACTIONS(444),
    [anon_sym_BANG] = ACTIONS(444),
    [anon_sym_PLUS_PLUS] = ACTIONS(446),
    [anon_sym_DASH_DASH] = ACTIONS(446),
    [anon_sym_STAR] = ACTIONS(448),
    [anon_sym_AMP] = ACTIONS(448),
    [anon_sym_BSLASH] = ACTIONS(450),
    [anon_sym_sizeof] = ACTIONS(452),
    [anon_sym_L_SQUOTE] = ACTIONS(454),
    [anon_sym_u_SQUOTE] = ACTIONS(454),
    [anon_sym_U_SQUOTE] = ACTIONS(454),
    [anon_sym_u8_SQUOTE] = ACTIONS(454),
    [anon_sym_SQUOTE] = ACTIONS(454),
    [anon_sym_L_DQUOTE] = ACTIONS(456),
    [anon_sym_u_DQUOTE] = ACTIONS(456),
    [anon_sym_U_DQUOTE] = ACTIONS(456),
    [anon_sym_u8_DQUOTE] = ACTIONS(456),
    [anon_sym_DQUOTE] = ACTIONS(456),
    [anon_sym_const] = ACTIONS(458),
    [anon_sym_volatile] = ACTIONS(458),
    [anon_sym_struct] = ACTIONS(460),
    [anon_sym_union] = ACTIONS(462),
    [anon_sym_enum] = ACTIONS(464),
    [anon_sym_signed] = ACTIONS(466),
    [anon_sym_unsigned] = ACTIONS(466),
    [anon_sym_long] = ACTIONS(466),
    [anon_sym_short] = ACTIONS(466),
    [sym_hll_primitive_type] = ACTIONS(468),
    [aux_sym_symbol_token1] = ACTIONS(470),
    [aux_sym_symbol_token2] = ACTIONS(472),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(603),
    [sym__hll_number_literal_pre_hook] = ACTIONS(476),
  },
  [STATE(62)] = {
    [sym_trace32_hll_variable] = STATE(799),
    [sym__hll_expression] = STATE(1094),
    [sym_hll_call_expression] = STATE(798),
    [sym_hll_field_expression] = STATE(798),
    [sym_hll_subscript_expression] = STATE(798),
    [sym_hll_cast_expression] = STATE(1094),
    [sym_hll_sizeof_expression] = STATE(1094),
    [sym_hll_pointer_expression] = STATE(798),
    [sym_hll_comma_expression] = STATE(2219),
    [sym_hll_update_expression] = STATE(1094),
    [sym_hll_unary_expression] = STATE(1094),
    [sym_hll_binary_expression] = STATE(1094),
    [sym_hll_assignment_expression] = STATE(1094),
    [sym__hll_assignment_left_expression] = STATE(1652),
    [sym_hll_conditional_expression] = STATE(1094),
    [sym_hll_char_literal] = STATE(1094),
    [sym_hll_string_literal] = STATE(1094),
    [sym_hll_parenthesized_expression] = STATE(798),
    [sym_hll_type_descriptor] = STATE(2118),
    [sym_hll_type_qualifier] = STATE(1518),
    [sym__hll_type_specifier] = STATE(1531),
    [sym_hll_struct_specifier] = STATE(1531),
    [sym_hll_union_specifier] = STATE(1531),
    [sym_hll_enum_specifier] = STATE(1531),
    [sym_hll_sized_type_specifier] = STATE(1531),
    [sym__hll_type_identifier] = STATE(1531),
    [sym_symbol] = STATE(1094),
    [aux_sym_block_repeat1] = STATE(500),
    [aux_sym_hll_type_descriptor_repeat1] = STATE(1518),
    [aux_sym_hll_sized_type_specifier_repeat1] = STATE(1743),
    [sym_identifier] = ACTIONS(438),
    [anon_sym_LPAREN] = ACTIONS(440),
    [anon_sym_PLUS] = ACTIONS(442),
    [anon_sym_DASH] = ACTIONS(442),
    [anon_sym_TILDE] = ACTIONS(444),
    [anon_sym_BANG] = ACTIONS(444),
    [anon_sym_PLUS_PLUS] = ACTIONS(446),
    [anon_sym_DASH_DASH] = ACTIONS(446),
    [anon_sym_STAR] = ACTIONS(448),
    [anon_sym_AMP] = ACTIONS(448),
    [anon_sym_BSLASH] = ACTIONS(450),
    [anon_sym_sizeof] = ACTIONS(452),
    [anon_sym_L_SQUOTE] = ACTIONS(454),
    [anon_sym_u_SQUOTE] = ACTIONS(454),
    [anon_sym_U_SQUOTE] = ACTIONS(454),
    [anon_sym_u8_SQUOTE] = ACTIONS(454),
    [anon_sym_SQUOTE] = ACTIONS(454),
    [anon_sym_L_DQUOTE] = ACTIONS(456),
    [anon_sym_u_DQUOTE] = ACTIONS(456),
    [anon_sym_U_DQUOTE] = ACTIONS(456),
    [anon_sym_u8_DQUOTE] = ACTIONS(456),
    [anon_sym_DQUOTE] = ACTIONS(456),
    [anon_sym_const] = ACTIONS(458),
    [anon_sym_volatile] = ACTIONS(458),
    [anon_sym_struct] = ACTIONS(460),
    [anon_sym_union] = ACTIONS(462),
    [anon_sym_enum] = ACTIONS(464),
    [anon_sym_signed] = ACTIONS(466),
    [anon_sym_unsigned] = ACTIONS(466),
    [anon_sym_long] = ACTIONS(466),
    [anon_sym_short] = ACTIONS(466),
    [sym_hll_primitive_type] = ACTIONS(549),
    [aux_sym_symbol_token1] = ACTIONS(470),
    [aux_sym_symbol_token2] = ACTIONS(472),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(551),
    [sym__hll_number_literal_pre_hook] = ACTIONS(476),
  },
  [STATE(63)] = {
    [sym_trace32_hll_variable] = STATE(799),
    [sym__hll_expression] = STATE(1102),
    [sym_hll_call_expression] = STATE(798),
    [sym_hll_field_expression] = STATE(798),
    [sym_hll_subscript_expression] = STATE(798),
    [sym_hll_cast_expression] = STATE(1102),
    [sym_hll_sizeof_expression] = STATE(1102),
    [sym_hll_pointer_expression] = STATE(798),
    [sym_hll_comma_expression] = STATE(2051),
    [sym_hll_update_expression] = STATE(1102),
    [sym_hll_unary_expression] = STATE(1102),
    [sym_hll_binary_expression] = STATE(1102),
    [sym_hll_assignment_expression] = STATE(1102),
    [sym__hll_assignment_left_expression] = STATE(1652),
    [sym_hll_conditional_expression] = STATE(1102),
    [sym_hll_char_literal] = STATE(1102),
    [sym_hll_string_literal] = STATE(1102),
    [sym_hll_parenthesized_expression] = STATE(798),
    [sym_hll_type_descriptor] = STATE(2153),
    [sym_hll_type_qualifier] = STATE(1518),
    [sym__hll_type_specifier] = STATE(1534),
    [sym_hll_struct_specifier] = STATE(1534),
    [sym_hll_union_specifier] = STATE(1534),
    [sym_hll_enum_specifier] = STATE(1534),
    [sym_hll_sized_type_specifier] = STATE(1534),
    [sym__hll_type_identifier] = STATE(1534),
    [sym_symbol] = STATE(1102),
    [aux_sym_block_repeat1] = STATE(64),
    [aux_sym_hll_type_descriptor_repeat1] = STATE(1518),
    [aux_sym_hll_sized_type_specifier_repeat1] = STATE(1743),
    [sym_identifier] = ACTIONS(438),
    [anon_sym_LPAREN] = ACTIONS(440),
    [anon_sym_PLUS] = ACTIONS(442),
    [anon_sym_DASH] = ACTIONS(442),
    [anon_sym_TILDE] = ACTIONS(444),
    [anon_sym_BANG] = ACTIONS(444),
    [anon_sym_PLUS_PLUS] = ACTIONS(446),
    [anon_sym_DASH_DASH] = ACTIONS(446),
    [anon_sym_STAR] = ACTIONS(448),
    [anon_sym_AMP] = ACTIONS(448),
    [anon_sym_BSLASH] = ACTIONS(450),
    [anon_sym_sizeof] = ACTIONS(452),
    [anon_sym_L_SQUOTE] = ACTIONS(454),
    [anon_sym_u_SQUOTE] = ACTIONS(454),
    [anon_sym_U_SQUOTE] = ACTIONS(454),
    [anon_sym_u8_SQUOTE] = ACTIONS(454),
    [anon_sym_SQUOTE] = ACTIONS(454),
    [anon_sym_L_DQUOTE] = ACTIONS(456),
    [anon_sym_u_DQUOTE] = ACTIONS(456),
    [anon_sym_U_DQUOTE] = ACTIONS(456),
    [anon_sym_u8_DQUOTE] = ACTIONS(456),
    [anon_sym_DQUOTE] = ACTIONS(456),
    [anon_sym_const] = ACTIONS(458),
    [anon_sym_volatile] = ACTIONS(458),
    [anon_sym_struct] = ACTIONS(460),
    [anon_sym_union] = ACTIONS(462),
    [anon_sym_enum] = ACTIONS(464),
    [anon_sym_signed] = ACTIONS(466),
    [anon_sym_unsigned] = ACTIONS(466),
    [anon_sym_long] = ACTIONS(466),
    [anon_sym_short] = ACTIONS(466),
    [sym_hll_primitive_type] = ACTIONS(468),
    [aux_sym_symbol_token1] = ACTIONS(470),
    [aux_sym_symbol_token2] = ACTIONS(472),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(605),
    [sym__hll_number_literal_pre_hook] = ACTIONS(476),
  },
  [STATE(64)] = {
    [sym_trace32_hll_variable] = STATE(799),
    [sym__hll_expression] = STATE(1104),
    [sym_hll_call_expression] = STATE(798),
    [sym_hll_field_expression] = STATE(798),
    [sym_hll_subscript_expression] = STATE(798),
    [sym_hll_cast_expression] = STATE(1104),
    [sym_hll_sizeof_expression] = STATE(1104),
    [sym_hll_pointer_expression] = STATE(798),
    [sym_hll_comma_expression] = STATE(2060),
    [sym_hll_update_expression] = STATE(1104),
    [sym_hll_unary_expression] = STATE(1104),
    [sym_hll_binary_expression] = STATE(1104),
    [sym_hll_assignment_expression] = STATE(1104),
    [sym__hll_assignment_left_expression] = STATE(1652),
    [sym_hll_conditional_expression] = STATE(1104),
    [sym_hll_char_literal] = STATE(1104),
    [sym_hll_string_literal] = STATE(1104),
    [sym_hll_parenthesized_expression] = STATE(798),
    [sym_hll_type_descriptor] = STATE(2157),
    [sym_hll_type_qualifier] = STATE(1518),
    [sym__hll_type_specifier] = STATE(1531),
    [sym_hll_struct_specifier] = STATE(1531),
    [sym_hll_union_specifier] = STATE(1531),
    [sym_hll_enum_specifier] = STATE(1531),
    [sym_hll_sized_type_specifier] = STATE(1531),
    [sym__hll_type_identifier] = STATE(1531),
    [sym_symbol] = STATE(1104),
    [aux_sym_block_repeat1] = STATE(500),
    [aux_sym_hll_type_descriptor_repeat1] = STATE(1518),
    [aux_sym_hll_sized_type_specifier_repeat1] = STATE(1743),
    [sym_identifier] = ACTIONS(438),
    [anon_sym_LPAREN] = ACTIONS(440),
    [anon_sym_PLUS] = ACTIONS(442),
    [anon_sym_DASH] = ACTIONS(442),
    [anon_sym_TILDE] = ACTIONS(444),
    [anon_sym_BANG] = ACTIONS(444),
    [anon_sym_PLUS_PLUS] = ACTIONS(446),
    [anon_sym_DASH_DASH] = ACTIONS(446),
    [anon_sym_STAR] = ACTIONS(448),
    [anon_sym_AMP] = ACTIONS(448),
    [anon_sym_BSLASH] = ACTIONS(450),
    [anon_sym_sizeof] = ACTIONS(452),
    [anon_sym_L_SQUOTE] = ACTIONS(454),
    [anon_sym_u_SQUOTE] = ACTIONS(454),
    [anon_sym_U_SQUOTE] = ACTIONS(454),
    [anon_sym_u8_SQUOTE] = ACTIONS(454),
    [anon_sym_SQUOTE] = ACTIONS(454),
    [anon_sym_L_DQUOTE] = ACTIONS(456),
    [anon_sym_u_DQUOTE] = ACTIONS(456),
    [anon_sym_U_DQUOTE] = ACTIONS(456),
    [anon_sym_u8_DQUOTE] = ACTIONS(456),
    [anon_sym_DQUOTE] = ACTIONS(456),
    [anon_sym_const] = ACTIONS(458),
    [anon_sym_volatile] = ACTIONS(458),
    [anon_sym_struct] = ACTIONS(460),
    [anon_sym_union] = ACTIONS(462),
    [anon_sym_enum] = ACTIONS(464),
    [anon_sym_signed] = ACTIONS(466),
    [anon_sym_unsigned] = ACTIONS(466),
    [anon_sym_long] = ACTIONS(466),
    [anon_sym_short] = ACTIONS(466),
    [sym_hll_primitive_type] = ACTIONS(549),
    [aux_sym_symbol_token1] = ACTIONS(470),
    [aux_sym_symbol_token2] = ACTIONS(472),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(551),
    [sym__hll_number_literal_pre_hook] = ACTIONS(476),
  },
  [STATE(65)] = {
    [sym_trace32_hll_variable] = STATE(799),
    [sym__hll_expression] = STATE(1082),
    [sym_hll_call_expression] = STATE(798),
    [sym_hll_field_expression] = STATE(798),
    [sym_hll_subscript_expression] = STATE(798),
    [sym_hll_cast_expression] = STATE(1082),
    [sym_hll_sizeof_expression] = STATE(1082),
    [sym_hll_pointer_expression] = STATE(798),
    [sym_hll_comma_expression] = STATE(2149),
    [sym_hll_update_expression] = STATE(1082),
    [sym_hll_unary_expression] = STATE(1082),
    [sym_hll_binary_expression] = STATE(1082),
    [sym_hll_assignment_expression] = STATE(1082),
    [sym__hll_assignment_left_expression] = STATE(1652),
    [sym_hll_conditional_expression] = STATE(1082),
    [sym_hll_char_literal] = STATE(1082),
    [sym_hll_string_literal] = STATE(1082),
    [sym_hll_parenthesized_expression] = STATE(798),
    [sym_hll_type_descriptor] = STATE(2052),
    [sym_hll_type_qualifier] = STATE(1518),
    [sym__hll_type_specifier] = STATE(1534),
    [sym_hll_struct_specifier] = STATE(1534),
    [sym_hll_union_specifier] = STATE(1534),
    [sym_hll_enum_specifier] = STATE(1534),
    [sym_hll_sized_type_specifier] = STATE(1534),
    [sym__hll_type_identifier] = STATE(1534),
    [sym_symbol] = STATE(1082),
    [aux_sym_block_repeat1] = STATE(66),
    [aux_sym_hll_type_descriptor_repeat1] = STATE(1518),
    [aux_sym_hll_sized_type_specifier_repeat1] = STATE(1743),
    [sym_identifier] = ACTIONS(438),
    [anon_sym_LPAREN] = ACTIONS(440),
    [anon_sym_PLUS] = ACTIONS(442),
    [anon_sym_DASH] = ACTIONS(442),
    [anon_sym_TILDE] = ACTIONS(444),
    [anon_sym_BANG] = ACTIONS(444),
    [anon_sym_PLUS_PLUS] = ACTIONS(446),
    [anon_sym_DASH_DASH] = ACTIONS(446),
    [anon_sym_STAR] = ACTIONS(448),
    [anon_sym_AMP] = ACTIONS(448),
    [anon_sym_BSLASH] = ACTIONS(450),
    [anon_sym_sizeof] = ACTIONS(452),
    [anon_sym_L_SQUOTE] = ACTIONS(454),
    [anon_sym_u_SQUOTE] = ACTIONS(454),
    [anon_sym_U_SQUOTE] = ACTIONS(454),
    [anon_sym_u8_SQUOTE] = ACTIONS(454),
    [anon_sym_SQUOTE] = ACTIONS(454),
    [anon_sym_L_DQUOTE] = ACTIONS(456),
    [anon_sym_u_DQUOTE] = ACTIONS(456),
    [anon_sym_U_DQUOTE] = ACTIONS(456),
    [anon_sym_u8_DQUOTE] = ACTIONS(456),
    [anon_sym_DQUOTE] = ACTIONS(456),
    [anon_sym_const] = ACTIONS(458),
    [anon_sym_volatile] = ACTIONS(458),
    [anon_sym_struct] = ACTIONS(460),
    [anon_sym_union] = ACTIONS(462),
    [anon_sym_enum] = ACTIONS(464),
    [anon_sym_signed] = ACTIONS(466),
    [anon_sym_unsigned] = ACTIONS(466),
    [anon_sym_long] = ACTIONS(466),
    [anon_sym_short] = ACTIONS(466),
    [sym_hll_primitive_type] = ACTIONS(468),
    [aux_sym_symbol_token1] = ACTIONS(470),
    [aux_sym_symbol_token2] = ACTIONS(472),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(607),
    [sym__hll_number_literal_pre_hook] = ACTIONS(476),
  },
  [STATE(66)] = {
    [sym_trace32_hll_variable] = STATE(799),
    [sym__hll_expression] = STATE(1057),
    [sym_hll_call_expression] = STATE(798),
    [sym_hll_field_expression] = STATE(798),
    [sym_hll_subscript_expression] = STATE(798),
    [sym_hll_cast_expression] = STATE(1057),
    [sym_hll_sizeof_expression] = STATE(1057),
    [sym_hll_pointer_expression] = STATE(798),
    [sym_hll_comma_expression] = STATE(2179),
    [sym_hll_update_expression] = STATE(1057),
    [sym_hll_unary_expression] = STATE(1057),
    [sym_hll_binary_expression] = STATE(1057),
    [sym_hll_assignment_expression] = STATE(1057),
    [sym__hll_assignment_left_expression] = STATE(1652),
    [sym_hll_conditional_expression] = STATE(1057),
    [sym_hll_char_literal] = STATE(1057),
    [sym_hll_string_literal] = STATE(1057),
    [sym_hll_parenthesized_expression] = STATE(798),
    [sym_hll_type_descriptor] = STATE(2061),
    [sym_hll_type_qualifier] = STATE(1518),
    [sym__hll_type_specifier] = STATE(1531),
    [sym_hll_struct_specifier] = STATE(1531),
    [sym_hll_union_specifier] = STATE(1531),
    [sym_hll_enum_specifier] = STATE(1531),
    [sym_hll_sized_type_specifier] = STATE(1531),
    [sym__hll_type_identifier] = STATE(1531),
    [sym_symbol] = STATE(1057),
    [aux_sym_block_repeat1] = STATE(500),
    [aux_sym_hll_type_descriptor_repeat1] = STATE(1518),
    [aux_sym_hll_sized_type_specifier_repeat1] = STATE(1743),
    [sym_identifier] = ACTIONS(438),
    [anon_sym_LPAREN] = ACTIONS(440),
    [anon_sym_PLUS] = ACTIONS(442),
    [anon_sym_DASH] = ACTIONS(442),
    [anon_sym_TILDE] = ACTIONS(444),
    [anon_sym_BANG] = ACTIONS(444),
    [anon_sym_PLUS_PLUS] = ACTIONS(446),
    [anon_sym_DASH_DASH] = ACTIONS(446),
    [anon_sym_STAR] = ACTIONS(448),
    [anon_sym_AMP] = ACTIONS(448),
    [anon_sym_BSLASH] = ACTIONS(450),
    [anon_sym_sizeof] = ACTIONS(452),
    [anon_sym_L_SQUOTE] = ACTIONS(454),
    [anon_sym_u_SQUOTE] = ACTIONS(454),
    [anon_sym_U_SQUOTE] = ACTIONS(454),
    [anon_sym_u8_SQUOTE] = ACTIONS(454),
    [anon_sym_SQUOTE] = ACTIONS(454),
    [anon_sym_L_DQUOTE] = ACTIONS(456),
    [anon_sym_u_DQUOTE] = ACTIONS(456),
    [anon_sym_U_DQUOTE] = ACTIONS(456),
    [anon_sym_u8_DQUOTE] = ACTIONS(456),
    [anon_sym_DQUOTE] = ACTIONS(456),
    [anon_sym_const] = ACTIONS(458),
    [anon_sym_volatile] = ACTIONS(458),
    [anon_sym_struct] = ACTIONS(460),
    [anon_sym_union] = ACTIONS(462),
    [anon_sym_enum] = ACTIONS(464),
    [anon_sym_signed] = ACTIONS(466),
    [anon_sym_unsigned] = ACTIONS(466),
    [anon_sym_long] = ACTIONS(466),
    [anon_sym_short] = ACTIONS(466),
    [sym_hll_primitive_type] = ACTIONS(549),
    [aux_sym_symbol_token1] = ACTIONS(470),
    [aux_sym_symbol_token2] = ACTIONS(472),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(551),
    [sym__hll_number_literal_pre_hook] = ACTIONS(476),
  },
  [STATE(67)] = {
    [sym_trace32_hll_variable] = STATE(799),
    [sym__hll_expression] = STATE(1083),
    [sym_hll_call_expression] = STATE(798),
    [sym_hll_field_expression] = STATE(798),
    [sym_hll_subscript_expression] = STATE(798),
    [sym_hll_cast_expression] = STATE(1083),
    [sym_hll_sizeof_expression] = STATE(1083),
    [sym_hll_pointer_expression] = STATE(798),
    [sym_hll_comma_expression] = STATE(2154),
    [sym_hll_update_expression] = STATE(1083),
    [sym_hll_unary_expression] = STATE(1083),
    [sym_hll_binary_expression] = STATE(1083),
    [sym_hll_assignment_expression] = STATE(1083),
    [sym__hll_assignment_left_expression] = STATE(1652),
    [sym_hll_conditional_expression] = STATE(1083),
    [sym_hll_char_literal] = STATE(1083),
    [sym_hll_string_literal] = STATE(1083),
    [sym_hll_parenthesized_expression] = STATE(798),
    [sym_hll_type_descriptor] = STATE(2080),
    [sym_hll_type_qualifier] = STATE(1518),
    [sym__hll_type_specifier] = STATE(1534),
    [sym_hll_struct_specifier] = STATE(1534),
    [sym_hll_union_specifier] = STATE(1534),
    [sym_hll_enum_specifier] = STATE(1534),
    [sym_hll_sized_type_specifier] = STATE(1534),
    [sym__hll_type_identifier] = STATE(1534),
    [sym_symbol] = STATE(1083),
    [aux_sym_block_repeat1] = STATE(68),
    [aux_sym_hll_type_descriptor_repeat1] = STATE(1518),
    [aux_sym_hll_sized_type_specifier_repeat1] = STATE(1743),
    [sym_identifier] = ACTIONS(438),
    [anon_sym_LPAREN] = ACTIONS(440),
    [anon_sym_PLUS] = ACTIONS(442),
    [anon_sym_DASH] = ACTIONS(442),
    [anon_sym_TILDE] = ACTIONS(444),
    [anon_sym_BANG] = ACTIONS(444),
    [anon_sym_PLUS_PLUS] = ACTIONS(446),
    [anon_sym_DASH_DASH] = ACTIONS(446),
    [anon_sym_STAR] = ACTIONS(448),
    [anon_sym_AMP] = ACTIONS(448),
    [anon_sym_BSLASH] = ACTIONS(450),
    [anon_sym_sizeof] = ACTIONS(452),
    [anon_sym_L_SQUOTE] = ACTIONS(454),
    [anon_sym_u_SQUOTE] = ACTIONS(454),
    [anon_sym_U_SQUOTE] = ACTIONS(454),
    [anon_sym_u8_SQUOTE] = ACTIONS(454),
    [anon_sym_SQUOTE] = ACTIONS(454),
    [anon_sym_L_DQUOTE] = ACTIONS(456),
    [anon_sym_u_DQUOTE] = ACTIONS(456),
    [anon_sym_U_DQUOTE] = ACTIONS(456),
    [anon_sym_u8_DQUOTE] = ACTIONS(456),
    [anon_sym_DQUOTE] = ACTIONS(456),
    [anon_sym_const] = ACTIONS(458),
    [anon_sym_volatile] = ACTIONS(458),
    [anon_sym_struct] = ACTIONS(460),
    [anon_sym_union] = ACTIONS(462),
    [anon_sym_enum] = ACTIONS(464),
    [anon_sym_signed] = ACTIONS(466),
    [anon_sym_unsigned] = ACTIONS(466),
    [anon_sym_long] = ACTIONS(466),
    [anon_sym_short] = ACTIONS(466),
    [sym_hll_primitive_type] = ACTIONS(468),
    [aux_sym_symbol_token1] = ACTIONS(470),
    [aux_sym_symbol_token2] = ACTIONS(472),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(609),
    [sym__hll_number_literal_pre_hook] = ACTIONS(476),
  },
  [STATE(68)] = {
    [sym_trace32_hll_variable] = STATE(799),
    [sym__hll_expression] = STATE(1086),
    [sym_hll_call_expression] = STATE(798),
    [sym_hll_field_expression] = STATE(798),
    [sym_hll_subscript_expression] = STATE(798),
    [sym_hll_cast_expression] = STATE(1086),
    [sym_hll_sizeof_expression] = STATE(1086),
    [sym_hll_pointer_expression] = STATE(798),
    [sym_hll_comma_expression] = STATE(2081),
    [sym_hll_update_expression] = STATE(1086),
    [sym_hll_unary_expression] = STATE(1086),
    [sym_hll_binary_expression] = STATE(1086),
    [sym_hll_assignment_expression] = STATE(1086),
    [sym__hll_assignment_left_expression] = STATE(1652),
    [sym_hll_conditional_expression] = STATE(1086),
    [sym_hll_char_literal] = STATE(1086),
    [sym_hll_string_literal] = STATE(1086),
    [sym_hll_parenthesized_expression] = STATE(798),
    [sym_hll_type_descriptor] = STATE(2085),
    [sym_hll_type_qualifier] = STATE(1518),
    [sym__hll_type_specifier] = STATE(1531),
    [sym_hll_struct_specifier] = STATE(1531),
    [sym_hll_union_specifier] = STATE(1531),
    [sym_hll_enum_specifier] = STATE(1531),
    [sym_hll_sized_type_specifier] = STATE(1531),
    [sym__hll_type_identifier] = STATE(1531),
    [sym_symbol] = STATE(1086),
    [aux_sym_block_repeat1] = STATE(500),
    [aux_sym_hll_type_descriptor_repeat1] = STATE(1518),
    [aux_sym_hll_sized_type_specifier_repeat1] = STATE(1743),
    [sym_identifier] = ACTIONS(438),
    [anon_sym_LPAREN] = ACTIONS(440),
    [anon_sym_PLUS] = ACTIONS(442),
    [anon_sym_DASH] = ACTIONS(442),
    [anon_sym_TILDE] = ACTIONS(444),
    [anon_sym_BANG] = ACTIONS(444),
    [anon_sym_PLUS_PLUS] = ACTIONS(446),
    [anon_sym_DASH_DASH] = ACTIONS(446),
    [anon_sym_STAR] = ACTIONS(448),
    [anon_sym_AMP] = ACTIONS(448),
    [anon_sym_BSLASH] = ACTIONS(450),
    [anon_sym_sizeof] = ACTIONS(452),
    [anon_sym_L_SQUOTE] = ACTIONS(454),
    [anon_sym_u_SQUOTE] = ACTIONS(454),
    [anon_sym_U_SQUOTE] = ACTIONS(454),
    [anon_sym_u8_SQUOTE] = ACTIONS(454),
    [anon_sym_SQUOTE] = ACTIONS(454),
    [anon_sym_L_DQUOTE] = ACTIONS(456),
    [anon_sym_u_DQUOTE] = ACTIONS(456),
    [anon_sym_U_DQUOTE] = ACTIONS(456),
    [anon_sym_u8_DQUOTE] = ACTIONS(456),
    [anon_sym_DQUOTE] = ACTIONS(456),
    [anon_sym_const] = ACTIONS(458),
    [anon_sym_volatile] = ACTIONS(458),
    [anon_sym_struct] = ACTIONS(460),
    [anon_sym_union] = ACTIONS(462),
    [anon_sym_enum] = ACTIONS(464),
    [anon_sym_signed] = ACTIONS(466),
    [anon_sym_unsigned] = ACTIONS(466),
    [anon_sym_long] = ACTIONS(466),
    [anon_sym_short] = ACTIONS(466),
    [sym_hll_primitive_type] = ACTIONS(549),
    [aux_sym_symbol_token1] = ACTIONS(470),
    [aux_sym_symbol_token2] = ACTIONS(472),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(551),
    [sym__hll_number_literal_pre_hook] = ACTIONS(476),
  },
  [STATE(69)] = {
    [sym_trace32_hll_variable] = STATE(799),
    [sym__hll_expression] = STATE(1093),
    [sym_hll_call_expression] = STATE(798),
    [sym_hll_field_expression] = STATE(798),
    [sym_hll_subscript_expression] = STATE(798),
    [sym_hll_cast_expression] = STATE(1093),
    [sym_hll_sizeof_expression] = STATE(1093),
    [sym_hll_pointer_expression] = STATE(798),
    [sym_hll_comma_expression] = STATE(2204),
    [sym_hll_update_expression] = STATE(1093),
    [sym_hll_unary_expression] = STATE(1093),
    [sym_hll_binary_expression] = STATE(1093),
    [sym_hll_assignment_expression] = STATE(1093),
    [sym__hll_assignment_left_expression] = STATE(1652),
    [sym_hll_conditional_expression] = STATE(1093),
    [sym_hll_char_literal] = STATE(1093),
    [sym_hll_string_literal] = STATE(1093),
    [sym_hll_parenthesized_expression] = STATE(798),
    [sym_hll_type_descriptor] = STATE(2097),
    [sym_hll_type_qualifier] = STATE(1518),
    [sym__hll_type_specifier] = STATE(1534),
    [sym_hll_struct_specifier] = STATE(1534),
    [sym_hll_union_specifier] = STATE(1534),
    [sym_hll_enum_specifier] = STATE(1534),
    [sym_hll_sized_type_specifier] = STATE(1534),
    [sym__hll_type_identifier] = STATE(1534),
    [sym_symbol] = STATE(1093),
    [aux_sym_block_repeat1] = STATE(70),
    [aux_sym_hll_type_descriptor_repeat1] = STATE(1518),
    [aux_sym_hll_sized_type_specifier_repeat1] = STATE(1743),
    [sym_identifier] = ACTIONS(438),
    [anon_sym_LPAREN] = ACTIONS(440),
    [anon_sym_PLUS] = ACTIONS(442),
    [anon_sym_DASH] = ACTIONS(442),
    [anon_sym_TILDE] = ACTIONS(444),
    [anon_sym_BANG] = ACTIONS(444),
    [anon_sym_PLUS_PLUS] = ACTIONS(446),
    [anon_sym_DASH_DASH] = ACTIONS(446),
    [anon_sym_STAR] = ACTIONS(448),
    [anon_sym_AMP] = ACTIONS(448),
    [anon_sym_BSLASH] = ACTIONS(450),
    [anon_sym_sizeof] = ACTIONS(452),
    [anon_sym_L_SQUOTE] = ACTIONS(454),
    [anon_sym_u_SQUOTE] = ACTIONS(454),
    [anon_sym_U_SQUOTE] = ACTIONS(454),
    [anon_sym_u8_SQUOTE] = ACTIONS(454),
    [anon_sym_SQUOTE] = ACTIONS(454),
    [anon_sym_L_DQUOTE] = ACTIONS(456),
    [anon_sym_u_DQUOTE] = ACTIONS(456),
    [anon_sym_U_DQUOTE] = ACTIONS(456),
    [anon_sym_u8_DQUOTE] = ACTIONS(456),
    [anon_sym_DQUOTE] = ACTIONS(456),
    [anon_sym_const] = ACTIONS(458),
    [anon_sym_volatile] = ACTIONS(458),
    [anon_sym_struct] = ACTIONS(460),
    [anon_sym_union] = ACTIONS(462),
    [anon_sym_enum] = ACTIONS(464),
    [anon_sym_signed] = ACTIONS(466),
    [anon_sym_unsigned] = ACTIONS(466),
    [anon_sym_long] = ACTIONS(466),
    [anon_sym_short] = ACTIONS(466),
    [sym_hll_primitive_type] = ACTIONS(468),
    [aux_sym_symbol_token1] = ACTIONS(470),
    [aux_sym_symbol_token2] = ACTIONS(472),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(611),
    [sym__hll_number_literal_pre_hook] = ACTIONS(476),
  },
  [STATE(70)] = {
    [sym_trace32_hll_variable] = STATE(799),
    [sym__hll_expression] = STATE(1094),
    [sym_hll_call_expression] = STATE(798),
    [sym_hll_field_expression] = STATE(798),
    [sym_hll_subscript_expression] = STATE(798),
    [sym_hll_cast_expression] = STATE(1094),
    [sym_hll_sizeof_expression] = STATE(1094),
    [sym_hll_pointer_expression] = STATE(798),
    [sym_hll_comma_expression] = STATE(2219),
    [sym_hll_update_expression] = STATE(1094),
    [sym_hll_unary_expression] = STATE(1094),
    [sym_hll_binary_expression] = STATE(1094),
    [sym_hll_assignment_expression] = STATE(1094),
    [sym__hll_assignment_left_expression] = STATE(1652),
    [sym_hll_conditional_expression] = STATE(1094),
    [sym_hll_char_literal] = STATE(1094),
    [sym_hll_string_literal] = STATE(1094),
    [sym_hll_parenthesized_expression] = STATE(798),
    [sym_hll_type_descriptor] = STATE(2100),
    [sym_hll_type_qualifier] = STATE(1518),
    [sym__hll_type_specifier] = STATE(1531),
    [sym_hll_struct_specifier] = STATE(1531),
    [sym_hll_union_specifier] = STATE(1531),
    [sym_hll_enum_specifier] = STATE(1531),
    [sym_hll_sized_type_specifier] = STATE(1531),
    [sym__hll_type_identifier] = STATE(1531),
    [sym_symbol] = STATE(1094),
    [aux_sym_block_repeat1] = STATE(500),
    [aux_sym_hll_type_descriptor_repeat1] = STATE(1518),
    [aux_sym_hll_sized_type_specifier_repeat1] = STATE(1743),
    [sym_identifier] = ACTIONS(438),
    [anon_sym_LPAREN] = ACTIONS(440),
    [anon_sym_PLUS] = ACTIONS(442),
    [anon_sym_DASH] = ACTIONS(442),
    [anon_sym_TILDE] = ACTIONS(444),
    [anon_sym_BANG] = ACTIONS(444),
    [anon_sym_PLUS_PLUS] = ACTIONS(446),
    [anon_sym_DASH_DASH] = ACTIONS(446),
    [anon_sym_STAR] = ACTIONS(448),
    [anon_sym_AMP] = ACTIONS(448),
    [anon_sym_BSLASH] = ACTIONS(450),
    [anon_sym_sizeof] = ACTIONS(452),
    [anon_sym_L_SQUOTE] = ACTIONS(454),
    [anon_sym_u_SQUOTE] = ACTIONS(454),
    [anon_sym_U_SQUOTE] = ACTIONS(454),
    [anon_sym_u8_SQUOTE] = ACTIONS(454),
    [anon_sym_SQUOTE] = ACTIONS(454),
    [anon_sym_L_DQUOTE] = ACTIONS(456),
    [anon_sym_u_DQUOTE] = ACTIONS(456),
    [anon_sym_U_DQUOTE] = ACTIONS(456),
    [anon_sym_u8_DQUOTE] = ACTIONS(456),
    [anon_sym_DQUOTE] = ACTIONS(456),
    [anon_sym_const] = ACTIONS(458),
    [anon_sym_volatile] = ACTIONS(458),
    [anon_sym_struct] = ACTIONS(460),
    [anon_sym_union] = ACTIONS(462),
    [anon_sym_enum] = ACTIONS(464),
    [anon_sym_signed] = ACTIONS(466),
    [anon_sym_unsigned] = ACTIONS(466),
    [anon_sym_long] = ACTIONS(466),
    [anon_sym_short] = ACTIONS(466),
    [sym_hll_primitive_type] = ACTIONS(549),
    [aux_sym_symbol_token1] = ACTIONS(470),
    [aux_sym_symbol_token2] = ACTIONS(472),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(551),
    [sym__hll_number_literal_pre_hook] = ACTIONS(476),
  },
  [STATE(71)] = {
    [sym_trace32_hll_variable] = STATE(799),
    [sym__hll_expression] = STATE(1093),
    [sym_hll_call_expression] = STATE(798),
    [sym_hll_field_expression] = STATE(798),
    [sym_hll_subscript_expression] = STATE(798),
    [sym_hll_cast_expression] = STATE(1093),
    [sym_hll_sizeof_expression] = STATE(1093),
    [sym_hll_pointer_expression] = STATE(798),
    [sym_hll_comma_expression] = STATE(2204),
    [sym_hll_update_expression] = STATE(1093),
    [sym_hll_unary_expression] = STATE(1093),
    [sym_hll_binary_expression] = STATE(1093),
    [sym_hll_assignment_expression] = STATE(1093),
    [sym__hll_assignment_left_expression] = STATE(1652),
    [sym_hll_conditional_expression] = STATE(1093),
    [sym_hll_char_literal] = STATE(1093),
    [sym_hll_string_literal] = STATE(1093),
    [sym_hll_parenthesized_expression] = STATE(798),
    [sym_hll_type_descriptor] = STATE(2110),
    [sym_hll_type_qualifier] = STATE(1518),
    [sym__hll_type_specifier] = STATE(1534),
    [sym_hll_struct_specifier] = STATE(1534),
    [sym_hll_union_specifier] = STATE(1534),
    [sym_hll_enum_specifier] = STATE(1534),
    [sym_hll_sized_type_specifier] = STATE(1534),
    [sym__hll_type_identifier] = STATE(1534),
    [sym_symbol] = STATE(1093),
    [aux_sym_block_repeat1] = STATE(72),
    [aux_sym_hll_type_descriptor_repeat1] = STATE(1518),
    [aux_sym_hll_sized_type_specifier_repeat1] = STATE(1743),
    [sym_identifier] = ACTIONS(438),
    [anon_sym_LPAREN] = ACTIONS(440),
    [anon_sym_PLUS] = ACTIONS(442),
    [anon_sym_DASH] = ACTIONS(442),
    [anon_sym_TILDE] = ACTIONS(444),
    [anon_sym_BANG] = ACTIONS(444),
    [anon_sym_PLUS_PLUS] = ACTIONS(446),
    [anon_sym_DASH_DASH] = ACTIONS(446),
    [anon_sym_STAR] = ACTIONS(448),
    [anon_sym_AMP] = ACTIONS(448),
    [anon_sym_BSLASH] = ACTIONS(450),
    [anon_sym_sizeof] = ACTIONS(452),
    [anon_sym_L_SQUOTE] = ACTIONS(454),
    [anon_sym_u_SQUOTE] = ACTIONS(454),
    [anon_sym_U_SQUOTE] = ACTIONS(454),
    [anon_sym_u8_SQUOTE] = ACTIONS(454),
    [anon_sym_SQUOTE] = ACTIONS(454),
    [anon_sym_L_DQUOTE] = ACTIONS(456),
    [anon_sym_u_DQUOTE] = ACTIONS(456),
    [anon_sym_U_DQUOTE] = ACTIONS(456),
    [anon_sym_u8_DQUOTE] = ACTIONS(456),
    [anon_sym_DQUOTE] = ACTIONS(456),
    [anon_sym_const] = ACTIONS(458),
    [anon_sym_volatile] = ACTIONS(458),
    [anon_sym_struct] = ACTIONS(460),
    [anon_sym_union] = ACTIONS(462),
    [anon_sym_enum] = ACTIONS(464),
    [anon_sym_signed] = ACTIONS(466),
    [anon_sym_unsigned] = ACTIONS(466),
    [anon_sym_long] = ACTIONS(466),
    [anon_sym_short] = ACTIONS(466),
    [sym_hll_primitive_type] = ACTIONS(468),
    [aux_sym_symbol_token1] = ACTIONS(470),
    [aux_sym_symbol_token2] = ACTIONS(472),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(613),
    [sym__hll_number_literal_pre_hook] = ACTIONS(476),
  },
  [STATE(72)] = {
    [sym_trace32_hll_variable] = STATE(799),
    [sym__hll_expression] = STATE(1094),
    [sym_hll_call_expression] = STATE(798),
    [sym_hll_field_expression] = STATE(798),
    [sym_hll_subscript_expression] = STATE(798),
    [sym_hll_cast_expression] = STATE(1094),
    [sym_hll_sizeof_expression] = STATE(1094),
    [sym_hll_pointer_expression] = STATE(798),
    [sym_hll_comma_expression] = STATE(2219),
    [sym_hll_update_expression] = STATE(1094),
    [sym_hll_unary_expression] = STATE(1094),
    [sym_hll_binary_expression] = STATE(1094),
    [sym_hll_assignment_expression] = STATE(1094),
    [sym__hll_assignment_left_expression] = STATE(1652),
    [sym_hll_conditional_expression] = STATE(1094),
    [sym_hll_char_literal] = STATE(1094),
    [sym_hll_string_literal] = STATE(1094),
    [sym_hll_parenthesized_expression] = STATE(798),
    [sym_hll_type_descriptor] = STATE(2113),
    [sym_hll_type_qualifier] = STATE(1518),
    [sym__hll_type_specifier] = STATE(1531),
    [sym_hll_struct_specifier] = STATE(1531),
    [sym_hll_union_specifier] = STATE(1531),
    [sym_hll_enum_specifier] = STATE(1531),
    [sym_hll_sized_type_specifier] = STATE(1531),
    [sym__hll_type_identifier] = STATE(1531),
    [sym_symbol] = STATE(1094),
    [aux_sym_block_repeat1] = STATE(500),
    [aux_sym_hll_type_descriptor_repeat1] = STATE(1518),
    [aux_sym_hll_sized_type_specifier_repeat1] = STATE(1743),
    [sym_identifier] = ACTIONS(438),
    [anon_sym_LPAREN] = ACTIONS(440),
    [anon_sym_PLUS] = ACTIONS(442),
    [anon_sym_DASH] = ACTIONS(442),
    [anon_sym_TILDE] = ACTIONS(444),
    [anon_sym_BANG] = ACTIONS(444),
    [anon_sym_PLUS_PLUS] = ACTIONS(446),
    [anon_sym_DASH_DASH] = ACTIONS(446),
    [anon_sym_STAR] = ACTIONS(448),
    [anon_sym_AMP] = ACTIONS(448),
    [anon_sym_BSLASH] = ACTIONS(450),
    [anon_sym_sizeof] = ACTIONS(452),
    [anon_sym_L_SQUOTE] = ACTIONS(454),
    [anon_sym_u_SQUOTE] = ACTIONS(454),
    [anon_sym_U_SQUOTE] = ACTIONS(454),
    [anon_sym_u8_SQUOTE] = ACTIONS(454),
    [anon_sym_SQUOTE] = ACTIONS(454),
    [anon_sym_L_DQUOTE] = ACTIONS(456),
    [anon_sym_u_DQUOTE] = ACTIONS(456),
    [anon_sym_U_DQUOTE] = ACTIONS(456),
    [anon_sym_u8_DQUOTE] = ACTIONS(456),
    [anon_sym_DQUOTE] = ACTIONS(456),
    [anon_sym_const] = ACTIONS(458),
    [anon_sym_volatile] = ACTIONS(458),
    [anon_sym_struct] = ACTIONS(460),
    [anon_sym_union] = ACTIONS(462),
    [anon_sym_enum] = ACTIONS(464),
    [anon_sym_signed] = ACTIONS(466),
    [anon_sym_unsigned] = ACTIONS(466),
    [anon_sym_long] = ACTIONS(466),
    [anon_sym_short] = ACTIONS(466),
    [sym_hll_primitive_type] = ACTIONS(549),
    [aux_sym_symbol_token1] = ACTIONS(470),
    [aux_sym_symbol_token2] = ACTIONS(472),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(551),
    [sym__hll_number_literal_pre_hook] = ACTIONS(476),
  },
  [STATE(73)] = {
    [sym_trace32_hll_variable] = STATE(812),
    [sym__hll_expression] = STATE(985),
    [sym_hll_call_expression] = STATE(811),
    [sym_hll_field_expression] = STATE(811),
    [sym_hll_subscript_expression] = STATE(811),
    [sym_hll_cast_expression] = STATE(985),
    [sym_hll_sizeof_expression] = STATE(985),
    [sym_hll_pointer_expression] = STATE(811),
    [sym_hll_update_expression] = STATE(985),
    [sym_hll_unary_expression] = STATE(985),
    [sym_hll_binary_expression] = STATE(985),
    [sym_hll_assignment_expression] = STATE(985),
    [sym__hll_assignment_left_expression] = STATE(1655),
    [sym_hll_conditional_expression] = STATE(985),
    [sym_hll_char_literal] = STATE(985),
    [sym_hll_string_literal] = STATE(985),
    [sym_hll_parenthesized_expression] = STATE(811),
    [sym_symbol] = STATE(985),
    [sym_identifier] = ACTIONS(559),
    [anon_sym_LPAREN] = ACTIONS(561),
    [anon_sym_PLUS] = ACTIONS(563),
    [anon_sym_DASH] = ACTIONS(563),
    [anon_sym_TILDE] = ACTIONS(565),
    [anon_sym_BANG] = ACTIONS(563),
    [anon_sym_PLUS_PLUS] = ACTIONS(567),
    [anon_sym_DASH_DASH] = ACTIONS(567),
    [anon_sym_PIPE_PIPE] = ACTIONS(334),
    [anon_sym_STAR] = ACTIONS(569),
    [anon_sym_SLASH] = ACTIONS(336),
    [anon_sym_PERCENT] = ACTIONS(334),
    [anon_sym_PIPE] = ACTIONS(336),
    [anon_sym_CARET] = ACTIONS(334),
    [anon_sym_EQ_EQ] = ACTIONS(334),
    [anon_sym_BANG_EQ] = ACTIONS(334),
    [anon_sym_GT] = ACTIONS(336),
    [anon_sym_GT_EQ] = ACTIONS(334),
    [anon_sym_LT_EQ] = ACTIONS(334),
    [anon_sym_LT] = ACTIONS(336),
    [anon_sym_LT_LT] = ACTIONS(334),
    [anon_sym_GT_GT] = ACTIONS(334),
    [anon_sym_AMP_AMP] = ACTIONS(334),
    [anon_sym_AMP] = ACTIONS(352),
    [anon_sym_DOT] = ACTIONS(334),
    [anon_sym_QMARK] = ACTIONS(334),
    [anon_sym_BSLASH] = ACTIONS(571),
    [anon_sym_DASH_GT] = ACTIONS(334),
    [anon_sym_LBRACK] = ACTIONS(334),
    [anon_sym_sizeof] = ACTIONS(573),
    [anon_sym_L_SQUOTE] = ACTIONS(575),
    [anon_sym_u_SQUOTE] = ACTIONS(575),
    [anon_sym_U_SQUOTE] = ACTIONS(575),
    [anon_sym_u8_SQUOTE] = ACTIONS(575),
    [anon_sym_SQUOTE] = ACTIONS(575),
    [anon_sym_L_DQUOTE] = ACTIONS(577),
    [anon_sym_u_DQUOTE] = ACTIONS(577),
    [anon_sym_U_DQUOTE] = ACTIONS(577),
    [anon_sym_u8_DQUOTE] = ACTIONS(577),
    [anon_sym_DQUOTE] = ACTIONS(577),
    [aux_sym__hll_expression_separator_token1] = ACTIONS(334),
    [aux_sym__hll_expression_separator_token2] = ACTIONS(336),
    [aux_sym_symbol_token1] = ACTIONS(579),
    [aux_sym_symbol_token2] = ACTIONS(581),
    [sym_comment] = ACTIONS(334),
    [sym__blank_line] = ACTIONS(334),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(336),
    [sym__hll_number_literal_pre_hook] = ACTIONS(583),
  },
  [STATE(74)] = {
    [sym_trace32_hll_variable] = STATE(799),
    [sym__hll_expression] = STATE(1104),
    [sym_hll_call_expression] = STATE(798),
    [sym_hll_field_expression] = STATE(798),
    [sym_hll_subscript_expression] = STATE(798),
    [sym_hll_cast_expression] = STATE(1104),
    [sym_hll_sizeof_expression] = STATE(1104),
    [sym_hll_pointer_expression] = STATE(798),
    [sym_hll_comma_expression] = STATE(2060),
    [sym_hll_update_expression] = STATE(1104),
    [sym_hll_unary_expression] = STATE(1104),
    [sym_hll_binary_expression] = STATE(1104),
    [sym_hll_assignment_expression] = STATE(1104),
    [sym__hll_assignment_left_expression] = STATE(1652),
    [sym_hll_conditional_expression] = STATE(1104),
    [sym_hll_char_literal] = STATE(1104),
    [sym_hll_string_literal] = STATE(1104),
    [sym_hll_parenthesized_expression] = STATE(798),
    [sym_hll_type_descriptor] = STATE(2126),
    [sym_hll_type_qualifier] = STATE(1518),
    [sym__hll_type_specifier] = STATE(1531),
    [sym_hll_struct_specifier] = STATE(1531),
    [sym_hll_union_specifier] = STATE(1531),
    [sym_hll_enum_specifier] = STATE(1531),
    [sym_hll_sized_type_specifier] = STATE(1531),
    [sym__hll_type_identifier] = STATE(1531),
    [sym_symbol] = STATE(1104),
    [aux_sym_block_repeat1] = STATE(500),
    [aux_sym_hll_type_descriptor_repeat1] = STATE(1518),
    [aux_sym_hll_sized_type_specifier_repeat1] = STATE(1743),
    [sym_identifier] = ACTIONS(438),
    [anon_sym_LPAREN] = ACTIONS(440),
    [anon_sym_PLUS] = ACTIONS(442),
    [anon_sym_DASH] = ACTIONS(442),
    [anon_sym_TILDE] = ACTIONS(444),
    [anon_sym_BANG] = ACTIONS(444),
    [anon_sym_PLUS_PLUS] = ACTIONS(446),
    [anon_sym_DASH_DASH] = ACTIONS(446),
    [anon_sym_STAR] = ACTIONS(448),
    [anon_sym_AMP] = ACTIONS(448),
    [anon_sym_BSLASH] = ACTIONS(450),
    [anon_sym_sizeof] = ACTIONS(452),
    [anon_sym_L_SQUOTE] = ACTIONS(454),
    [anon_sym_u_SQUOTE] = ACTIONS(454),
    [anon_sym_U_SQUOTE] = ACTIONS(454),
    [anon_sym_u8_SQUOTE] = ACTIONS(454),
    [anon_sym_SQUOTE] = ACTIONS(454),
    [anon_sym_L_DQUOTE] = ACTIONS(456),
    [anon_sym_u_DQUOTE] = ACTIONS(456),
    [anon_sym_U_DQUOTE] = ACTIONS(456),
    [anon_sym_u8_DQUOTE] = ACTIONS(456),
    [anon_sym_DQUOTE] = ACTIONS(456),
    [anon_sym_const] = ACTIONS(458),
    [anon_sym_volatile] = ACTIONS(458),
    [anon_sym_struct] = ACTIONS(460),
    [anon_sym_union] = ACTIONS(462),
    [anon_sym_enum] = ACTIONS(464),
    [anon_sym_signed] = ACTIONS(466),
    [anon_sym_unsigned] = ACTIONS(466),
    [anon_sym_long] = ACTIONS(466),
    [anon_sym_short] = ACTIONS(466),
    [sym_hll_primitive_type] = ACTIONS(549),
    [aux_sym_symbol_token1] = ACTIONS(470),
    [aux_sym_symbol_token2] = ACTIONS(472),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(551),
    [sym__hll_number_literal_pre_hook] = ACTIONS(476),
  },
  [STATE(75)] = {
    [sym_trace32_hll_variable] = STATE(799),
    [sym__hll_expression] = STATE(1102),
    [sym_hll_call_expression] = STATE(798),
    [sym_hll_field_expression] = STATE(798),
    [sym_hll_subscript_expression] = STATE(798),
    [sym_hll_cast_expression] = STATE(1102),
    [sym_hll_sizeof_expression] = STATE(1102),
    [sym_hll_pointer_expression] = STATE(798),
    [sym_hll_comma_expression] = STATE(2051),
    [sym_hll_update_expression] = STATE(1102),
    [sym_hll_unary_expression] = STATE(1102),
    [sym_hll_binary_expression] = STATE(1102),
    [sym_hll_assignment_expression] = STATE(1102),
    [sym__hll_assignment_left_expression] = STATE(1652),
    [sym_hll_conditional_expression] = STATE(1102),
    [sym_hll_char_literal] = STATE(1102),
    [sym_hll_string_literal] = STATE(1102),
    [sym_hll_parenthesized_expression] = STATE(798),
    [sym_hll_type_descriptor] = STATE(2135),
    [sym_hll_type_qualifier] = STATE(1518),
    [sym__hll_type_specifier] = STATE(1534),
    [sym_hll_struct_specifier] = STATE(1534),
    [sym_hll_union_specifier] = STATE(1534),
    [sym_hll_enum_specifier] = STATE(1534),
    [sym_hll_sized_type_specifier] = STATE(1534),
    [sym__hll_type_identifier] = STATE(1534),
    [sym_symbol] = STATE(1102),
    [aux_sym_block_repeat1] = STATE(76),
    [aux_sym_hll_type_descriptor_repeat1] = STATE(1518),
    [aux_sym_hll_sized_type_specifier_repeat1] = STATE(1743),
    [sym_identifier] = ACTIONS(438),
    [anon_sym_LPAREN] = ACTIONS(440),
    [anon_sym_PLUS] = ACTIONS(442),
    [anon_sym_DASH] = ACTIONS(442),
    [anon_sym_TILDE] = ACTIONS(444),
    [anon_sym_BANG] = ACTIONS(444),
    [anon_sym_PLUS_PLUS] = ACTIONS(446),
    [anon_sym_DASH_DASH] = ACTIONS(446),
    [anon_sym_STAR] = ACTIONS(448),
    [anon_sym_AMP] = ACTIONS(448),
    [anon_sym_BSLASH] = ACTIONS(450),
    [anon_sym_sizeof] = ACTIONS(452),
    [anon_sym_L_SQUOTE] = ACTIONS(454),
    [anon_sym_u_SQUOTE] = ACTIONS(454),
    [anon_sym_U_SQUOTE] = ACTIONS(454),
    [anon_sym_u8_SQUOTE] = ACTIONS(454),
    [anon_sym_SQUOTE] = ACTIONS(454),
    [anon_sym_L_DQUOTE] = ACTIONS(456),
    [anon_sym_u_DQUOTE] = ACTIONS(456),
    [anon_sym_U_DQUOTE] = ACTIONS(456),
    [anon_sym_u8_DQUOTE] = ACTIONS(456),
    [anon_sym_DQUOTE] = ACTIONS(456),
    [anon_sym_const] = ACTIONS(458),
    [anon_sym_volatile] = ACTIONS(458),
    [anon_sym_struct] = ACTIONS(460),
    [anon_sym_union] = ACTIONS(462),
    [anon_sym_enum] = ACTIONS(464),
    [anon_sym_signed] = ACTIONS(466),
    [anon_sym_unsigned] = ACTIONS(466),
    [anon_sym_long] = ACTIONS(466),
    [anon_sym_short] = ACTIONS(466),
    [sym_hll_primitive_type] = ACTIONS(468),
    [aux_sym_symbol_token1] = ACTIONS(470),
    [aux_sym_symbol_token2] = ACTIONS(472),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(615),
    [sym__hll_number_literal_pre_hook] = ACTIONS(476),
  },
  [STATE(76)] = {
    [sym_trace32_hll_variable] = STATE(799),
    [sym__hll_expression] = STATE(1104),
    [sym_hll_call_expression] = STATE(798),
    [sym_hll_field_expression] = STATE(798),
    [sym_hll_subscript_expression] = STATE(798),
    [sym_hll_cast_expression] = STATE(1104),
    [sym_hll_sizeof_expression] = STATE(1104),
    [sym_hll_pointer_expression] = STATE(798),
    [sym_hll_comma_expression] = STATE(2060),
    [sym_hll_update_expression] = STATE(1104),
    [sym_hll_unary_expression] = STATE(1104),
    [sym_hll_binary_expression] = STATE(1104),
    [sym_hll_assignment_expression] = STATE(1104),
    [sym__hll_assignment_left_expression] = STATE(1652),
    [sym_hll_conditional_expression] = STATE(1104),
    [sym_hll_char_literal] = STATE(1104),
    [sym_hll_string_literal] = STATE(1104),
    [sym_hll_parenthesized_expression] = STATE(798),
    [sym_hll_type_descriptor] = STATE(2137),
    [sym_hll_type_qualifier] = STATE(1518),
    [sym__hll_type_specifier] = STATE(1531),
    [sym_hll_struct_specifier] = STATE(1531),
    [sym_hll_union_specifier] = STATE(1531),
    [sym_hll_enum_specifier] = STATE(1531),
    [sym_hll_sized_type_specifier] = STATE(1531),
    [sym__hll_type_identifier] = STATE(1531),
    [sym_symbol] = STATE(1104),
    [aux_sym_block_repeat1] = STATE(500),
    [aux_sym_hll_type_descriptor_repeat1] = STATE(1518),
    [aux_sym_hll_sized_type_specifier_repeat1] = STATE(1743),
    [sym_identifier] = ACTIONS(438),
    [anon_sym_LPAREN] = ACTIONS(440),
    [anon_sym_PLUS] = ACTIONS(442),
    [anon_sym_DASH] = ACTIONS(442),
    [anon_sym_TILDE] = ACTIONS(444),
    [anon_sym_BANG] = ACTIONS(444),
    [anon_sym_PLUS_PLUS] = ACTIONS(446),
    [anon_sym_DASH_DASH] = ACTIONS(446),
    [anon_sym_STAR] = ACTIONS(448),
    [anon_sym_AMP] = ACTIONS(448),
    [anon_sym_BSLASH] = ACTIONS(450),
    [anon_sym_sizeof] = ACTIONS(452),
    [anon_sym_L_SQUOTE] = ACTIONS(454),
    [anon_sym_u_SQUOTE] = ACTIONS(454),
    [anon_sym_U_SQUOTE] = ACTIONS(454),
    [anon_sym_u8_SQUOTE] = ACTIONS(454),
    [anon_sym_SQUOTE] = ACTIONS(454),
    [anon_sym_L_DQUOTE] = ACTIONS(456),
    [anon_sym_u_DQUOTE] = ACTIONS(456),
    [anon_sym_U_DQUOTE] = ACTIONS(456),
    [anon_sym_u8_DQUOTE] = ACTIONS(456),
    [anon_sym_DQUOTE] = ACTIONS(456),
    [anon_sym_const] = ACTIONS(458),
    [anon_sym_volatile] = ACTIONS(458),
    [anon_sym_struct] = ACTIONS(460),
    [anon_sym_union] = ACTIONS(462),
    [anon_sym_enum] = ACTIONS(464),
    [anon_sym_signed] = ACTIONS(466),
    [anon_sym_unsigned] = ACTIONS(466),
    [anon_sym_long] = ACTIONS(466),
    [anon_sym_short] = ACTIONS(466),
    [sym_hll_primitive_type] = ACTIONS(549),
    [aux_sym_symbol_token1] = ACTIONS(470),
    [aux_sym_symbol_token2] = ACTIONS(472),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(551),
    [sym__hll_number_literal_pre_hook] = ACTIONS(476),
  },
  [STATE(77)] = {
    [sym_trace32_hll_variable] = STATE(799),
    [sym__hll_expression] = STATE(1102),
    [sym_hll_call_expression] = STATE(798),
    [sym_hll_field_expression] = STATE(798),
    [sym_hll_subscript_expression] = STATE(798),
    [sym_hll_cast_expression] = STATE(1102),
    [sym_hll_sizeof_expression] = STATE(1102),
    [sym_hll_pointer_expression] = STATE(798),
    [sym_hll_comma_expression] = STATE(2051),
    [sym_hll_update_expression] = STATE(1102),
    [sym_hll_unary_expression] = STATE(1102),
    [sym_hll_binary_expression] = STATE(1102),
    [sym_hll_assignment_expression] = STATE(1102),
    [sym__hll_assignment_left_expression] = STATE(1652),
    [sym_hll_conditional_expression] = STATE(1102),
    [sym_hll_char_literal] = STATE(1102),
    [sym_hll_string_literal] = STATE(1102),
    [sym_hll_parenthesized_expression] = STATE(798),
    [sym_hll_type_descriptor] = STATE(2148),
    [sym_hll_type_qualifier] = STATE(1518),
    [sym__hll_type_specifier] = STATE(1534),
    [sym_hll_struct_specifier] = STATE(1534),
    [sym_hll_union_specifier] = STATE(1534),
    [sym_hll_enum_specifier] = STATE(1534),
    [sym_hll_sized_type_specifier] = STATE(1534),
    [sym__hll_type_identifier] = STATE(1534),
    [sym_symbol] = STATE(1102),
    [aux_sym_block_repeat1] = STATE(78),
    [aux_sym_hll_type_descriptor_repeat1] = STATE(1518),
    [aux_sym_hll_sized_type_specifier_repeat1] = STATE(1743),
    [sym_identifier] = ACTIONS(438),
    [anon_sym_LPAREN] = ACTIONS(440),
    [anon_sym_PLUS] = ACTIONS(442),
    [anon_sym_DASH] = ACTIONS(442),
    [anon_sym_TILDE] = ACTIONS(444),
    [anon_sym_BANG] = ACTIONS(444),
    [anon_sym_PLUS_PLUS] = ACTIONS(446),
    [anon_sym_DASH_DASH] = ACTIONS(446),
    [anon_sym_STAR] = ACTIONS(448),
    [anon_sym_AMP] = ACTIONS(448),
    [anon_sym_BSLASH] = ACTIONS(450),
    [anon_sym_sizeof] = ACTIONS(452),
    [anon_sym_L_SQUOTE] = ACTIONS(454),
    [anon_sym_u_SQUOTE] = ACTIONS(454),
    [anon_sym_U_SQUOTE] = ACTIONS(454),
    [anon_sym_u8_SQUOTE] = ACTIONS(454),
    [anon_sym_SQUOTE] = ACTIONS(454),
    [anon_sym_L_DQUOTE] = ACTIONS(456),
    [anon_sym_u_DQUOTE] = ACTIONS(456),
    [anon_sym_U_DQUOTE] = ACTIONS(456),
    [anon_sym_u8_DQUOTE] = ACTIONS(456),
    [anon_sym_DQUOTE] = ACTIONS(456),
    [anon_sym_const] = ACTIONS(458),
    [anon_sym_volatile] = ACTIONS(458),
    [anon_sym_struct] = ACTIONS(460),
    [anon_sym_union] = ACTIONS(462),
    [anon_sym_enum] = ACTIONS(464),
    [anon_sym_signed] = ACTIONS(466),
    [anon_sym_unsigned] = ACTIONS(466),
    [anon_sym_long] = ACTIONS(466),
    [anon_sym_short] = ACTIONS(466),
    [sym_hll_primitive_type] = ACTIONS(468),
    [aux_sym_symbol_token1] = ACTIONS(470),
    [aux_sym_symbol_token2] = ACTIONS(472),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(617),
    [sym__hll_number_literal_pre_hook] = ACTIONS(476),
  },
  [STATE(78)] = {
    [sym_trace32_hll_variable] = STATE(799),
    [sym__hll_expression] = STATE(1104),
    [sym_hll_call_expression] = STATE(798),
    [sym_hll_field_expression] = STATE(798),
    [sym_hll_subscript_expression] = STATE(798),
    [sym_hll_cast_expression] = STATE(1104),
    [sym_hll_sizeof_expression] = STATE(1104),
    [sym_hll_pointer_expression] = STATE(798),
    [sym_hll_comma_expression] = STATE(2060),
    [sym_hll_update_expression] = STATE(1104),
    [sym_hll_unary_expression] = STATE(1104),
    [sym_hll_binary_expression] = STATE(1104),
    [sym_hll_assignment_expression] = STATE(1104),
    [sym__hll_assignment_left_expression] = STATE(1652),
    [sym_hll_conditional_expression] = STATE(1104),
    [sym_hll_char_literal] = STATE(1104),
    [sym_hll_string_literal] = STATE(1104),
    [sym_hll_parenthesized_expression] = STATE(798),
    [sym_hll_type_descriptor] = STATE(2152),
    [sym_hll_type_qualifier] = STATE(1518),
    [sym__hll_type_specifier] = STATE(1531),
    [sym_hll_struct_specifier] = STATE(1531),
    [sym_hll_union_specifier] = STATE(1531),
    [sym_hll_enum_specifier] = STATE(1531),
    [sym_hll_sized_type_specifier] = STATE(1531),
    [sym__hll_type_identifier] = STATE(1531),
    [sym_symbol] = STATE(1104),
    [aux_sym_block_repeat1] = STATE(500),
    [aux_sym_hll_type_descriptor_repeat1] = STATE(1518),
    [aux_sym_hll_sized_type_specifier_repeat1] = STATE(1743),
    [sym_identifier] = ACTIONS(438),
    [anon_sym_LPAREN] = ACTIONS(440),
    [anon_sym_PLUS] = ACTIONS(442),
    [anon_sym_DASH] = ACTIONS(442),
    [anon_sym_TILDE] = ACTIONS(444),
    [anon_sym_BANG] = ACTIONS(444),
    [anon_sym_PLUS_PLUS] = ACTIONS(446),
    [anon_sym_DASH_DASH] = ACTIONS(446),
    [anon_sym_STAR] = ACTIONS(448),
    [anon_sym_AMP] = ACTIONS(448),
    [anon_sym_BSLASH] = ACTIONS(450),
    [anon_sym_sizeof] = ACTIONS(452),
    [anon_sym_L_SQUOTE] = ACTIONS(454),
    [anon_sym_u_SQUOTE] = ACTIONS(454),
    [anon_sym_U_SQUOTE] = ACTIONS(454),
    [anon_sym_u8_SQUOTE] = ACTIONS(454),
    [anon_sym_SQUOTE] = ACTIONS(454),
    [anon_sym_L_DQUOTE] = ACTIONS(456),
    [anon_sym_u_DQUOTE] = ACTIONS(456),
    [anon_sym_U_DQUOTE] = ACTIONS(456),
    [anon_sym_u8_DQUOTE] = ACTIONS(456),
    [anon_sym_DQUOTE] = ACTIONS(456),
    [anon_sym_const] = ACTIONS(458),
    [anon_sym_volatile] = ACTIONS(458),
    [anon_sym_struct] = ACTIONS(460),
    [anon_sym_union] = ACTIONS(462),
    [anon_sym_enum] = ACTIONS(464),
    [anon_sym_signed] = ACTIONS(466),
    [anon_sym_unsigned] = ACTIONS(466),
    [anon_sym_long] = ACTIONS(466),
    [anon_sym_short] = ACTIONS(466),
    [sym_hll_primitive_type] = ACTIONS(549),
    [aux_sym_symbol_token1] = ACTIONS(470),
    [aux_sym_symbol_token2] = ACTIONS(472),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(551),
    [sym__hll_number_literal_pre_hook] = ACTIONS(476),
  },
  [STATE(79)] = {
    [sym_trace32_hll_variable] = STATE(812),
    [sym__hll_expression] = STATE(986),
    [sym_hll_call_expression] = STATE(811),
    [sym_hll_field_expression] = STATE(811),
    [sym_hll_subscript_expression] = STATE(811),
    [sym_hll_cast_expression] = STATE(986),
    [sym_hll_sizeof_expression] = STATE(986),
    [sym_hll_pointer_expression] = STATE(811),
    [sym_hll_update_expression] = STATE(986),
    [sym_hll_unary_expression] = STATE(986),
    [sym_hll_binary_expression] = STATE(986),
    [sym_hll_assignment_expression] = STATE(986),
    [sym__hll_assignment_left_expression] = STATE(1655),
    [sym_hll_conditional_expression] = STATE(986),
    [sym_hll_char_literal] = STATE(986),
    [sym_hll_string_literal] = STATE(986),
    [sym_hll_parenthesized_expression] = STATE(811),
    [sym_symbol] = STATE(986),
    [sym_identifier] = ACTIONS(559),
    [anon_sym_LPAREN] = ACTIONS(561),
    [anon_sym_PLUS] = ACTIONS(563),
    [anon_sym_DASH] = ACTIONS(563),
    [anon_sym_TILDE] = ACTIONS(565),
    [anon_sym_BANG] = ACTIONS(563),
    [anon_sym_PLUS_PLUS] = ACTIONS(567),
    [anon_sym_DASH_DASH] = ACTIONS(567),
    [anon_sym_PIPE_PIPE] = ACTIONS(330),
    [anon_sym_STAR] = ACTIONS(569),
    [anon_sym_SLASH] = ACTIONS(332),
    [anon_sym_PERCENT] = ACTIONS(330),
    [anon_sym_PIPE] = ACTIONS(332),
    [anon_sym_CARET] = ACTIONS(330),
    [anon_sym_EQ_EQ] = ACTIONS(330),
    [anon_sym_BANG_EQ] = ACTIONS(330),
    [anon_sym_GT] = ACTIONS(332),
    [anon_sym_GT_EQ] = ACTIONS(330),
    [anon_sym_LT_EQ] = ACTIONS(330),
    [anon_sym_LT] = ACTIONS(332),
    [anon_sym_LT_LT] = ACTIONS(330),
    [anon_sym_GT_GT] = ACTIONS(330),
    [anon_sym_AMP_AMP] = ACTIONS(330),
    [anon_sym_AMP] = ACTIONS(352),
    [anon_sym_DOT] = ACTIONS(330),
    [anon_sym_QMARK] = ACTIONS(330),
    [anon_sym_BSLASH] = ACTIONS(571),
    [anon_sym_DASH_GT] = ACTIONS(330),
    [anon_sym_LBRACK] = ACTIONS(330),
    [anon_sym_sizeof] = ACTIONS(573),
    [anon_sym_L_SQUOTE] = ACTIONS(575),
    [anon_sym_u_SQUOTE] = ACTIONS(575),
    [anon_sym_U_SQUOTE] = ACTIONS(575),
    [anon_sym_u8_SQUOTE] = ACTIONS(575),
    [anon_sym_SQUOTE] = ACTIONS(575),
    [anon_sym_L_DQUOTE] = ACTIONS(577),
    [anon_sym_u_DQUOTE] = ACTIONS(577),
    [anon_sym_U_DQUOTE] = ACTIONS(577),
    [anon_sym_u8_DQUOTE] = ACTIONS(577),
    [anon_sym_DQUOTE] = ACTIONS(577),
    [aux_sym__hll_expression_separator_token1] = ACTIONS(330),
    [aux_sym__hll_expression_separator_token2] = ACTIONS(332),
    [aux_sym_symbol_token1] = ACTIONS(579),
    [aux_sym_symbol_token2] = ACTIONS(581),
    [sym_comment] = ACTIONS(330),
    [sym__blank_line] = ACTIONS(330),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(332),
    [sym__hll_number_literal_pre_hook] = ACTIONS(583),
  },
  [STATE(80)] = {
    [sym_trace32_hll_variable] = STATE(812),
    [sym__hll_expression] = STATE(987),
    [sym_hll_call_expression] = STATE(811),
    [sym_hll_field_expression] = STATE(811),
    [sym_hll_subscript_expression] = STATE(811),
    [sym_hll_cast_expression] = STATE(987),
    [sym_hll_sizeof_expression] = STATE(987),
    [sym_hll_pointer_expression] = STATE(811),
    [sym_hll_update_expression] = STATE(987),
    [sym_hll_unary_expression] = STATE(987),
    [sym_hll_binary_expression] = STATE(987),
    [sym_hll_assignment_expression] = STATE(987),
    [sym__hll_assignment_left_expression] = STATE(1655),
    [sym_hll_conditional_expression] = STATE(987),
    [sym_hll_char_literal] = STATE(987),
    [sym_hll_string_literal] = STATE(987),
    [sym_hll_parenthesized_expression] = STATE(811),
    [sym_symbol] = STATE(987),
    [sym_identifier] = ACTIONS(559),
    [anon_sym_LPAREN] = ACTIONS(561),
    [anon_sym_PLUS] = ACTIONS(563),
    [anon_sym_DASH] = ACTIONS(563),
    [anon_sym_TILDE] = ACTIONS(565),
    [anon_sym_BANG] = ACTIONS(563),
    [anon_sym_PLUS_PLUS] = ACTIONS(567),
    [anon_sym_DASH_DASH] = ACTIONS(567),
    [anon_sym_PIPE_PIPE] = ACTIONS(302),
    [anon_sym_STAR] = ACTIONS(569),
    [anon_sym_SLASH] = ACTIONS(306),
    [anon_sym_PERCENT] = ACTIONS(302),
    [anon_sym_PIPE] = ACTIONS(306),
    [anon_sym_CARET] = ACTIONS(302),
    [anon_sym_EQ_EQ] = ACTIONS(302),
    [anon_sym_BANG_EQ] = ACTIONS(302),
    [anon_sym_GT] = ACTIONS(306),
    [anon_sym_GT_EQ] = ACTIONS(302),
    [anon_sym_LT_EQ] = ACTIONS(302),
    [anon_sym_LT] = ACTIONS(306),
    [anon_sym_LT_LT] = ACTIONS(302),
    [anon_sym_GT_GT] = ACTIONS(302),
    [anon_sym_AMP_AMP] = ACTIONS(302),
    [anon_sym_AMP] = ACTIONS(352),
    [anon_sym_DOT] = ACTIONS(302),
    [anon_sym_QMARK] = ACTIONS(302),
    [anon_sym_BSLASH] = ACTIONS(571),
    [anon_sym_DASH_GT] = ACTIONS(302),
    [anon_sym_LBRACK] = ACTIONS(302),
    [anon_sym_sizeof] = ACTIONS(573),
    [anon_sym_L_SQUOTE] = ACTIONS(575),
    [anon_sym_u_SQUOTE] = ACTIONS(575),
    [anon_sym_U_SQUOTE] = ACTIONS(575),
    [anon_sym_u8_SQUOTE] = ACTIONS(575),
    [anon_sym_SQUOTE] = ACTIONS(575),
    [anon_sym_L_DQUOTE] = ACTIONS(577),
    [anon_sym_u_DQUOTE] = ACTIONS(577),
    [anon_sym_U_DQUOTE] = ACTIONS(577),
    [anon_sym_u8_DQUOTE] = ACTIONS(577),
    [anon_sym_DQUOTE] = ACTIONS(577),
    [aux_sym__hll_expression_separator_token1] = ACTIONS(302),
    [aux_sym__hll_expression_separator_token2] = ACTIONS(306),
    [aux_sym_symbol_token1] = ACTIONS(579),
    [aux_sym_symbol_token2] = ACTIONS(581),
    [sym_comment] = ACTIONS(302),
    [sym__blank_line] = ACTIONS(302),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(306),
    [sym__hll_number_literal_pre_hook] = ACTIONS(583),
  },
  [STATE(81)] = {
    [sym_trace32_hll_variable] = STATE(799),
    [sym__hll_expression] = STATE(1094),
    [sym_hll_call_expression] = STATE(798),
    [sym_hll_field_expression] = STATE(798),
    [sym_hll_subscript_expression] = STATE(798),
    [sym_hll_cast_expression] = STATE(1094),
    [sym_hll_sizeof_expression] = STATE(1094),
    [sym_hll_pointer_expression] = STATE(798),
    [sym_hll_comma_expression] = STATE(2219),
    [sym_hll_update_expression] = STATE(1094),
    [sym_hll_unary_expression] = STATE(1094),
    [sym_hll_binary_expression] = STATE(1094),
    [sym_hll_assignment_expression] = STATE(1094),
    [sym__hll_assignment_left_expression] = STATE(1652),
    [sym_hll_conditional_expression] = STATE(1094),
    [sym_hll_char_literal] = STATE(1094),
    [sym_hll_string_literal] = STATE(1094),
    [sym_hll_parenthesized_expression] = STATE(798),
    [sym_hll_type_descriptor] = STATE(2105),
    [sym_hll_type_qualifier] = STATE(1518),
    [sym__hll_type_specifier] = STATE(1531),
    [sym_hll_struct_specifier] = STATE(1531),
    [sym_hll_union_specifier] = STATE(1531),
    [sym_hll_enum_specifier] = STATE(1531),
    [sym_hll_sized_type_specifier] = STATE(1531),
    [sym__hll_type_identifier] = STATE(1531),
    [sym_symbol] = STATE(1094),
    [aux_sym_block_repeat1] = STATE(500),
    [aux_sym_hll_type_descriptor_repeat1] = STATE(1518),
    [aux_sym_hll_sized_type_specifier_repeat1] = STATE(1743),
    [sym_identifier] = ACTIONS(438),
    [anon_sym_LPAREN] = ACTIONS(440),
    [anon_sym_PLUS] = ACTIONS(442),
    [anon_sym_DASH] = ACTIONS(442),
    [anon_sym_TILDE] = ACTIONS(444),
    [anon_sym_BANG] = ACTIONS(444),
    [anon_sym_PLUS_PLUS] = ACTIONS(446),
    [anon_sym_DASH_DASH] = ACTIONS(446),
    [anon_sym_STAR] = ACTIONS(448),
    [anon_sym_AMP] = ACTIONS(448),
    [anon_sym_BSLASH] = ACTIONS(450),
    [anon_sym_sizeof] = ACTIONS(452),
    [anon_sym_L_SQUOTE] = ACTIONS(454),
    [anon_sym_u_SQUOTE] = ACTIONS(454),
    [anon_sym_U_SQUOTE] = ACTIONS(454),
    [anon_sym_u8_SQUOTE] = ACTIONS(454),
    [anon_sym_SQUOTE] = ACTIONS(454),
    [anon_sym_L_DQUOTE] = ACTIONS(456),
    [anon_sym_u_DQUOTE] = ACTIONS(456),
    [anon_sym_U_DQUOTE] = ACTIONS(456),
    [anon_sym_u8_DQUOTE] = ACTIONS(456),
    [anon_sym_DQUOTE] = ACTIONS(456),
    [anon_sym_const] = ACTIONS(458),
    [anon_sym_volatile] = ACTIONS(458),
    [anon_sym_struct] = ACTIONS(460),
    [anon_sym_union] = ACTIONS(462),
    [anon_sym_enum] = ACTIONS(464),
    [anon_sym_signed] = ACTIONS(466),
    [anon_sym_unsigned] = ACTIONS(466),
    [anon_sym_long] = ACTIONS(466),
    [anon_sym_short] = ACTIONS(466),
    [sym_hll_primitive_type] = ACTIONS(549),
    [aux_sym_symbol_token1] = ACTIONS(470),
    [aux_sym_symbol_token2] = ACTIONS(472),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(551),
    [sym__hll_number_literal_pre_hook] = ACTIONS(476),
  },
  [STATE(82)] = {
    [sym_trace32_hll_variable] = STATE(842),
    [sym__hll_expression] = STATE(1185),
    [sym_hll_call_expression] = STATE(841),
    [sym_hll_field_expression] = STATE(841),
    [sym_hll_subscript_expression] = STATE(841),
    [sym_hll_cast_expression] = STATE(1185),
    [sym_hll_sizeof_expression] = STATE(1185),
    [sym_hll_pointer_expression] = STATE(841),
    [sym_hll_update_expression] = STATE(1185),
    [sym_hll_unary_expression] = STATE(1185),
    [sym_hll_binary_expression] = STATE(1185),
    [sym_hll_assignment_expression] = STATE(1185),
    [sym__hll_assignment_left_expression] = STATE(1596),
    [sym_hll_conditional_expression] = STATE(1185),
    [sym_hll_char_literal] = STATE(1185),
    [sym_hll_string_literal] = STATE(1185),
    [sym_hll_parenthesized_expression] = STATE(841),
    [sym_symbol] = STATE(1185),
    [sym_identifier] = ACTIONS(619),
    [anon_sym_RPAREN] = ACTIONS(334),
    [anon_sym_LPAREN] = ACTIONS(621),
    [anon_sym_PLUS] = ACTIONS(623),
    [anon_sym_DASH] = ACTIONS(623),
    [anon_sym_TILDE] = ACTIONS(625),
    [anon_sym_BANG] = ACTIONS(623),
    [anon_sym_PLUS_PLUS] = ACTIONS(627),
    [anon_sym_DASH_DASH] = ACTIONS(627),
    [anon_sym_PIPE_PIPE] = ACTIONS(334),
    [anon_sym_STAR] = ACTIONS(448),
    [anon_sym_SLASH] = ACTIONS(334),
    [anon_sym_PERCENT] = ACTIONS(334),
    [anon_sym_PIPE] = ACTIONS(336),
    [anon_sym_CARET] = ACTIONS(334),
    [anon_sym_EQ_EQ] = ACTIONS(334),
    [anon_sym_BANG_EQ] = ACTIONS(334),
    [anon_sym_GT] = ACTIONS(336),
    [anon_sym_GT_EQ] = ACTIONS(334),
    [anon_sym_LT_EQ] = ACTIONS(334),
    [anon_sym_LT] = ACTIONS(336),
    [anon_sym_LT_LT] = ACTIONS(334),
    [anon_sym_GT_GT] = ACTIONS(334),
    [anon_sym_AMP_AMP] = ACTIONS(334),
    [anon_sym_AMP] = ACTIONS(314),
    [anon_sym_COLON] = ACTIONS(334),
    [anon_sym_DOT] = ACTIONS(334),
    [anon_sym_QMARK] = ACTIONS(334),
    [anon_sym_BSLASH] = ACTIONS(629),
    [anon_sym_DASH_GT] = ACTIONS(334),
    [anon_sym_LBRACK] = ACTIONS(334),
    [anon_sym_RBRACK] = ACTIONS(334),
    [anon_sym_sizeof] = ACTIONS(631),
    [anon_sym_L_SQUOTE] = ACTIONS(575),
    [anon_sym_u_SQUOTE] = ACTIONS(575),
    [anon_sym_U_SQUOTE] = ACTIONS(575),
    [anon_sym_u8_SQUOTE] = ACTIONS(575),
    [anon_sym_SQUOTE] = ACTIONS(575),
    [anon_sym_L_DQUOTE] = ACTIONS(577),
    [anon_sym_u_DQUOTE] = ACTIONS(577),
    [anon_sym_U_DQUOTE] = ACTIONS(577),
    [anon_sym_u8_DQUOTE] = ACTIONS(577),
    [anon_sym_DQUOTE] = ACTIONS(577),
    [aux_sym_symbol_token1] = ACTIONS(579),
    [aux_sym_symbol_token2] = ACTIONS(581),
    [sym__line_continuation] = ACTIONS(3),
    [sym__hll_number_literal_pre_hook] = ACTIONS(583),
  },
  [STATE(83)] = {
    [sym_trace32_hll_variable] = STATE(890),
    [sym__hll_expression] = STATE(1259),
    [sym_hll_call_expression] = STATE(889),
    [sym_hll_field_expression] = STATE(889),
    [sym_hll_subscript_expression] = STATE(889),
    [sym_hll_cast_expression] = STATE(1259),
    [sym_hll_sizeof_expression] = STATE(1259),
    [sym_hll_pointer_expression] = STATE(889),
    [sym_hll_update_expression] = STATE(1259),
    [sym_hll_unary_expression] = STATE(1259),
    [sym_hll_binary_expression] = STATE(1259),
    [sym_hll_assignment_expression] = STATE(1259),
    [sym__hll_assignment_left_expression] = STATE(1609),
    [sym_hll_conditional_expression] = STATE(1259),
    [sym_hll_char_literal] = STATE(1259),
    [sym_hll_string_literal] = STATE(1259),
    [sym_hll_parenthesized_expression] = STATE(889),
    [sym_symbol] = STATE(1259),
    [sym_identifier] = ACTIONS(633),
    [anon_sym_LPAREN] = ACTIONS(635),
    [anon_sym_PLUS] = ACTIONS(637),
    [anon_sym_DASH] = ACTIONS(637),
    [anon_sym_TILDE] = ACTIONS(639),
    [anon_sym_BANG] = ACTIONS(637),
    [anon_sym_PLUS_PLUS] = ACTIONS(641),
    [anon_sym_DASH_DASH] = ACTIONS(641),
    [anon_sym_PIPE_PIPE] = ACTIONS(302),
    [anon_sym_STAR] = ACTIONS(643),
    [anon_sym_SLASH] = ACTIONS(302),
    [anon_sym_PERCENT] = ACTIONS(302),
    [anon_sym_PIPE] = ACTIONS(306),
    [anon_sym_CARET] = ACTIONS(302),
    [anon_sym_EQ_EQ] = ACTIONS(302),
    [anon_sym_BANG_EQ] = ACTIONS(302),
    [anon_sym_GT] = ACTIONS(306),
    [anon_sym_GT_EQ] = ACTIONS(302),
    [anon_sym_LT_EQ] = ACTIONS(302),
    [anon_sym_LT] = ACTIONS(306),
    [anon_sym_LT_LT] = ACTIONS(302),
    [anon_sym_GT_GT] = ACTIONS(302),
    [anon_sym_AMP_AMP] = ACTIONS(302),
    [anon_sym_AMP] = ACTIONS(404),
    [anon_sym_DOT] = ACTIONS(302),
    [anon_sym_QMARK] = ACTIONS(302),
    [anon_sym_BSLASH] = ACTIONS(645),
    [anon_sym_DASH_GT] = ACTIONS(302),
    [anon_sym_LBRACK] = ACTIONS(302),
    [anon_sym_sizeof] = ACTIONS(647),
    [anon_sym_L_SQUOTE] = ACTIONS(649),
    [anon_sym_u_SQUOTE] = ACTIONS(649),
    [anon_sym_U_SQUOTE] = ACTIONS(649),
    [anon_sym_u8_SQUOTE] = ACTIONS(649),
    [anon_sym_SQUOTE] = ACTIONS(649),
    [anon_sym_L_DQUOTE] = ACTIONS(651),
    [anon_sym_u_DQUOTE] = ACTIONS(651),
    [anon_sym_U_DQUOTE] = ACTIONS(651),
    [anon_sym_u8_DQUOTE] = ACTIONS(651),
    [anon_sym_DQUOTE] = ACTIONS(651),
    [aux_sym__hll_expression_separator_token1] = ACTIONS(302),
    [aux_sym__hll_expression_separator_token2] = ACTIONS(302),
    [aux_sym_symbol_token1] = ACTIONS(653),
    [aux_sym_symbol_token2] = ACTIONS(655),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(306),
    [sym__hll_number_literal_pre_hook] = ACTIONS(657),
  },
  [STATE(84)] = {
    [sym_trace32_hll_variable] = STATE(842),
    [sym__hll_expression] = STATE(1183),
    [sym_hll_call_expression] = STATE(841),
    [sym_hll_field_expression] = STATE(841),
    [sym_hll_subscript_expression] = STATE(841),
    [sym_hll_cast_expression] = STATE(1183),
    [sym_hll_sizeof_expression] = STATE(1183),
    [sym_hll_pointer_expression] = STATE(841),
    [sym_hll_update_expression] = STATE(1183),
    [sym_hll_unary_expression] = STATE(1183),
    [sym_hll_binary_expression] = STATE(1183),
    [sym_hll_assignment_expression] = STATE(1183),
    [sym__hll_assignment_left_expression] = STATE(1596),
    [sym_hll_conditional_expression] = STATE(1183),
    [sym_hll_char_literal] = STATE(1183),
    [sym_hll_string_literal] = STATE(1183),
    [sym_hll_parenthesized_expression] = STATE(841),
    [sym_symbol] = STATE(1183),
    [sym_identifier] = ACTIONS(619),
    [anon_sym_RPAREN] = ACTIONS(338),
    [anon_sym_LPAREN] = ACTIONS(621),
    [anon_sym_PLUS] = ACTIONS(623),
    [anon_sym_DASH] = ACTIONS(623),
    [anon_sym_TILDE] = ACTIONS(625),
    [anon_sym_BANG] = ACTIONS(623),
    [anon_sym_PLUS_PLUS] = ACTIONS(627),
    [anon_sym_DASH_DASH] = ACTIONS(627),
    [anon_sym_PIPE_PIPE] = ACTIONS(338),
    [anon_sym_STAR] = ACTIONS(448),
    [anon_sym_SLASH] = ACTIONS(338),
    [anon_sym_PERCENT] = ACTIONS(338),
    [anon_sym_PIPE] = ACTIONS(340),
    [anon_sym_CARET] = ACTIONS(338),
    [anon_sym_EQ_EQ] = ACTIONS(338),
    [anon_sym_BANG_EQ] = ACTIONS(338),
    [anon_sym_GT] = ACTIONS(340),
    [anon_sym_GT_EQ] = ACTIONS(338),
    [anon_sym_LT_EQ] = ACTIONS(338),
    [anon_sym_LT] = ACTIONS(340),
    [anon_sym_LT_LT] = ACTIONS(338),
    [anon_sym_GT_GT] = ACTIONS(338),
    [anon_sym_AMP_AMP] = ACTIONS(338),
    [anon_sym_AMP] = ACTIONS(314),
    [anon_sym_COLON] = ACTIONS(338),
    [anon_sym_DOT] = ACTIONS(338),
    [anon_sym_QMARK] = ACTIONS(338),
    [anon_sym_BSLASH] = ACTIONS(629),
    [anon_sym_DASH_GT] = ACTIONS(338),
    [anon_sym_LBRACK] = ACTIONS(338),
    [anon_sym_RBRACK] = ACTIONS(338),
    [anon_sym_sizeof] = ACTIONS(631),
    [anon_sym_L_SQUOTE] = ACTIONS(575),
    [anon_sym_u_SQUOTE] = ACTIONS(575),
    [anon_sym_U_SQUOTE] = ACTIONS(575),
    [anon_sym_u8_SQUOTE] = ACTIONS(575),
    [anon_sym_SQUOTE] = ACTIONS(575),
    [anon_sym_L_DQUOTE] = ACTIONS(577),
    [anon_sym_u_DQUOTE] = ACTIONS(577),
    [anon_sym_U_DQUOTE] = ACTIONS(577),
    [anon_sym_u8_DQUOTE] = ACTIONS(577),
    [anon_sym_DQUOTE] = ACTIONS(577),
    [aux_sym_symbol_token1] = ACTIONS(579),
    [aux_sym_symbol_token2] = ACTIONS(581),
    [sym__line_continuation] = ACTIONS(3),
    [sym__hll_number_literal_pre_hook] = ACTIONS(583),
  },
  [STATE(85)] = {
    [sym_trace32_hll_variable] = STATE(842),
    [sym__hll_expression] = STATE(1186),
    [sym_hll_call_expression] = STATE(841),
    [sym_hll_field_expression] = STATE(841),
    [sym_hll_subscript_expression] = STATE(841),
    [sym_hll_cast_expression] = STATE(1186),
    [sym_hll_sizeof_expression] = STATE(1186),
    [sym_hll_pointer_expression] = STATE(841),
    [sym_hll_update_expression] = STATE(1186),
    [sym_hll_unary_expression] = STATE(1186),
    [sym_hll_binary_expression] = STATE(1186),
    [sym_hll_assignment_expression] = STATE(1186),
    [sym__hll_assignment_left_expression] = STATE(1596),
    [sym_hll_conditional_expression] = STATE(1186),
    [sym_hll_char_literal] = STATE(1186),
    [sym_hll_string_literal] = STATE(1186),
    [sym_hll_parenthesized_expression] = STATE(841),
    [sym_symbol] = STATE(1186),
    [sym_identifier] = ACTIONS(619),
    [anon_sym_RPAREN] = ACTIONS(330),
    [anon_sym_LPAREN] = ACTIONS(621),
    [anon_sym_PLUS] = ACTIONS(623),
    [anon_sym_DASH] = ACTIONS(623),
    [anon_sym_TILDE] = ACTIONS(625),
    [anon_sym_BANG] = ACTIONS(623),
    [anon_sym_PLUS_PLUS] = ACTIONS(627),
    [anon_sym_DASH_DASH] = ACTIONS(627),
    [anon_sym_PIPE_PIPE] = ACTIONS(330),
    [anon_sym_STAR] = ACTIONS(448),
    [anon_sym_SLASH] = ACTIONS(330),
    [anon_sym_PERCENT] = ACTIONS(330),
    [anon_sym_PIPE] = ACTIONS(332),
    [anon_sym_CARET] = ACTIONS(330),
    [anon_sym_EQ_EQ] = ACTIONS(330),
    [anon_sym_BANG_EQ] = ACTIONS(330),
    [anon_sym_GT] = ACTIONS(332),
    [anon_sym_GT_EQ] = ACTIONS(330),
    [anon_sym_LT_EQ] = ACTIONS(330),
    [anon_sym_LT] = ACTIONS(332),
    [anon_sym_LT_LT] = ACTIONS(330),
    [anon_sym_GT_GT] = ACTIONS(330),
    [anon_sym_AMP_AMP] = ACTIONS(330),
    [anon_sym_AMP] = ACTIONS(314),
    [anon_sym_COLON] = ACTIONS(330),
    [anon_sym_DOT] = ACTIONS(330),
    [anon_sym_QMARK] = ACTIONS(330),
    [anon_sym_BSLASH] = ACTIONS(629),
    [anon_sym_DASH_GT] = ACTIONS(330),
    [anon_sym_LBRACK] = ACTIONS(330),
    [anon_sym_RBRACK] = ACTIONS(330),
    [anon_sym_sizeof] = ACTIONS(631),
    [anon_sym_L_SQUOTE] = ACTIONS(575),
    [anon_sym_u_SQUOTE] = ACTIONS(575),
    [anon_sym_U_SQUOTE] = ACTIONS(575),
    [anon_sym_u8_SQUOTE] = ACTIONS(575),
    [anon_sym_SQUOTE] = ACTIONS(575),
    [anon_sym_L_DQUOTE] = ACTIONS(577),
    [anon_sym_u_DQUOTE] = ACTIONS(577),
    [anon_sym_U_DQUOTE] = ACTIONS(577),
    [anon_sym_u8_DQUOTE] = ACTIONS(577),
    [anon_sym_DQUOTE] = ACTIONS(577),
    [aux_sym_symbol_token1] = ACTIONS(579),
    [aux_sym_symbol_token2] = ACTIONS(581),
    [sym__line_continuation] = ACTIONS(3),
    [sym__hll_number_literal_pre_hook] = ACTIONS(583),
  },
  [STATE(86)] = {
    [sym_trace32_hll_variable] = STATE(842),
    [sym__hll_expression] = STATE(1187),
    [sym_hll_call_expression] = STATE(841),
    [sym_hll_field_expression] = STATE(841),
    [sym_hll_subscript_expression] = STATE(841),
    [sym_hll_cast_expression] = STATE(1187),
    [sym_hll_sizeof_expression] = STATE(1187),
    [sym_hll_pointer_expression] = STATE(841),
    [sym_hll_update_expression] = STATE(1187),
    [sym_hll_unary_expression] = STATE(1187),
    [sym_hll_binary_expression] = STATE(1187),
    [sym_hll_assignment_expression] = STATE(1187),
    [sym__hll_assignment_left_expression] = STATE(1596),
    [sym_hll_conditional_expression] = STATE(1187),
    [sym_hll_char_literal] = STATE(1187),
    [sym_hll_string_literal] = STATE(1187),
    [sym_hll_parenthesized_expression] = STATE(841),
    [sym_symbol] = STATE(1187),
    [sym_identifier] = ACTIONS(619),
    [anon_sym_RPAREN] = ACTIONS(302),
    [anon_sym_LPAREN] = ACTIONS(621),
    [anon_sym_PLUS] = ACTIONS(623),
    [anon_sym_DASH] = ACTIONS(623),
    [anon_sym_TILDE] = ACTIONS(625),
    [anon_sym_BANG] = ACTIONS(623),
    [anon_sym_PLUS_PLUS] = ACTIONS(627),
    [anon_sym_DASH_DASH] = ACTIONS(627),
    [anon_sym_PIPE_PIPE] = ACTIONS(302),
    [anon_sym_STAR] = ACTIONS(448),
    [anon_sym_SLASH] = ACTIONS(302),
    [anon_sym_PERCENT] = ACTIONS(302),
    [anon_sym_PIPE] = ACTIONS(306),
    [anon_sym_CARET] = ACTIONS(302),
    [anon_sym_EQ_EQ] = ACTIONS(302),
    [anon_sym_BANG_EQ] = ACTIONS(302),
    [anon_sym_GT] = ACTIONS(306),
    [anon_sym_GT_EQ] = ACTIONS(302),
    [anon_sym_LT_EQ] = ACTIONS(302),
    [anon_sym_LT] = ACTIONS(306),
    [anon_sym_LT_LT] = ACTIONS(302),
    [anon_sym_GT_GT] = ACTIONS(302),
    [anon_sym_AMP_AMP] = ACTIONS(302),
    [anon_sym_AMP] = ACTIONS(314),
    [anon_sym_COLON] = ACTIONS(302),
    [anon_sym_DOT] = ACTIONS(302),
    [anon_sym_QMARK] = ACTIONS(302),
    [anon_sym_BSLASH] = ACTIONS(629),
    [anon_sym_DASH_GT] = ACTIONS(302),
    [anon_sym_LBRACK] = ACTIONS(302),
    [anon_sym_RBRACK] = ACTIONS(302),
    [anon_sym_sizeof] = ACTIONS(631),
    [anon_sym_L_SQUOTE] = ACTIONS(575),
    [anon_sym_u_SQUOTE] = ACTIONS(575),
    [anon_sym_U_SQUOTE] = ACTIONS(575),
    [anon_sym_u8_SQUOTE] = ACTIONS(575),
    [anon_sym_SQUOTE] = ACTIONS(575),
    [anon_sym_L_DQUOTE] = ACTIONS(577),
    [anon_sym_u_DQUOTE] = ACTIONS(577),
    [anon_sym_U_DQUOTE] = ACTIONS(577),
    [anon_sym_u8_DQUOTE] = ACTIONS(577),
    [anon_sym_DQUOTE] = ACTIONS(577),
    [aux_sym_symbol_token1] = ACTIONS(579),
    [aux_sym_symbol_token2] = ACTIONS(581),
    [sym__line_continuation] = ACTIONS(3),
    [sym__hll_number_literal_pre_hook] = ACTIONS(583),
  },
  [STATE(87)] = {
    [sym_trace32_hll_variable] = STATE(890),
    [sym__hll_expression] = STATE(1247),
    [sym_hll_call_expression] = STATE(889),
    [sym_hll_field_expression] = STATE(889),
    [sym_hll_subscript_expression] = STATE(889),
    [sym_hll_cast_expression] = STATE(1247),
    [sym_hll_sizeof_expression] = STATE(1247),
    [sym_hll_pointer_expression] = STATE(889),
    [sym_hll_update_expression] = STATE(1247),
    [sym_hll_unary_expression] = STATE(1247),
    [sym_hll_binary_expression] = STATE(1247),
    [sym_hll_assignment_expression] = STATE(1247),
    [sym__hll_assignment_left_expression] = STATE(1609),
    [sym_hll_conditional_expression] = STATE(1247),
    [sym_hll_char_literal] = STATE(1247),
    [sym_hll_string_literal] = STATE(1247),
    [sym_hll_parenthesized_expression] = STATE(889),
    [sym_symbol] = STATE(1247),
    [sym_identifier] = ACTIONS(633),
    [anon_sym_LPAREN] = ACTIONS(635),
    [anon_sym_PLUS] = ACTIONS(637),
    [anon_sym_DASH] = ACTIONS(637),
    [anon_sym_TILDE] = ACTIONS(639),
    [anon_sym_BANG] = ACTIONS(637),
    [anon_sym_PLUS_PLUS] = ACTIONS(641),
    [anon_sym_DASH_DASH] = ACTIONS(641),
    [anon_sym_PIPE_PIPE] = ACTIONS(338),
    [anon_sym_STAR] = ACTIONS(643),
    [anon_sym_SLASH] = ACTIONS(338),
    [anon_sym_PERCENT] = ACTIONS(338),
    [anon_sym_PIPE] = ACTIONS(340),
    [anon_sym_CARET] = ACTIONS(338),
    [anon_sym_EQ_EQ] = ACTIONS(338),
    [anon_sym_BANG_EQ] = ACTIONS(338),
    [anon_sym_GT] = ACTIONS(340),
    [anon_sym_GT_EQ] = ACTIONS(338),
    [anon_sym_LT_EQ] = ACTIONS(338),
    [anon_sym_LT] = ACTIONS(340),
    [anon_sym_LT_LT] = ACTIONS(338),
    [anon_sym_GT_GT] = ACTIONS(338),
    [anon_sym_AMP_AMP] = ACTIONS(338),
    [anon_sym_AMP] = ACTIONS(404),
    [anon_sym_DOT] = ACTIONS(338),
    [anon_sym_QMARK] = ACTIONS(338),
    [anon_sym_BSLASH] = ACTIONS(645),
    [anon_sym_DASH_GT] = ACTIONS(338),
    [anon_sym_LBRACK] = ACTIONS(338),
    [anon_sym_sizeof] = ACTIONS(647),
    [anon_sym_L_SQUOTE] = ACTIONS(649),
    [anon_sym_u_SQUOTE] = ACTIONS(649),
    [anon_sym_U_SQUOTE] = ACTIONS(649),
    [anon_sym_u8_SQUOTE] = ACTIONS(649),
    [anon_sym_SQUOTE] = ACTIONS(649),
    [anon_sym_L_DQUOTE] = ACTIONS(651),
    [anon_sym_u_DQUOTE] = ACTIONS(651),
    [anon_sym_U_DQUOTE] = ACTIONS(651),
    [anon_sym_u8_DQUOTE] = ACTIONS(651),
    [anon_sym_DQUOTE] = ACTIONS(651),
    [aux_sym__hll_expression_separator_token1] = ACTIONS(338),
    [aux_sym__hll_expression_separator_token2] = ACTIONS(338),
    [aux_sym_symbol_token1] = ACTIONS(653),
    [aux_sym_symbol_token2] = ACTIONS(655),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(340),
    [sym__hll_number_literal_pre_hook] = ACTIONS(657),
  },
  [STATE(88)] = {
    [sym_trace32_hll_variable] = STATE(890),
    [sym__hll_expression] = STATE(1255),
    [sym_hll_call_expression] = STATE(889),
    [sym_hll_field_expression] = STATE(889),
    [sym_hll_subscript_expression] = STATE(889),
    [sym_hll_cast_expression] = STATE(1255),
    [sym_hll_sizeof_expression] = STATE(1255),
    [sym_hll_pointer_expression] = STATE(889),
    [sym_hll_update_expression] = STATE(1255),
    [sym_hll_unary_expression] = STATE(1255),
    [sym_hll_binary_expression] = STATE(1255),
    [sym_hll_assignment_expression] = STATE(1255),
    [sym__hll_assignment_left_expression] = STATE(1609),
    [sym_hll_conditional_expression] = STATE(1255),
    [sym_hll_char_literal] = STATE(1255),
    [sym_hll_string_literal] = STATE(1255),
    [sym_hll_parenthesized_expression] = STATE(889),
    [sym_symbol] = STATE(1255),
    [sym_identifier] = ACTIONS(633),
    [anon_sym_LPAREN] = ACTIONS(635),
    [anon_sym_PLUS] = ACTIONS(637),
    [anon_sym_DASH] = ACTIONS(637),
    [anon_sym_TILDE] = ACTIONS(639),
    [anon_sym_BANG] = ACTIONS(637),
    [anon_sym_PLUS_PLUS] = ACTIONS(641),
    [anon_sym_DASH_DASH] = ACTIONS(641),
    [anon_sym_PIPE_PIPE] = ACTIONS(334),
    [anon_sym_STAR] = ACTIONS(643),
    [anon_sym_SLASH] = ACTIONS(334),
    [anon_sym_PERCENT] = ACTIONS(334),
    [anon_sym_PIPE] = ACTIONS(336),
    [anon_sym_CARET] = ACTIONS(334),
    [anon_sym_EQ_EQ] = ACTIONS(334),
    [anon_sym_BANG_EQ] = ACTIONS(334),
    [anon_sym_GT] = ACTIONS(336),
    [anon_sym_GT_EQ] = ACTIONS(334),
    [anon_sym_LT_EQ] = ACTIONS(334),
    [anon_sym_LT] = ACTIONS(336),
    [anon_sym_LT_LT] = ACTIONS(334),
    [anon_sym_GT_GT] = ACTIONS(334),
    [anon_sym_AMP_AMP] = ACTIONS(334),
    [anon_sym_AMP] = ACTIONS(404),
    [anon_sym_DOT] = ACTIONS(334),
    [anon_sym_QMARK] = ACTIONS(334),
    [anon_sym_BSLASH] = ACTIONS(645),
    [anon_sym_DASH_GT] = ACTIONS(334),
    [anon_sym_LBRACK] = ACTIONS(334),
    [anon_sym_sizeof] = ACTIONS(647),
    [anon_sym_L_SQUOTE] = ACTIONS(649),
    [anon_sym_u_SQUOTE] = ACTIONS(649),
    [anon_sym_U_SQUOTE] = ACTIONS(649),
    [anon_sym_u8_SQUOTE] = ACTIONS(649),
    [anon_sym_SQUOTE] = ACTIONS(649),
    [anon_sym_L_DQUOTE] = ACTIONS(651),
    [anon_sym_u_DQUOTE] = ACTIONS(651),
    [anon_sym_U_DQUOTE] = ACTIONS(651),
    [anon_sym_u8_DQUOTE] = ACTIONS(651),
    [anon_sym_DQUOTE] = ACTIONS(651),
    [aux_sym__hll_expression_separator_token1] = ACTIONS(334),
    [aux_sym__hll_expression_separator_token2] = ACTIONS(334),
    [aux_sym_symbol_token1] = ACTIONS(653),
    [aux_sym_symbol_token2] = ACTIONS(655),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(336),
    [sym__hll_number_literal_pre_hook] = ACTIONS(657),
  },
  [STATE(89)] = {
    [sym_trace32_hll_variable] = STATE(890),
    [sym__hll_expression] = STATE(1256),
    [sym_hll_call_expression] = STATE(889),
    [sym_hll_field_expression] = STATE(889),
    [sym_hll_subscript_expression] = STATE(889),
    [sym_hll_cast_expression] = STATE(1256),
    [sym_hll_sizeof_expression] = STATE(1256),
    [sym_hll_pointer_expression] = STATE(889),
    [sym_hll_update_expression] = STATE(1256),
    [sym_hll_unary_expression] = STATE(1256),
    [sym_hll_binary_expression] = STATE(1256),
    [sym_hll_assignment_expression] = STATE(1256),
    [sym__hll_assignment_left_expression] = STATE(1609),
    [sym_hll_conditional_expression] = STATE(1256),
    [sym_hll_char_literal] = STATE(1256),
    [sym_hll_string_literal] = STATE(1256),
    [sym_hll_parenthesized_expression] = STATE(889),
    [sym_symbol] = STATE(1256),
    [sym_identifier] = ACTIONS(633),
    [anon_sym_LPAREN] = ACTIONS(635),
    [anon_sym_PLUS] = ACTIONS(637),
    [anon_sym_DASH] = ACTIONS(637),
    [anon_sym_TILDE] = ACTIONS(639),
    [anon_sym_BANG] = ACTIONS(637),
    [anon_sym_PLUS_PLUS] = ACTIONS(641),
    [anon_sym_DASH_DASH] = ACTIONS(641),
    [anon_sym_PIPE_PIPE] = ACTIONS(330),
    [anon_sym_STAR] = ACTIONS(643),
    [anon_sym_SLASH] = ACTIONS(330),
    [anon_sym_PERCENT] = ACTIONS(330),
    [anon_sym_PIPE] = ACTIONS(332),
    [anon_sym_CARET] = ACTIONS(330),
    [anon_sym_EQ_EQ] = ACTIONS(330),
    [anon_sym_BANG_EQ] = ACTIONS(330),
    [anon_sym_GT] = ACTIONS(332),
    [anon_sym_GT_EQ] = ACTIONS(330),
    [anon_sym_LT_EQ] = ACTIONS(330),
    [anon_sym_LT] = ACTIONS(332),
    [anon_sym_LT_LT] = ACTIONS(330),
    [anon_sym_GT_GT] = ACTIONS(330),
    [anon_sym_AMP_AMP] = ACTIONS(330),
    [anon_sym_AMP] = ACTIONS(404),
    [anon_sym_DOT] = ACTIONS(330),
    [anon_sym_QMARK] = ACTIONS(330),
    [anon_sym_BSLASH] = ACTIONS(645),
    [anon_sym_DASH_GT] = ACTIONS(330),
    [anon_sym_LBRACK] = ACTIONS(330),
    [anon_sym_sizeof] = ACTIONS(647),
    [anon_sym_L_SQUOTE] = ACTIONS(649),
    [anon_sym_u_SQUOTE] = ACTIONS(649),
    [anon_sym_U_SQUOTE] = ACTIONS(649),
    [anon_sym_u8_SQUOTE] = ACTIONS(649),
    [anon_sym_SQUOTE] = ACTIONS(649),
    [anon_sym_L_DQUOTE] = ACTIONS(651),
    [anon_sym_u_DQUOTE] = ACTIONS(651),
    [anon_sym_U_DQUOTE] = ACTIONS(651),
    [anon_sym_u8_DQUOTE] = ACTIONS(651),
    [anon_sym_DQUOTE] = ACTIONS(651),
    [aux_sym__hll_expression_separator_token1] = ACTIONS(330),
    [aux_sym__hll_expression_separator_token2] = ACTIONS(330),
    [aux_sym_symbol_token1] = ACTIONS(653),
    [aux_sym_symbol_token2] = ACTIONS(655),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(332),
    [sym__hll_number_literal_pre_hook] = ACTIONS(657),
  },
};

static const uint16_t ts_small_parse_table[] = {
  [0] = 42,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(120), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(147), 1,
      anon_sym_AMP,
    ACTIONS(155), 1,
      sym__decimal_number_pre_hook,
    ACTIONS(179), 1,
      sym_identifier,
    ACTIONS(181), 1,
      anon_sym_LPAREN,
    ACTIONS(183), 1,
      anon_sym_LBRACE,
    ACTIONS(191), 1,
      anon_sym_STAR,
    ACTIONS(193), 1,
      anon_sym_BSLASH,
    ACTIONS(195), 1,
      anon_sym_SQUOTE,
    ACTIONS(197), 1,
      anon_sym_DQUOTE,
    ACTIONS(199), 1,
      sym_access_class,
    ACTIONS(205), 1,
      aux_sym_symbol_token1,
    ACTIONS(207), 1,
      aux_sym_symbol_token2,
    ACTIONS(211), 1,
      sym_path,
    ACTIONS(436), 1,
      sym__blank,
    STATE(228), 1,
      sym_memory_space,
    STATE(935), 1,
      aux_sym_block_repeat1,
    STATE(980), 1,
      sym_macro,
    STATE(1060), 1,
      sym_call_expression,
    STATE(1061), 1,
      sym__hll_var_call_expression,
    STATE(1080), 1,
      sym_integer,
    STATE(1100), 1,
      aux_sym__path_expression_repeat2,
    STATE(1172), 1,
      aux_sym__path_expression_repeat1,
    STATE(1371), 1,
      sym__and_expression,
    STATE(1374), 1,
      sym__file_dialog,
    STATE(1377), 1,
      sym_trace32_hll_variable,
    STATE(1378), 1,
      sym__unary_expression,
    STATE(1392), 1,
      sym__prefix_postfix_expression,
    STATE(1394), 1,
      sym__binary_expression,
    STATE(1550), 1,
      sym__address_binary_expression,
    STATE(2349), 1,
      sym__function_identifier,
    STATE(2359), 1,
      sym__hll_var_call_expression_function,
    ACTIONS(149), 2,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
    ACTIONS(185), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(187), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(189), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(203), 2,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
    STATE(1575), 2,
      sym__address_expression,
      sym__parenthesized_address_expression,
    ACTIONS(659), 3,
      sym_float,
      sym_time,
      sym_frequency,
    ACTIONS(661), 3,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
    STATE(1266), 13,
      sym__expression,
      sym__parenthesized_expression,
      sym__path_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_assignment_expression,
      sym__literal,
      sym_address,
      sym_bitmask,
      sym_string,
      sym_character,
      sym_symbol,
      sym__special_command_operator,
  [149] = 42,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(120), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(147), 1,
      anon_sym_AMP,
    ACTIONS(155), 1,
      sym__decimal_number_pre_hook,
    ACTIONS(179), 1,
      sym_identifier,
    ACTIONS(181), 1,
      anon_sym_LPAREN,
    ACTIONS(183), 1,
      anon_sym_LBRACE,
    ACTIONS(191), 1,
      anon_sym_STAR,
    ACTIONS(193), 1,
      anon_sym_BSLASH,
    ACTIONS(195), 1,
      anon_sym_SQUOTE,
    ACTIONS(197), 1,
      anon_sym_DQUOTE,
    ACTIONS(199), 1,
      sym_access_class,
    ACTIONS(205), 1,
      aux_sym_symbol_token1,
    ACTIONS(207), 1,
      aux_sym_symbol_token2,
    ACTIONS(211), 1,
      sym_path,
    ACTIONS(667), 1,
      sym__blank,
    STATE(107), 1,
      aux_sym_block_repeat1,
    STATE(228), 1,
      sym_memory_space,
    STATE(980), 1,
      sym_macro,
    STATE(1060), 1,
      sym_call_expression,
    STATE(1061), 1,
      sym__hll_var_call_expression,
    STATE(1080), 1,
      sym_integer,
    STATE(1100), 1,
      aux_sym__path_expression_repeat2,
    STATE(1172), 1,
      aux_sym__path_expression_repeat1,
    STATE(1371), 1,
      sym__and_expression,
    STATE(1374), 1,
      sym__file_dialog,
    STATE(1377), 1,
      sym_trace32_hll_variable,
    STATE(1378), 1,
      sym__unary_expression,
    STATE(1392), 1,
      sym__prefix_postfix_expression,
    STATE(1394), 1,
      sym__binary_expression,
    STATE(1550), 1,
      sym__address_binary_expression,
    STATE(2349), 1,
      sym__function_identifier,
    STATE(2359), 1,
      sym__hll_var_call_expression_function,
    ACTIONS(149), 2,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
    ACTIONS(185), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(187), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(189), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(203), 2,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
    STATE(1575), 2,
      sym__address_expression,
      sym__parenthesized_address_expression,
    ACTIONS(663), 3,
      sym_float,
      sym_time,
      sym_frequency,
    ACTIONS(665), 3,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
    STATE(1289), 13,
      sym__expression,
      sym__parenthesized_expression,
      sym__path_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_assignment_expression,
      sym__literal,
      sym_address,
      sym_bitmask,
      sym_string,
      sym_character,
      sym_symbol,
      sym__special_command_operator,
  [298] = 42,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(76), 1,
      anon_sym_BSLASH,
    ACTIONS(78), 1,
      anon_sym_SQUOTE,
    ACTIONS(80), 1,
      anon_sym_DQUOTE,
    ACTIONS(82), 1,
      sym_access_class,
    ACTIONS(90), 1,
      aux_sym_symbol_token1,
    ACTIONS(92), 1,
      aux_sym_symbol_token2,
    ACTIONS(98), 1,
      sym_path,
    ACTIONS(120), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(140), 1,
      sym_identifier,
    ACTIONS(157), 1,
      anon_sym_LPAREN,
    ACTIONS(159), 1,
      anon_sym_LBRACE,
    ACTIONS(167), 1,
      anon_sym_STAR,
    ACTIONS(169), 1,
      anon_sym_AMP,
    ACTIONS(177), 1,
      sym__decimal_number_pre_hook,
    ACTIONS(673), 1,
      sym__blank,
    STATE(93), 1,
      aux_sym_block_repeat1,
    STATE(236), 1,
      sym_memory_space,
    STATE(970), 1,
      sym_macro,
    STATE(1049), 1,
      sym__hll_var_call_expression,
    STATE(1053), 1,
      aux_sym__path_expression_repeat2,
    STATE(1097), 1,
      sym_call_expression,
    STATE(1098), 1,
      sym_integer,
    STATE(1218), 1,
      aux_sym__path_expression_repeat1,
    STATE(1399), 1,
      sym__unary_expression,
    STATE(1400), 1,
      sym__prefix_postfix_expression,
    STATE(1404), 1,
      sym__binary_expression,
    STATE(1406), 1,
      sym__and_expression,
    STATE(1412), 1,
      sym_trace32_hll_variable,
    STATE(1417), 1,
      sym__file_dialog,
    STATE(1550), 1,
      sym__address_binary_expression,
    STATE(2257), 1,
      sym__function_identifier,
    STATE(2260), 1,
      sym__hll_var_call_expression_function,
    ACTIONS(88), 2,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
    ACTIONS(161), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(163), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(165), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(171), 2,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
    STATE(1575), 2,
      sym__address_expression,
      sym__parenthesized_address_expression,
    ACTIONS(669), 3,
      sym_float,
      sym_time,
      sym_frequency,
    ACTIONS(671), 3,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
    STATE(1201), 13,
      sym__expression,
      sym__parenthesized_expression,
      sym__path_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_assignment_expression,
      sym__literal,
      sym_address,
      sym_bitmask,
      sym_string,
      sym_character,
      sym_symbol,
      sym__special_command_operator,
  [447] = 42,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(76), 1,
      anon_sym_BSLASH,
    ACTIONS(78), 1,
      anon_sym_SQUOTE,
    ACTIONS(80), 1,
      anon_sym_DQUOTE,
    ACTIONS(82), 1,
      sym_access_class,
    ACTIONS(90), 1,
      aux_sym_symbol_token1,
    ACTIONS(92), 1,
      aux_sym_symbol_token2,
    ACTIONS(98), 1,
      sym_path,
    ACTIONS(120), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(140), 1,
      sym_identifier,
    ACTIONS(157), 1,
      anon_sym_LPAREN,
    ACTIONS(159), 1,
      anon_sym_LBRACE,
    ACTIONS(167), 1,
      anon_sym_STAR,
    ACTIONS(169), 1,
      anon_sym_AMP,
    ACTIONS(177), 1,
      sym__decimal_number_pre_hook,
    ACTIONS(436), 1,
      sym__blank,
    STATE(236), 1,
      sym_memory_space,
    STATE(935), 1,
      aux_sym_block_repeat1,
    STATE(970), 1,
      sym_macro,
    STATE(1049), 1,
      sym__hll_var_call_expression,
    STATE(1053), 1,
      aux_sym__path_expression_repeat2,
    STATE(1097), 1,
      sym_call_expression,
    STATE(1098), 1,
      sym_integer,
    STATE(1218), 1,
      aux_sym__path_expression_repeat1,
    STATE(1399), 1,
      sym__unary_expression,
    STATE(1400), 1,
      sym__prefix_postfix_expression,
    STATE(1404), 1,
      sym__binary_expression,
    STATE(1406), 1,
      sym__and_expression,
    STATE(1412), 1,
      sym_trace32_hll_variable,
    STATE(1417), 1,
      sym__file_dialog,
    STATE(1550), 1,
      sym__address_binary_expression,
    STATE(2257), 1,
      sym__function_identifier,
    STATE(2260), 1,
      sym__hll_var_call_expression_function,
    ACTIONS(88), 2,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
    ACTIONS(161), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(163), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(165), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(171), 2,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
    STATE(1575), 2,
      sym__address_expression,
      sym__parenthesized_address_expression,
    ACTIONS(675), 3,
      sym_float,
      sym_time,
      sym_frequency,
    ACTIONS(677), 3,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
    STATE(1212), 13,
      sym__expression,
      sym__parenthesized_expression,
      sym__path_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_assignment_expression,
      sym__literal,
      sym_address,
      sym_bitmask,
      sym_string,
      sym_character,
      sym_symbol,
      sym__special_command_operator,
  [596] = 42,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(76), 1,
      anon_sym_BSLASH,
    ACTIONS(78), 1,
      anon_sym_SQUOTE,
    ACTIONS(80), 1,
      anon_sym_DQUOTE,
    ACTIONS(82), 1,
      sym_access_class,
    ACTIONS(90), 1,
      aux_sym_symbol_token1,
    ACTIONS(92), 1,
      aux_sym_symbol_token2,
    ACTIONS(98), 1,
      sym_path,
    ACTIONS(120), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(140), 1,
      sym_identifier,
    ACTIONS(157), 1,
      anon_sym_LPAREN,
    ACTIONS(159), 1,
      anon_sym_LBRACE,
    ACTIONS(167), 1,
      anon_sym_STAR,
    ACTIONS(169), 1,
      anon_sym_AMP,
    ACTIONS(177), 1,
      sym__decimal_number_pre_hook,
    ACTIONS(683), 1,
      sym__blank,
    STATE(95), 1,
      aux_sym_block_repeat1,
    STATE(236), 1,
      sym_memory_space,
    STATE(970), 1,
      sym_macro,
    STATE(1049), 1,
      sym__hll_var_call_expression,
    STATE(1053), 1,
      aux_sym__path_expression_repeat2,
    STATE(1097), 1,
      sym_call_expression,
    STATE(1098), 1,
      sym_integer,
    STATE(1218), 1,
      aux_sym__path_expression_repeat1,
    STATE(1399), 1,
      sym__unary_expression,
    STATE(1400), 1,
      sym__prefix_postfix_expression,
    STATE(1404), 1,
      sym__binary_expression,
    STATE(1406), 1,
      sym__and_expression,
    STATE(1412), 1,
      sym_trace32_hll_variable,
    STATE(1417), 1,
      sym__file_dialog,
    STATE(1550), 1,
      sym__address_binary_expression,
    STATE(2257), 1,
      sym__function_identifier,
    STATE(2260), 1,
      sym__hll_var_call_expression_function,
    ACTIONS(88), 2,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
    ACTIONS(161), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(163), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(165), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(171), 2,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
    STATE(1575), 2,
      sym__address_expression,
      sym__parenthesized_address_expression,
    ACTIONS(679), 3,
      sym_float,
      sym_time,
      sym_frequency,
    ACTIONS(681), 3,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
    STATE(1215), 13,
      sym__expression,
      sym__parenthesized_expression,
      sym__path_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_assignment_expression,
      sym__literal,
      sym_address,
      sym_bitmask,
      sym_string,
      sym_character,
      sym_symbol,
      sym__special_command_operator,
  [745] = 42,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(76), 1,
      anon_sym_BSLASH,
    ACTIONS(78), 1,
      anon_sym_SQUOTE,
    ACTIONS(80), 1,
      anon_sym_DQUOTE,
    ACTIONS(82), 1,
      sym_access_class,
    ACTIONS(90), 1,
      aux_sym_symbol_token1,
    ACTIONS(92), 1,
      aux_sym_symbol_token2,
    ACTIONS(98), 1,
      sym_path,
    ACTIONS(120), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(140), 1,
      sym_identifier,
    ACTIONS(157), 1,
      anon_sym_LPAREN,
    ACTIONS(159), 1,
      anon_sym_LBRACE,
    ACTIONS(167), 1,
      anon_sym_STAR,
    ACTIONS(169), 1,
      anon_sym_AMP,
    ACTIONS(177), 1,
      sym__decimal_number_pre_hook,
    ACTIONS(436), 1,
      sym__blank,
    STATE(236), 1,
      sym_memory_space,
    STATE(935), 1,
      aux_sym_block_repeat1,
    STATE(970), 1,
      sym_macro,
    STATE(1049), 1,
      sym__hll_var_call_expression,
    STATE(1053), 1,
      aux_sym__path_expression_repeat2,
    STATE(1097), 1,
      sym_call_expression,
    STATE(1098), 1,
      sym_integer,
    STATE(1218), 1,
      aux_sym__path_expression_repeat1,
    STATE(1399), 1,
      sym__unary_expression,
    STATE(1400), 1,
      sym__prefix_postfix_expression,
    STATE(1404), 1,
      sym__binary_expression,
    STATE(1406), 1,
      sym__and_expression,
    STATE(1412), 1,
      sym_trace32_hll_variable,
    STATE(1417), 1,
      sym__file_dialog,
    STATE(1550), 1,
      sym__address_binary_expression,
    STATE(2257), 1,
      sym__function_identifier,
    STATE(2260), 1,
      sym__hll_var_call_expression_function,
    ACTIONS(88), 2,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
    ACTIONS(161), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(163), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(165), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(171), 2,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
    STATE(1575), 2,
      sym__address_expression,
      sym__parenthesized_address_expression,
    ACTIONS(685), 3,
      sym_float,
      sym_time,
      sym_frequency,
    ACTIONS(687), 3,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
    STATE(1141), 13,
      sym__expression,
      sym__parenthesized_expression,
      sym__path_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_assignment_expression,
      sym__literal,
      sym_address,
      sym_bitmask,
      sym_string,
      sym_character,
      sym_symbol,
      sym__special_command_operator,
  [894] = 42,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(120), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(147), 1,
      anon_sym_AMP,
    ACTIONS(155), 1,
      sym__decimal_number_pre_hook,
    ACTIONS(179), 1,
      sym_identifier,
    ACTIONS(181), 1,
      anon_sym_LPAREN,
    ACTIONS(183), 1,
      anon_sym_LBRACE,
    ACTIONS(191), 1,
      anon_sym_STAR,
    ACTIONS(193), 1,
      anon_sym_BSLASH,
    ACTIONS(195), 1,
      anon_sym_SQUOTE,
    ACTIONS(197), 1,
      anon_sym_DQUOTE,
    ACTIONS(199), 1,
      sym_access_class,
    ACTIONS(205), 1,
      aux_sym_symbol_token1,
    ACTIONS(207), 1,
      aux_sym_symbol_token2,
    ACTIONS(211), 1,
      sym_path,
    ACTIONS(693), 1,
      sym__blank,
    STATE(116), 1,
      aux_sym_block_repeat1,
    STATE(228), 1,
      sym_memory_space,
    STATE(980), 1,
      sym_macro,
    STATE(1060), 1,
      sym_call_expression,
    STATE(1061), 1,
      sym__hll_var_call_expression,
    STATE(1080), 1,
      sym_integer,
    STATE(1100), 1,
      aux_sym__path_expression_repeat2,
    STATE(1172), 1,
      aux_sym__path_expression_repeat1,
    STATE(1371), 1,
      sym__and_expression,
    STATE(1374), 1,
      sym__file_dialog,
    STATE(1377), 1,
      sym_trace32_hll_variable,
    STATE(1378), 1,
      sym__unary_expression,
    STATE(1392), 1,
      sym__prefix_postfix_expression,
    STATE(1394), 1,
      sym__binary_expression,
    STATE(1550), 1,
      sym__address_binary_expression,
    STATE(2349), 1,
      sym__function_identifier,
    STATE(2359), 1,
      sym__hll_var_call_expression_function,
    ACTIONS(149), 2,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
    ACTIONS(185), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(187), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(189), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(203), 2,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
    STATE(1575), 2,
      sym__address_expression,
      sym__parenthesized_address_expression,
    ACTIONS(689), 3,
      sym_float,
      sym_time,
      sym_frequency,
    ACTIONS(691), 3,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
    STATE(1262), 13,
      sym__expression,
      sym__parenthesized_expression,
      sym__path_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_assignment_expression,
      sym__literal,
      sym_address,
      sym_bitmask,
      sym_string,
      sym_character,
      sym_symbol,
      sym__special_command_operator,
  [1043] = 40,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(96), 1,
      sym__decimal_number_pre_hook,
    ACTIONS(100), 1,
      sym_identifier,
    ACTIONS(102), 1,
      anon_sym_LPAREN,
    ACTIONS(104), 1,
      anon_sym_LBRACE,
    ACTIONS(116), 1,
      anon_sym_STAR,
    ACTIONS(120), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(122), 1,
      anon_sym_BSLASH,
    ACTIONS(124), 1,
      anon_sym_SQUOTE,
    ACTIONS(126), 1,
      anon_sym_DQUOTE,
    ACTIONS(128), 1,
      sym_access_class,
    ACTIONS(134), 1,
      aux_sym_symbol_token1,
    ACTIONS(136), 1,
      aux_sym_symbol_token2,
    ACTIONS(695), 1,
      anon_sym_AMP,
    ACTIONS(701), 1,
      sym__blank,
    STATE(100), 1,
      aux_sym_block_repeat1,
    STATE(224), 1,
      sym_memory_space,
    STATE(328), 1,
      sym_macro,
    STATE(345), 1,
      sym__hll_var_call_expression,
    STATE(347), 1,
      sym_call_expression,
    STATE(350), 1,
      sym_integer,
    STATE(371), 1,
      aux_sym__path_expression_repeat1,
    STATE(450), 1,
      sym__unary_expression,
    STATE(451), 1,
      sym__prefix_postfix_expression,
    STATE(452), 1,
      sym__binary_expression,
    STATE(453), 1,
      sym__and_expression,
    STATE(457), 1,
      sym_trace32_hll_variable,
    STATE(459), 1,
      sym__file_dialog,
    STATE(1550), 1,
      sym__address_binary_expression,
    STATE(2354), 1,
      sym__function_identifier,
    STATE(2355), 1,
      sym__hll_var_call_expression_function,
    ACTIONS(84), 2,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
    ACTIONS(110), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(112), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(114), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(132), 2,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
    STATE(1575), 2,
      sym__address_expression,
      sym__parenthesized_address_expression,
    ACTIONS(697), 3,
      sym_float,
      sym_time,
      sym_frequency,
    ACTIONS(699), 4,
      sym_path,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
    STATE(380), 14,
      sym__expression,
      sym__parenthesized_expression,
      sym__path_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_assignment_expression,
      sym__literal,
      sym_address,
      sym_bitmask,
      sym_string,
      sym_character,
      sym_symbol,
      sym__special_command_operator,
      aux_sym__path_expression_repeat2,
  [1188] = 42,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(120), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(147), 1,
      anon_sym_AMP,
    ACTIONS(155), 1,
      sym__decimal_number_pre_hook,
    ACTIONS(179), 1,
      sym_identifier,
    ACTIONS(181), 1,
      anon_sym_LPAREN,
    ACTIONS(183), 1,
      anon_sym_LBRACE,
    ACTIONS(191), 1,
      anon_sym_STAR,
    ACTIONS(193), 1,
      anon_sym_BSLASH,
    ACTIONS(195), 1,
      anon_sym_SQUOTE,
    ACTIONS(197), 1,
      anon_sym_DQUOTE,
    ACTIONS(199), 1,
      sym_access_class,
    ACTIONS(205), 1,
      aux_sym_symbol_token1,
    ACTIONS(207), 1,
      aux_sym_symbol_token2,
    ACTIONS(211), 1,
      sym_path,
    ACTIONS(436), 1,
      sym__blank,
    STATE(228), 1,
      sym_memory_space,
    STATE(935), 1,
      aux_sym_block_repeat1,
    STATE(980), 1,
      sym_macro,
    STATE(1060), 1,
      sym_call_expression,
    STATE(1061), 1,
      sym__hll_var_call_expression,
    STATE(1080), 1,
      sym_integer,
    STATE(1100), 1,
      aux_sym__path_expression_repeat2,
    STATE(1172), 1,
      aux_sym__path_expression_repeat1,
    STATE(1371), 1,
      sym__and_expression,
    STATE(1374), 1,
      sym__file_dialog,
    STATE(1377), 1,
      sym_trace32_hll_variable,
    STATE(1378), 1,
      sym__unary_expression,
    STATE(1392), 1,
      sym__prefix_postfix_expression,
    STATE(1394), 1,
      sym__binary_expression,
    STATE(1550), 1,
      sym__address_binary_expression,
    STATE(2349), 1,
      sym__function_identifier,
    STATE(2359), 1,
      sym__hll_var_call_expression_function,
    ACTIONS(149), 2,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
    ACTIONS(185), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(187), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(189), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(203), 2,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
    STATE(1575), 2,
      sym__address_expression,
      sym__parenthesized_address_expression,
    ACTIONS(703), 3,
      sym_float,
      sym_time,
      sym_frequency,
    ACTIONS(705), 3,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
    STATE(1353), 13,
      sym__expression,
      sym__parenthesized_expression,
      sym__path_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_assignment_expression,
      sym__literal,
      sym_address,
      sym_bitmask,
      sym_string,
      sym_character,
      sym_symbol,
      sym__special_command_operator,
  [1337] = 43,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(76), 1,
      anon_sym_BSLASH,
    ACTIONS(78), 1,
      anon_sym_SQUOTE,
    ACTIONS(80), 1,
      anon_sym_DQUOTE,
    ACTIONS(82), 1,
      sym_access_class,
    ACTIONS(90), 1,
      aux_sym_symbol_token1,
    ACTIONS(92), 1,
      aux_sym_symbol_token2,
    ACTIONS(98), 1,
      sym_path,
    ACTIONS(120), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(157), 1,
      anon_sym_LPAREN,
    ACTIONS(159), 1,
      anon_sym_LBRACE,
    ACTIONS(167), 1,
      anon_sym_STAR,
    ACTIONS(169), 1,
      anon_sym_AMP,
    ACTIONS(177), 1,
      sym__decimal_number_pre_hook,
    ACTIONS(436), 1,
      sym__blank,
    ACTIONS(707), 1,
      sym_identifier,
    STATE(236), 1,
      sym_memory_space,
    STATE(935), 1,
      aux_sym_block_repeat1,
    STATE(1046), 1,
      sym_call_expression,
    STATE(1049), 1,
      sym__hll_var_call_expression,
    STATE(1052), 1,
      sym_integer,
    STATE(1053), 1,
      aux_sym__path_expression_repeat2,
    STATE(1218), 1,
      aux_sym__path_expression_repeat1,
    STATE(1355), 1,
      sym_macro,
    STATE(1399), 1,
      sym__unary_expression,
    STATE(1400), 1,
      sym__prefix_postfix_expression,
    STATE(1404), 1,
      sym__binary_expression,
    STATE(1406), 1,
      sym__and_expression,
    STATE(1412), 1,
      sym_trace32_hll_variable,
    STATE(1417), 1,
      sym__file_dialog,
    STATE(1550), 1,
      sym__address_binary_expression,
    STATE(2257), 1,
      sym__function_identifier,
    STATE(2260), 1,
      sym__hll_var_call_expression_function,
    ACTIONS(60), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(62), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(88), 2,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
    ACTIONS(171), 2,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
    ACTIONS(222), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1575), 2,
      sym__address_expression,
      sym__parenthesized_address_expression,
    ACTIONS(709), 3,
      sym_float,
      sym_time,
      sym_frequency,
    ACTIONS(711), 3,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
    STATE(1454), 6,
      sym__expression,
      sym__parenthesized_expression,
      sym__path_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_assignment_expression,
    STATE(1514), 7,
      sym__literal,
      sym_address,
      sym_bitmask,
      sym_string,
      sym_character,
      sym_symbol,
      sym__special_command_operator,
  [1488] = 40,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(96), 1,
      sym__decimal_number_pre_hook,
    ACTIONS(100), 1,
      sym_identifier,
    ACTIONS(102), 1,
      anon_sym_LPAREN,
    ACTIONS(104), 1,
      anon_sym_LBRACE,
    ACTIONS(116), 1,
      anon_sym_STAR,
    ACTIONS(120), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(122), 1,
      anon_sym_BSLASH,
    ACTIONS(124), 1,
      anon_sym_SQUOTE,
    ACTIONS(126), 1,
      anon_sym_DQUOTE,
    ACTIONS(128), 1,
      sym_access_class,
    ACTIONS(134), 1,
      aux_sym_symbol_token1,
    ACTIONS(136), 1,
      aux_sym_symbol_token2,
    ACTIONS(436), 1,
      sym__blank,
    ACTIONS(695), 1,
      anon_sym_AMP,
    STATE(224), 1,
      sym_memory_space,
    STATE(328), 1,
      sym_macro,
    STATE(345), 1,
      sym__hll_var_call_expression,
    STATE(347), 1,
      sym_call_expression,
    STATE(350), 1,
      sym_integer,
    STATE(371), 1,
      aux_sym__path_expression_repeat1,
    STATE(450), 1,
      sym__unary_expression,
    STATE(451), 1,
      sym__prefix_postfix_expression,
    STATE(452), 1,
      sym__binary_expression,
    STATE(453), 1,
      sym__and_expression,
    STATE(457), 1,
      sym_trace32_hll_variable,
    STATE(459), 1,
      sym__file_dialog,
    STATE(935), 1,
      aux_sym_block_repeat1,
    STATE(1550), 1,
      sym__address_binary_expression,
    STATE(2354), 1,
      sym__function_identifier,
    STATE(2355), 1,
      sym__hll_var_call_expression_function,
    ACTIONS(84), 2,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
    ACTIONS(110), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(112), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(114), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(132), 2,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
    STATE(1575), 2,
      sym__address_expression,
      sym__parenthesized_address_expression,
    ACTIONS(713), 3,
      sym_float,
      sym_time,
      sym_frequency,
    ACTIONS(715), 4,
      sym_path,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
    STATE(373), 14,
      sym__expression,
      sym__parenthesized_expression,
      sym__path_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_assignment_expression,
      sym__literal,
      sym_address,
      sym_bitmask,
      sym_string,
      sym_character,
      sym_symbol,
      sym__special_command_operator,
      aux_sym__path_expression_repeat2,
  [1633] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(404), 1,
      anon_sym_AMP,
    ACTIONS(643), 1,
      anon_sym_STAR,
    ACTIONS(645), 1,
      anon_sym_BSLASH,
    ACTIONS(653), 1,
      aux_sym_symbol_token1,
    ACTIONS(655), 1,
      aux_sym_symbol_token2,
    ACTIONS(657), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(717), 1,
      sym_identifier,
    ACTIONS(719), 1,
      anon_sym_LPAREN,
    ACTIONS(723), 1,
      anon_sym_TILDE,
    ACTIONS(727), 1,
      anon_sym_sizeof,
    STATE(885), 1,
      sym_trace32_hll_variable,
    STATE(1605), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(725), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(340), 3,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(721), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
    ACTIONS(649), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(651), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(884), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1247), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
    ACTIONS(338), 17,
      anon_sym_PIPE_PIPE,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [1740] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(404), 1,
      anon_sym_AMP,
    ACTIONS(643), 1,
      anon_sym_STAR,
    ACTIONS(645), 1,
      anon_sym_BSLASH,
    ACTIONS(653), 1,
      aux_sym_symbol_token1,
    ACTIONS(655), 1,
      aux_sym_symbol_token2,
    ACTIONS(657), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(717), 1,
      sym_identifier,
    ACTIONS(719), 1,
      anon_sym_LPAREN,
    ACTIONS(723), 1,
      anon_sym_TILDE,
    ACTIONS(727), 1,
      anon_sym_sizeof,
    STATE(885), 1,
      sym_trace32_hll_variable,
    STATE(1605), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(725), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(336), 3,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(721), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
    ACTIONS(649), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(651), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(884), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1255), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
    ACTIONS(334), 17,
      anon_sym_PIPE_PIPE,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [1847] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(404), 1,
      anon_sym_AMP,
    ACTIONS(643), 1,
      anon_sym_STAR,
    ACTIONS(645), 1,
      anon_sym_BSLASH,
    ACTIONS(653), 1,
      aux_sym_symbol_token1,
    ACTIONS(655), 1,
      aux_sym_symbol_token2,
    ACTIONS(657), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(717), 1,
      sym_identifier,
    ACTIONS(719), 1,
      anon_sym_LPAREN,
    ACTIONS(723), 1,
      anon_sym_TILDE,
    ACTIONS(727), 1,
      anon_sym_sizeof,
    STATE(885), 1,
      sym_trace32_hll_variable,
    STATE(1605), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(725), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(332), 3,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(721), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
    ACTIONS(649), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(651), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(884), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1256), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
    ACTIONS(330), 17,
      anon_sym_PIPE_PIPE,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [1954] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(404), 1,
      anon_sym_AMP,
    ACTIONS(643), 1,
      anon_sym_STAR,
    ACTIONS(645), 1,
      anon_sym_BSLASH,
    ACTIONS(653), 1,
      aux_sym_symbol_token1,
    ACTIONS(655), 1,
      aux_sym_symbol_token2,
    ACTIONS(657), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(717), 1,
      sym_identifier,
    ACTIONS(719), 1,
      anon_sym_LPAREN,
    ACTIONS(723), 1,
      anon_sym_TILDE,
    ACTIONS(727), 1,
      anon_sym_sizeof,
    STATE(885), 1,
      sym_trace32_hll_variable,
    STATE(1605), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(725), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(306), 3,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(721), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
    ACTIONS(649), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(651), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(884), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1259), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
    ACTIONS(302), 17,
      anon_sym_PIPE_PIPE,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [2061] = 42,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(120), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(147), 1,
      anon_sym_AMP,
    ACTIONS(155), 1,
      sym__decimal_number_pre_hook,
    ACTIONS(179), 1,
      sym_identifier,
    ACTIONS(181), 1,
      anon_sym_LPAREN,
    ACTIONS(183), 1,
      anon_sym_LBRACE,
    ACTIONS(191), 1,
      anon_sym_STAR,
    ACTIONS(193), 1,
      anon_sym_BSLASH,
    ACTIONS(195), 1,
      anon_sym_SQUOTE,
    ACTIONS(197), 1,
      anon_sym_DQUOTE,
    ACTIONS(199), 1,
      sym_access_class,
    ACTIONS(205), 1,
      aux_sym_symbol_token1,
    ACTIONS(207), 1,
      aux_sym_symbol_token2,
    ACTIONS(211), 1,
      sym_path,
    ACTIONS(436), 1,
      sym__blank,
    STATE(228), 1,
      sym_memory_space,
    STATE(935), 1,
      aux_sym_block_repeat1,
    STATE(980), 1,
      sym_macro,
    STATE(1060), 1,
      sym_call_expression,
    STATE(1061), 1,
      sym__hll_var_call_expression,
    STATE(1080), 1,
      sym_integer,
    STATE(1100), 1,
      aux_sym__path_expression_repeat2,
    STATE(1172), 1,
      aux_sym__path_expression_repeat1,
    STATE(1371), 1,
      sym__and_expression,
    STATE(1374), 1,
      sym__file_dialog,
    STATE(1377), 1,
      sym_trace32_hll_variable,
    STATE(1378), 1,
      sym__unary_expression,
    STATE(1392), 1,
      sym__prefix_postfix_expression,
    STATE(1394), 1,
      sym__binary_expression,
    STATE(1550), 1,
      sym__address_binary_expression,
    STATE(2349), 1,
      sym__function_identifier,
    STATE(2359), 1,
      sym__hll_var_call_expression_function,
    ACTIONS(149), 2,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
    ACTIONS(185), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(187), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(189), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(203), 2,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
    STATE(1575), 2,
      sym__address_expression,
      sym__parenthesized_address_expression,
    ACTIONS(729), 3,
      sym_float,
      sym_time,
      sym_frequency,
    ACTIONS(731), 3,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
    STATE(1332), 13,
      sym__expression,
      sym__parenthesized_expression,
      sym__path_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_assignment_expression,
      sym__literal,
      sym_address,
      sym_bitmask,
      sym_string,
      sym_character,
      sym_symbol,
      sym__special_command_operator,
  [2210] = 40,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(96), 1,
      sym__decimal_number_pre_hook,
    ACTIONS(100), 1,
      sym_identifier,
    ACTIONS(102), 1,
      anon_sym_LPAREN,
    ACTIONS(104), 1,
      anon_sym_LBRACE,
    ACTIONS(116), 1,
      anon_sym_STAR,
    ACTIONS(120), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(122), 1,
      anon_sym_BSLASH,
    ACTIONS(124), 1,
      anon_sym_SQUOTE,
    ACTIONS(126), 1,
      anon_sym_DQUOTE,
    ACTIONS(128), 1,
      sym_access_class,
    ACTIONS(134), 1,
      aux_sym_symbol_token1,
    ACTIONS(136), 1,
      aux_sym_symbol_token2,
    ACTIONS(436), 1,
      sym__blank,
    ACTIONS(695), 1,
      anon_sym_AMP,
    STATE(224), 1,
      sym_memory_space,
    STATE(328), 1,
      sym_macro,
    STATE(345), 1,
      sym__hll_var_call_expression,
    STATE(347), 1,
      sym_call_expression,
    STATE(350), 1,
      sym_integer,
    STATE(371), 1,
      aux_sym__path_expression_repeat1,
    STATE(450), 1,
      sym__unary_expression,
    STATE(451), 1,
      sym__prefix_postfix_expression,
    STATE(452), 1,
      sym__binary_expression,
    STATE(453), 1,
      sym__and_expression,
    STATE(457), 1,
      sym_trace32_hll_variable,
    STATE(459), 1,
      sym__file_dialog,
    STATE(935), 1,
      aux_sym_block_repeat1,
    STATE(1550), 1,
      sym__address_binary_expression,
    STATE(2354), 1,
      sym__function_identifier,
    STATE(2355), 1,
      sym__hll_var_call_expression_function,
    ACTIONS(84), 2,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
    ACTIONS(110), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(112), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(114), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(132), 2,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
    STATE(1575), 2,
      sym__address_expression,
      sym__parenthesized_address_expression,
    ACTIONS(733), 3,
      sym_float,
      sym_time,
      sym_frequency,
    ACTIONS(735), 4,
      sym_path,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
    STATE(9), 14,
      sym__expression,
      sym__parenthesized_expression,
      sym__path_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_assignment_expression,
      sym__literal,
      sym_address,
      sym_bitmask,
      sym_string,
      sym_character,
      sym_symbol,
      sym__special_command_operator,
      aux_sym__path_expression_repeat2,
  [2355] = 42,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(120), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(147), 1,
      anon_sym_AMP,
    ACTIONS(155), 1,
      sym__decimal_number_pre_hook,
    ACTIONS(179), 1,
      sym_identifier,
    ACTIONS(181), 1,
      anon_sym_LPAREN,
    ACTIONS(183), 1,
      anon_sym_LBRACE,
    ACTIONS(191), 1,
      anon_sym_STAR,
    ACTIONS(193), 1,
      anon_sym_BSLASH,
    ACTIONS(195), 1,
      anon_sym_SQUOTE,
    ACTIONS(197), 1,
      anon_sym_DQUOTE,
    ACTIONS(199), 1,
      sym_access_class,
    ACTIONS(205), 1,
      aux_sym_symbol_token1,
    ACTIONS(207), 1,
      aux_sym_symbol_token2,
    ACTIONS(211), 1,
      sym_path,
    ACTIONS(436), 1,
      sym__blank,
    STATE(228), 1,
      sym_memory_space,
    STATE(935), 1,
      aux_sym_block_repeat1,
    STATE(980), 1,
      sym_macro,
    STATE(1060), 1,
      sym_call_expression,
    STATE(1061), 1,
      sym__hll_var_call_expression,
    STATE(1080), 1,
      sym_integer,
    STATE(1100), 1,
      aux_sym__path_expression_repeat2,
    STATE(1172), 1,
      aux_sym__path_expression_repeat1,
    STATE(1371), 1,
      sym__and_expression,
    STATE(1374), 1,
      sym__file_dialog,
    STATE(1377), 1,
      sym_trace32_hll_variable,
    STATE(1378), 1,
      sym__unary_expression,
    STATE(1392), 1,
      sym__prefix_postfix_expression,
    STATE(1394), 1,
      sym__binary_expression,
    STATE(1550), 1,
      sym__address_binary_expression,
    STATE(2349), 1,
      sym__function_identifier,
    STATE(2359), 1,
      sym__hll_var_call_expression_function,
    ACTIONS(149), 2,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
    ACTIONS(185), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(187), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(189), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(203), 2,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
    STATE(1575), 2,
      sym__address_expression,
      sym__parenthesized_address_expression,
    ACTIONS(737), 3,
      sym_float,
      sym_time,
      sym_frequency,
    ACTIONS(739), 3,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
    STATE(1339), 13,
      sym__expression,
      sym__parenthesized_expression,
      sym__path_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_assignment_expression,
      sym__literal,
      sym_address,
      sym_bitmask,
      sym_string,
      sym_character,
      sym_symbol,
      sym__special_command_operator,
  [2504] = 42,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(120), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(147), 1,
      anon_sym_AMP,
    ACTIONS(155), 1,
      sym__decimal_number_pre_hook,
    ACTIONS(179), 1,
      sym_identifier,
    ACTIONS(181), 1,
      anon_sym_LPAREN,
    ACTIONS(183), 1,
      anon_sym_LBRACE,
    ACTIONS(191), 1,
      anon_sym_STAR,
    ACTIONS(193), 1,
      anon_sym_BSLASH,
    ACTIONS(195), 1,
      anon_sym_SQUOTE,
    ACTIONS(197), 1,
      anon_sym_DQUOTE,
    ACTIONS(199), 1,
      sym_access_class,
    ACTIONS(205), 1,
      aux_sym_symbol_token1,
    ACTIONS(207), 1,
      aux_sym_symbol_token2,
    ACTIONS(211), 1,
      sym_path,
    ACTIONS(745), 1,
      sym__blank,
    STATE(111), 1,
      aux_sym_block_repeat1,
    STATE(228), 1,
      sym_memory_space,
    STATE(980), 1,
      sym_macro,
    STATE(1060), 1,
      sym_call_expression,
    STATE(1061), 1,
      sym__hll_var_call_expression,
    STATE(1080), 1,
      sym_integer,
    STATE(1100), 1,
      aux_sym__path_expression_repeat2,
    STATE(1172), 1,
      aux_sym__path_expression_repeat1,
    STATE(1371), 1,
      sym__and_expression,
    STATE(1374), 1,
      sym__file_dialog,
    STATE(1377), 1,
      sym_trace32_hll_variable,
    STATE(1378), 1,
      sym__unary_expression,
    STATE(1392), 1,
      sym__prefix_postfix_expression,
    STATE(1394), 1,
      sym__binary_expression,
    STATE(1550), 1,
      sym__address_binary_expression,
    STATE(2349), 1,
      sym__function_identifier,
    STATE(2359), 1,
      sym__hll_var_call_expression_function,
    ACTIONS(149), 2,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
    ACTIONS(185), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(187), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(189), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(203), 2,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
    STATE(1575), 2,
      sym__address_expression,
      sym__parenthesized_address_expression,
    ACTIONS(741), 3,
      sym_float,
      sym_time,
      sym_frequency,
    ACTIONS(743), 3,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
    STATE(1340), 13,
      sym__expression,
      sym__parenthesized_expression,
      sym__path_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_assignment_expression,
      sym__literal,
      sym_address,
      sym_bitmask,
      sym_string,
      sym_character,
      sym_symbol,
      sym__special_command_operator,
  [2653] = 43,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(98), 1,
      sym_path,
    ACTIONS(120), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(147), 1,
      anon_sym_AMP,
    ACTIONS(155), 1,
      sym__decimal_number_pre_hook,
    ACTIONS(157), 1,
      anon_sym_LPAREN,
    ACTIONS(159), 1,
      anon_sym_LBRACE,
    ACTIONS(191), 1,
      anon_sym_STAR,
    ACTIONS(193), 1,
      anon_sym_BSLASH,
    ACTIONS(195), 1,
      anon_sym_SQUOTE,
    ACTIONS(197), 1,
      anon_sym_DQUOTE,
    ACTIONS(199), 1,
      sym_access_class,
    ACTIONS(205), 1,
      aux_sym_symbol_token1,
    ACTIONS(207), 1,
      aux_sym_symbol_token2,
    ACTIONS(436), 1,
      sym__blank,
    ACTIONS(747), 1,
      sym_identifier,
    STATE(228), 1,
      sym_memory_space,
    STATE(935), 1,
      aux_sym_block_repeat1,
    STATE(1046), 1,
      sym_call_expression,
    STATE(1049), 1,
      sym__hll_var_call_expression,
    STATE(1053), 1,
      aux_sym__path_expression_repeat2,
    STATE(1077), 1,
      sym_macro,
    STATE(1080), 1,
      sym_integer,
    STATE(1218), 1,
      aux_sym__path_expression_repeat1,
    STATE(1374), 1,
      sym__file_dialog,
    STATE(1377), 1,
      sym_trace32_hll_variable,
    STATE(1399), 1,
      sym__unary_expression,
    STATE(1400), 1,
      sym__prefix_postfix_expression,
    STATE(1404), 1,
      sym__binary_expression,
    STATE(1406), 1,
      sym__and_expression,
    STATE(1550), 1,
      sym__address_binary_expression,
    STATE(2257), 1,
      sym__function_identifier,
    STATE(2260), 1,
      sym__hll_var_call_expression_function,
    ACTIONS(60), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(62), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(149), 2,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
    ACTIONS(203), 2,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
    ACTIONS(222), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1575), 2,
      sym__address_expression,
      sym__parenthesized_address_expression,
    ACTIONS(749), 3,
      sym_float,
      sym_time,
      sym_frequency,
    ACTIONS(751), 3,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
    STATE(1454), 6,
      sym__expression,
      sym__parenthesized_expression,
      sym__path_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_assignment_expression,
    STATE(1499), 7,
      sym__literal,
      sym_address,
      sym_bitmask,
      sym_string,
      sym_character,
      sym_symbol,
      sym__special_command_operator,
  [2804] = 42,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(76), 1,
      anon_sym_BSLASH,
    ACTIONS(78), 1,
      anon_sym_SQUOTE,
    ACTIONS(80), 1,
      anon_sym_DQUOTE,
    ACTIONS(82), 1,
      sym_access_class,
    ACTIONS(90), 1,
      aux_sym_symbol_token1,
    ACTIONS(92), 1,
      aux_sym_symbol_token2,
    ACTIONS(98), 1,
      sym_path,
    ACTIONS(120), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(140), 1,
      sym_identifier,
    ACTIONS(157), 1,
      anon_sym_LPAREN,
    ACTIONS(159), 1,
      anon_sym_LBRACE,
    ACTIONS(167), 1,
      anon_sym_STAR,
    ACTIONS(169), 1,
      anon_sym_AMP,
    ACTIONS(177), 1,
      sym__decimal_number_pre_hook,
    ACTIONS(757), 1,
      sym__blank,
    STATE(141), 1,
      aux_sym_block_repeat1,
    STATE(236), 1,
      sym_memory_space,
    STATE(975), 1,
      sym_macro,
    STATE(1046), 1,
      sym_call_expression,
    STATE(1049), 1,
      sym__hll_var_call_expression,
    STATE(1052), 1,
      sym_integer,
    STATE(1053), 1,
      aux_sym__path_expression_repeat2,
    STATE(1218), 1,
      aux_sym__path_expression_repeat1,
    STATE(1399), 1,
      sym__unary_expression,
    STATE(1400), 1,
      sym__prefix_postfix_expression,
    STATE(1404), 1,
      sym__binary_expression,
    STATE(1406), 1,
      sym__and_expression,
    STATE(1412), 1,
      sym_trace32_hll_variable,
    STATE(1417), 1,
      sym__file_dialog,
    STATE(1550), 1,
      sym__address_binary_expression,
    STATE(2257), 1,
      sym__function_identifier,
    STATE(2260), 1,
      sym__hll_var_call_expression_function,
    ACTIONS(60), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(62), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(88), 2,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
    ACTIONS(171), 2,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
    ACTIONS(222), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1575), 2,
      sym__address_expression,
      sym__parenthesized_address_expression,
    ACTIONS(753), 3,
      sym_float,
      sym_time,
      sym_frequency,
    ACTIONS(755), 3,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
    STATE(1395), 13,
      sym__expression,
      sym__parenthesized_expression,
      sym__path_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_assignment_expression,
      sym__literal,
      sym_address,
      sym_bitmask,
      sym_string,
      sym_character,
      sym_symbol,
      sym__special_command_operator,
  [2953] = 42,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(120), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(147), 1,
      anon_sym_AMP,
    ACTIONS(155), 1,
      sym__decimal_number_pre_hook,
    ACTIONS(179), 1,
      sym_identifier,
    ACTIONS(181), 1,
      anon_sym_LPAREN,
    ACTIONS(183), 1,
      anon_sym_LBRACE,
    ACTIONS(191), 1,
      anon_sym_STAR,
    ACTIONS(193), 1,
      anon_sym_BSLASH,
    ACTIONS(195), 1,
      anon_sym_SQUOTE,
    ACTIONS(197), 1,
      anon_sym_DQUOTE,
    ACTIONS(199), 1,
      sym_access_class,
    ACTIONS(205), 1,
      aux_sym_symbol_token1,
    ACTIONS(207), 1,
      aux_sym_symbol_token2,
    ACTIONS(211), 1,
      sym_path,
    ACTIONS(436), 1,
      sym__blank,
    STATE(228), 1,
      sym_memory_space,
    STATE(935), 1,
      aux_sym_block_repeat1,
    STATE(980), 1,
      sym_macro,
    STATE(1060), 1,
      sym_call_expression,
    STATE(1061), 1,
      sym__hll_var_call_expression,
    STATE(1080), 1,
      sym_integer,
    STATE(1100), 1,
      aux_sym__path_expression_repeat2,
    STATE(1172), 1,
      aux_sym__path_expression_repeat1,
    STATE(1371), 1,
      sym__and_expression,
    STATE(1374), 1,
      sym__file_dialog,
    STATE(1377), 1,
      sym_trace32_hll_variable,
    STATE(1378), 1,
      sym__unary_expression,
    STATE(1392), 1,
      sym__prefix_postfix_expression,
    STATE(1394), 1,
      sym__binary_expression,
    STATE(1550), 1,
      sym__address_binary_expression,
    STATE(2349), 1,
      sym__function_identifier,
    STATE(2359), 1,
      sym__hll_var_call_expression_function,
    ACTIONS(149), 2,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
    ACTIONS(185), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(187), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(189), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(203), 2,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
    STATE(1575), 2,
      sym__address_expression,
      sym__parenthesized_address_expression,
    ACTIONS(759), 3,
      sym_float,
      sym_time,
      sym_frequency,
    ACTIONS(761), 3,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
    STATE(1290), 13,
      sym__expression,
      sym__parenthesized_expression,
      sym__path_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_assignment_expression,
      sym__literal,
      sym_address,
      sym_bitmask,
      sym_string,
      sym_character,
      sym_symbol,
      sym__special_command_operator,
  [3102] = 40,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(96), 1,
      sym__decimal_number_pre_hook,
    ACTIONS(100), 1,
      sym_identifier,
    ACTIONS(102), 1,
      anon_sym_LPAREN,
    ACTIONS(104), 1,
      anon_sym_LBRACE,
    ACTIONS(116), 1,
      anon_sym_STAR,
    ACTIONS(120), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(122), 1,
      anon_sym_BSLASH,
    ACTIONS(124), 1,
      anon_sym_SQUOTE,
    ACTIONS(126), 1,
      anon_sym_DQUOTE,
    ACTIONS(128), 1,
      sym_access_class,
    ACTIONS(134), 1,
      aux_sym_symbol_token1,
    ACTIONS(136), 1,
      aux_sym_symbol_token2,
    ACTIONS(436), 1,
      sym__blank,
    ACTIONS(695), 1,
      anon_sym_AMP,
    STATE(224), 1,
      sym_memory_space,
    STATE(328), 1,
      sym_macro,
    STATE(345), 1,
      sym__hll_var_call_expression,
    STATE(347), 1,
      sym_call_expression,
    STATE(350), 1,
      sym_integer,
    STATE(371), 1,
      aux_sym__path_expression_repeat1,
    STATE(450), 1,
      sym__unary_expression,
    STATE(451), 1,
      sym__prefix_postfix_expression,
    STATE(452), 1,
      sym__binary_expression,
    STATE(453), 1,
      sym__and_expression,
    STATE(457), 1,
      sym_trace32_hll_variable,
    STATE(459), 1,
      sym__file_dialog,
    STATE(935), 1,
      aux_sym_block_repeat1,
    STATE(1550), 1,
      sym__address_binary_expression,
    STATE(2354), 1,
      sym__function_identifier,
    STATE(2355), 1,
      sym__hll_var_call_expression_function,
    ACTIONS(84), 2,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
    ACTIONS(110), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(112), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(114), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(132), 2,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
    STATE(1575), 2,
      sym__address_expression,
      sym__parenthesized_address_expression,
    ACTIONS(763), 3,
      sym_float,
      sym_time,
      sym_frequency,
    ACTIONS(765), 4,
      sym_path,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
    STATE(383), 14,
      sym__expression,
      sym__parenthesized_expression,
      sym__path_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_assignment_expression,
      sym__literal,
      sym_address,
      sym_bitmask,
      sym_string,
      sym_character,
      sym_symbol,
      sym__special_command_operator,
      aux_sym__path_expression_repeat2,
  [3247] = 42,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(76), 1,
      anon_sym_BSLASH,
    ACTIONS(78), 1,
      anon_sym_SQUOTE,
    ACTIONS(80), 1,
      anon_sym_DQUOTE,
    ACTIONS(82), 1,
      sym_access_class,
    ACTIONS(90), 1,
      aux_sym_symbol_token1,
    ACTIONS(92), 1,
      aux_sym_symbol_token2,
    ACTIONS(98), 1,
      sym_path,
    ACTIONS(120), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(140), 1,
      sym_identifier,
    ACTIONS(157), 1,
      anon_sym_LPAREN,
    ACTIONS(159), 1,
      anon_sym_LBRACE,
    ACTIONS(167), 1,
      anon_sym_STAR,
    ACTIONS(169), 1,
      anon_sym_AMP,
    ACTIONS(177), 1,
      sym__decimal_number_pre_hook,
    ACTIONS(771), 1,
      sym__blank,
    STATE(114), 1,
      aux_sym_block_repeat1,
    STATE(236), 1,
      sym_memory_space,
    STATE(975), 1,
      sym_macro,
    STATE(1046), 1,
      sym_call_expression,
    STATE(1049), 1,
      sym__hll_var_call_expression,
    STATE(1052), 1,
      sym_integer,
    STATE(1053), 1,
      aux_sym__path_expression_repeat2,
    STATE(1218), 1,
      aux_sym__path_expression_repeat1,
    STATE(1399), 1,
      sym__unary_expression,
    STATE(1400), 1,
      sym__prefix_postfix_expression,
    STATE(1404), 1,
      sym__binary_expression,
    STATE(1406), 1,
      sym__and_expression,
    STATE(1412), 1,
      sym_trace32_hll_variable,
    STATE(1417), 1,
      sym__file_dialog,
    STATE(1550), 1,
      sym__address_binary_expression,
    STATE(2257), 1,
      sym__function_identifier,
    STATE(2260), 1,
      sym__hll_var_call_expression_function,
    ACTIONS(60), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(62), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(88), 2,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
    ACTIONS(171), 2,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
    ACTIONS(222), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1575), 2,
      sym__address_expression,
      sym__parenthesized_address_expression,
    ACTIONS(767), 3,
      sym_float,
      sym_time,
      sym_frequency,
    ACTIONS(769), 3,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
    STATE(1422), 13,
      sym__expression,
      sym__parenthesized_expression,
      sym__path_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_assignment_expression,
      sym__literal,
      sym_address,
      sym_bitmask,
      sym_string,
      sym_character,
      sym_symbol,
      sym__special_command_operator,
  [3396] = 42,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(76), 1,
      anon_sym_BSLASH,
    ACTIONS(78), 1,
      anon_sym_SQUOTE,
    ACTIONS(80), 1,
      anon_sym_DQUOTE,
    ACTIONS(82), 1,
      sym_access_class,
    ACTIONS(90), 1,
      aux_sym_symbol_token1,
    ACTIONS(92), 1,
      aux_sym_symbol_token2,
    ACTIONS(98), 1,
      sym_path,
    ACTIONS(120), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(140), 1,
      sym_identifier,
    ACTIONS(157), 1,
      anon_sym_LPAREN,
    ACTIONS(159), 1,
      anon_sym_LBRACE,
    ACTIONS(167), 1,
      anon_sym_STAR,
    ACTIONS(169), 1,
      anon_sym_AMP,
    ACTIONS(177), 1,
      sym__decimal_number_pre_hook,
    ACTIONS(436), 1,
      sym__blank,
    STATE(236), 1,
      sym_memory_space,
    STATE(935), 1,
      aux_sym_block_repeat1,
    STATE(975), 1,
      sym_macro,
    STATE(1046), 1,
      sym_call_expression,
    STATE(1049), 1,
      sym__hll_var_call_expression,
    STATE(1052), 1,
      sym_integer,
    STATE(1053), 1,
      aux_sym__path_expression_repeat2,
    STATE(1218), 1,
      aux_sym__path_expression_repeat1,
    STATE(1399), 1,
      sym__unary_expression,
    STATE(1400), 1,
      sym__prefix_postfix_expression,
    STATE(1404), 1,
      sym__binary_expression,
    STATE(1406), 1,
      sym__and_expression,
    STATE(1412), 1,
      sym_trace32_hll_variable,
    STATE(1417), 1,
      sym__file_dialog,
    STATE(1550), 1,
      sym__address_binary_expression,
    STATE(2257), 1,
      sym__function_identifier,
    STATE(2260), 1,
      sym__hll_var_call_expression_function,
    ACTIONS(60), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(62), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(88), 2,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
    ACTIONS(171), 2,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
    ACTIONS(222), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1575), 2,
      sym__address_expression,
      sym__parenthesized_address_expression,
    ACTIONS(773), 3,
      sym_float,
      sym_time,
      sym_frequency,
    ACTIONS(775), 3,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
    STATE(1423), 13,
      sym__expression,
      sym__parenthesized_expression,
      sym__path_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_assignment_expression,
      sym__literal,
      sym_address,
      sym_bitmask,
      sym_string,
      sym_character,
      sym_symbol,
      sym__special_command_operator,
  [3545] = 40,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(96), 1,
      sym__decimal_number_pre_hook,
    ACTIONS(100), 1,
      sym_identifier,
    ACTIONS(102), 1,
      anon_sym_LPAREN,
    ACTIONS(104), 1,
      anon_sym_LBRACE,
    ACTIONS(116), 1,
      anon_sym_STAR,
    ACTIONS(120), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(122), 1,
      anon_sym_BSLASH,
    ACTIONS(124), 1,
      anon_sym_SQUOTE,
    ACTIONS(126), 1,
      anon_sym_DQUOTE,
    ACTIONS(128), 1,
      sym_access_class,
    ACTIONS(134), 1,
      aux_sym_symbol_token1,
    ACTIONS(136), 1,
      aux_sym_symbol_token2,
    ACTIONS(436), 1,
      sym__blank,
    ACTIONS(695), 1,
      anon_sym_AMP,
    STATE(224), 1,
      sym_memory_space,
    STATE(328), 1,
      sym_macro,
    STATE(345), 1,
      sym__hll_var_call_expression,
    STATE(347), 1,
      sym_call_expression,
    STATE(350), 1,
      sym_integer,
    STATE(371), 1,
      aux_sym__path_expression_repeat1,
    STATE(450), 1,
      sym__unary_expression,
    STATE(451), 1,
      sym__prefix_postfix_expression,
    STATE(452), 1,
      sym__binary_expression,
    STATE(453), 1,
      sym__and_expression,
    STATE(457), 1,
      sym_trace32_hll_variable,
    STATE(459), 1,
      sym__file_dialog,
    STATE(935), 1,
      aux_sym_block_repeat1,
    STATE(1550), 1,
      sym__address_binary_expression,
    STATE(2354), 1,
      sym__function_identifier,
    STATE(2355), 1,
      sym__hll_var_call_expression_function,
    ACTIONS(84), 2,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
    ACTIONS(110), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(112), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(114), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(132), 2,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
    STATE(1575), 2,
      sym__address_expression,
      sym__parenthesized_address_expression,
    ACTIONS(777), 3,
      sym_float,
      sym_time,
      sym_frequency,
    ACTIONS(779), 4,
      sym_path,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
    STATE(10), 14,
      sym__expression,
      sym__parenthesized_expression,
      sym__path_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_assignment_expression,
      sym__literal,
      sym_address,
      sym_bitmask,
      sym_string,
      sym_character,
      sym_symbol,
      sym__special_command_operator,
      aux_sym__path_expression_repeat2,
  [3690] = 42,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(120), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(147), 1,
      anon_sym_AMP,
    ACTIONS(155), 1,
      sym__decimal_number_pre_hook,
    ACTIONS(179), 1,
      sym_identifier,
    ACTIONS(181), 1,
      anon_sym_LPAREN,
    ACTIONS(183), 1,
      anon_sym_LBRACE,
    ACTIONS(191), 1,
      anon_sym_STAR,
    ACTIONS(193), 1,
      anon_sym_BSLASH,
    ACTIONS(195), 1,
      anon_sym_SQUOTE,
    ACTIONS(197), 1,
      anon_sym_DQUOTE,
    ACTIONS(199), 1,
      sym_access_class,
    ACTIONS(205), 1,
      aux_sym_symbol_token1,
    ACTIONS(207), 1,
      aux_sym_symbol_token2,
    ACTIONS(211), 1,
      sym_path,
    ACTIONS(436), 1,
      sym__blank,
    STATE(228), 1,
      sym_memory_space,
    STATE(935), 1,
      aux_sym_block_repeat1,
    STATE(980), 1,
      sym_macro,
    STATE(1060), 1,
      sym_call_expression,
    STATE(1061), 1,
      sym__hll_var_call_expression,
    STATE(1080), 1,
      sym_integer,
    STATE(1100), 1,
      aux_sym__path_expression_repeat2,
    STATE(1172), 1,
      aux_sym__path_expression_repeat1,
    STATE(1371), 1,
      sym__and_expression,
    STATE(1374), 1,
      sym__file_dialog,
    STATE(1377), 1,
      sym_trace32_hll_variable,
    STATE(1378), 1,
      sym__unary_expression,
    STATE(1392), 1,
      sym__prefix_postfix_expression,
    STATE(1394), 1,
      sym__binary_expression,
    STATE(1550), 1,
      sym__address_binary_expression,
    STATE(2349), 1,
      sym__function_identifier,
    STATE(2359), 1,
      sym__hll_var_call_expression_function,
    ACTIONS(149), 2,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
    ACTIONS(185), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(187), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(189), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(203), 2,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
    STATE(1575), 2,
      sym__address_expression,
      sym__parenthesized_address_expression,
    ACTIONS(781), 3,
      sym_float,
      sym_time,
      sym_frequency,
    ACTIONS(783), 3,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
    STATE(1220), 13,
      sym__expression,
      sym__parenthesized_expression,
      sym__path_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_assignment_expression,
      sym__literal,
      sym_address,
      sym_bitmask,
      sym_string,
      sym_character,
      sym_symbol,
      sym__special_command_operator,
  [3839] = 42,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(120), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(147), 1,
      anon_sym_AMP,
    ACTIONS(155), 1,
      sym__decimal_number_pre_hook,
    ACTIONS(179), 1,
      sym_identifier,
    ACTIONS(181), 1,
      anon_sym_LPAREN,
    ACTIONS(183), 1,
      anon_sym_LBRACE,
    ACTIONS(191), 1,
      anon_sym_STAR,
    ACTIONS(193), 1,
      anon_sym_BSLASH,
    ACTIONS(195), 1,
      anon_sym_SQUOTE,
    ACTIONS(197), 1,
      anon_sym_DQUOTE,
    ACTIONS(199), 1,
      sym_access_class,
    ACTIONS(205), 1,
      aux_sym_symbol_token1,
    ACTIONS(207), 1,
      aux_sym_symbol_token2,
    ACTIONS(211), 1,
      sym_path,
    ACTIONS(789), 1,
      sym__blank,
    STATE(121), 1,
      aux_sym_block_repeat1,
    STATE(228), 1,
      sym_memory_space,
    STATE(980), 1,
      sym_macro,
    STATE(1060), 1,
      sym_call_expression,
    STATE(1061), 1,
      sym__hll_var_call_expression,
    STATE(1080), 1,
      sym_integer,
    STATE(1100), 1,
      aux_sym__path_expression_repeat2,
    STATE(1172), 1,
      aux_sym__path_expression_repeat1,
    STATE(1371), 1,
      sym__and_expression,
    STATE(1374), 1,
      sym__file_dialog,
    STATE(1377), 1,
      sym_trace32_hll_variable,
    STATE(1378), 1,
      sym__unary_expression,
    STATE(1392), 1,
      sym__prefix_postfix_expression,
    STATE(1394), 1,
      sym__binary_expression,
    STATE(1550), 1,
      sym__address_binary_expression,
    STATE(2349), 1,
      sym__function_identifier,
    STATE(2359), 1,
      sym__hll_var_call_expression_function,
    ACTIONS(149), 2,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
    ACTIONS(185), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(187), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(189), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(203), 2,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
    STATE(1575), 2,
      sym__address_expression,
      sym__parenthesized_address_expression,
    ACTIONS(785), 3,
      sym_float,
      sym_time,
      sym_frequency,
    ACTIONS(787), 3,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
    STATE(1236), 13,
      sym__expression,
      sym__parenthesized_expression,
      sym__path_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_assignment_expression,
      sym__literal,
      sym_address,
      sym_bitmask,
      sym_string,
      sym_character,
      sym_symbol,
      sym__special_command_operator,
  [3988] = 42,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(120), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(147), 1,
      anon_sym_AMP,
    ACTIONS(155), 1,
      sym__decimal_number_pre_hook,
    ACTIONS(179), 1,
      sym_identifier,
    ACTIONS(181), 1,
      anon_sym_LPAREN,
    ACTIONS(183), 1,
      anon_sym_LBRACE,
    ACTIONS(191), 1,
      anon_sym_STAR,
    ACTIONS(193), 1,
      anon_sym_BSLASH,
    ACTIONS(195), 1,
      anon_sym_SQUOTE,
    ACTIONS(197), 1,
      anon_sym_DQUOTE,
    ACTIONS(199), 1,
      sym_access_class,
    ACTIONS(205), 1,
      aux_sym_symbol_token1,
    ACTIONS(207), 1,
      aux_sym_symbol_token2,
    ACTIONS(211), 1,
      sym_path,
    ACTIONS(436), 1,
      sym__blank,
    STATE(228), 1,
      sym_memory_space,
    STATE(935), 1,
      aux_sym_block_repeat1,
    STATE(980), 1,
      sym_macro,
    STATE(1060), 1,
      sym_call_expression,
    STATE(1061), 1,
      sym__hll_var_call_expression,
    STATE(1080), 1,
      sym_integer,
    STATE(1100), 1,
      aux_sym__path_expression_repeat2,
    STATE(1172), 1,
      aux_sym__path_expression_repeat1,
    STATE(1371), 1,
      sym__and_expression,
    STATE(1374), 1,
      sym__file_dialog,
    STATE(1377), 1,
      sym_trace32_hll_variable,
    STATE(1378), 1,
      sym__unary_expression,
    STATE(1392), 1,
      sym__prefix_postfix_expression,
    STATE(1394), 1,
      sym__binary_expression,
    STATE(1550), 1,
      sym__address_binary_expression,
    STATE(2349), 1,
      sym__function_identifier,
    STATE(2359), 1,
      sym__hll_var_call_expression_function,
    ACTIONS(149), 2,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
    ACTIONS(185), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(187), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(189), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(203), 2,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
    STATE(1575), 2,
      sym__address_expression,
      sym__parenthesized_address_expression,
    ACTIONS(791), 3,
      sym_float,
      sym_time,
      sym_frequency,
    ACTIONS(793), 3,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
    STATE(1305), 13,
      sym__expression,
      sym__parenthesized_expression,
      sym__path_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_assignment_expression,
      sym__literal,
      sym_address,
      sym_bitmask,
      sym_string,
      sym_character,
      sym_symbol,
      sym__special_command_operator,
  [4137] = 43,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(98), 1,
      sym_path,
    ACTIONS(120), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(147), 1,
      anon_sym_AMP,
    ACTIONS(155), 1,
      sym__decimal_number_pre_hook,
    ACTIONS(157), 1,
      anon_sym_LPAREN,
    ACTIONS(159), 1,
      anon_sym_LBRACE,
    ACTIONS(191), 1,
      anon_sym_STAR,
    ACTIONS(193), 1,
      anon_sym_BSLASH,
    ACTIONS(195), 1,
      anon_sym_SQUOTE,
    ACTIONS(197), 1,
      anon_sym_DQUOTE,
    ACTIONS(199), 1,
      sym_access_class,
    ACTIONS(205), 1,
      aux_sym_symbol_token1,
    ACTIONS(207), 1,
      aux_sym_symbol_token2,
    ACTIONS(436), 1,
      sym__blank,
    ACTIONS(795), 1,
      sym_identifier,
    STATE(228), 1,
      sym_memory_space,
    STATE(935), 1,
      aux_sym_block_repeat1,
    STATE(1046), 1,
      sym_call_expression,
    STATE(1049), 1,
      sym__hll_var_call_expression,
    STATE(1053), 1,
      aux_sym__path_expression_repeat2,
    STATE(1080), 1,
      sym_integer,
    STATE(1106), 1,
      sym_macro,
    STATE(1218), 1,
      aux_sym__path_expression_repeat1,
    STATE(1374), 1,
      sym__file_dialog,
    STATE(1377), 1,
      sym_trace32_hll_variable,
    STATE(1399), 1,
      sym__unary_expression,
    STATE(1400), 1,
      sym__prefix_postfix_expression,
    STATE(1404), 1,
      sym__binary_expression,
    STATE(1406), 1,
      sym__and_expression,
    STATE(1550), 1,
      sym__address_binary_expression,
    STATE(2257), 1,
      sym__function_identifier,
    STATE(2260), 1,
      sym__hll_var_call_expression_function,
    ACTIONS(60), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(62), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(149), 2,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
    ACTIONS(203), 2,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
    ACTIONS(222), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1575), 2,
      sym__address_expression,
      sym__parenthesized_address_expression,
    ACTIONS(797), 3,
      sym_float,
      sym_time,
      sym_frequency,
    ACTIONS(799), 3,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
    STATE(1454), 6,
      sym__expression,
      sym__parenthesized_expression,
      sym__path_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_assignment_expression,
    STATE(1450), 7,
      sym__literal,
      sym_address,
      sym_bitmask,
      sym_string,
      sym_character,
      sym_symbol,
      sym__special_command_operator,
  [4288] = 42,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(76), 1,
      anon_sym_BSLASH,
    ACTIONS(78), 1,
      anon_sym_SQUOTE,
    ACTIONS(80), 1,
      anon_sym_DQUOTE,
    ACTIONS(82), 1,
      sym_access_class,
    ACTIONS(90), 1,
      aux_sym_symbol_token1,
    ACTIONS(92), 1,
      aux_sym_symbol_token2,
    ACTIONS(98), 1,
      sym_path,
    ACTIONS(120), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(140), 1,
      sym_identifier,
    ACTIONS(157), 1,
      anon_sym_LPAREN,
    ACTIONS(159), 1,
      anon_sym_LBRACE,
    ACTIONS(167), 1,
      anon_sym_STAR,
    ACTIONS(169), 1,
      anon_sym_AMP,
    ACTIONS(177), 1,
      sym__decimal_number_pre_hook,
    ACTIONS(805), 1,
      sym__blank,
    STATE(124), 1,
      aux_sym_block_repeat1,
    STATE(236), 1,
      sym_memory_space,
    STATE(970), 1,
      sym_macro,
    STATE(1049), 1,
      sym__hll_var_call_expression,
    STATE(1053), 1,
      aux_sym__path_expression_repeat2,
    STATE(1097), 1,
      sym_call_expression,
    STATE(1098), 1,
      sym_integer,
    STATE(1218), 1,
      aux_sym__path_expression_repeat1,
    STATE(1399), 1,
      sym__unary_expression,
    STATE(1400), 1,
      sym__prefix_postfix_expression,
    STATE(1404), 1,
      sym__binary_expression,
    STATE(1406), 1,
      sym__and_expression,
    STATE(1412), 1,
      sym_trace32_hll_variable,
    STATE(1417), 1,
      sym__file_dialog,
    STATE(1550), 1,
      sym__address_binary_expression,
    STATE(2257), 1,
      sym__function_identifier,
    STATE(2260), 1,
      sym__hll_var_call_expression_function,
    ACTIONS(88), 2,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
    ACTIONS(161), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(163), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(165), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(171), 2,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
    STATE(1575), 2,
      sym__address_expression,
      sym__parenthesized_address_expression,
    ACTIONS(801), 3,
      sym_float,
      sym_time,
      sym_frequency,
    ACTIONS(803), 3,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
    STATE(1341), 13,
      sym__expression,
      sym__parenthesized_expression,
      sym__path_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_assignment_expression,
      sym__literal,
      sym_address,
      sym_bitmask,
      sym_string,
      sym_character,
      sym_symbol,
      sym__special_command_operator,
  [4437] = 42,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(120), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(147), 1,
      anon_sym_AMP,
    ACTIONS(155), 1,
      sym__decimal_number_pre_hook,
    ACTIONS(179), 1,
      sym_identifier,
    ACTIONS(181), 1,
      anon_sym_LPAREN,
    ACTIONS(183), 1,
      anon_sym_LBRACE,
    ACTIONS(191), 1,
      anon_sym_STAR,
    ACTIONS(193), 1,
      anon_sym_BSLASH,
    ACTIONS(195), 1,
      anon_sym_SQUOTE,
    ACTIONS(197), 1,
      anon_sym_DQUOTE,
    ACTIONS(199), 1,
      sym_access_class,
    ACTIONS(205), 1,
      aux_sym_symbol_token1,
    ACTIONS(207), 1,
      aux_sym_symbol_token2,
    ACTIONS(211), 1,
      sym_path,
    ACTIONS(436), 1,
      sym__blank,
    STATE(228), 1,
      sym_memory_space,
    STATE(935), 1,
      aux_sym_block_repeat1,
    STATE(980), 1,
      sym_macro,
    STATE(1060), 1,
      sym_call_expression,
    STATE(1061), 1,
      sym__hll_var_call_expression,
    STATE(1080), 1,
      sym_integer,
    STATE(1100), 1,
      aux_sym__path_expression_repeat2,
    STATE(1172), 1,
      aux_sym__path_expression_repeat1,
    STATE(1371), 1,
      sym__and_expression,
    STATE(1374), 1,
      sym__file_dialog,
    STATE(1377), 1,
      sym_trace32_hll_variable,
    STATE(1378), 1,
      sym__unary_expression,
    STATE(1392), 1,
      sym__prefix_postfix_expression,
    STATE(1394), 1,
      sym__binary_expression,
    STATE(1550), 1,
      sym__address_binary_expression,
    STATE(2349), 1,
      sym__function_identifier,
    STATE(2359), 1,
      sym__hll_var_call_expression_function,
    ACTIONS(149), 2,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
    ACTIONS(185), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(187), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(189), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(203), 2,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
    STATE(1575), 2,
      sym__address_expression,
      sym__parenthesized_address_expression,
    ACTIONS(807), 3,
      sym_float,
      sym_time,
      sym_frequency,
    ACTIONS(809), 3,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
    STATE(1140), 13,
      sym__expression,
      sym__parenthesized_expression,
      sym__path_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_assignment_expression,
      sym__literal,
      sym_address,
      sym_bitmask,
      sym_string,
      sym_character,
      sym_symbol,
      sym__special_command_operator,
  [4586] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(378), 1,
      anon_sym_AMP,
    ACTIONS(579), 1,
      aux_sym_symbol_token1,
    ACTIONS(581), 1,
      aux_sym_symbol_token2,
    ACTIONS(583), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(811), 1,
      sym_identifier,
    ACTIONS(813), 1,
      anon_sym_LPAREN,
    ACTIONS(817), 1,
      anon_sym_TILDE,
    ACTIONS(821), 1,
      anon_sym_STAR,
    ACTIONS(823), 1,
      anon_sym_BSLASH,
    ACTIONS(825), 1,
      anon_sym_sizeof,
    STATE(916), 1,
      sym_trace32_hll_variable,
    STATE(1587), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(819), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(815), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
    ACTIONS(340), 4,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(575), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(577), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(915), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1291), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
    ACTIONS(338), 16,
      anon_sym_PIPE_PIPE,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      sym_comment,
      sym__blank_line,
  [4693] = 42,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(120), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(147), 1,
      anon_sym_AMP,
    ACTIONS(155), 1,
      sym__decimal_number_pre_hook,
    ACTIONS(179), 1,
      sym_identifier,
    ACTIONS(181), 1,
      anon_sym_LPAREN,
    ACTIONS(183), 1,
      anon_sym_LBRACE,
    ACTIONS(191), 1,
      anon_sym_STAR,
    ACTIONS(193), 1,
      anon_sym_BSLASH,
    ACTIONS(195), 1,
      anon_sym_SQUOTE,
    ACTIONS(197), 1,
      anon_sym_DQUOTE,
    ACTIONS(199), 1,
      sym_access_class,
    ACTIONS(205), 1,
      aux_sym_symbol_token1,
    ACTIONS(207), 1,
      aux_sym_symbol_token2,
    ACTIONS(211), 1,
      sym_path,
    ACTIONS(436), 1,
      sym__blank,
    STATE(228), 1,
      sym_memory_space,
    STATE(935), 1,
      aux_sym_block_repeat1,
    STATE(980), 1,
      sym_macro,
    STATE(1060), 1,
      sym_call_expression,
    STATE(1061), 1,
      sym__hll_var_call_expression,
    STATE(1080), 1,
      sym_integer,
    STATE(1100), 1,
      aux_sym__path_expression_repeat2,
    STATE(1172), 1,
      aux_sym__path_expression_repeat1,
    STATE(1371), 1,
      sym__and_expression,
    STATE(1374), 1,
      sym__file_dialog,
    STATE(1377), 1,
      sym_trace32_hll_variable,
    STATE(1378), 1,
      sym__unary_expression,
    STATE(1392), 1,
      sym__prefix_postfix_expression,
    STATE(1394), 1,
      sym__binary_expression,
    STATE(1550), 1,
      sym__address_binary_expression,
    STATE(2349), 1,
      sym__function_identifier,
    STATE(2359), 1,
      sym__hll_var_call_expression_function,
    ACTIONS(149), 2,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
    ACTIONS(185), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(187), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(189), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(203), 2,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
    STATE(1575), 2,
      sym__address_expression,
      sym__parenthesized_address_expression,
    ACTIONS(827), 3,
      sym_float,
      sym_time,
      sym_frequency,
    ACTIONS(829), 3,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
    STATE(1271), 13,
      sym__expression,
      sym__parenthesized_expression,
      sym__path_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_assignment_expression,
      sym__literal,
      sym_address,
      sym_bitmask,
      sym_string,
      sym_character,
      sym_symbol,
      sym__special_command_operator,
  [4842] = 42,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(76), 1,
      anon_sym_BSLASH,
    ACTIONS(78), 1,
      anon_sym_SQUOTE,
    ACTIONS(80), 1,
      anon_sym_DQUOTE,
    ACTIONS(82), 1,
      sym_access_class,
    ACTIONS(90), 1,
      aux_sym_symbol_token1,
    ACTIONS(92), 1,
      aux_sym_symbol_token2,
    ACTIONS(98), 1,
      sym_path,
    ACTIONS(120), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(140), 1,
      sym_identifier,
    ACTIONS(157), 1,
      anon_sym_LPAREN,
    ACTIONS(159), 1,
      anon_sym_LBRACE,
    ACTIONS(167), 1,
      anon_sym_STAR,
    ACTIONS(169), 1,
      anon_sym_AMP,
    ACTIONS(177), 1,
      sym__decimal_number_pre_hook,
    ACTIONS(436), 1,
      sym__blank,
    STATE(236), 1,
      sym_memory_space,
    STATE(935), 1,
      aux_sym_block_repeat1,
    STATE(970), 1,
      sym_macro,
    STATE(1049), 1,
      sym__hll_var_call_expression,
    STATE(1053), 1,
      aux_sym__path_expression_repeat2,
    STATE(1097), 1,
      sym_call_expression,
    STATE(1098), 1,
      sym_integer,
    STATE(1218), 1,
      aux_sym__path_expression_repeat1,
    STATE(1399), 1,
      sym__unary_expression,
    STATE(1400), 1,
      sym__prefix_postfix_expression,
    STATE(1404), 1,
      sym__binary_expression,
    STATE(1406), 1,
      sym__and_expression,
    STATE(1412), 1,
      sym_trace32_hll_variable,
    STATE(1417), 1,
      sym__file_dialog,
    STATE(1550), 1,
      sym__address_binary_expression,
    STATE(2257), 1,
      sym__function_identifier,
    STATE(2260), 1,
      sym__hll_var_call_expression_function,
    ACTIONS(88), 2,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
    ACTIONS(161), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(163), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(165), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(171), 2,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
    STATE(1575), 2,
      sym__address_expression,
      sym__parenthesized_address_expression,
    ACTIONS(831), 3,
      sym_float,
      sym_time,
      sym_frequency,
    ACTIONS(833), 3,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
    STATE(1288), 13,
      sym__expression,
      sym__parenthesized_expression,
      sym__path_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_assignment_expression,
      sym__literal,
      sym_address,
      sym_bitmask,
      sym_string,
      sym_character,
      sym_symbol,
      sym__special_command_operator,
  [4991] = 42,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(76), 1,
      anon_sym_BSLASH,
    ACTIONS(78), 1,
      anon_sym_SQUOTE,
    ACTIONS(80), 1,
      anon_sym_DQUOTE,
    ACTIONS(82), 1,
      sym_access_class,
    ACTIONS(90), 1,
      aux_sym_symbol_token1,
    ACTIONS(92), 1,
      aux_sym_symbol_token2,
    ACTIONS(98), 1,
      sym_path,
    ACTIONS(120), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(140), 1,
      sym_identifier,
    ACTIONS(157), 1,
      anon_sym_LPAREN,
    ACTIONS(159), 1,
      anon_sym_LBRACE,
    ACTIONS(167), 1,
      anon_sym_STAR,
    ACTIONS(169), 1,
      anon_sym_AMP,
    ACTIONS(177), 1,
      sym__decimal_number_pre_hook,
    ACTIONS(835), 1,
      sym__blank,
    STATE(129), 1,
      aux_sym_block_repeat1,
    STATE(236), 1,
      sym_memory_space,
    STATE(970), 1,
      sym_macro,
    STATE(1049), 1,
      sym__hll_var_call_expression,
    STATE(1053), 1,
      aux_sym__path_expression_repeat2,
    STATE(1097), 1,
      sym_call_expression,
    STATE(1098), 1,
      sym_integer,
    STATE(1218), 1,
      aux_sym__path_expression_repeat1,
    STATE(1399), 1,
      sym__unary_expression,
    STATE(1400), 1,
      sym__prefix_postfix_expression,
    STATE(1404), 1,
      sym__binary_expression,
    STATE(1406), 1,
      sym__and_expression,
    STATE(1412), 1,
      sym_trace32_hll_variable,
    STATE(1417), 1,
      sym__file_dialog,
    STATE(1550), 1,
      sym__address_binary_expression,
    STATE(2257), 1,
      sym__function_identifier,
    STATE(2260), 1,
      sym__hll_var_call_expression_function,
    ACTIONS(88), 2,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
    ACTIONS(161), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(163), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(165), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(171), 2,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
    STATE(1575), 2,
      sym__address_expression,
      sym__parenthesized_address_expression,
    ACTIONS(831), 3,
      sym_float,
      sym_time,
      sym_frequency,
    ACTIONS(833), 3,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
    STATE(1288), 13,
      sym__expression,
      sym__parenthesized_expression,
      sym__path_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_assignment_expression,
      sym__literal,
      sym_address,
      sym_bitmask,
      sym_string,
      sym_character,
      sym_symbol,
      sym__special_command_operator,
  [5140] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(378), 1,
      anon_sym_AMP,
    ACTIONS(579), 1,
      aux_sym_symbol_token1,
    ACTIONS(581), 1,
      aux_sym_symbol_token2,
    ACTIONS(583), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(811), 1,
      sym_identifier,
    ACTIONS(813), 1,
      anon_sym_LPAREN,
    ACTIONS(817), 1,
      anon_sym_TILDE,
    ACTIONS(821), 1,
      anon_sym_STAR,
    ACTIONS(823), 1,
      anon_sym_BSLASH,
    ACTIONS(825), 1,
      anon_sym_sizeof,
    STATE(916), 1,
      sym_trace32_hll_variable,
    STATE(1587), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(819), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(815), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
    ACTIONS(336), 4,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(575), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(577), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(915), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1351), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
    ACTIONS(334), 16,
      anon_sym_PIPE_PIPE,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      sym_comment,
      sym__blank_line,
  [5247] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(378), 1,
      anon_sym_AMP,
    ACTIONS(579), 1,
      aux_sym_symbol_token1,
    ACTIONS(581), 1,
      aux_sym_symbol_token2,
    ACTIONS(583), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(811), 1,
      sym_identifier,
    ACTIONS(813), 1,
      anon_sym_LPAREN,
    ACTIONS(817), 1,
      anon_sym_TILDE,
    ACTIONS(821), 1,
      anon_sym_STAR,
    ACTIONS(823), 1,
      anon_sym_BSLASH,
    ACTIONS(825), 1,
      anon_sym_sizeof,
    STATE(916), 1,
      sym_trace32_hll_variable,
    STATE(1587), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(819), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(815), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
    ACTIONS(332), 4,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(575), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(577), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(915), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1356), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
    ACTIONS(330), 16,
      anon_sym_PIPE_PIPE,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      sym_comment,
      sym__blank_line,
  [5354] = 42,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(120), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(147), 1,
      anon_sym_AMP,
    ACTIONS(155), 1,
      sym__decimal_number_pre_hook,
    ACTIONS(179), 1,
      sym_identifier,
    ACTIONS(181), 1,
      anon_sym_LPAREN,
    ACTIONS(183), 1,
      anon_sym_LBRACE,
    ACTIONS(191), 1,
      anon_sym_STAR,
    ACTIONS(193), 1,
      anon_sym_BSLASH,
    ACTIONS(195), 1,
      anon_sym_SQUOTE,
    ACTIONS(197), 1,
      anon_sym_DQUOTE,
    ACTIONS(199), 1,
      sym_access_class,
    ACTIONS(205), 1,
      aux_sym_symbol_token1,
    ACTIONS(207), 1,
      aux_sym_symbol_token2,
    ACTIONS(211), 1,
      sym_path,
    ACTIONS(436), 1,
      sym__blank,
    STATE(228), 1,
      sym_memory_space,
    STATE(935), 1,
      aux_sym_block_repeat1,
    STATE(980), 1,
      sym_macro,
    STATE(1060), 1,
      sym_call_expression,
    STATE(1061), 1,
      sym__hll_var_call_expression,
    STATE(1080), 1,
      sym_integer,
    STATE(1100), 1,
      aux_sym__path_expression_repeat2,
    STATE(1172), 1,
      aux_sym__path_expression_repeat1,
    STATE(1371), 1,
      sym__and_expression,
    STATE(1374), 1,
      sym__file_dialog,
    STATE(1377), 1,
      sym_trace32_hll_variable,
    STATE(1378), 1,
      sym__unary_expression,
    STATE(1392), 1,
      sym__prefix_postfix_expression,
    STATE(1394), 1,
      sym__binary_expression,
    STATE(1550), 1,
      sym__address_binary_expression,
    STATE(2349), 1,
      sym__function_identifier,
    STATE(2359), 1,
      sym__hll_var_call_expression_function,
    ACTIONS(149), 2,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
    ACTIONS(185), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(187), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(189), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(203), 2,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
    STATE(1575), 2,
      sym__address_expression,
      sym__parenthesized_address_expression,
    ACTIONS(837), 3,
      sym_float,
      sym_time,
      sym_frequency,
    ACTIONS(839), 3,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
    STATE(1296), 13,
      sym__expression,
      sym__parenthesized_expression,
      sym__path_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_assignment_expression,
      sym__literal,
      sym_address,
      sym_bitmask,
      sym_string,
      sym_character,
      sym_symbol,
      sym__special_command_operator,
  [5503] = 42,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(76), 1,
      anon_sym_BSLASH,
    ACTIONS(78), 1,
      anon_sym_SQUOTE,
    ACTIONS(80), 1,
      anon_sym_DQUOTE,
    ACTIONS(82), 1,
      sym_access_class,
    ACTIONS(90), 1,
      aux_sym_symbol_token1,
    ACTIONS(92), 1,
      aux_sym_symbol_token2,
    ACTIONS(98), 1,
      sym_path,
    ACTIONS(120), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(140), 1,
      sym_identifier,
    ACTIONS(157), 1,
      anon_sym_LPAREN,
    ACTIONS(159), 1,
      anon_sym_LBRACE,
    ACTIONS(167), 1,
      anon_sym_STAR,
    ACTIONS(169), 1,
      anon_sym_AMP,
    ACTIONS(177), 1,
      sym__decimal_number_pre_hook,
    ACTIONS(436), 1,
      sym__blank,
    STATE(236), 1,
      sym_memory_space,
    STATE(935), 1,
      aux_sym_block_repeat1,
    STATE(970), 1,
      sym_macro,
    STATE(1049), 1,
      sym__hll_var_call_expression,
    STATE(1053), 1,
      aux_sym__path_expression_repeat2,
    STATE(1097), 1,
      sym_call_expression,
    STATE(1098), 1,
      sym_integer,
    STATE(1218), 1,
      aux_sym__path_expression_repeat1,
    STATE(1399), 1,
      sym__unary_expression,
    STATE(1400), 1,
      sym__prefix_postfix_expression,
    STATE(1404), 1,
      sym__binary_expression,
    STATE(1406), 1,
      sym__and_expression,
    STATE(1412), 1,
      sym_trace32_hll_variable,
    STATE(1417), 1,
      sym__file_dialog,
    STATE(1550), 1,
      sym__address_binary_expression,
    STATE(2257), 1,
      sym__function_identifier,
    STATE(2260), 1,
      sym__hll_var_call_expression_function,
    ACTIONS(88), 2,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
    ACTIONS(161), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(163), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(165), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(171), 2,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
    STATE(1575), 2,
      sym__address_expression,
      sym__parenthesized_address_expression,
    ACTIONS(841), 3,
      sym_float,
      sym_time,
      sym_frequency,
    ACTIONS(843), 3,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
    STATE(1306), 13,
      sym__expression,
      sym__parenthesized_expression,
      sym__path_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_assignment_expression,
      sym__literal,
      sym_address,
      sym_bitmask,
      sym_string,
      sym_character,
      sym_symbol,
      sym__special_command_operator,
  [5652] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(378), 1,
      anon_sym_AMP,
    ACTIONS(579), 1,
      aux_sym_symbol_token1,
    ACTIONS(581), 1,
      aux_sym_symbol_token2,
    ACTIONS(583), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(811), 1,
      sym_identifier,
    ACTIONS(813), 1,
      anon_sym_LPAREN,
    ACTIONS(817), 1,
      anon_sym_TILDE,
    ACTIONS(821), 1,
      anon_sym_STAR,
    ACTIONS(823), 1,
      anon_sym_BSLASH,
    ACTIONS(825), 1,
      anon_sym_sizeof,
    STATE(916), 1,
      sym_trace32_hll_variable,
    STATE(1587), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(819), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(815), 3,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BANG,
    ACTIONS(306), 4,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(575), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(577), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(915), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1292), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
    ACTIONS(302), 16,
      anon_sym_PIPE_PIPE,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      sym_comment,
      sym__blank_line,
  [5759] = 42,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(120), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(147), 1,
      anon_sym_AMP,
    ACTIONS(155), 1,
      sym__decimal_number_pre_hook,
    ACTIONS(179), 1,
      sym_identifier,
    ACTIONS(181), 1,
      anon_sym_LPAREN,
    ACTIONS(183), 1,
      anon_sym_LBRACE,
    ACTIONS(191), 1,
      anon_sym_STAR,
    ACTIONS(193), 1,
      anon_sym_BSLASH,
    ACTIONS(195), 1,
      anon_sym_SQUOTE,
    ACTIONS(197), 1,
      anon_sym_DQUOTE,
    ACTIONS(199), 1,
      sym_access_class,
    ACTIONS(205), 1,
      aux_sym_symbol_token1,
    ACTIONS(207), 1,
      aux_sym_symbol_token2,
    ACTIONS(211), 1,
      sym_path,
    ACTIONS(436), 1,
      sym__blank,
    STATE(228), 1,
      sym_memory_space,
    STATE(935), 1,
      aux_sym_block_repeat1,
    STATE(980), 1,
      sym_macro,
    STATE(1060), 1,
      sym_call_expression,
    STATE(1061), 1,
      sym__hll_var_call_expression,
    STATE(1080), 1,
      sym_integer,
    STATE(1100), 1,
      aux_sym__path_expression_repeat2,
    STATE(1172), 1,
      aux_sym__path_expression_repeat1,
    STATE(1371), 1,
      sym__and_expression,
    STATE(1374), 1,
      sym__file_dialog,
    STATE(1377), 1,
      sym_trace32_hll_variable,
    STATE(1378), 1,
      sym__unary_expression,
    STATE(1392), 1,
      sym__prefix_postfix_expression,
    STATE(1394), 1,
      sym__binary_expression,
    STATE(1550), 1,
      sym__address_binary_expression,
    STATE(2349), 1,
      sym__function_identifier,
    STATE(2359), 1,
      sym__hll_var_call_expression_function,
    ACTIONS(149), 2,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
    ACTIONS(185), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(187), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(189), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(203), 2,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
    STATE(1575), 2,
      sym__address_expression,
      sym__parenthesized_address_expression,
    ACTIONS(845), 3,
      sym_float,
      sym_time,
      sym_frequency,
    ACTIONS(847), 3,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
    STATE(1313), 13,
      sym__expression,
      sym__parenthesized_expression,
      sym__path_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_assignment_expression,
      sym__literal,
      sym_address,
      sym_bitmask,
      sym_string,
      sym_character,
      sym_symbol,
      sym__special_command_operator,
  [5908] = 42,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(120), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(147), 1,
      anon_sym_AMP,
    ACTIONS(155), 1,
      sym__decimal_number_pre_hook,
    ACTIONS(179), 1,
      sym_identifier,
    ACTIONS(181), 1,
      anon_sym_LPAREN,
    ACTIONS(183), 1,
      anon_sym_LBRACE,
    ACTIONS(191), 1,
      anon_sym_STAR,
    ACTIONS(193), 1,
      anon_sym_BSLASH,
    ACTIONS(195), 1,
      anon_sym_SQUOTE,
    ACTIONS(197), 1,
      anon_sym_DQUOTE,
    ACTIONS(199), 1,
      sym_access_class,
    ACTIONS(205), 1,
      aux_sym_symbol_token1,
    ACTIONS(207), 1,
      aux_sym_symbol_token2,
    ACTIONS(211), 1,
      sym_path,
    ACTIONS(436), 1,
      sym__blank,
    STATE(228), 1,
      sym_memory_space,
    STATE(935), 1,
      aux_sym_block_repeat1,
    STATE(980), 1,
      sym_macro,
    STATE(1060), 1,
      sym_call_expression,
    STATE(1061), 1,
      sym__hll_var_call_expression,
    STATE(1080), 1,
      sym_integer,
    STATE(1100), 1,
      aux_sym__path_expression_repeat2,
    STATE(1172), 1,
      aux_sym__path_expression_repeat1,
    STATE(1371), 1,
      sym__and_expression,
    STATE(1374), 1,
      sym__file_dialog,
    STATE(1377), 1,
      sym_trace32_hll_variable,
    STATE(1378), 1,
      sym__unary_expression,
    STATE(1392), 1,
      sym__prefix_postfix_expression,
    STATE(1394), 1,
      sym__binary_expression,
    STATE(1550), 1,
      sym__address_binary_expression,
    STATE(2349), 1,
      sym__function_identifier,
    STATE(2359), 1,
      sym__hll_var_call_expression_function,
    ACTIONS(149), 2,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
    ACTIONS(185), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(187), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(189), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(203), 2,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
    STATE(1575), 2,
      sym__address_expression,
      sym__parenthesized_address_expression,
    ACTIONS(849), 3,
      sym_float,
      sym_time,
      sym_frequency,
    ACTIONS(851), 3,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
    STATE(1357), 13,
      sym__expression,
      sym__parenthesized_expression,
      sym__path_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_assignment_expression,
      sym__literal,
      sym_address,
      sym_bitmask,
      sym_string,
      sym_character,
      sym_symbol,
      sym__special_command_operator,
  [6057] = 40,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(96), 1,
      sym__decimal_number_pre_hook,
    ACTIONS(100), 1,
      sym_identifier,
    ACTIONS(102), 1,
      anon_sym_LPAREN,
    ACTIONS(104), 1,
      anon_sym_LBRACE,
    ACTIONS(116), 1,
      anon_sym_STAR,
    ACTIONS(120), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(122), 1,
      anon_sym_BSLASH,
    ACTIONS(124), 1,
      anon_sym_SQUOTE,
    ACTIONS(126), 1,
      anon_sym_DQUOTE,
    ACTIONS(128), 1,
      sym_access_class,
    ACTIONS(134), 1,
      aux_sym_symbol_token1,
    ACTIONS(136), 1,
      aux_sym_symbol_token2,
    ACTIONS(695), 1,
      anon_sym_AMP,
    ACTIONS(857), 1,
      sym__blank,
    STATE(112), 1,
      aux_sym_block_repeat1,
    STATE(224), 1,
      sym_memory_space,
    STATE(328), 1,
      sym_macro,
    STATE(345), 1,
      sym__hll_var_call_expression,
    STATE(347), 1,
      sym_call_expression,
    STATE(350), 1,
      sym_integer,
    STATE(371), 1,
      aux_sym__path_expression_repeat1,
    STATE(450), 1,
      sym__unary_expression,
    STATE(451), 1,
      sym__prefix_postfix_expression,
    STATE(452), 1,
      sym__binary_expression,
    STATE(453), 1,
      sym__and_expression,
    STATE(457), 1,
      sym_trace32_hll_variable,
    STATE(459), 1,
      sym__file_dialog,
    STATE(1550), 1,
      sym__address_binary_expression,
    STATE(2354), 1,
      sym__function_identifier,
    STATE(2355), 1,
      sym__hll_var_call_expression_function,
    ACTIONS(84), 2,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
    ACTIONS(110), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(112), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(114), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(132), 2,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
    STATE(1575), 2,
      sym__address_expression,
      sym__parenthesized_address_expression,
    ACTIONS(853), 3,
      sym_float,
      sym_time,
      sym_frequency,
    ACTIONS(855), 4,
      sym_path,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
    STATE(366), 14,
      sym__expression,
      sym__parenthesized_expression,
      sym__path_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_assignment_expression,
      sym__literal,
      sym_address,
      sym_bitmask,
      sym_string,
      sym_character,
      sym_symbol,
      sym__special_command_operator,
      aux_sym__path_expression_repeat2,
  [6202] = 42,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(120), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(147), 1,
      anon_sym_AMP,
    ACTIONS(155), 1,
      sym__decimal_number_pre_hook,
    ACTIONS(179), 1,
      sym_identifier,
    ACTIONS(181), 1,
      anon_sym_LPAREN,
    ACTIONS(183), 1,
      anon_sym_LBRACE,
    ACTIONS(191), 1,
      anon_sym_STAR,
    ACTIONS(193), 1,
      anon_sym_BSLASH,
    ACTIONS(195), 1,
      anon_sym_SQUOTE,
    ACTIONS(197), 1,
      anon_sym_DQUOTE,
    ACTIONS(199), 1,
      sym_access_class,
    ACTIONS(205), 1,
      aux_sym_symbol_token1,
    ACTIONS(207), 1,
      aux_sym_symbol_token2,
    ACTIONS(211), 1,
      sym_path,
    ACTIONS(436), 1,
      sym__blank,
    STATE(228), 1,
      sym_memory_space,
    STATE(935), 1,
      aux_sym_block_repeat1,
    STATE(980), 1,
      sym_macro,
    STATE(1060), 1,
      sym_call_expression,
    STATE(1061), 1,
      sym__hll_var_call_expression,
    STATE(1080), 1,
      sym_integer,
    STATE(1100), 1,
      aux_sym__path_expression_repeat2,
    STATE(1172), 1,
      aux_sym__path_expression_repeat1,
    STATE(1371), 1,
      sym__and_expression,
    STATE(1374), 1,
      sym__file_dialog,
    STATE(1377), 1,
      sym_trace32_hll_variable,
    STATE(1378), 1,
      sym__unary_expression,
    STATE(1392), 1,
      sym__prefix_postfix_expression,
    STATE(1394), 1,
      sym__binary_expression,
    STATE(1550), 1,
      sym__address_binary_expression,
    STATE(2349), 1,
      sym__function_identifier,
    STATE(2359), 1,
      sym__hll_var_call_expression_function,
    ACTIONS(149), 2,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
    ACTIONS(185), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(187), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(189), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(203), 2,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
    STATE(1575), 2,
      sym__address_expression,
      sym__parenthesized_address_expression,
    ACTIONS(859), 3,
      sym_float,
      sym_time,
      sym_frequency,
    ACTIONS(861), 3,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
    STATE(1335), 13,
      sym__expression,
      sym__parenthesized_expression,
      sym__path_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_assignment_expression,
      sym__literal,
      sym_address,
      sym_bitmask,
      sym_string,
      sym_character,
      sym_symbol,
      sym__special_command_operator,
  [6351] = 42,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(120), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(147), 1,
      anon_sym_AMP,
    ACTIONS(155), 1,
      sym__decimal_number_pre_hook,
    ACTIONS(179), 1,
      sym_identifier,
    ACTIONS(181), 1,
      anon_sym_LPAREN,
    ACTIONS(183), 1,
      anon_sym_LBRACE,
    ACTIONS(191), 1,
      anon_sym_STAR,
    ACTIONS(193), 1,
      anon_sym_BSLASH,
    ACTIONS(195), 1,
      anon_sym_SQUOTE,
    ACTIONS(197), 1,
      anon_sym_DQUOTE,
    ACTIONS(199), 1,
      sym_access_class,
    ACTIONS(205), 1,
      aux_sym_symbol_token1,
    ACTIONS(207), 1,
      aux_sym_symbol_token2,
    ACTIONS(211), 1,
      sym_path,
    ACTIONS(436), 1,
      sym__blank,
    STATE(228), 1,
      sym_memory_space,
    STATE(935), 1,
      aux_sym_block_repeat1,
    STATE(980), 1,
      sym_macro,
    STATE(1060), 1,
      sym_call_expression,
    STATE(1061), 1,
      sym__hll_var_call_expression,
    STATE(1080), 1,
      sym_integer,
    STATE(1100), 1,
      aux_sym__path_expression_repeat2,
    STATE(1172), 1,
      aux_sym__path_expression_repeat1,
    STATE(1371), 1,
      sym__and_expression,
    STATE(1374), 1,
      sym__file_dialog,
    STATE(1377), 1,
      sym_trace32_hll_variable,
    STATE(1378), 1,
      sym__unary_expression,
    STATE(1392), 1,
      sym__prefix_postfix_expression,
    STATE(1394), 1,
      sym__binary_expression,
    STATE(1550), 1,
      sym__address_binary_expression,
    STATE(2349), 1,
      sym__function_identifier,
    STATE(2359), 1,
      sym__hll_var_call_expression_function,
    ACTIONS(149), 2,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
    ACTIONS(185), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(187), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(189), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(203), 2,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
    STATE(1575), 2,
      sym__address_expression,
      sym__parenthesized_address_expression,
    ACTIONS(863), 3,
      sym_float,
      sym_time,
      sym_frequency,
    ACTIONS(865), 3,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
    STATE(1336), 13,
      sym__expression,
      sym__parenthesized_expression,
      sym__path_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_assignment_expression,
      sym__literal,
      sym_address,
      sym_bitmask,
      sym_string,
      sym_character,
      sym_symbol,
      sym__special_command_operator,
  [6500] = 42,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(120), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(147), 1,
      anon_sym_AMP,
    ACTIONS(155), 1,
      sym__decimal_number_pre_hook,
    ACTIONS(179), 1,
      sym_identifier,
    ACTIONS(181), 1,
      anon_sym_LPAREN,
    ACTIONS(183), 1,
      anon_sym_LBRACE,
    ACTIONS(191), 1,
      anon_sym_STAR,
    ACTIONS(193), 1,
      anon_sym_BSLASH,
    ACTIONS(195), 1,
      anon_sym_SQUOTE,
    ACTIONS(197), 1,
      anon_sym_DQUOTE,
    ACTIONS(199), 1,
      sym_access_class,
    ACTIONS(205), 1,
      aux_sym_symbol_token1,
    ACTIONS(207), 1,
      aux_sym_symbol_token2,
    ACTIONS(211), 1,
      sym_path,
    ACTIONS(436), 1,
      sym__blank,
    STATE(228), 1,
      sym_memory_space,
    STATE(935), 1,
      aux_sym_block_repeat1,
    STATE(980), 1,
      sym_macro,
    STATE(1060), 1,
      sym_call_expression,
    STATE(1061), 1,
      sym__hll_var_call_expression,
    STATE(1080), 1,
      sym_integer,
    STATE(1100), 1,
      aux_sym__path_expression_repeat2,
    STATE(1172), 1,
      aux_sym__path_expression_repeat1,
    STATE(1371), 1,
      sym__and_expression,
    STATE(1374), 1,
      sym__file_dialog,
    STATE(1377), 1,
      sym_trace32_hll_variable,
    STATE(1378), 1,
      sym__unary_expression,
    STATE(1392), 1,
      sym__prefix_postfix_expression,
    STATE(1394), 1,
      sym__binary_expression,
    STATE(1550), 1,
      sym__address_binary_expression,
    STATE(2349), 1,
      sym__function_identifier,
    STATE(2359), 1,
      sym__hll_var_call_expression_function,
    ACTIONS(149), 2,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
    ACTIONS(185), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(187), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(189), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(203), 2,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
    STATE(1575), 2,
      sym__address_expression,
      sym__parenthesized_address_expression,
    ACTIONS(867), 3,
      sym_float,
      sym_time,
      sym_frequency,
    ACTIONS(869), 3,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
    STATE(1343), 13,
      sym__expression,
      sym__parenthesized_expression,
      sym__path_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_assignment_expression,
      sym__literal,
      sym_address,
      sym_bitmask,
      sym_string,
      sym_character,
      sym_symbol,
      sym__special_command_operator,
  [6649] = 42,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(120), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(147), 1,
      anon_sym_AMP,
    ACTIONS(155), 1,
      sym__decimal_number_pre_hook,
    ACTIONS(179), 1,
      sym_identifier,
    ACTIONS(181), 1,
      anon_sym_LPAREN,
    ACTIONS(183), 1,
      anon_sym_LBRACE,
    ACTIONS(191), 1,
      anon_sym_STAR,
    ACTIONS(193), 1,
      anon_sym_BSLASH,
    ACTIONS(195), 1,
      anon_sym_SQUOTE,
    ACTIONS(197), 1,
      anon_sym_DQUOTE,
    ACTIONS(199), 1,
      sym_access_class,
    ACTIONS(205), 1,
      aux_sym_symbol_token1,
    ACTIONS(207), 1,
      aux_sym_symbol_token2,
    ACTIONS(211), 1,
      sym_path,
    ACTIONS(436), 1,
      sym__blank,
    STATE(228), 1,
      sym_memory_space,
    STATE(935), 1,
      aux_sym_block_repeat1,
    STATE(980), 1,
      sym_macro,
    STATE(1060), 1,
      sym_call_expression,
    STATE(1061), 1,
      sym__hll_var_call_expression,
    STATE(1080), 1,
      sym_integer,
    STATE(1100), 1,
      aux_sym__path_expression_repeat2,
    STATE(1172), 1,
      aux_sym__path_expression_repeat1,
    STATE(1371), 1,
      sym__and_expression,
    STATE(1374), 1,
      sym__file_dialog,
    STATE(1377), 1,
      sym_trace32_hll_variable,
    STATE(1378), 1,
      sym__unary_expression,
    STATE(1392), 1,
      sym__prefix_postfix_expression,
    STATE(1394), 1,
      sym__binary_expression,
    STATE(1550), 1,
      sym__address_binary_expression,
    STATE(2349), 1,
      sym__function_identifier,
    STATE(2359), 1,
      sym__hll_var_call_expression_function,
    ACTIONS(149), 2,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
    ACTIONS(185), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(187), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(189), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(203), 2,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
    STATE(1575), 2,
      sym__address_expression,
      sym__parenthesized_address_expression,
    ACTIONS(871), 3,
      sym_float,
      sym_time,
      sym_frequency,
    ACTIONS(873), 3,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
    STATE(1346), 13,
      sym__expression,
      sym__parenthesized_expression,
      sym__path_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_assignment_expression,
      sym__literal,
      sym_address,
      sym_bitmask,
      sym_string,
      sym_character,
      sym_symbol,
      sym__special_command_operator,
  [6798] = 42,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(120), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(147), 1,
      anon_sym_AMP,
    ACTIONS(155), 1,
      sym__decimal_number_pre_hook,
    ACTIONS(179), 1,
      sym_identifier,
    ACTIONS(181), 1,
      anon_sym_LPAREN,
    ACTIONS(183), 1,
      anon_sym_LBRACE,
    ACTIONS(191), 1,
      anon_sym_STAR,
    ACTIONS(193), 1,
      anon_sym_BSLASH,
    ACTIONS(195), 1,
      anon_sym_SQUOTE,
    ACTIONS(197), 1,
      anon_sym_DQUOTE,
    ACTIONS(199), 1,
      sym_access_class,
    ACTIONS(205), 1,
      aux_sym_symbol_token1,
    ACTIONS(207), 1,
      aux_sym_symbol_token2,
    ACTIONS(211), 1,
      sym_path,
    ACTIONS(436), 1,
      sym__blank,
    STATE(228), 1,
      sym_memory_space,
    STATE(935), 1,
      aux_sym_block_repeat1,
    STATE(980), 1,
      sym_macro,
    STATE(1060), 1,
      sym_call_expression,
    STATE(1061), 1,
      sym__hll_var_call_expression,
    STATE(1080), 1,
      sym_integer,
    STATE(1100), 1,
      aux_sym__path_expression_repeat2,
    STATE(1172), 1,
      aux_sym__path_expression_repeat1,
    STATE(1371), 1,
      sym__and_expression,
    STATE(1374), 1,
      sym__file_dialog,
    STATE(1377), 1,
      sym_trace32_hll_variable,
    STATE(1378), 1,
      sym__unary_expression,
    STATE(1392), 1,
      sym__prefix_postfix_expression,
    STATE(1394), 1,
      sym__binary_expression,
    STATE(1550), 1,
      sym__address_binary_expression,
    STATE(2349), 1,
      sym__function_identifier,
    STATE(2359), 1,
      sym__hll_var_call_expression_function,
    ACTIONS(149), 2,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
    ACTIONS(185), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(187), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(189), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(203), 2,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
    STATE(1575), 2,
      sym__address_expression,
      sym__parenthesized_address_expression,
    ACTIONS(875), 3,
      sym_float,
      sym_time,
      sym_frequency,
    ACTIONS(877), 3,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
    STATE(1348), 13,
      sym__expression,
      sym__parenthesized_expression,
      sym__path_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_assignment_expression,
      sym__literal,
      sym_address,
      sym_bitmask,
      sym_string,
      sym_character,
      sym_symbol,
      sym__special_command_operator,
  [6947] = 40,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(96), 1,
      sym__decimal_number_pre_hook,
    ACTIONS(100), 1,
      sym_identifier,
    ACTIONS(102), 1,
      anon_sym_LPAREN,
    ACTIONS(104), 1,
      anon_sym_LBRACE,
    ACTIONS(116), 1,
      anon_sym_STAR,
    ACTIONS(120), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(122), 1,
      anon_sym_BSLASH,
    ACTIONS(124), 1,
      anon_sym_SQUOTE,
    ACTIONS(126), 1,
      anon_sym_DQUOTE,
    ACTIONS(128), 1,
      sym_access_class,
    ACTIONS(134), 1,
      aux_sym_symbol_token1,
    ACTIONS(136), 1,
      aux_sym_symbol_token2,
    ACTIONS(436), 1,
      sym__blank,
    ACTIONS(695), 1,
      anon_sym_AMP,
    STATE(224), 1,
      sym_memory_space,
    STATE(328), 1,
      sym_macro,
    STATE(345), 1,
      sym__hll_var_call_expression,
    STATE(347), 1,
      sym_call_expression,
    STATE(350), 1,
      sym_integer,
    STATE(371), 1,
      aux_sym__path_expression_repeat1,
    STATE(450), 1,
      sym__unary_expression,
    STATE(451), 1,
      sym__prefix_postfix_expression,
    STATE(452), 1,
      sym__binary_expression,
    STATE(453), 1,
      sym__and_expression,
    STATE(457), 1,
      sym_trace32_hll_variable,
    STATE(459), 1,
      sym__file_dialog,
    STATE(935), 1,
      aux_sym_block_repeat1,
    STATE(1550), 1,
      sym__address_binary_expression,
    STATE(2354), 1,
      sym__function_identifier,
    STATE(2355), 1,
      sym__hll_var_call_expression_function,
    ACTIONS(84), 2,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
    ACTIONS(110), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(112), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(114), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(132), 2,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
    STATE(1575), 2,
      sym__address_expression,
      sym__parenthesized_address_expression,
    ACTIONS(879), 3,
      sym_float,
      sym_time,
      sym_frequency,
    ACTIONS(881), 4,
      sym_path,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
    STATE(11), 14,
      sym__expression,
      sym__parenthesized_expression,
      sym__path_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_assignment_expression,
      sym__literal,
      sym_address,
      sym_bitmask,
      sym_string,
      sym_character,
      sym_symbol,
      sym__special_command_operator,
      aux_sym__path_expression_repeat2,
  [7092] = 40,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(96), 1,
      sym__decimal_number_pre_hook,
    ACTIONS(100), 1,
      sym_identifier,
    ACTIONS(102), 1,
      anon_sym_LPAREN,
    ACTIONS(104), 1,
      anon_sym_LBRACE,
    ACTIONS(116), 1,
      anon_sym_STAR,
    ACTIONS(120), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(122), 1,
      anon_sym_BSLASH,
    ACTIONS(124), 1,
      anon_sym_SQUOTE,
    ACTIONS(126), 1,
      anon_sym_DQUOTE,
    ACTIONS(128), 1,
      sym_access_class,
    ACTIONS(134), 1,
      aux_sym_symbol_token1,
    ACTIONS(136), 1,
      aux_sym_symbol_token2,
    ACTIONS(436), 1,
      sym__blank,
    ACTIONS(695), 1,
      anon_sym_AMP,
    STATE(224), 1,
      sym_memory_space,
    STATE(328), 1,
      sym_macro,
    STATE(345), 1,
      sym__hll_var_call_expression,
    STATE(347), 1,
      sym_call_expression,
    STATE(350), 1,
      sym_integer,
    STATE(371), 1,
      aux_sym__path_expression_repeat1,
    STATE(450), 1,
      sym__unary_expression,
    STATE(451), 1,
      sym__prefix_postfix_expression,
    STATE(452), 1,
      sym__binary_expression,
    STATE(453), 1,
      sym__and_expression,
    STATE(457), 1,
      sym_trace32_hll_variable,
    STATE(459), 1,
      sym__file_dialog,
    STATE(935), 1,
      aux_sym_block_repeat1,
    STATE(1550), 1,
      sym__address_binary_expression,
    STATE(2354), 1,
      sym__function_identifier,
    STATE(2355), 1,
      sym__hll_var_call_expression_function,
    ACTIONS(84), 2,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
    ACTIONS(110), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(112), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(114), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(132), 2,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
    STATE(1575), 2,
      sym__address_expression,
      sym__parenthesized_address_expression,
    ACTIONS(883), 3,
      sym_float,
      sym_time,
      sym_frequency,
    ACTIONS(885), 4,
      sym_path,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
    STATE(12), 14,
      sym__expression,
      sym__parenthesized_expression,
      sym__path_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_assignment_expression,
      sym__literal,
      sym_address,
      sym_bitmask,
      sym_string,
      sym_character,
      sym_symbol,
      sym__special_command_operator,
      aux_sym__path_expression_repeat2,
  [7237] = 42,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(76), 1,
      anon_sym_BSLASH,
    ACTIONS(78), 1,
      anon_sym_SQUOTE,
    ACTIONS(80), 1,
      anon_sym_DQUOTE,
    ACTIONS(82), 1,
      sym_access_class,
    ACTIONS(90), 1,
      aux_sym_symbol_token1,
    ACTIONS(92), 1,
      aux_sym_symbol_token2,
    ACTIONS(98), 1,
      sym_path,
    ACTIONS(120), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(140), 1,
      sym_identifier,
    ACTIONS(157), 1,
      anon_sym_LPAREN,
    ACTIONS(159), 1,
      anon_sym_LBRACE,
    ACTIONS(167), 1,
      anon_sym_STAR,
    ACTIONS(169), 1,
      anon_sym_AMP,
    ACTIONS(177), 1,
      sym__decimal_number_pre_hook,
    ACTIONS(436), 1,
      sym__blank,
    STATE(236), 1,
      sym_memory_space,
    STATE(935), 1,
      aux_sym_block_repeat1,
    STATE(975), 1,
      sym_macro,
    STATE(1046), 1,
      sym_call_expression,
    STATE(1049), 1,
      sym__hll_var_call_expression,
    STATE(1052), 1,
      sym_integer,
    STATE(1053), 1,
      aux_sym__path_expression_repeat2,
    STATE(1218), 1,
      aux_sym__path_expression_repeat1,
    STATE(1399), 1,
      sym__unary_expression,
    STATE(1400), 1,
      sym__prefix_postfix_expression,
    STATE(1404), 1,
      sym__binary_expression,
    STATE(1406), 1,
      sym__and_expression,
    STATE(1412), 1,
      sym_trace32_hll_variable,
    STATE(1417), 1,
      sym__file_dialog,
    STATE(1550), 1,
      sym__address_binary_expression,
    STATE(2257), 1,
      sym__function_identifier,
    STATE(2260), 1,
      sym__hll_var_call_expression_function,
    ACTIONS(60), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(62), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(88), 2,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
    ACTIONS(171), 2,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
    ACTIONS(222), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1575), 2,
      sym__address_expression,
      sym__parenthesized_address_expression,
    ACTIONS(887), 3,
      sym_float,
      sym_time,
      sym_frequency,
    ACTIONS(889), 3,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
    STATE(1416), 13,
      sym__expression,
      sym__parenthesized_expression,
      sym__path_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_assignment_expression,
      sym__literal,
      sym_address,
      sym_bitmask,
      sym_string,
      sym_character,
      sym_symbol,
      sym__special_command_operator,
  [7386] = 41,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(76), 1,
      anon_sym_BSLASH,
    ACTIONS(78), 1,
      anon_sym_SQUOTE,
    ACTIONS(80), 1,
      anon_sym_DQUOTE,
    ACTIONS(82), 1,
      sym_access_class,
    ACTIONS(90), 1,
      aux_sym_symbol_token1,
    ACTIONS(92), 1,
      aux_sym_symbol_token2,
    ACTIONS(98), 1,
      sym_path,
    ACTIONS(120), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(140), 1,
      sym_identifier,
    ACTIONS(157), 1,
      anon_sym_LPAREN,
    ACTIONS(159), 1,
      anon_sym_LBRACE,
    ACTIONS(167), 1,
      anon_sym_STAR,
    ACTIONS(169), 1,
      anon_sym_AMP,
    ACTIONS(177), 1,
      sym__decimal_number_pre_hook,
    ACTIONS(891), 1,
      anon_sym_RPAREN,
    STATE(236), 1,
      sym_memory_space,
    STATE(970), 1,
      sym_macro,
    STATE(1049), 1,
      sym__hll_var_call_expression,
    STATE(1053), 1,
      aux_sym__path_expression_repeat2,
    STATE(1097), 1,
      sym_call_expression,
    STATE(1098), 1,
      sym_integer,
    STATE(1218), 1,
      aux_sym__path_expression_repeat1,
    STATE(1399), 1,
      sym__unary_expression,
    STATE(1400), 1,
      sym__prefix_postfix_expression,
    STATE(1404), 1,
      sym__binary_expression,
    STATE(1406), 1,
      sym__and_expression,
    STATE(1412), 1,
      sym_trace32_hll_variable,
    STATE(1417), 1,
      sym__file_dialog,
    STATE(1550), 1,
      sym__address_binary_expression,
    STATE(2257), 1,
      sym__function_identifier,
    STATE(2260), 1,
      sym__hll_var_call_expression_function,
    ACTIONS(88), 2,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
    ACTIONS(161), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(163), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(165), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(171), 2,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
    STATE(1575), 2,
      sym__address_expression,
      sym__parenthesized_address_expression,
    ACTIONS(893), 3,
      sym_float,
      sym_time,
      sym_frequency,
    ACTIONS(895), 3,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
    STATE(1177), 13,
      sym__expression,
      sym__parenthesized_expression,
      sym__path_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_assignment_expression,
      sym__literal,
      sym_address,
      sym_bitmask,
      sym_string,
      sym_character,
      sym_symbol,
      sym__special_command_operator,
  [7532] = 41,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(76), 1,
      anon_sym_BSLASH,
    ACTIONS(78), 1,
      anon_sym_SQUOTE,
    ACTIONS(80), 1,
      anon_sym_DQUOTE,
    ACTIONS(82), 1,
      sym_access_class,
    ACTIONS(90), 1,
      aux_sym_symbol_token1,
    ACTIONS(92), 1,
      aux_sym_symbol_token2,
    ACTIONS(98), 1,
      sym_path,
    ACTIONS(120), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(140), 1,
      sym_identifier,
    ACTIONS(157), 1,
      anon_sym_LPAREN,
    ACTIONS(159), 1,
      anon_sym_LBRACE,
    ACTIONS(167), 1,
      anon_sym_STAR,
    ACTIONS(169), 1,
      anon_sym_AMP,
    ACTIONS(177), 1,
      sym__decimal_number_pre_hook,
    ACTIONS(897), 1,
      anon_sym_RPAREN,
    STATE(236), 1,
      sym_memory_space,
    STATE(970), 1,
      sym_macro,
    STATE(1049), 1,
      sym__hll_var_call_expression,
    STATE(1053), 1,
      aux_sym__path_expression_repeat2,
    STATE(1097), 1,
      sym_call_expression,
    STATE(1098), 1,
      sym_integer,
    STATE(1218), 1,
      aux_sym__path_expression_repeat1,
    STATE(1399), 1,
      sym__unary_expression,
    STATE(1400), 1,
      sym__prefix_postfix_expression,
    STATE(1404), 1,
      sym__binary_expression,
    STATE(1406), 1,
      sym__and_expression,
    STATE(1412), 1,
      sym_trace32_hll_variable,
    STATE(1417), 1,
      sym__file_dialog,
    STATE(1550), 1,
      sym__address_binary_expression,
    STATE(2257), 1,
      sym__function_identifier,
    STATE(2260), 1,
      sym__hll_var_call_expression_function,
    ACTIONS(88), 2,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
    ACTIONS(161), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(163), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(165), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(171), 2,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
    STATE(1575), 2,
      sym__address_expression,
      sym__parenthesized_address_expression,
    ACTIONS(899), 3,
      sym_float,
      sym_time,
      sym_frequency,
    ACTIONS(901), 3,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
    STATE(1261), 13,
      sym__expression,
      sym__parenthesized_expression,
      sym__path_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_assignment_expression,
      sym__literal,
      sym_address,
      sym_bitmask,
      sym_string,
      sym_character,
      sym_symbol,
      sym__special_command_operator,
  [7678] = 41,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(76), 1,
      anon_sym_BSLASH,
    ACTIONS(78), 1,
      anon_sym_SQUOTE,
    ACTIONS(80), 1,
      anon_sym_DQUOTE,
    ACTIONS(82), 1,
      sym_access_class,
    ACTIONS(90), 1,
      aux_sym_symbol_token1,
    ACTIONS(92), 1,
      aux_sym_symbol_token2,
    ACTIONS(98), 1,
      sym_path,
    ACTIONS(120), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(140), 1,
      sym_identifier,
    ACTIONS(157), 1,
      anon_sym_LPAREN,
    ACTIONS(159), 1,
      anon_sym_LBRACE,
    ACTIONS(167), 1,
      anon_sym_STAR,
    ACTIONS(169), 1,
      anon_sym_AMP,
    ACTIONS(177), 1,
      sym__decimal_number_pre_hook,
    ACTIONS(903), 1,
      anon_sym_RPAREN,
    STATE(236), 1,
      sym_memory_space,
    STATE(970), 1,
      sym_macro,
    STATE(1049), 1,
      sym__hll_var_call_expression,
    STATE(1053), 1,
      aux_sym__path_expression_repeat2,
    STATE(1097), 1,
      sym_call_expression,
    STATE(1098), 1,
      sym_integer,
    STATE(1218), 1,
      aux_sym__path_expression_repeat1,
    STATE(1399), 1,
      sym__unary_expression,
    STATE(1400), 1,
      sym__prefix_postfix_expression,
    STATE(1404), 1,
      sym__binary_expression,
    STATE(1406), 1,
      sym__and_expression,
    STATE(1412), 1,
      sym_trace32_hll_variable,
    STATE(1417), 1,
      sym__file_dialog,
    STATE(1550), 1,
      sym__address_binary_expression,
    STATE(2257), 1,
      sym__function_identifier,
    STATE(2260), 1,
      sym__hll_var_call_expression_function,
    ACTIONS(88), 2,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
    ACTIONS(161), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(163), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(165), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(171), 2,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
    STATE(1575), 2,
      sym__address_expression,
      sym__parenthesized_address_expression,
    ACTIONS(905), 3,
      sym_float,
      sym_time,
      sym_frequency,
    ACTIONS(907), 3,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
    STATE(1152), 13,
      sym__expression,
      sym__parenthesized_expression,
      sym__path_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_assignment_expression,
      sym__literal,
      sym_address,
      sym_bitmask,
      sym_string,
      sym_character,
      sym_symbol,
      sym__special_command_operator,
  [7824] = 40,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(76), 1,
      anon_sym_BSLASH,
    ACTIONS(78), 1,
      anon_sym_SQUOTE,
    ACTIONS(80), 1,
      anon_sym_DQUOTE,
    ACTIONS(82), 1,
      sym_access_class,
    ACTIONS(90), 1,
      aux_sym_symbol_token1,
    ACTIONS(92), 1,
      aux_sym_symbol_token2,
    ACTIONS(98), 1,
      sym_path,
    ACTIONS(120), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(140), 1,
      sym_identifier,
    ACTIONS(157), 1,
      anon_sym_LPAREN,
    ACTIONS(159), 1,
      anon_sym_LBRACE,
    ACTIONS(167), 1,
      anon_sym_STAR,
    ACTIONS(169), 1,
      anon_sym_AMP,
    ACTIONS(177), 1,
      sym__decimal_number_pre_hook,
    STATE(236), 1,
      sym_memory_space,
    STATE(975), 1,
      sym_macro,
    STATE(1046), 1,
      sym_call_expression,
    STATE(1049), 1,
      sym__hll_var_call_expression,
    STATE(1052), 1,
      sym_integer,
    STATE(1053), 1,
      aux_sym__path_expression_repeat2,
    STATE(1218), 1,
      aux_sym__path_expression_repeat1,
    STATE(1399), 1,
      sym__unary_expression,
    STATE(1400), 1,
      sym__prefix_postfix_expression,
    STATE(1404), 1,
      sym__binary_expression,
    STATE(1406), 1,
      sym__and_expression,
    STATE(1412), 1,
      sym_trace32_hll_variable,
    STATE(1417), 1,
      sym__file_dialog,
    STATE(1550), 1,
      sym__address_binary_expression,
    STATE(2257), 1,
      sym__function_identifier,
    STATE(2260), 1,
      sym__hll_var_call_expression_function,
    ACTIONS(60), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(62), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(88), 2,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
    ACTIONS(171), 2,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
    ACTIONS(222), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1575), 2,
      sym__address_expression,
      sym__parenthesized_address_expression,
    ACTIONS(909), 3,
      sym_float,
      sym_time,
      sym_frequency,
    ACTIONS(911), 3,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
    STATE(1401), 13,
      sym__expression,
      sym__parenthesized_expression,
      sym__path_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_assignment_expression,
      sym__literal,
      sym_address,
      sym_bitmask,
      sym_string,
      sym_character,
      sym_symbol,
      sym__special_command_operator,
  [7967] = 40,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(76), 1,
      anon_sym_BSLASH,
    ACTIONS(78), 1,
      anon_sym_SQUOTE,
    ACTIONS(80), 1,
      anon_sym_DQUOTE,
    ACTIONS(82), 1,
      sym_access_class,
    ACTIONS(90), 1,
      aux_sym_symbol_token1,
    ACTIONS(92), 1,
      aux_sym_symbol_token2,
    ACTIONS(98), 1,
      sym_path,
    ACTIONS(120), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(140), 1,
      sym_identifier,
    ACTIONS(157), 1,
      anon_sym_LPAREN,
    ACTIONS(159), 1,
      anon_sym_LBRACE,
    ACTIONS(167), 1,
      anon_sym_STAR,
    ACTIONS(169), 1,
      anon_sym_AMP,
    ACTIONS(177), 1,
      sym__decimal_number_pre_hook,
    STATE(236), 1,
      sym_memory_space,
    STATE(970), 1,
      sym_macro,
    STATE(1049), 1,
      sym__hll_var_call_expression,
    STATE(1053), 1,
      aux_sym__path_expression_repeat2,
    STATE(1097), 1,
      sym_call_expression,
    STATE(1098), 1,
      sym_integer,
    STATE(1218), 1,
      aux_sym__path_expression_repeat1,
    STATE(1399), 1,
      sym__unary_expression,
    STATE(1400), 1,
      sym__prefix_postfix_expression,
    STATE(1404), 1,
      sym__binary_expression,
    STATE(1406), 1,
      sym__and_expression,
    STATE(1412), 1,
      sym_trace32_hll_variable,
    STATE(1417), 1,
      sym__file_dialog,
    STATE(1550), 1,
      sym__address_binary_expression,
    STATE(2257), 1,
      sym__function_identifier,
    STATE(2260), 1,
      sym__hll_var_call_expression_function,
    ACTIONS(88), 2,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
    ACTIONS(161), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(163), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(165), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(171), 2,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
    STATE(1575), 2,
      sym__address_expression,
      sym__parenthesized_address_expression,
    ACTIONS(913), 3,
      sym_float,
      sym_time,
      sym_frequency,
    ACTIONS(915), 3,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
    STATE(1202), 13,
      sym__expression,
      sym__parenthesized_expression,
      sym__path_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_assignment_expression,
      sym__literal,
      sym_address,
      sym_bitmask,
      sym_string,
      sym_character,
      sym_symbol,
      sym__special_command_operator,
  [8110] = 40,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(76), 1,
      anon_sym_BSLASH,
    ACTIONS(78), 1,
      anon_sym_SQUOTE,
    ACTIONS(80), 1,
      anon_sym_DQUOTE,
    ACTIONS(82), 1,
      sym_access_class,
    ACTIONS(90), 1,
      aux_sym_symbol_token1,
    ACTIONS(92), 1,
      aux_sym_symbol_token2,
    ACTIONS(98), 1,
      sym_path,
    ACTIONS(120), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(140), 1,
      sym_identifier,
    ACTIONS(157), 1,
      anon_sym_LPAREN,
    ACTIONS(159), 1,
      anon_sym_LBRACE,
    ACTIONS(167), 1,
      anon_sym_STAR,
    ACTIONS(169), 1,
      anon_sym_AMP,
    ACTIONS(177), 1,
      sym__decimal_number_pre_hook,
    STATE(236), 1,
      sym_memory_space,
    STATE(970), 1,
      sym_macro,
    STATE(1049), 1,
      sym__hll_var_call_expression,
    STATE(1053), 1,
      aux_sym__path_expression_repeat2,
    STATE(1097), 1,
      sym_call_expression,
    STATE(1098), 1,
      sym_integer,
    STATE(1218), 1,
      aux_sym__path_expression_repeat1,
    STATE(1399), 1,
      sym__unary_expression,
    STATE(1400), 1,
      sym__prefix_postfix_expression,
    STATE(1404), 1,
      sym__binary_expression,
    STATE(1406), 1,
      sym__and_expression,
    STATE(1412), 1,
      sym_trace32_hll_variable,
    STATE(1417), 1,
      sym__file_dialog,
    STATE(1550), 1,
      sym__address_binary_expression,
    STATE(2257), 1,
      sym__function_identifier,
    STATE(2260), 1,
      sym__hll_var_call_expression_function,
    ACTIONS(88), 2,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
    ACTIONS(161), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(163), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(165), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(171), 2,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
    STATE(1575), 2,
      sym__address_expression,
      sym__parenthesized_address_expression,
    ACTIONS(917), 3,
      sym_float,
      sym_time,
      sym_frequency,
    ACTIONS(919), 3,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
    STATE(1214), 13,
      sym__expression,
      sym__parenthesized_expression,
      sym__path_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_assignment_expression,
      sym__literal,
      sym_address,
      sym_bitmask,
      sym_string,
      sym_character,
      sym_symbol,
      sym__special_command_operator,
  [8253] = 40,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(76), 1,
      anon_sym_BSLASH,
    ACTIONS(78), 1,
      anon_sym_SQUOTE,
    ACTIONS(80), 1,
      anon_sym_DQUOTE,
    ACTIONS(82), 1,
      sym_access_class,
    ACTIONS(90), 1,
      aux_sym_symbol_token1,
    ACTIONS(92), 1,
      aux_sym_symbol_token2,
    ACTIONS(98), 1,
      sym_path,
    ACTIONS(120), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(140), 1,
      sym_identifier,
    ACTIONS(157), 1,
      anon_sym_LPAREN,
    ACTIONS(159), 1,
      anon_sym_LBRACE,
    ACTIONS(167), 1,
      anon_sym_STAR,
    ACTIONS(169), 1,
      anon_sym_AMP,
    ACTIONS(177), 1,
      sym__decimal_number_pre_hook,
    STATE(236), 1,
      sym_memory_space,
    STATE(970), 1,
      sym_macro,
    STATE(1049), 1,
      sym__hll_var_call_expression,
    STATE(1053), 1,
      aux_sym__path_expression_repeat2,
    STATE(1097), 1,
      sym_call_expression,
    STATE(1098), 1,
      sym_integer,
    STATE(1218), 1,
      aux_sym__path_expression_repeat1,
    STATE(1399), 1,
      sym__unary_expression,
    STATE(1400), 1,
      sym__prefix_postfix_expression,
    STATE(1404), 1,
      sym__binary_expression,
    STATE(1406), 1,
      sym__and_expression,
    STATE(1412), 1,
      sym_trace32_hll_variable,
    STATE(1417), 1,
      sym__file_dialog,
    STATE(1550), 1,
      sym__address_binary_expression,
    STATE(2257), 1,
      sym__function_identifier,
    STATE(2260), 1,
      sym__hll_var_call_expression_function,
    ACTIONS(88), 2,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
    ACTIONS(161), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(163), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(165), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(171), 2,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
    STATE(1575), 2,
      sym__address_expression,
      sym__parenthesized_address_expression,
    ACTIONS(921), 3,
      sym_float,
      sym_time,
      sym_frequency,
    ACTIONS(923), 3,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
    STATE(1216), 13,
      sym__expression,
      sym__parenthesized_expression,
      sym__path_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_assignment_expression,
      sym__literal,
      sym_address,
      sym_bitmask,
      sym_string,
      sym_character,
      sym_symbol,
      sym__special_command_operator,
  [8396] = 40,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(76), 1,
      anon_sym_BSLASH,
    ACTIONS(78), 1,
      anon_sym_SQUOTE,
    ACTIONS(80), 1,
      anon_sym_DQUOTE,
    ACTIONS(82), 1,
      sym_access_class,
    ACTIONS(90), 1,
      aux_sym_symbol_token1,
    ACTIONS(92), 1,
      aux_sym_symbol_token2,
    ACTIONS(98), 1,
      sym_path,
    ACTIONS(120), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(140), 1,
      sym_identifier,
    ACTIONS(157), 1,
      anon_sym_LPAREN,
    ACTIONS(159), 1,
      anon_sym_LBRACE,
    ACTIONS(167), 1,
      anon_sym_STAR,
    ACTIONS(169), 1,
      anon_sym_AMP,
    ACTIONS(177), 1,
      sym__decimal_number_pre_hook,
    STATE(236), 1,
      sym_memory_space,
    STATE(970), 1,
      sym_macro,
    STATE(1049), 1,
      sym__hll_var_call_expression,
    STATE(1053), 1,
      aux_sym__path_expression_repeat2,
    STATE(1097), 1,
      sym_call_expression,
    STATE(1098), 1,
      sym_integer,
    STATE(1218), 1,
      aux_sym__path_expression_repeat1,
    STATE(1399), 1,
      sym__unary_expression,
    STATE(1400), 1,
      sym__prefix_postfix_expression,
    STATE(1404), 1,
      sym__binary_expression,
    STATE(1406), 1,
      sym__and_expression,
    STATE(1412), 1,
      sym_trace32_hll_variable,
    STATE(1417), 1,
      sym__file_dialog,
    STATE(1550), 1,
      sym__address_binary_expression,
    STATE(2257), 1,
      sym__function_identifier,
    STATE(2260), 1,
      sym__hll_var_call_expression_function,
    ACTIONS(88), 2,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
    ACTIONS(161), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(163), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(165), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(171), 2,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
    STATE(1575), 2,
      sym__address_expression,
      sym__parenthesized_address_expression,
    ACTIONS(925), 3,
      sym_float,
      sym_time,
      sym_frequency,
    ACTIONS(927), 3,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
    STATE(1200), 13,
      sym__expression,
      sym__parenthesized_expression,
      sym__path_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_assignment_expression,
      sym__literal,
      sym_address,
      sym_bitmask,
      sym_string,
      sym_character,
      sym_symbol,
      sym__special_command_operator,
  [8539] = 40,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(76), 1,
      anon_sym_BSLASH,
    ACTIONS(78), 1,
      anon_sym_SQUOTE,
    ACTIONS(80), 1,
      anon_sym_DQUOTE,
    ACTIONS(82), 1,
      sym_access_class,
    ACTIONS(90), 1,
      aux_sym_symbol_token1,
    ACTIONS(92), 1,
      aux_sym_symbol_token2,
    ACTIONS(98), 1,
      sym_path,
    ACTIONS(120), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(140), 1,
      sym_identifier,
    ACTIONS(157), 1,
      anon_sym_LPAREN,
    ACTIONS(159), 1,
      anon_sym_LBRACE,
    ACTIONS(167), 1,
      anon_sym_STAR,
    ACTIONS(169), 1,
      anon_sym_AMP,
    ACTIONS(177), 1,
      sym__decimal_number_pre_hook,
    STATE(236), 1,
      sym_memory_space,
    STATE(975), 1,
      sym_macro,
    STATE(1046), 1,
      sym_call_expression,
    STATE(1049), 1,
      sym__hll_var_call_expression,
    STATE(1052), 1,
      sym_integer,
    STATE(1053), 1,
      aux_sym__path_expression_repeat2,
    STATE(1218), 1,
      aux_sym__path_expression_repeat1,
    STATE(1399), 1,
      sym__unary_expression,
    STATE(1400), 1,
      sym__prefix_postfix_expression,
    STATE(1404), 1,
      sym__binary_expression,
    STATE(1406), 1,
      sym__and_expression,
    STATE(1412), 1,
      sym_trace32_hll_variable,
    STATE(1417), 1,
      sym__file_dialog,
    STATE(1550), 1,
      sym__address_binary_expression,
    STATE(2257), 1,
      sym__function_identifier,
    STATE(2260), 1,
      sym__hll_var_call_expression_function,
    ACTIONS(60), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(62), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(88), 2,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
    ACTIONS(171), 2,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
    ACTIONS(222), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1646), 2,
      sym__address_expression,
      sym__parenthesized_address_expression,
    ACTIONS(218), 3,
      sym_float,
      sym_time,
      sym_frequency,
    ACTIONS(220), 3,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
    STATE(1454), 13,
      sym__expression,
      sym__parenthesized_expression,
      sym__path_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_assignment_expression,
      sym__literal,
      sym_address,
      sym_bitmask,
      sym_string,
      sym_character,
      sym_symbol,
      sym__special_command_operator,
  [8682] = 40,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(76), 1,
      anon_sym_BSLASH,
    ACTIONS(78), 1,
      anon_sym_SQUOTE,
    ACTIONS(80), 1,
      anon_sym_DQUOTE,
    ACTIONS(82), 1,
      sym_access_class,
    ACTIONS(90), 1,
      aux_sym_symbol_token1,
    ACTIONS(92), 1,
      aux_sym_symbol_token2,
    ACTIONS(98), 1,
      sym_path,
    ACTIONS(120), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(140), 1,
      sym_identifier,
    ACTIONS(157), 1,
      anon_sym_LPAREN,
    ACTIONS(159), 1,
      anon_sym_LBRACE,
    ACTIONS(167), 1,
      anon_sym_STAR,
    ACTIONS(169), 1,
      anon_sym_AMP,
    ACTIONS(177), 1,
      sym__decimal_number_pre_hook,
    STATE(236), 1,
      sym_memory_space,
    STATE(975), 1,
      sym_macro,
    STATE(1046), 1,
      sym_call_expression,
    STATE(1049), 1,
      sym__hll_var_call_expression,
    STATE(1052), 1,
      sym_integer,
    STATE(1053), 1,
      aux_sym__path_expression_repeat2,
    STATE(1218), 1,
      aux_sym__path_expression_repeat1,
    STATE(1399), 1,
      sym__unary_expression,
    STATE(1400), 1,
      sym__prefix_postfix_expression,
    STATE(1404), 1,
      sym__binary_expression,
    STATE(1406), 1,
      sym__and_expression,
    STATE(1412), 1,
      sym_trace32_hll_variable,
    STATE(1417), 1,
      sym__file_dialog,
    STATE(1550), 1,
      sym__address_binary_expression,
    STATE(2257), 1,
      sym__function_identifier,
    STATE(2260), 1,
      sym__hll_var_call_expression_function,
    ACTIONS(60), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(62), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(88), 2,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
    ACTIONS(171), 2,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
    ACTIONS(222), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1576), 2,
      sym__address_expression,
      sym__parenthesized_address_expression,
    ACTIONS(218), 3,
      sym_float,
      sym_time,
      sym_frequency,
    ACTIONS(220), 3,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
    STATE(1454), 13,
      sym__expression,
      sym__parenthesized_expression,
      sym__path_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_assignment_expression,
      sym__literal,
      sym_address,
      sym_bitmask,
      sym_string,
      sym_character,
      sym_symbol,
      sym__special_command_operator,
  [8825] = 40,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(929), 1,
      sym_identifier,
    ACTIONS(932), 1,
      anon_sym_LPAREN,
    ACTIONS(935), 1,
      anon_sym_LBRACE,
    ACTIONS(947), 1,
      anon_sym_STAR,
    ACTIONS(950), 1,
      anon_sym_AMP,
    ACTIONS(953), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(956), 1,
      anon_sym_BSLASH,
    ACTIONS(959), 1,
      anon_sym_SQUOTE,
    ACTIONS(962), 1,
      anon_sym_DQUOTE,
    ACTIONS(965), 1,
      sym_access_class,
    ACTIONS(977), 1,
      aux_sym_symbol_token1,
    ACTIONS(980), 1,
      aux_sym_symbol_token2,
    ACTIONS(986), 1,
      sym__decimal_number_pre_hook,
    ACTIONS(989), 1,
      sym_path,
    STATE(236), 1,
      sym_memory_space,
    STATE(975), 1,
      sym_macro,
    STATE(1046), 1,
      sym_call_expression,
    STATE(1049), 1,
      sym__hll_var_call_expression,
    STATE(1052), 1,
      sym_integer,
    STATE(1053), 1,
      aux_sym__path_expression_repeat2,
    STATE(1218), 1,
      aux_sym__path_expression_repeat1,
    STATE(1399), 1,
      sym__unary_expression,
    STATE(1400), 1,
      sym__prefix_postfix_expression,
    STATE(1404), 1,
      sym__binary_expression,
    STATE(1406), 1,
      sym__and_expression,
    STATE(1412), 1,
      sym_trace32_hll_variable,
    STATE(1417), 1,
      sym__file_dialog,
    STATE(1550), 1,
      sym__address_binary_expression,
    STATE(2257), 1,
      sym__function_identifier,
    STATE(2260), 1,
      sym__hll_var_call_expression_function,
    ACTIONS(938), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(941), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(944), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(968), 2,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
    ACTIONS(974), 2,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
    STATE(1579), 2,
      sym__address_expression,
      sym__parenthesized_address_expression,
    ACTIONS(971), 3,
      sym_float,
      sym_time,
      sym_frequency,
    ACTIONS(983), 3,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
    STATE(1454), 13,
      sym__expression,
      sym__parenthesized_expression,
      sym__path_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_assignment_expression,
      sym__literal,
      sym_address,
      sym_bitmask,
      sym_string,
      sym_character,
      sym_symbol,
      sym__special_command_operator,
  [8968] = 40,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(992), 1,
      sym_identifier,
    ACTIONS(995), 1,
      anon_sym_LPAREN,
    ACTIONS(998), 1,
      anon_sym_LBRACE,
    ACTIONS(1010), 1,
      anon_sym_STAR,
    ACTIONS(1013), 1,
      anon_sym_AMP,
    ACTIONS(1016), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(1019), 1,
      anon_sym_BSLASH,
    ACTIONS(1022), 1,
      anon_sym_SQUOTE,
    ACTIONS(1025), 1,
      anon_sym_DQUOTE,
    ACTIONS(1028), 1,
      sym_access_class,
    ACTIONS(1040), 1,
      aux_sym_symbol_token1,
    ACTIONS(1043), 1,
      aux_sym_symbol_token2,
    ACTIONS(1049), 1,
      sym__decimal_number_pre_hook,
    ACTIONS(1052), 1,
      sym_path,
    STATE(236), 1,
      sym_memory_space,
    STATE(975), 1,
      sym_macro,
    STATE(1046), 1,
      sym_call_expression,
    STATE(1049), 1,
      sym__hll_var_call_expression,
    STATE(1052), 1,
      sym_integer,
    STATE(1053), 1,
      aux_sym__path_expression_repeat2,
    STATE(1218), 1,
      aux_sym__path_expression_repeat1,
    STATE(1399), 1,
      sym__unary_expression,
    STATE(1400), 1,
      sym__prefix_postfix_expression,
    STATE(1404), 1,
      sym__binary_expression,
    STATE(1406), 1,
      sym__and_expression,
    STATE(1412), 1,
      sym_trace32_hll_variable,
    STATE(1417), 1,
      sym__file_dialog,
    STATE(1550), 1,
      sym__address_binary_expression,
    STATE(2257), 1,
      sym__function_identifier,
    STATE(2260), 1,
      sym__hll_var_call_expression_function,
    ACTIONS(1001), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1004), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(1007), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1031), 2,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
    ACTIONS(1037), 2,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
    STATE(1591), 2,
      sym__address_expression,
      sym__parenthesized_address_expression,
    ACTIONS(1034), 3,
      sym_float,
      sym_time,
      sym_frequency,
    ACTIONS(1046), 3,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
    STATE(1454), 13,
      sym__expression,
      sym__parenthesized_expression,
      sym__path_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_assignment_expression,
      sym__literal,
      sym_address,
      sym_bitmask,
      sym_string,
      sym_character,
      sym_symbol,
      sym__special_command_operator,
  [9111] = 40,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(76), 1,
      anon_sym_BSLASH,
    ACTIONS(78), 1,
      anon_sym_SQUOTE,
    ACTIONS(80), 1,
      anon_sym_DQUOTE,
    ACTIONS(82), 1,
      sym_access_class,
    ACTIONS(90), 1,
      aux_sym_symbol_token1,
    ACTIONS(92), 1,
      aux_sym_symbol_token2,
    ACTIONS(98), 1,
      sym_path,
    ACTIONS(120), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(140), 1,
      sym_identifier,
    ACTIONS(157), 1,
      anon_sym_LPAREN,
    ACTIONS(159), 1,
      anon_sym_LBRACE,
    ACTIONS(167), 1,
      anon_sym_STAR,
    ACTIONS(169), 1,
      anon_sym_AMP,
    ACTIONS(177), 1,
      sym__decimal_number_pre_hook,
    STATE(236), 1,
      sym_memory_space,
    STATE(970), 1,
      sym_macro,
    STATE(1049), 1,
      sym__hll_var_call_expression,
    STATE(1053), 1,
      aux_sym__path_expression_repeat2,
    STATE(1097), 1,
      sym_call_expression,
    STATE(1098), 1,
      sym_integer,
    STATE(1218), 1,
      aux_sym__path_expression_repeat1,
    STATE(1399), 1,
      sym__unary_expression,
    STATE(1400), 1,
      sym__prefix_postfix_expression,
    STATE(1404), 1,
      sym__binary_expression,
    STATE(1406), 1,
      sym__and_expression,
    STATE(1412), 1,
      sym_trace32_hll_variable,
    STATE(1417), 1,
      sym__file_dialog,
    STATE(1550), 1,
      sym__address_binary_expression,
    STATE(2257), 1,
      sym__function_identifier,
    STATE(2260), 1,
      sym__hll_var_call_expression_function,
    ACTIONS(88), 2,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
    ACTIONS(161), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(163), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(165), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(171), 2,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
    STATE(1575), 2,
      sym__address_expression,
      sym__parenthesized_address_expression,
    ACTIONS(1055), 3,
      sym_float,
      sym_time,
      sym_frequency,
    ACTIONS(1057), 3,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
    STATE(1180), 13,
      sym__expression,
      sym__parenthesized_expression,
      sym__path_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_assignment_expression,
      sym__literal,
      sym_address,
      sym_bitmask,
      sym_string,
      sym_character,
      sym_symbol,
      sym__special_command_operator,
  [9254] = 40,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(76), 1,
      anon_sym_BSLASH,
    ACTIONS(78), 1,
      anon_sym_SQUOTE,
    ACTIONS(80), 1,
      anon_sym_DQUOTE,
    ACTIONS(82), 1,
      sym_access_class,
    ACTIONS(90), 1,
      aux_sym_symbol_token1,
    ACTIONS(92), 1,
      aux_sym_symbol_token2,
    ACTIONS(98), 1,
      sym_path,
    ACTIONS(120), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(140), 1,
      sym_identifier,
    ACTIONS(157), 1,
      anon_sym_LPAREN,
    ACTIONS(159), 1,
      anon_sym_LBRACE,
    ACTIONS(167), 1,
      anon_sym_STAR,
    ACTIONS(169), 1,
      anon_sym_AMP,
    ACTIONS(177), 1,
      sym__decimal_number_pre_hook,
    STATE(236), 1,
      sym_memory_space,
    STATE(1049), 1,
      sym__hll_var_call_expression,
    STATE(1051), 1,
      sym_macro,
    STATE(1053), 1,
      aux_sym__path_expression_repeat2,
    STATE(1205), 1,
      sym_call_expression,
    STATE(1206), 1,
      sym_integer,
    STATE(1218), 1,
      aux_sym__path_expression_repeat1,
    STATE(1399), 1,
      sym__unary_expression,
    STATE(1400), 1,
      sym__prefix_postfix_expression,
    STATE(1404), 1,
      sym__binary_expression,
    STATE(1406), 1,
      sym__and_expression,
    STATE(1412), 1,
      sym_trace32_hll_variable,
    STATE(1417), 1,
      sym__file_dialog,
    STATE(1550), 1,
      sym__address_binary_expression,
    STATE(2257), 1,
      sym__function_identifier,
    STATE(2260), 1,
      sym__hll_var_call_expression_function,
    ACTIONS(60), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(62), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(88), 2,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
    ACTIONS(171), 2,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
    ACTIONS(222), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1538), 2,
      sym__address_expression,
      sym__parenthesized_address_expression,
    ACTIONS(218), 3,
      sym_float,
      sym_time,
      sym_frequency,
    ACTIONS(220), 3,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
    STATE(1454), 13,
      sym__expression,
      sym__parenthesized_expression,
      sym__path_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_assignment_expression,
      sym__literal,
      sym_address,
      sym_bitmask,
      sym_string,
      sym_character,
      sym_symbol,
      sym__special_command_operator,
  [9397] = 40,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(76), 1,
      anon_sym_BSLASH,
    ACTIONS(78), 1,
      anon_sym_SQUOTE,
    ACTIONS(80), 1,
      anon_sym_DQUOTE,
    ACTIONS(82), 1,
      sym_access_class,
    ACTIONS(90), 1,
      aux_sym_symbol_token1,
    ACTIONS(92), 1,
      aux_sym_symbol_token2,
    ACTIONS(98), 1,
      sym_path,
    ACTIONS(120), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(140), 1,
      sym_identifier,
    ACTIONS(157), 1,
      anon_sym_LPAREN,
    ACTIONS(159), 1,
      anon_sym_LBRACE,
    ACTIONS(167), 1,
      anon_sym_STAR,
    ACTIONS(169), 1,
      anon_sym_AMP,
    ACTIONS(177), 1,
      sym__decimal_number_pre_hook,
    STATE(236), 1,
      sym_memory_space,
    STATE(1049), 1,
      sym__hll_var_call_expression,
    STATE(1051), 1,
      sym_macro,
    STATE(1053), 1,
      aux_sym__path_expression_repeat2,
    STATE(1205), 1,
      sym_call_expression,
    STATE(1206), 1,
      sym_integer,
    STATE(1218), 1,
      aux_sym__path_expression_repeat1,
    STATE(1399), 1,
      sym__unary_expression,
    STATE(1400), 1,
      sym__prefix_postfix_expression,
    STATE(1404), 1,
      sym__binary_expression,
    STATE(1406), 1,
      sym__and_expression,
    STATE(1412), 1,
      sym_trace32_hll_variable,
    STATE(1417), 1,
      sym__file_dialog,
    STATE(1550), 1,
      sym__address_binary_expression,
    STATE(2257), 1,
      sym__function_identifier,
    STATE(2260), 1,
      sym__hll_var_call_expression_function,
    ACTIONS(60), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(62), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(88), 2,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
    ACTIONS(171), 2,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
    ACTIONS(222), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1551), 2,
      sym__address_expression,
      sym__parenthesized_address_expression,
    ACTIONS(218), 3,
      sym_float,
      sym_time,
      sym_frequency,
    ACTIONS(220), 3,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
    STATE(1454), 13,
      sym__expression,
      sym__parenthesized_expression,
      sym__path_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_assignment_expression,
      sym__literal,
      sym_address,
      sym_bitmask,
      sym_string,
      sym_character,
      sym_symbol,
      sym__special_command_operator,
  [9540] = 40,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(76), 1,
      anon_sym_BSLASH,
    ACTIONS(78), 1,
      anon_sym_SQUOTE,
    ACTIONS(80), 1,
      anon_sym_DQUOTE,
    ACTIONS(82), 1,
      sym_access_class,
    ACTIONS(90), 1,
      aux_sym_symbol_token1,
    ACTIONS(92), 1,
      aux_sym_symbol_token2,
    ACTIONS(98), 1,
      sym_path,
    ACTIONS(120), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(140), 1,
      sym_identifier,
    ACTIONS(157), 1,
      anon_sym_LPAREN,
    ACTIONS(159), 1,
      anon_sym_LBRACE,
    ACTIONS(167), 1,
      anon_sym_STAR,
    ACTIONS(169), 1,
      anon_sym_AMP,
    ACTIONS(177), 1,
      sym__decimal_number_pre_hook,
    STATE(236), 1,
      sym_memory_space,
    STATE(1049), 1,
      sym__hll_var_call_expression,
    STATE(1051), 1,
      sym_macro,
    STATE(1053), 1,
      aux_sym__path_expression_repeat2,
    STATE(1205), 1,
      sym_call_expression,
    STATE(1206), 1,
      sym_integer,
    STATE(1218), 1,
      aux_sym__path_expression_repeat1,
    STATE(1399), 1,
      sym__unary_expression,
    STATE(1400), 1,
      sym__prefix_postfix_expression,
    STATE(1404), 1,
      sym__binary_expression,
    STATE(1406), 1,
      sym__and_expression,
    STATE(1412), 1,
      sym_trace32_hll_variable,
    STATE(1417), 1,
      sym__file_dialog,
    STATE(1550), 1,
      sym__address_binary_expression,
    STATE(2257), 1,
      sym__function_identifier,
    STATE(2260), 1,
      sym__hll_var_call_expression_function,
    ACTIONS(60), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(62), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(88), 2,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
    ACTIONS(171), 2,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
    ACTIONS(222), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1546), 2,
      sym__address_expression,
      sym__parenthesized_address_expression,
    ACTIONS(218), 3,
      sym_float,
      sym_time,
      sym_frequency,
    ACTIONS(220), 3,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
    STATE(1454), 13,
      sym__expression,
      sym__parenthesized_expression,
      sym__path_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_assignment_expression,
      sym__literal,
      sym_address,
      sym_bitmask,
      sym_string,
      sym_character,
      sym_symbol,
      sym__special_command_operator,
  [9683] = 40,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(76), 1,
      anon_sym_BSLASH,
    ACTIONS(78), 1,
      anon_sym_SQUOTE,
    ACTIONS(80), 1,
      anon_sym_DQUOTE,
    ACTIONS(82), 1,
      sym_access_class,
    ACTIONS(90), 1,
      aux_sym_symbol_token1,
    ACTIONS(92), 1,
      aux_sym_symbol_token2,
    ACTIONS(98), 1,
      sym_path,
    ACTIONS(120), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(140), 1,
      sym_identifier,
    ACTIONS(157), 1,
      anon_sym_LPAREN,
    ACTIONS(159), 1,
      anon_sym_LBRACE,
    ACTIONS(167), 1,
      anon_sym_STAR,
    ACTIONS(169), 1,
      anon_sym_AMP,
    ACTIONS(177), 1,
      sym__decimal_number_pre_hook,
    STATE(236), 1,
      sym_memory_space,
    STATE(1049), 1,
      sym__hll_var_call_expression,
    STATE(1051), 1,
      sym_macro,
    STATE(1053), 1,
      aux_sym__path_expression_repeat2,
    STATE(1205), 1,
      sym_call_expression,
    STATE(1206), 1,
      sym_integer,
    STATE(1218), 1,
      aux_sym__path_expression_repeat1,
    STATE(1399), 1,
      sym__unary_expression,
    STATE(1400), 1,
      sym__prefix_postfix_expression,
    STATE(1404), 1,
      sym__binary_expression,
    STATE(1406), 1,
      sym__and_expression,
    STATE(1412), 1,
      sym_trace32_hll_variable,
    STATE(1417), 1,
      sym__file_dialog,
    STATE(1550), 1,
      sym__address_binary_expression,
    STATE(2257), 1,
      sym__function_identifier,
    STATE(2260), 1,
      sym__hll_var_call_expression_function,
    ACTIONS(60), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(62), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(88), 2,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
    ACTIONS(171), 2,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
    ACTIONS(222), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1547), 2,
      sym__address_expression,
      sym__parenthesized_address_expression,
    ACTIONS(218), 3,
      sym_float,
      sym_time,
      sym_frequency,
    ACTIONS(220), 3,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
    STATE(1454), 13,
      sym__expression,
      sym__parenthesized_expression,
      sym__path_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_assignment_expression,
      sym__literal,
      sym_address,
      sym_bitmask,
      sym_string,
      sym_character,
      sym_symbol,
      sym__special_command_operator,
  [9826] = 40,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(76), 1,
      anon_sym_BSLASH,
    ACTIONS(78), 1,
      anon_sym_SQUOTE,
    ACTIONS(80), 1,
      anon_sym_DQUOTE,
    ACTIONS(82), 1,
      sym_access_class,
    ACTIONS(90), 1,
      aux_sym_symbol_token1,
    ACTIONS(92), 1,
      aux_sym_symbol_token2,
    ACTIONS(98), 1,
      sym_path,
    ACTIONS(120), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(140), 1,
      sym_identifier,
    ACTIONS(157), 1,
      anon_sym_LPAREN,
    ACTIONS(159), 1,
      anon_sym_LBRACE,
    ACTIONS(167), 1,
      anon_sym_STAR,
    ACTIONS(169), 1,
      anon_sym_AMP,
    ACTIONS(177), 1,
      sym__decimal_number_pre_hook,
    STATE(236), 1,
      sym_memory_space,
    STATE(1049), 1,
      sym__hll_var_call_expression,
    STATE(1051), 1,
      sym_macro,
    STATE(1053), 1,
      aux_sym__path_expression_repeat2,
    STATE(1205), 1,
      sym_call_expression,
    STATE(1206), 1,
      sym_integer,
    STATE(1218), 1,
      aux_sym__path_expression_repeat1,
    STATE(1399), 1,
      sym__unary_expression,
    STATE(1400), 1,
      sym__prefix_postfix_expression,
    STATE(1404), 1,
      sym__binary_expression,
    STATE(1406), 1,
      sym__and_expression,
    STATE(1412), 1,
      sym_trace32_hll_variable,
    STATE(1417), 1,
      sym__file_dialog,
    STATE(1550), 1,
      sym__address_binary_expression,
    STATE(2257), 1,
      sym__function_identifier,
    STATE(2260), 1,
      sym__hll_var_call_expression_function,
    ACTIONS(60), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(62), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(88), 2,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
    ACTIONS(171), 2,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
    ACTIONS(222), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1548), 2,
      sym__address_expression,
      sym__parenthesized_address_expression,
    ACTIONS(218), 3,
      sym_float,
      sym_time,
      sym_frequency,
    ACTIONS(220), 3,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
    STATE(1454), 13,
      sym__expression,
      sym__parenthesized_expression,
      sym__path_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_assignment_expression,
      sym__literal,
      sym_address,
      sym_bitmask,
      sym_string,
      sym_character,
      sym_symbol,
      sym__special_command_operator,
  [9969] = 40,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(76), 1,
      anon_sym_BSLASH,
    ACTIONS(78), 1,
      anon_sym_SQUOTE,
    ACTIONS(80), 1,
      anon_sym_DQUOTE,
    ACTIONS(82), 1,
      sym_access_class,
    ACTIONS(90), 1,
      aux_sym_symbol_token1,
    ACTIONS(92), 1,
      aux_sym_symbol_token2,
    ACTIONS(98), 1,
      sym_path,
    ACTIONS(120), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(140), 1,
      sym_identifier,
    ACTIONS(157), 1,
      anon_sym_LPAREN,
    ACTIONS(159), 1,
      anon_sym_LBRACE,
    ACTIONS(167), 1,
      anon_sym_STAR,
    ACTIONS(169), 1,
      anon_sym_AMP,
    ACTIONS(177), 1,
      sym__decimal_number_pre_hook,
    STATE(236), 1,
      sym_memory_space,
    STATE(975), 1,
      sym_macro,
    STATE(1046), 1,
      sym_call_expression,
    STATE(1049), 1,
      sym__hll_var_call_expression,
    STATE(1052), 1,
      sym_integer,
    STATE(1053), 1,
      aux_sym__path_expression_repeat2,
    STATE(1218), 1,
      aux_sym__path_expression_repeat1,
    STATE(1399), 1,
      sym__unary_expression,
    STATE(1400), 1,
      sym__prefix_postfix_expression,
    STATE(1404), 1,
      sym__binary_expression,
    STATE(1406), 1,
      sym__and_expression,
    STATE(1412), 1,
      sym_trace32_hll_variable,
    STATE(1417), 1,
      sym__file_dialog,
    STATE(1550), 1,
      sym__address_binary_expression,
    STATE(2257), 1,
      sym__function_identifier,
    STATE(2260), 1,
      sym__hll_var_call_expression_function,
    ACTIONS(88), 2,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
    ACTIONS(161), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(163), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(165), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(171), 2,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
    STATE(1572), 2,
      sym__address_expression,
      sym__parenthesized_address_expression,
    ACTIONS(1059), 3,
      sym_float,
      sym_time,
      sym_frequency,
    ACTIONS(1061), 3,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
    STATE(1393), 13,
      sym__expression,
      sym__parenthesized_expression,
      sym__path_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_assignment_expression,
      sym__literal,
      sym_address,
      sym_bitmask,
      sym_string,
      sym_character,
      sym_symbol,
      sym__special_command_operator,
  [10112] = 40,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(76), 1,
      anon_sym_BSLASH,
    ACTIONS(78), 1,
      anon_sym_SQUOTE,
    ACTIONS(80), 1,
      anon_sym_DQUOTE,
    ACTIONS(82), 1,
      sym_access_class,
    ACTIONS(90), 1,
      aux_sym_symbol_token1,
    ACTIONS(92), 1,
      aux_sym_symbol_token2,
    ACTIONS(98), 1,
      sym_path,
    ACTIONS(120), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(140), 1,
      sym_identifier,
    ACTIONS(157), 1,
      anon_sym_LPAREN,
    ACTIONS(159), 1,
      anon_sym_LBRACE,
    ACTIONS(167), 1,
      anon_sym_STAR,
    ACTIONS(169), 1,
      anon_sym_AMP,
    ACTIONS(177), 1,
      sym__decimal_number_pre_hook,
    STATE(236), 1,
      sym_memory_space,
    STATE(970), 1,
      sym_macro,
    STATE(1049), 1,
      sym__hll_var_call_expression,
    STATE(1053), 1,
      aux_sym__path_expression_repeat2,
    STATE(1097), 1,
      sym_call_expression,
    STATE(1098), 1,
      sym_integer,
    STATE(1218), 1,
      aux_sym__path_expression_repeat1,
    STATE(1399), 1,
      sym__unary_expression,
    STATE(1400), 1,
      sym__prefix_postfix_expression,
    STATE(1404), 1,
      sym__binary_expression,
    STATE(1406), 1,
      sym__and_expression,
    STATE(1412), 1,
      sym_trace32_hll_variable,
    STATE(1417), 1,
      sym__file_dialog,
    STATE(1550), 1,
      sym__address_binary_expression,
    STATE(2257), 1,
      sym__function_identifier,
    STATE(2260), 1,
      sym__hll_var_call_expression_function,
    ACTIONS(88), 2,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
    ACTIONS(161), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(163), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(165), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(171), 2,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
    STATE(1575), 2,
      sym__address_expression,
      sym__parenthesized_address_expression,
    ACTIONS(1063), 3,
      sym_float,
      sym_time,
      sym_frequency,
    ACTIONS(1065), 3,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
    STATE(1233), 13,
      sym__expression,
      sym__parenthesized_expression,
      sym__path_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_assignment_expression,
      sym__literal,
      sym_address,
      sym_bitmask,
      sym_string,
      sym_character,
      sym_symbol,
      sym__special_command_operator,
  [10255] = 40,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(76), 1,
      anon_sym_BSLASH,
    ACTIONS(78), 1,
      anon_sym_SQUOTE,
    ACTIONS(80), 1,
      anon_sym_DQUOTE,
    ACTIONS(82), 1,
      sym_access_class,
    ACTIONS(90), 1,
      aux_sym_symbol_token1,
    ACTIONS(92), 1,
      aux_sym_symbol_token2,
    ACTIONS(98), 1,
      sym_path,
    ACTIONS(120), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(140), 1,
      sym_identifier,
    ACTIONS(157), 1,
      anon_sym_LPAREN,
    ACTIONS(159), 1,
      anon_sym_LBRACE,
    ACTIONS(167), 1,
      anon_sym_STAR,
    ACTIONS(169), 1,
      anon_sym_AMP,
    ACTIONS(177), 1,
      sym__decimal_number_pre_hook,
    STATE(236), 1,
      sym_memory_space,
    STATE(975), 1,
      sym_macro,
    STATE(1046), 1,
      sym_call_expression,
    STATE(1049), 1,
      sym__hll_var_call_expression,
    STATE(1052), 1,
      sym_integer,
    STATE(1053), 1,
      aux_sym__path_expression_repeat2,
    STATE(1218), 1,
      aux_sym__path_expression_repeat1,
    STATE(1399), 1,
      sym__unary_expression,
    STATE(1400), 1,
      sym__prefix_postfix_expression,
    STATE(1404), 1,
      sym__binary_expression,
    STATE(1406), 1,
      sym__and_expression,
    STATE(1412), 1,
      sym_trace32_hll_variable,
    STATE(1417), 1,
      sym__file_dialog,
    STATE(1550), 1,
      sym__address_binary_expression,
    STATE(2257), 1,
      sym__function_identifier,
    STATE(2260), 1,
      sym__hll_var_call_expression_function,
    ACTIONS(60), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(62), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(88), 2,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
    ACTIONS(171), 2,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
    ACTIONS(222), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1575), 2,
      sym__address_expression,
      sym__parenthesized_address_expression,
    ACTIONS(1067), 3,
      sym_float,
      sym_time,
      sym_frequency,
    ACTIONS(1069), 3,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
    STATE(1409), 13,
      sym__expression,
      sym__parenthesized_expression,
      sym__path_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_assignment_expression,
      sym__literal,
      sym_address,
      sym_bitmask,
      sym_string,
      sym_character,
      sym_symbol,
      sym__special_command_operator,
  [10398] = 40,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(76), 1,
      anon_sym_BSLASH,
    ACTIONS(78), 1,
      anon_sym_SQUOTE,
    ACTIONS(80), 1,
      anon_sym_DQUOTE,
    ACTIONS(82), 1,
      sym_access_class,
    ACTIONS(90), 1,
      aux_sym_symbol_token1,
    ACTIONS(92), 1,
      aux_sym_symbol_token2,
    ACTIONS(98), 1,
      sym_path,
    ACTIONS(120), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(140), 1,
      sym_identifier,
    ACTIONS(157), 1,
      anon_sym_LPAREN,
    ACTIONS(159), 1,
      anon_sym_LBRACE,
    ACTIONS(167), 1,
      anon_sym_STAR,
    ACTIONS(169), 1,
      anon_sym_AMP,
    ACTIONS(177), 1,
      sym__decimal_number_pre_hook,
    STATE(236), 1,
      sym_memory_space,
    STATE(975), 1,
      sym_macro,
    STATE(1046), 1,
      sym_call_expression,
    STATE(1049), 1,
      sym__hll_var_call_expression,
    STATE(1052), 1,
      sym_integer,
    STATE(1053), 1,
      aux_sym__path_expression_repeat2,
    STATE(1218), 1,
      aux_sym__path_expression_repeat1,
    STATE(1399), 1,
      sym__unary_expression,
    STATE(1400), 1,
      sym__prefix_postfix_expression,
    STATE(1404), 1,
      sym__binary_expression,
    STATE(1406), 1,
      sym__and_expression,
    STATE(1412), 1,
      sym_trace32_hll_variable,
    STATE(1417), 1,
      sym__file_dialog,
    STATE(1550), 1,
      sym__address_binary_expression,
    STATE(2257), 1,
      sym__function_identifier,
    STATE(2260), 1,
      sym__hll_var_call_expression_function,
    ACTIONS(60), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(62), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(88), 2,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
    ACTIONS(171), 2,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
    ACTIONS(222), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1575), 2,
      sym__address_expression,
      sym__parenthesized_address_expression,
    ACTIONS(1071), 3,
      sym_float,
      sym_time,
      sym_frequency,
    ACTIONS(1073), 3,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
    STATE(1410), 13,
      sym__expression,
      sym__parenthesized_expression,
      sym__path_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_assignment_expression,
      sym__literal,
      sym_address,
      sym_bitmask,
      sym_string,
      sym_character,
      sym_symbol,
      sym__special_command_operator,
  [10541] = 40,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(76), 1,
      anon_sym_BSLASH,
    ACTIONS(78), 1,
      anon_sym_SQUOTE,
    ACTIONS(80), 1,
      anon_sym_DQUOTE,
    ACTIONS(82), 1,
      sym_access_class,
    ACTIONS(90), 1,
      aux_sym_symbol_token1,
    ACTIONS(92), 1,
      aux_sym_symbol_token2,
    ACTIONS(98), 1,
      sym_path,
    ACTIONS(120), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(140), 1,
      sym_identifier,
    ACTIONS(157), 1,
      anon_sym_LPAREN,
    ACTIONS(159), 1,
      anon_sym_LBRACE,
    ACTIONS(167), 1,
      anon_sym_STAR,
    ACTIONS(169), 1,
      anon_sym_AMP,
    ACTIONS(177), 1,
      sym__decimal_number_pre_hook,
    STATE(236), 1,
      sym_memory_space,
    STATE(970), 1,
      sym_macro,
    STATE(1049), 1,
      sym__hll_var_call_expression,
    STATE(1053), 1,
      aux_sym__path_expression_repeat2,
    STATE(1097), 1,
      sym_call_expression,
    STATE(1098), 1,
      sym_integer,
    STATE(1218), 1,
      aux_sym__path_expression_repeat1,
    STATE(1399), 1,
      sym__unary_expression,
    STATE(1400), 1,
      sym__prefix_postfix_expression,
    STATE(1404), 1,
      sym__binary_expression,
    STATE(1406), 1,
      sym__and_expression,
    STATE(1412), 1,
      sym_trace32_hll_variable,
    STATE(1417), 1,
      sym__file_dialog,
    STATE(1550), 1,
      sym__address_binary_expression,
    STATE(2257), 1,
      sym__function_identifier,
    STATE(2260), 1,
      sym__hll_var_call_expression_function,
    ACTIONS(88), 2,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
    ACTIONS(161), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(163), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(165), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(171), 2,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
    STATE(1575), 2,
      sym__address_expression,
      sym__parenthesized_address_expression,
    ACTIONS(1075), 3,
      sym_float,
      sym_time,
      sym_frequency,
    ACTIONS(1077), 3,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
    STATE(1173), 13,
      sym__expression,
      sym__parenthesized_expression,
      sym__path_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_assignment_expression,
      sym__literal,
      sym_address,
      sym_bitmask,
      sym_string,
      sym_character,
      sym_symbol,
      sym__special_command_operator,
  [10684] = 40,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(76), 1,
      anon_sym_BSLASH,
    ACTIONS(78), 1,
      anon_sym_SQUOTE,
    ACTIONS(80), 1,
      anon_sym_DQUOTE,
    ACTIONS(82), 1,
      sym_access_class,
    ACTIONS(90), 1,
      aux_sym_symbol_token1,
    ACTIONS(92), 1,
      aux_sym_symbol_token2,
    ACTIONS(98), 1,
      sym_path,
    ACTIONS(120), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(140), 1,
      sym_identifier,
    ACTIONS(157), 1,
      anon_sym_LPAREN,
    ACTIONS(159), 1,
      anon_sym_LBRACE,
    ACTIONS(167), 1,
      anon_sym_STAR,
    ACTIONS(169), 1,
      anon_sym_AMP,
    ACTIONS(177), 1,
      sym__decimal_number_pre_hook,
    STATE(236), 1,
      sym_memory_space,
    STATE(975), 1,
      sym_macro,
    STATE(1046), 1,
      sym_call_expression,
    STATE(1049), 1,
      sym__hll_var_call_expression,
    STATE(1052), 1,
      sym_integer,
    STATE(1053), 1,
      aux_sym__path_expression_repeat2,
    STATE(1218), 1,
      aux_sym__path_expression_repeat1,
    STATE(1399), 1,
      sym__unary_expression,
    STATE(1400), 1,
      sym__prefix_postfix_expression,
    STATE(1404), 1,
      sym__binary_expression,
    STATE(1406), 1,
      sym__and_expression,
    STATE(1412), 1,
      sym_trace32_hll_variable,
    STATE(1417), 1,
      sym__file_dialog,
    STATE(1550), 1,
      sym__address_binary_expression,
    STATE(2257), 1,
      sym__function_identifier,
    STATE(2260), 1,
      sym__hll_var_call_expression_function,
    ACTIONS(60), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(62), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(88), 2,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
    ACTIONS(171), 2,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
    ACTIONS(222), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1575), 2,
      sym__address_expression,
      sym__parenthesized_address_expression,
    ACTIONS(1079), 3,
      sym_float,
      sym_time,
      sym_frequency,
    ACTIONS(1081), 3,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
    STATE(1396), 13,
      sym__expression,
      sym__parenthesized_expression,
      sym__path_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_assignment_expression,
      sym__literal,
      sym_address,
      sym_bitmask,
      sym_string,
      sym_character,
      sym_symbol,
      sym__special_command_operator,
  [10827] = 40,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(76), 1,
      anon_sym_BSLASH,
    ACTIONS(78), 1,
      anon_sym_SQUOTE,
    ACTIONS(80), 1,
      anon_sym_DQUOTE,
    ACTIONS(82), 1,
      sym_access_class,
    ACTIONS(90), 1,
      aux_sym_symbol_token1,
    ACTIONS(92), 1,
      aux_sym_symbol_token2,
    ACTIONS(98), 1,
      sym_path,
    ACTIONS(120), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(140), 1,
      sym_identifier,
    ACTIONS(157), 1,
      anon_sym_LPAREN,
    ACTIONS(159), 1,
      anon_sym_LBRACE,
    ACTIONS(167), 1,
      anon_sym_STAR,
    ACTIONS(169), 1,
      anon_sym_AMP,
    ACTIONS(177), 1,
      sym__decimal_number_pre_hook,
    STATE(236), 1,
      sym_memory_space,
    STATE(970), 1,
      sym_macro,
    STATE(1049), 1,
      sym__hll_var_call_expression,
    STATE(1053), 1,
      aux_sym__path_expression_repeat2,
    STATE(1097), 1,
      sym_call_expression,
    STATE(1098), 1,
      sym_integer,
    STATE(1218), 1,
      aux_sym__path_expression_repeat1,
    STATE(1399), 1,
      sym__unary_expression,
    STATE(1400), 1,
      sym__prefix_postfix_expression,
    STATE(1404), 1,
      sym__binary_expression,
    STATE(1406), 1,
      sym__and_expression,
    STATE(1412), 1,
      sym_trace32_hll_variable,
    STATE(1417), 1,
      sym__file_dialog,
    STATE(1550), 1,
      sym__address_binary_expression,
    STATE(2257), 1,
      sym__function_identifier,
    STATE(2260), 1,
      sym__hll_var_call_expression_function,
    ACTIONS(88), 2,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
    ACTIONS(161), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(163), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(165), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(171), 2,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
    STATE(1575), 2,
      sym__address_expression,
      sym__parenthesized_address_expression,
    ACTIONS(1083), 3,
      sym_float,
      sym_time,
      sym_frequency,
    ACTIONS(1085), 3,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
    STATE(1240), 13,
      sym__expression,
      sym__parenthesized_expression,
      sym__path_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_assignment_expression,
      sym__literal,
      sym_address,
      sym_bitmask,
      sym_string,
      sym_character,
      sym_symbol,
      sym__special_command_operator,
  [10970] = 40,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(76), 1,
      anon_sym_BSLASH,
    ACTIONS(78), 1,
      anon_sym_SQUOTE,
    ACTIONS(80), 1,
      anon_sym_DQUOTE,
    ACTIONS(82), 1,
      sym_access_class,
    ACTIONS(90), 1,
      aux_sym_symbol_token1,
    ACTIONS(92), 1,
      aux_sym_symbol_token2,
    ACTIONS(98), 1,
      sym_path,
    ACTIONS(120), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(140), 1,
      sym_identifier,
    ACTIONS(157), 1,
      anon_sym_LPAREN,
    ACTIONS(159), 1,
      anon_sym_LBRACE,
    ACTIONS(167), 1,
      anon_sym_STAR,
    ACTIONS(169), 1,
      anon_sym_AMP,
    ACTIONS(177), 1,
      sym__decimal_number_pre_hook,
    STATE(236), 1,
      sym_memory_space,
    STATE(975), 1,
      sym_macro,
    STATE(1046), 1,
      sym_call_expression,
    STATE(1049), 1,
      sym__hll_var_call_expression,
    STATE(1052), 1,
      sym_integer,
    STATE(1053), 1,
      aux_sym__path_expression_repeat2,
    STATE(1218), 1,
      aux_sym__path_expression_repeat1,
    STATE(1399), 1,
      sym__unary_expression,
    STATE(1400), 1,
      sym__prefix_postfix_expression,
    STATE(1404), 1,
      sym__binary_expression,
    STATE(1406), 1,
      sym__and_expression,
    STATE(1412), 1,
      sym_trace32_hll_variable,
    STATE(1417), 1,
      sym__file_dialog,
    STATE(1550), 1,
      sym__address_binary_expression,
    STATE(2257), 1,
      sym__function_identifier,
    STATE(2260), 1,
      sym__hll_var_call_expression_function,
    ACTIONS(60), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(62), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(88), 2,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
    ACTIONS(171), 2,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
    ACTIONS(222), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1575), 2,
      sym__address_expression,
      sym__parenthesized_address_expression,
    ACTIONS(1087), 3,
      sym_float,
      sym_time,
      sym_frequency,
    ACTIONS(1089), 3,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
    STATE(1358), 13,
      sym__expression,
      sym__parenthesized_expression,
      sym__path_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_assignment_expression,
      sym__literal,
      sym_address,
      sym_bitmask,
      sym_string,
      sym_character,
      sym_symbol,
      sym__special_command_operator,
  [11113] = 40,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(76), 1,
      anon_sym_BSLASH,
    ACTIONS(78), 1,
      anon_sym_SQUOTE,
    ACTIONS(80), 1,
      anon_sym_DQUOTE,
    ACTIONS(82), 1,
      sym_access_class,
    ACTIONS(90), 1,
      aux_sym_symbol_token1,
    ACTIONS(92), 1,
      aux_sym_symbol_token2,
    ACTIONS(98), 1,
      sym_path,
    ACTIONS(120), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(140), 1,
      sym_identifier,
    ACTIONS(157), 1,
      anon_sym_LPAREN,
    ACTIONS(159), 1,
      anon_sym_LBRACE,
    ACTIONS(167), 1,
      anon_sym_STAR,
    ACTIONS(169), 1,
      anon_sym_AMP,
    ACTIONS(177), 1,
      sym__decimal_number_pre_hook,
    STATE(236), 1,
      sym_memory_space,
    STATE(975), 1,
      sym_macro,
    STATE(1046), 1,
      sym_call_expression,
    STATE(1049), 1,
      sym__hll_var_call_expression,
    STATE(1052), 1,
      sym_integer,
    STATE(1053), 1,
      aux_sym__path_expression_repeat2,
    STATE(1218), 1,
      aux_sym__path_expression_repeat1,
    STATE(1399), 1,
      sym__unary_expression,
    STATE(1400), 1,
      sym__prefix_postfix_expression,
    STATE(1404), 1,
      sym__binary_expression,
    STATE(1406), 1,
      sym__and_expression,
    STATE(1412), 1,
      sym_trace32_hll_variable,
    STATE(1417), 1,
      sym__file_dialog,
    STATE(1550), 1,
      sym__address_binary_expression,
    STATE(2257), 1,
      sym__function_identifier,
    STATE(2260), 1,
      sym__hll_var_call_expression_function,
    ACTIONS(60), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(62), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(88), 2,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
    ACTIONS(171), 2,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
    ACTIONS(222), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1575), 2,
      sym__address_expression,
      sym__parenthesized_address_expression,
    ACTIONS(1091), 3,
      sym_float,
      sym_time,
      sym_frequency,
    ACTIONS(1093), 3,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
    STATE(1403), 13,
      sym__expression,
      sym__parenthesized_expression,
      sym__path_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_assignment_expression,
      sym__literal,
      sym_address,
      sym_bitmask,
      sym_string,
      sym_character,
      sym_symbol,
      sym__special_command_operator,
  [11256] = 40,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(76), 1,
      anon_sym_BSLASH,
    ACTIONS(78), 1,
      anon_sym_SQUOTE,
    ACTIONS(80), 1,
      anon_sym_DQUOTE,
    ACTIONS(82), 1,
      sym_access_class,
    ACTIONS(90), 1,
      aux_sym_symbol_token1,
    ACTIONS(92), 1,
      aux_sym_symbol_token2,
    ACTIONS(98), 1,
      sym_path,
    ACTIONS(120), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(140), 1,
      sym_identifier,
    ACTIONS(157), 1,
      anon_sym_LPAREN,
    ACTIONS(159), 1,
      anon_sym_LBRACE,
    ACTIONS(167), 1,
      anon_sym_STAR,
    ACTIONS(169), 1,
      anon_sym_AMP,
    ACTIONS(177), 1,
      sym__decimal_number_pre_hook,
    STATE(236), 1,
      sym_memory_space,
    STATE(975), 1,
      sym_macro,
    STATE(1046), 1,
      sym_call_expression,
    STATE(1049), 1,
      sym__hll_var_call_expression,
    STATE(1052), 1,
      sym_integer,
    STATE(1053), 1,
      aux_sym__path_expression_repeat2,
    STATE(1218), 1,
      aux_sym__path_expression_repeat1,
    STATE(1399), 1,
      sym__unary_expression,
    STATE(1400), 1,
      sym__prefix_postfix_expression,
    STATE(1404), 1,
      sym__binary_expression,
    STATE(1406), 1,
      sym__and_expression,
    STATE(1412), 1,
      sym_trace32_hll_variable,
    STATE(1417), 1,
      sym__file_dialog,
    STATE(1550), 1,
      sym__address_binary_expression,
    STATE(2257), 1,
      sym__function_identifier,
    STATE(2260), 1,
      sym__hll_var_call_expression_function,
    ACTIONS(60), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(62), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(88), 2,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
    ACTIONS(171), 2,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
    ACTIONS(222), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1575), 2,
      sym__address_expression,
      sym__parenthesized_address_expression,
    ACTIONS(1095), 3,
      sym_float,
      sym_time,
      sym_frequency,
    ACTIONS(1097), 3,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
    STATE(1405), 13,
      sym__expression,
      sym__parenthesized_expression,
      sym__path_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_assignment_expression,
      sym__literal,
      sym_address,
      sym_bitmask,
      sym_string,
      sym_character,
      sym_symbol,
      sym__special_command_operator,
  [11399] = 40,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(76), 1,
      anon_sym_BSLASH,
    ACTIONS(78), 1,
      anon_sym_SQUOTE,
    ACTIONS(80), 1,
      anon_sym_DQUOTE,
    ACTIONS(82), 1,
      sym_access_class,
    ACTIONS(90), 1,
      aux_sym_symbol_token1,
    ACTIONS(92), 1,
      aux_sym_symbol_token2,
    ACTIONS(98), 1,
      sym_path,
    ACTIONS(120), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(140), 1,
      sym_identifier,
    ACTIONS(157), 1,
      anon_sym_LPAREN,
    ACTIONS(159), 1,
      anon_sym_LBRACE,
    ACTIONS(167), 1,
      anon_sym_STAR,
    ACTIONS(169), 1,
      anon_sym_AMP,
    ACTIONS(177), 1,
      sym__decimal_number_pre_hook,
    STATE(236), 1,
      sym_memory_space,
    STATE(975), 1,
      sym_macro,
    STATE(1046), 1,
      sym_call_expression,
    STATE(1049), 1,
      sym__hll_var_call_expression,
    STATE(1052), 1,
      sym_integer,
    STATE(1053), 1,
      aux_sym__path_expression_repeat2,
    STATE(1218), 1,
      aux_sym__path_expression_repeat1,
    STATE(1399), 1,
      sym__unary_expression,
    STATE(1400), 1,
      sym__prefix_postfix_expression,
    STATE(1404), 1,
      sym__binary_expression,
    STATE(1406), 1,
      sym__and_expression,
    STATE(1412), 1,
      sym_trace32_hll_variable,
    STATE(1417), 1,
      sym__file_dialog,
    STATE(1550), 1,
      sym__address_binary_expression,
    STATE(2257), 1,
      sym__function_identifier,
    STATE(2260), 1,
      sym__hll_var_call_expression_function,
    ACTIONS(60), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(62), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(88), 2,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
    ACTIONS(171), 2,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
    ACTIONS(222), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1575), 2,
      sym__address_expression,
      sym__parenthesized_address_expression,
    ACTIONS(1099), 3,
      sym_float,
      sym_time,
      sym_frequency,
    ACTIONS(1101), 3,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
    STATE(1407), 13,
      sym__expression,
      sym__parenthesized_expression,
      sym__path_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_assignment_expression,
      sym__literal,
      sym_address,
      sym_bitmask,
      sym_string,
      sym_character,
      sym_symbol,
      sym__special_command_operator,
  [11542] = 40,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(76), 1,
      anon_sym_BSLASH,
    ACTIONS(78), 1,
      anon_sym_SQUOTE,
    ACTIONS(80), 1,
      anon_sym_DQUOTE,
    ACTIONS(82), 1,
      sym_access_class,
    ACTIONS(90), 1,
      aux_sym_symbol_token1,
    ACTIONS(92), 1,
      aux_sym_symbol_token2,
    ACTIONS(98), 1,
      sym_path,
    ACTIONS(120), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(140), 1,
      sym_identifier,
    ACTIONS(157), 1,
      anon_sym_LPAREN,
    ACTIONS(159), 1,
      anon_sym_LBRACE,
    ACTIONS(167), 1,
      anon_sym_STAR,
    ACTIONS(169), 1,
      anon_sym_AMP,
    ACTIONS(177), 1,
      sym__decimal_number_pre_hook,
    STATE(236), 1,
      sym_memory_space,
    STATE(975), 1,
      sym_macro,
    STATE(1046), 1,
      sym_call_expression,
    STATE(1049), 1,
      sym__hll_var_call_expression,
    STATE(1052), 1,
      sym_integer,
    STATE(1053), 1,
      aux_sym__path_expression_repeat2,
    STATE(1218), 1,
      aux_sym__path_expression_repeat1,
    STATE(1399), 1,
      sym__unary_expression,
    STATE(1400), 1,
      sym__prefix_postfix_expression,
    STATE(1404), 1,
      sym__binary_expression,
    STATE(1406), 1,
      sym__and_expression,
    STATE(1412), 1,
      sym_trace32_hll_variable,
    STATE(1417), 1,
      sym__file_dialog,
    STATE(1550), 1,
      sym__address_binary_expression,
    STATE(2257), 1,
      sym__function_identifier,
    STATE(2260), 1,
      sym__hll_var_call_expression_function,
    ACTIONS(60), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(62), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(88), 2,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
    ACTIONS(171), 2,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
    ACTIONS(222), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1575), 2,
      sym__address_expression,
      sym__parenthesized_address_expression,
    ACTIONS(1103), 3,
      sym_float,
      sym_time,
      sym_frequency,
    ACTIONS(1105), 3,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
    STATE(1408), 13,
      sym__expression,
      sym__parenthesized_expression,
      sym__path_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_assignment_expression,
      sym__literal,
      sym_address,
      sym_bitmask,
      sym_string,
      sym_character,
      sym_symbol,
      sym__special_command_operator,
  [11685] = 40,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(76), 1,
      anon_sym_BSLASH,
    ACTIONS(78), 1,
      anon_sym_SQUOTE,
    ACTIONS(80), 1,
      anon_sym_DQUOTE,
    ACTIONS(82), 1,
      sym_access_class,
    ACTIONS(90), 1,
      aux_sym_symbol_token1,
    ACTIONS(92), 1,
      aux_sym_symbol_token2,
    ACTIONS(98), 1,
      sym_path,
    ACTIONS(120), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(140), 1,
      sym_identifier,
    ACTIONS(157), 1,
      anon_sym_LPAREN,
    ACTIONS(159), 1,
      anon_sym_LBRACE,
    ACTIONS(167), 1,
      anon_sym_STAR,
    ACTIONS(169), 1,
      anon_sym_AMP,
    ACTIONS(177), 1,
      sym__decimal_number_pre_hook,
    STATE(236), 1,
      sym_memory_space,
    STATE(975), 1,
      sym_macro,
    STATE(1046), 1,
      sym_call_expression,
    STATE(1049), 1,
      sym__hll_var_call_expression,
    STATE(1052), 1,
      sym_integer,
    STATE(1053), 1,
      aux_sym__path_expression_repeat2,
    STATE(1218), 1,
      aux_sym__path_expression_repeat1,
    STATE(1399), 1,
      sym__unary_expression,
    STATE(1400), 1,
      sym__prefix_postfix_expression,
    STATE(1404), 1,
      sym__binary_expression,
    STATE(1406), 1,
      sym__and_expression,
    STATE(1412), 1,
      sym_trace32_hll_variable,
    STATE(1417), 1,
      sym__file_dialog,
    STATE(1550), 1,
      sym__address_binary_expression,
    STATE(2257), 1,
      sym__function_identifier,
    STATE(2260), 1,
      sym__hll_var_call_expression_function,
    ACTIONS(60), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(62), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(88), 2,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
    ACTIONS(171), 2,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
    ACTIONS(222), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1575), 2,
      sym__address_expression,
      sym__parenthesized_address_expression,
    ACTIONS(1107), 3,
      sym_float,
      sym_time,
      sym_frequency,
    ACTIONS(1109), 3,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
    STATE(1413), 13,
      sym__expression,
      sym__parenthesized_expression,
      sym__path_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_assignment_expression,
      sym__literal,
      sym_address,
      sym_bitmask,
      sym_string,
      sym_character,
      sym_symbol,
      sym__special_command_operator,
  [11828] = 40,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(76), 1,
      anon_sym_BSLASH,
    ACTIONS(78), 1,
      anon_sym_SQUOTE,
    ACTIONS(80), 1,
      anon_sym_DQUOTE,
    ACTIONS(82), 1,
      sym_access_class,
    ACTIONS(90), 1,
      aux_sym_symbol_token1,
    ACTIONS(92), 1,
      aux_sym_symbol_token2,
    ACTIONS(98), 1,
      sym_path,
    ACTIONS(120), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(140), 1,
      sym_identifier,
    ACTIONS(157), 1,
      anon_sym_LPAREN,
    ACTIONS(159), 1,
      anon_sym_LBRACE,
    ACTIONS(167), 1,
      anon_sym_STAR,
    ACTIONS(169), 1,
      anon_sym_AMP,
    ACTIONS(177), 1,
      sym__decimal_number_pre_hook,
    STATE(236), 1,
      sym_memory_space,
    STATE(975), 1,
      sym_macro,
    STATE(1046), 1,
      sym_call_expression,
    STATE(1049), 1,
      sym__hll_var_call_expression,
    STATE(1052), 1,
      sym_integer,
    STATE(1053), 1,
      aux_sym__path_expression_repeat2,
    STATE(1218), 1,
      aux_sym__path_expression_repeat1,
    STATE(1399), 1,
      sym__unary_expression,
    STATE(1400), 1,
      sym__prefix_postfix_expression,
    STATE(1404), 1,
      sym__binary_expression,
    STATE(1406), 1,
      sym__and_expression,
    STATE(1412), 1,
      sym_trace32_hll_variable,
    STATE(1417), 1,
      sym__file_dialog,
    STATE(1550), 1,
      sym__address_binary_expression,
    STATE(2257), 1,
      sym__function_identifier,
    STATE(2260), 1,
      sym__hll_var_call_expression_function,
    ACTIONS(60), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(62), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(88), 2,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
    ACTIONS(171), 2,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
    ACTIONS(222), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1575), 2,
      sym__address_expression,
      sym__parenthesized_address_expression,
    ACTIONS(224), 3,
      sym_float,
      sym_time,
      sym_frequency,
    ACTIONS(226), 3,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
    STATE(1411), 13,
      sym__expression,
      sym__parenthesized_expression,
      sym__path_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_assignment_expression,
      sym__literal,
      sym_address,
      sym_bitmask,
      sym_string,
      sym_character,
      sym_symbol,
      sym__special_command_operator,
  [11971] = 40,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(76), 1,
      anon_sym_BSLASH,
    ACTIONS(78), 1,
      anon_sym_SQUOTE,
    ACTIONS(80), 1,
      anon_sym_DQUOTE,
    ACTIONS(82), 1,
      sym_access_class,
    ACTIONS(90), 1,
      aux_sym_symbol_token1,
    ACTIONS(92), 1,
      aux_sym_symbol_token2,
    ACTIONS(98), 1,
      sym_path,
    ACTIONS(120), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(140), 1,
      sym_identifier,
    ACTIONS(157), 1,
      anon_sym_LPAREN,
    ACTIONS(159), 1,
      anon_sym_LBRACE,
    ACTIONS(167), 1,
      anon_sym_STAR,
    ACTIONS(169), 1,
      anon_sym_AMP,
    ACTIONS(177), 1,
      sym__decimal_number_pre_hook,
    STATE(236), 1,
      sym_memory_space,
    STATE(975), 1,
      sym_macro,
    STATE(1046), 1,
      sym_call_expression,
    STATE(1049), 1,
      sym__hll_var_call_expression,
    STATE(1052), 1,
      sym_integer,
    STATE(1053), 1,
      aux_sym__path_expression_repeat2,
    STATE(1218), 1,
      aux_sym__path_expression_repeat1,
    STATE(1399), 1,
      sym__unary_expression,
    STATE(1400), 1,
      sym__prefix_postfix_expression,
    STATE(1404), 1,
      sym__binary_expression,
    STATE(1406), 1,
      sym__and_expression,
    STATE(1412), 1,
      sym_trace32_hll_variable,
    STATE(1417), 1,
      sym__file_dialog,
    STATE(1550), 1,
      sym__address_binary_expression,
    STATE(2257), 1,
      sym__function_identifier,
    STATE(2260), 1,
      sym__hll_var_call_expression_function,
    ACTIONS(60), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(62), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(88), 2,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
    ACTIONS(171), 2,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
    ACTIONS(222), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1575), 2,
      sym__address_expression,
      sym__parenthesized_address_expression,
    ACTIONS(1111), 3,
      sym_float,
      sym_time,
      sym_frequency,
    ACTIONS(1113), 3,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
    STATE(1414), 13,
      sym__expression,
      sym__parenthesized_expression,
      sym__path_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_assignment_expression,
      sym__literal,
      sym_address,
      sym_bitmask,
      sym_string,
      sym_character,
      sym_symbol,
      sym__special_command_operator,
  [12114] = 40,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(76), 1,
      anon_sym_BSLASH,
    ACTIONS(78), 1,
      anon_sym_SQUOTE,
    ACTIONS(80), 1,
      anon_sym_DQUOTE,
    ACTIONS(82), 1,
      sym_access_class,
    ACTIONS(90), 1,
      aux_sym_symbol_token1,
    ACTIONS(92), 1,
      aux_sym_symbol_token2,
    ACTIONS(98), 1,
      sym_path,
    ACTIONS(120), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(140), 1,
      sym_identifier,
    ACTIONS(157), 1,
      anon_sym_LPAREN,
    ACTIONS(159), 1,
      anon_sym_LBRACE,
    ACTIONS(167), 1,
      anon_sym_STAR,
    ACTIONS(169), 1,
      anon_sym_AMP,
    ACTIONS(177), 1,
      sym__decimal_number_pre_hook,
    STATE(236), 1,
      sym_memory_space,
    STATE(975), 1,
      sym_macro,
    STATE(1046), 1,
      sym_call_expression,
    STATE(1049), 1,
      sym__hll_var_call_expression,
    STATE(1052), 1,
      sym_integer,
    STATE(1053), 1,
      aux_sym__path_expression_repeat2,
    STATE(1218), 1,
      aux_sym__path_expression_repeat1,
    STATE(1399), 1,
      sym__unary_expression,
    STATE(1400), 1,
      sym__prefix_postfix_expression,
    STATE(1404), 1,
      sym__binary_expression,
    STATE(1406), 1,
      sym__and_expression,
    STATE(1412), 1,
      sym_trace32_hll_variable,
    STATE(1417), 1,
      sym__file_dialog,
    STATE(1550), 1,
      sym__address_binary_expression,
    STATE(2257), 1,
      sym__function_identifier,
    STATE(2260), 1,
      sym__hll_var_call_expression_function,
    ACTIONS(60), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(62), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(88), 2,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
    ACTIONS(171), 2,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
    ACTIONS(222), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1575), 2,
      sym__address_expression,
      sym__parenthesized_address_expression,
    ACTIONS(1115), 3,
      sym_float,
      sym_time,
      sym_frequency,
    ACTIONS(1117), 3,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
    STATE(1415), 13,
      sym__expression,
      sym__parenthesized_expression,
      sym__path_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_assignment_expression,
      sym__literal,
      sym_address,
      sym_bitmask,
      sym_string,
      sym_character,
      sym_symbol,
      sym__special_command_operator,
  [12257] = 40,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(76), 1,
      anon_sym_BSLASH,
    ACTIONS(78), 1,
      anon_sym_SQUOTE,
    ACTIONS(80), 1,
      anon_sym_DQUOTE,
    ACTIONS(82), 1,
      sym_access_class,
    ACTIONS(90), 1,
      aux_sym_symbol_token1,
    ACTIONS(92), 1,
      aux_sym_symbol_token2,
    ACTIONS(98), 1,
      sym_path,
    ACTIONS(120), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(140), 1,
      sym_identifier,
    ACTIONS(157), 1,
      anon_sym_LPAREN,
    ACTIONS(159), 1,
      anon_sym_LBRACE,
    ACTIONS(167), 1,
      anon_sym_STAR,
    ACTIONS(169), 1,
      anon_sym_AMP,
    ACTIONS(177), 1,
      sym__decimal_number_pre_hook,
    STATE(236), 1,
      sym_memory_space,
    STATE(970), 1,
      sym_macro,
    STATE(1049), 1,
      sym__hll_var_call_expression,
    STATE(1053), 1,
      aux_sym__path_expression_repeat2,
    STATE(1097), 1,
      sym_call_expression,
    STATE(1098), 1,
      sym_integer,
    STATE(1218), 1,
      aux_sym__path_expression_repeat1,
    STATE(1399), 1,
      sym__unary_expression,
    STATE(1400), 1,
      sym__prefix_postfix_expression,
    STATE(1404), 1,
      sym__binary_expression,
    STATE(1406), 1,
      sym__and_expression,
    STATE(1412), 1,
      sym_trace32_hll_variable,
    STATE(1417), 1,
      sym__file_dialog,
    STATE(1550), 1,
      sym__address_binary_expression,
    STATE(2257), 1,
      sym__function_identifier,
    STATE(2260), 1,
      sym__hll_var_call_expression_function,
    ACTIONS(88), 2,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
    ACTIONS(161), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(163), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(165), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(171), 2,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
    STATE(1575), 2,
      sym__address_expression,
      sym__parenthesized_address_expression,
    ACTIONS(173), 3,
      sym_float,
      sym_time,
      sym_frequency,
    ACTIONS(175), 3,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
    STATE(1210), 13,
      sym__expression,
      sym__parenthesized_expression,
      sym__path_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_assignment_expression,
      sym__literal,
      sym_address,
      sym_bitmask,
      sym_string,
      sym_character,
      sym_symbol,
      sym__special_command_operator,
  [12400] = 40,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(76), 1,
      anon_sym_BSLASH,
    ACTIONS(78), 1,
      anon_sym_SQUOTE,
    ACTIONS(80), 1,
      anon_sym_DQUOTE,
    ACTIONS(82), 1,
      sym_access_class,
    ACTIONS(90), 1,
      aux_sym_symbol_token1,
    ACTIONS(92), 1,
      aux_sym_symbol_token2,
    ACTIONS(98), 1,
      sym_path,
    ACTIONS(120), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(140), 1,
      sym_identifier,
    ACTIONS(157), 1,
      anon_sym_LPAREN,
    ACTIONS(159), 1,
      anon_sym_LBRACE,
    ACTIONS(167), 1,
      anon_sym_STAR,
    ACTIONS(169), 1,
      anon_sym_AMP,
    ACTIONS(177), 1,
      sym__decimal_number_pre_hook,
    STATE(236), 1,
      sym_memory_space,
    STATE(970), 1,
      sym_macro,
    STATE(1049), 1,
      sym__hll_var_call_expression,
    STATE(1053), 1,
      aux_sym__path_expression_repeat2,
    STATE(1097), 1,
      sym_call_expression,
    STATE(1098), 1,
      sym_integer,
    STATE(1218), 1,
      aux_sym__path_expression_repeat1,
    STATE(1399), 1,
      sym__unary_expression,
    STATE(1400), 1,
      sym__prefix_postfix_expression,
    STATE(1404), 1,
      sym__binary_expression,
    STATE(1406), 1,
      sym__and_expression,
    STATE(1412), 1,
      sym_trace32_hll_variable,
    STATE(1417), 1,
      sym__file_dialog,
    STATE(1550), 1,
      sym__address_binary_expression,
    STATE(2257), 1,
      sym__function_identifier,
    STATE(2260), 1,
      sym__hll_var_call_expression_function,
    ACTIONS(88), 2,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
    ACTIONS(161), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(163), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(165), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(171), 2,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
    STATE(1575), 2,
      sym__address_expression,
      sym__parenthesized_address_expression,
    ACTIONS(1119), 3,
      sym_float,
      sym_time,
      sym_frequency,
    ACTIONS(1121), 3,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
    STATE(1198), 13,
      sym__expression,
      sym__parenthesized_expression,
      sym__path_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_assignment_expression,
      sym__literal,
      sym_address,
      sym_bitmask,
      sym_string,
      sym_character,
      sym_symbol,
      sym__special_command_operator,
  [12543] = 40,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(76), 1,
      anon_sym_BSLASH,
    ACTIONS(78), 1,
      anon_sym_SQUOTE,
    ACTIONS(80), 1,
      anon_sym_DQUOTE,
    ACTIONS(82), 1,
      sym_access_class,
    ACTIONS(90), 1,
      aux_sym_symbol_token1,
    ACTIONS(92), 1,
      aux_sym_symbol_token2,
    ACTIONS(98), 1,
      sym_path,
    ACTIONS(120), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(140), 1,
      sym_identifier,
    ACTIONS(157), 1,
      anon_sym_LPAREN,
    ACTIONS(159), 1,
      anon_sym_LBRACE,
    ACTIONS(167), 1,
      anon_sym_STAR,
    ACTIONS(169), 1,
      anon_sym_AMP,
    ACTIONS(177), 1,
      sym__decimal_number_pre_hook,
    STATE(236), 1,
      sym_memory_space,
    STATE(970), 1,
      sym_macro,
    STATE(1049), 1,
      sym__hll_var_call_expression,
    STATE(1053), 1,
      aux_sym__path_expression_repeat2,
    STATE(1097), 1,
      sym_call_expression,
    STATE(1098), 1,
      sym_integer,
    STATE(1218), 1,
      aux_sym__path_expression_repeat1,
    STATE(1399), 1,
      sym__unary_expression,
    STATE(1400), 1,
      sym__prefix_postfix_expression,
    STATE(1404), 1,
      sym__binary_expression,
    STATE(1406), 1,
      sym__and_expression,
    STATE(1412), 1,
      sym_trace32_hll_variable,
    STATE(1417), 1,
      sym__file_dialog,
    STATE(1550), 1,
      sym__address_binary_expression,
    STATE(2257), 1,
      sym__function_identifier,
    STATE(2260), 1,
      sym__hll_var_call_expression_function,
    ACTIONS(88), 2,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
    ACTIONS(161), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(163), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(165), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(171), 2,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
    STATE(1575), 2,
      sym__address_expression,
      sym__parenthesized_address_expression,
    ACTIONS(1123), 3,
      sym_float,
      sym_time,
      sym_frequency,
    ACTIONS(1125), 3,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
    STATE(1203), 13,
      sym__expression,
      sym__parenthesized_expression,
      sym__path_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_assignment_expression,
      sym__literal,
      sym_address,
      sym_bitmask,
      sym_string,
      sym_character,
      sym_symbol,
      sym__special_command_operator,
  [12686] = 40,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(76), 1,
      anon_sym_BSLASH,
    ACTIONS(78), 1,
      anon_sym_SQUOTE,
    ACTIONS(80), 1,
      anon_sym_DQUOTE,
    ACTIONS(82), 1,
      sym_access_class,
    ACTIONS(90), 1,
      aux_sym_symbol_token1,
    ACTIONS(92), 1,
      aux_sym_symbol_token2,
    ACTIONS(98), 1,
      sym_path,
    ACTIONS(120), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(140), 1,
      sym_identifier,
    ACTIONS(145), 1,
      anon_sym_LBRACE,
    ACTIONS(147), 1,
      anon_sym_AMP,
    ACTIONS(155), 1,
      sym__decimal_number_pre_hook,
    ACTIONS(167), 1,
      anon_sym_STAR,
    ACTIONS(1127), 1,
      anon_sym_LPAREN,
    STATE(236), 1,
      sym_memory_space,
    STATE(972), 1,
      sym_macro,
    STATE(1053), 1,
      aux_sym__path_expression_repeat2,
    STATE(1061), 1,
      sym__hll_var_call_expression,
    STATE(1107), 1,
      sym__address_binary_expression,
    STATE(1108), 1,
      sym_call_expression,
    STATE(1110), 1,
      sym_integer,
    STATE(1218), 1,
      aux_sym__path_expression_repeat1,
    STATE(1399), 1,
      sym__unary_expression,
    STATE(1400), 1,
      sym__prefix_postfix_expression,
    STATE(1404), 1,
      sym__binary_expression,
    STATE(1406), 1,
      sym__and_expression,
    STATE(1412), 1,
      sym_trace32_hll_variable,
    STATE(1417), 1,
      sym__file_dialog,
    STATE(2349), 1,
      sym__function_identifier,
    STATE(2359), 1,
      sym__hll_var_call_expression_function,
    ACTIONS(60), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(62), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(88), 2,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
    ACTIONS(149), 2,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
    ACTIONS(222), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1126), 2,
      sym__address_expression,
      sym__parenthesized_address_expression,
    ACTIONS(151), 3,
      sym_float,
      sym_time,
      sym_frequency,
    ACTIONS(153), 3,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
    STATE(1501), 13,
      sym__expression,
      sym__parenthesized_expression,
      sym__path_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_assignment_expression,
      sym__literal,
      sym_address,
      sym_bitmask,
      sym_string,
      sym_character,
      sym_symbol,
      sym__special_command_operator,
  [12829] = 40,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(51), 1,
      anon_sym_LBRACE,
    ACTIONS(76), 1,
      anon_sym_BSLASH,
    ACTIONS(78), 1,
      anon_sym_SQUOTE,
    ACTIONS(80), 1,
      anon_sym_DQUOTE,
    ACTIONS(82), 1,
      sym_access_class,
    ACTIONS(90), 1,
      aux_sym_symbol_token1,
    ACTIONS(92), 1,
      aux_sym_symbol_token2,
    ACTIONS(96), 1,
      sym__decimal_number_pre_hook,
    ACTIONS(98), 1,
      sym_path,
    ACTIONS(120), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(140), 1,
      sym_identifier,
    ACTIONS(167), 1,
      anon_sym_STAR,
    ACTIONS(695), 1,
      anon_sym_AMP,
    ACTIONS(1129), 1,
      anon_sym_LPAREN,
    STATE(236), 1,
      sym_memory_space,
    STATE(341), 1,
      sym_macro,
    STATE(345), 1,
      sym__hll_var_call_expression,
    STATE(354), 1,
      sym__address_binary_expression,
    STATE(364), 1,
      sym_call_expression,
    STATE(365), 1,
      sym_integer,
    STATE(1053), 1,
      aux_sym__path_expression_repeat2,
    STATE(1218), 1,
      aux_sym__path_expression_repeat1,
    STATE(1399), 1,
      sym__unary_expression,
    STATE(1400), 1,
      sym__prefix_postfix_expression,
    STATE(1404), 1,
      sym__binary_expression,
    STATE(1406), 1,
      sym__and_expression,
    STATE(1412), 1,
      sym_trace32_hll_variable,
    STATE(1417), 1,
      sym__file_dialog,
    STATE(2354), 1,
      sym__function_identifier,
    STATE(2355), 1,
      sym__hll_var_call_expression_function,
    ACTIONS(60), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(62), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(84), 2,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
    ACTIONS(88), 2,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
    ACTIONS(222), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(356), 2,
      sym__address_expression,
      sym__parenthesized_address_expression,
    ACTIONS(86), 3,
      sym_float,
      sym_time,
      sym_frequency,
    ACTIONS(94), 3,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
    STATE(1435), 13,
      sym__expression,
      sym__parenthesized_expression,
      sym__path_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_assignment_expression,
      sym__literal,
      sym_address,
      sym_bitmask,
      sym_string,
      sym_character,
      sym_symbol,
      sym__special_command_operator,
  [12972] = 40,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(51), 1,
      anon_sym_LBRACE,
    ACTIONS(76), 1,
      anon_sym_BSLASH,
    ACTIONS(78), 1,
      anon_sym_SQUOTE,
    ACTIONS(80), 1,
      anon_sym_DQUOTE,
    ACTIONS(82), 1,
      sym_access_class,
    ACTIONS(90), 1,
      aux_sym_symbol_token1,
    ACTIONS(92), 1,
      aux_sym_symbol_token2,
    ACTIONS(96), 1,
      sym__decimal_number_pre_hook,
    ACTIONS(98), 1,
      sym_path,
    ACTIONS(120), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(140), 1,
      sym_identifier,
    ACTIONS(167), 1,
      anon_sym_STAR,
    ACTIONS(695), 1,
      anon_sym_AMP,
    ACTIONS(1129), 1,
      anon_sym_LPAREN,
    STATE(236), 1,
      sym_memory_space,
    STATE(341), 1,
      sym_macro,
    STATE(345), 1,
      sym__hll_var_call_expression,
    STATE(354), 1,
      sym__address_binary_expression,
    STATE(364), 1,
      sym_call_expression,
    STATE(365), 1,
      sym_integer,
    STATE(1053), 1,
      aux_sym__path_expression_repeat2,
    STATE(1218), 1,
      aux_sym__path_expression_repeat1,
    STATE(1399), 1,
      sym__unary_expression,
    STATE(1400), 1,
      sym__prefix_postfix_expression,
    STATE(1404), 1,
      sym__binary_expression,
    STATE(1406), 1,
      sym__and_expression,
    STATE(1412), 1,
      sym_trace32_hll_variable,
    STATE(1417), 1,
      sym__file_dialog,
    STATE(2354), 1,
      sym__function_identifier,
    STATE(2355), 1,
      sym__hll_var_call_expression_function,
    ACTIONS(60), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(62), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(84), 2,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
    ACTIONS(88), 2,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
    ACTIONS(222), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(357), 2,
      sym__address_expression,
      sym__parenthesized_address_expression,
    ACTIONS(86), 3,
      sym_float,
      sym_time,
      sym_frequency,
    ACTIONS(94), 3,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
    STATE(1435), 13,
      sym__expression,
      sym__parenthesized_expression,
      sym__path_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_assignment_expression,
      sym__literal,
      sym_address,
      sym_bitmask,
      sym_string,
      sym_character,
      sym_symbol,
      sym__special_command_operator,
  [13115] = 40,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(51), 1,
      anon_sym_LBRACE,
    ACTIONS(76), 1,
      anon_sym_BSLASH,
    ACTIONS(78), 1,
      anon_sym_SQUOTE,
    ACTIONS(80), 1,
      anon_sym_DQUOTE,
    ACTIONS(82), 1,
      sym_access_class,
    ACTIONS(90), 1,
      aux_sym_symbol_token1,
    ACTIONS(92), 1,
      aux_sym_symbol_token2,
    ACTIONS(96), 1,
      sym__decimal_number_pre_hook,
    ACTIONS(98), 1,
      sym_path,
    ACTIONS(120), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(140), 1,
      sym_identifier,
    ACTIONS(167), 1,
      anon_sym_STAR,
    ACTIONS(695), 1,
      anon_sym_AMP,
    ACTIONS(1129), 1,
      anon_sym_LPAREN,
    STATE(236), 1,
      sym_memory_space,
    STATE(341), 1,
      sym_macro,
    STATE(345), 1,
      sym__hll_var_call_expression,
    STATE(354), 1,
      sym__address_binary_expression,
    STATE(364), 1,
      sym_call_expression,
    STATE(365), 1,
      sym_integer,
    STATE(1053), 1,
      aux_sym__path_expression_repeat2,
    STATE(1218), 1,
      aux_sym__path_expression_repeat1,
    STATE(1399), 1,
      sym__unary_expression,
    STATE(1400), 1,
      sym__prefix_postfix_expression,
    STATE(1404), 1,
      sym__binary_expression,
    STATE(1406), 1,
      sym__and_expression,
    STATE(1412), 1,
      sym_trace32_hll_variable,
    STATE(1417), 1,
      sym__file_dialog,
    STATE(2354), 1,
      sym__function_identifier,
    STATE(2355), 1,
      sym__hll_var_call_expression_function,
    ACTIONS(60), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(62), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(84), 2,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
    ACTIONS(88), 2,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
    ACTIONS(222), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(358), 2,
      sym__address_expression,
      sym__parenthesized_address_expression,
    ACTIONS(86), 3,
      sym_float,
      sym_time,
      sym_frequency,
    ACTIONS(94), 3,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
    STATE(1435), 13,
      sym__expression,
      sym__parenthesized_expression,
      sym__path_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_assignment_expression,
      sym__literal,
      sym_address,
      sym_bitmask,
      sym_string,
      sym_character,
      sym_symbol,
      sym__special_command_operator,
  [13258] = 40,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(51), 1,
      anon_sym_LBRACE,
    ACTIONS(76), 1,
      anon_sym_BSLASH,
    ACTIONS(78), 1,
      anon_sym_SQUOTE,
    ACTIONS(80), 1,
      anon_sym_DQUOTE,
    ACTIONS(82), 1,
      sym_access_class,
    ACTIONS(90), 1,
      aux_sym_symbol_token1,
    ACTIONS(92), 1,
      aux_sym_symbol_token2,
    ACTIONS(96), 1,
      sym__decimal_number_pre_hook,
    ACTIONS(98), 1,
      sym_path,
    ACTIONS(120), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(140), 1,
      sym_identifier,
    ACTIONS(167), 1,
      anon_sym_STAR,
    ACTIONS(695), 1,
      anon_sym_AMP,
    ACTIONS(1129), 1,
      anon_sym_LPAREN,
    STATE(236), 1,
      sym_memory_space,
    STATE(341), 1,
      sym_macro,
    STATE(345), 1,
      sym__hll_var_call_expression,
    STATE(354), 1,
      sym__address_binary_expression,
    STATE(364), 1,
      sym_call_expression,
    STATE(365), 1,
      sym_integer,
    STATE(1053), 1,
      aux_sym__path_expression_repeat2,
    STATE(1218), 1,
      aux_sym__path_expression_repeat1,
    STATE(1399), 1,
      sym__unary_expression,
    STATE(1400), 1,
      sym__prefix_postfix_expression,
    STATE(1404), 1,
      sym__binary_expression,
    STATE(1406), 1,
      sym__and_expression,
    STATE(1412), 1,
      sym_trace32_hll_variable,
    STATE(1417), 1,
      sym__file_dialog,
    STATE(2354), 1,
      sym__function_identifier,
    STATE(2355), 1,
      sym__hll_var_call_expression_function,
    ACTIONS(60), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(62), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(84), 2,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
    ACTIONS(88), 2,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
    ACTIONS(222), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(359), 2,
      sym__address_expression,
      sym__parenthesized_address_expression,
    ACTIONS(86), 3,
      sym_float,
      sym_time,
      sym_frequency,
    ACTIONS(94), 3,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
    STATE(1435), 13,
      sym__expression,
      sym__parenthesized_expression,
      sym__path_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_assignment_expression,
      sym__literal,
      sym_address,
      sym_bitmask,
      sym_string,
      sym_character,
      sym_symbol,
      sym__special_command_operator,
  [13401] = 40,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(51), 1,
      anon_sym_LBRACE,
    ACTIONS(76), 1,
      anon_sym_BSLASH,
    ACTIONS(78), 1,
      anon_sym_SQUOTE,
    ACTIONS(80), 1,
      anon_sym_DQUOTE,
    ACTIONS(82), 1,
      sym_access_class,
    ACTIONS(90), 1,
      aux_sym_symbol_token1,
    ACTIONS(92), 1,
      aux_sym_symbol_token2,
    ACTIONS(96), 1,
      sym__decimal_number_pre_hook,
    ACTIONS(98), 1,
      sym_path,
    ACTIONS(120), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(140), 1,
      sym_identifier,
    ACTIONS(167), 1,
      anon_sym_STAR,
    ACTIONS(695), 1,
      anon_sym_AMP,
    ACTIONS(1129), 1,
      anon_sym_LPAREN,
    STATE(236), 1,
      sym_memory_space,
    STATE(341), 1,
      sym_macro,
    STATE(345), 1,
      sym__hll_var_call_expression,
    STATE(354), 1,
      sym__address_binary_expression,
    STATE(364), 1,
      sym_call_expression,
    STATE(365), 1,
      sym_integer,
    STATE(1053), 1,
      aux_sym__path_expression_repeat2,
    STATE(1218), 1,
      aux_sym__path_expression_repeat1,
    STATE(1399), 1,
      sym__unary_expression,
    STATE(1400), 1,
      sym__prefix_postfix_expression,
    STATE(1404), 1,
      sym__binary_expression,
    STATE(1406), 1,
      sym__and_expression,
    STATE(1412), 1,
      sym_trace32_hll_variable,
    STATE(1417), 1,
      sym__file_dialog,
    STATE(2354), 1,
      sym__function_identifier,
    STATE(2355), 1,
      sym__hll_var_call_expression_function,
    ACTIONS(60), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(62), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(84), 2,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
    ACTIONS(88), 2,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
    ACTIONS(222), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(360), 2,
      sym__address_expression,
      sym__parenthesized_address_expression,
    ACTIONS(86), 3,
      sym_float,
      sym_time,
      sym_frequency,
    ACTIONS(94), 3,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
    STATE(1435), 13,
      sym__expression,
      sym__parenthesized_expression,
      sym__path_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_assignment_expression,
      sym__literal,
      sym_address,
      sym_bitmask,
      sym_string,
      sym_character,
      sym_symbol,
      sym__special_command_operator,
  [13544] = 40,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(76), 1,
      anon_sym_BSLASH,
    ACTIONS(78), 1,
      anon_sym_SQUOTE,
    ACTIONS(80), 1,
      anon_sym_DQUOTE,
    ACTIONS(82), 1,
      sym_access_class,
    ACTIONS(90), 1,
      aux_sym_symbol_token1,
    ACTIONS(92), 1,
      aux_sym_symbol_token2,
    ACTIONS(98), 1,
      sym_path,
    ACTIONS(120), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(140), 1,
      sym_identifier,
    ACTIONS(157), 1,
      anon_sym_LPAREN,
    ACTIONS(159), 1,
      anon_sym_LBRACE,
    ACTIONS(167), 1,
      anon_sym_STAR,
    ACTIONS(169), 1,
      anon_sym_AMP,
    ACTIONS(177), 1,
      sym__decimal_number_pre_hook,
    STATE(236), 1,
      sym_memory_space,
    STATE(975), 1,
      sym_macro,
    STATE(1046), 1,
      sym_call_expression,
    STATE(1049), 1,
      sym__hll_var_call_expression,
    STATE(1052), 1,
      sym_integer,
    STATE(1053), 1,
      aux_sym__path_expression_repeat2,
    STATE(1218), 1,
      aux_sym__path_expression_repeat1,
    STATE(1399), 1,
      sym__unary_expression,
    STATE(1400), 1,
      sym__prefix_postfix_expression,
    STATE(1404), 1,
      sym__binary_expression,
    STATE(1406), 1,
      sym__and_expression,
    STATE(1412), 1,
      sym_trace32_hll_variable,
    STATE(1417), 1,
      sym__file_dialog,
    STATE(1550), 1,
      sym__address_binary_expression,
    STATE(2257), 1,
      sym__function_identifier,
    STATE(2260), 1,
      sym__hll_var_call_expression_function,
    ACTIONS(88), 2,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
    ACTIONS(161), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(163), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(165), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(171), 2,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
    STATE(1557), 2,
      sym__address_expression,
      sym__parenthesized_address_expression,
    ACTIONS(1131), 3,
      sym_float,
      sym_time,
      sym_frequency,
    ACTIONS(1133), 3,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
    STATE(1362), 13,
      sym__expression,
      sym__parenthesized_expression,
      sym__path_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_assignment_expression,
      sym__literal,
      sym_address,
      sym_bitmask,
      sym_string,
      sym_character,
      sym_symbol,
      sym__special_command_operator,
  [13687] = 40,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(76), 1,
      anon_sym_BSLASH,
    ACTIONS(78), 1,
      anon_sym_SQUOTE,
    ACTIONS(80), 1,
      anon_sym_DQUOTE,
    ACTIONS(82), 1,
      sym_access_class,
    ACTIONS(90), 1,
      aux_sym_symbol_token1,
    ACTIONS(92), 1,
      aux_sym_symbol_token2,
    ACTIONS(98), 1,
      sym_path,
    ACTIONS(120), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(140), 1,
      sym_identifier,
    ACTIONS(167), 1,
      anon_sym_STAR,
    ACTIONS(169), 1,
      anon_sym_AMP,
    ACTIONS(177), 1,
      sym__decimal_number_pre_hook,
    ACTIONS(216), 1,
      anon_sym_LBRACE,
    ACTIONS(1135), 1,
      anon_sym_LPAREN,
    STATE(236), 1,
      sym_memory_space,
    STATE(967), 1,
      sym_macro,
    STATE(1034), 1,
      sym_call_expression,
    STATE(1035), 1,
      sym_integer,
    STATE(1049), 1,
      sym__hll_var_call_expression,
    STATE(1053), 1,
      aux_sym__path_expression_repeat2,
    STATE(1109), 1,
      sym__address_binary_expression,
    STATE(1218), 1,
      aux_sym__path_expression_repeat1,
    STATE(1399), 1,
      sym__unary_expression,
    STATE(1400), 1,
      sym__prefix_postfix_expression,
    STATE(1404), 1,
      sym__binary_expression,
    STATE(1406), 1,
      sym__and_expression,
    STATE(1412), 1,
      sym_trace32_hll_variable,
    STATE(1417), 1,
      sym__file_dialog,
    STATE(2257), 1,
      sym__function_identifier,
    STATE(2260), 1,
      sym__hll_var_call_expression_function,
    ACTIONS(60), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(62), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(88), 2,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
    ACTIONS(171), 2,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
    ACTIONS(222), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1038), 2,
      sym__address_expression,
      sym__parenthesized_address_expression,
    ACTIONS(218), 3,
      sym_float,
      sym_time,
      sym_frequency,
    ACTIONS(220), 3,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
    STATE(1454), 13,
      sym__expression,
      sym__parenthesized_expression,
      sym__path_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_assignment_expression,
      sym__literal,
      sym_address,
      sym_bitmask,
      sym_string,
      sym_character,
      sym_symbol,
      sym__special_command_operator,
  [13830] = 40,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(76), 1,
      anon_sym_BSLASH,
    ACTIONS(78), 1,
      anon_sym_SQUOTE,
    ACTIONS(80), 1,
      anon_sym_DQUOTE,
    ACTIONS(82), 1,
      sym_access_class,
    ACTIONS(90), 1,
      aux_sym_symbol_token1,
    ACTIONS(92), 1,
      aux_sym_symbol_token2,
    ACTIONS(98), 1,
      sym_path,
    ACTIONS(120), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(140), 1,
      sym_identifier,
    ACTIONS(167), 1,
      anon_sym_STAR,
    ACTIONS(169), 1,
      anon_sym_AMP,
    ACTIONS(177), 1,
      sym__decimal_number_pre_hook,
    ACTIONS(216), 1,
      anon_sym_LBRACE,
    ACTIONS(1135), 1,
      anon_sym_LPAREN,
    STATE(236), 1,
      sym_memory_space,
    STATE(967), 1,
      sym_macro,
    STATE(1034), 1,
      sym_call_expression,
    STATE(1035), 1,
      sym_integer,
    STATE(1049), 1,
      sym__hll_var_call_expression,
    STATE(1053), 1,
      aux_sym__path_expression_repeat2,
    STATE(1109), 1,
      sym__address_binary_expression,
    STATE(1218), 1,
      aux_sym__path_expression_repeat1,
    STATE(1399), 1,
      sym__unary_expression,
    STATE(1400), 1,
      sym__prefix_postfix_expression,
    STATE(1404), 1,
      sym__binary_expression,
    STATE(1406), 1,
      sym__and_expression,
    STATE(1412), 1,
      sym_trace32_hll_variable,
    STATE(1417), 1,
      sym__file_dialog,
    STATE(2257), 1,
      sym__function_identifier,
    STATE(2260), 1,
      sym__hll_var_call_expression_function,
    ACTIONS(60), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(62), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(88), 2,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
    ACTIONS(171), 2,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
    ACTIONS(222), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1039), 2,
      sym__address_expression,
      sym__parenthesized_address_expression,
    ACTIONS(218), 3,
      sym_float,
      sym_time,
      sym_frequency,
    ACTIONS(220), 3,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
    STATE(1454), 13,
      sym__expression,
      sym__parenthesized_expression,
      sym__path_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_assignment_expression,
      sym__literal,
      sym_address,
      sym_bitmask,
      sym_string,
      sym_character,
      sym_symbol,
      sym__special_command_operator,
  [13973] = 40,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(76), 1,
      anon_sym_BSLASH,
    ACTIONS(78), 1,
      anon_sym_SQUOTE,
    ACTIONS(80), 1,
      anon_sym_DQUOTE,
    ACTIONS(82), 1,
      sym_access_class,
    ACTIONS(90), 1,
      aux_sym_symbol_token1,
    ACTIONS(92), 1,
      aux_sym_symbol_token2,
    ACTIONS(98), 1,
      sym_path,
    ACTIONS(120), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(140), 1,
      sym_identifier,
    ACTIONS(167), 1,
      anon_sym_STAR,
    ACTIONS(169), 1,
      anon_sym_AMP,
    ACTIONS(177), 1,
      sym__decimal_number_pre_hook,
    ACTIONS(216), 1,
      anon_sym_LBRACE,
    ACTIONS(1135), 1,
      anon_sym_LPAREN,
    STATE(236), 1,
      sym_memory_space,
    STATE(967), 1,
      sym_macro,
    STATE(1034), 1,
      sym_call_expression,
    STATE(1035), 1,
      sym_integer,
    STATE(1049), 1,
      sym__hll_var_call_expression,
    STATE(1053), 1,
      aux_sym__path_expression_repeat2,
    STATE(1109), 1,
      sym__address_binary_expression,
    STATE(1218), 1,
      aux_sym__path_expression_repeat1,
    STATE(1399), 1,
      sym__unary_expression,
    STATE(1400), 1,
      sym__prefix_postfix_expression,
    STATE(1404), 1,
      sym__binary_expression,
    STATE(1406), 1,
      sym__and_expression,
    STATE(1412), 1,
      sym_trace32_hll_variable,
    STATE(1417), 1,
      sym__file_dialog,
    STATE(2257), 1,
      sym__function_identifier,
    STATE(2260), 1,
      sym__hll_var_call_expression_function,
    ACTIONS(60), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(62), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(88), 2,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
    ACTIONS(171), 2,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
    ACTIONS(222), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1041), 2,
      sym__address_expression,
      sym__parenthesized_address_expression,
    ACTIONS(218), 3,
      sym_float,
      sym_time,
      sym_frequency,
    ACTIONS(220), 3,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
    STATE(1454), 13,
      sym__expression,
      sym__parenthesized_expression,
      sym__path_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_assignment_expression,
      sym__literal,
      sym_address,
      sym_bitmask,
      sym_string,
      sym_character,
      sym_symbol,
      sym__special_command_operator,
  [14116] = 40,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(76), 1,
      anon_sym_BSLASH,
    ACTIONS(78), 1,
      anon_sym_SQUOTE,
    ACTIONS(80), 1,
      anon_sym_DQUOTE,
    ACTIONS(82), 1,
      sym_access_class,
    ACTIONS(90), 1,
      aux_sym_symbol_token1,
    ACTIONS(92), 1,
      aux_sym_symbol_token2,
    ACTIONS(98), 1,
      sym_path,
    ACTIONS(120), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(140), 1,
      sym_identifier,
    ACTIONS(167), 1,
      anon_sym_STAR,
    ACTIONS(169), 1,
      anon_sym_AMP,
    ACTIONS(177), 1,
      sym__decimal_number_pre_hook,
    ACTIONS(216), 1,
      anon_sym_LBRACE,
    ACTIONS(1135), 1,
      anon_sym_LPAREN,
    STATE(236), 1,
      sym_memory_space,
    STATE(967), 1,
      sym_macro,
    STATE(1034), 1,
      sym_call_expression,
    STATE(1035), 1,
      sym_integer,
    STATE(1049), 1,
      sym__hll_var_call_expression,
    STATE(1053), 1,
      aux_sym__path_expression_repeat2,
    STATE(1109), 1,
      sym__address_binary_expression,
    STATE(1218), 1,
      aux_sym__path_expression_repeat1,
    STATE(1399), 1,
      sym__unary_expression,
    STATE(1400), 1,
      sym__prefix_postfix_expression,
    STATE(1404), 1,
      sym__binary_expression,
    STATE(1406), 1,
      sym__and_expression,
    STATE(1412), 1,
      sym_trace32_hll_variable,
    STATE(1417), 1,
      sym__file_dialog,
    STATE(2257), 1,
      sym__function_identifier,
    STATE(2260), 1,
      sym__hll_var_call_expression_function,
    ACTIONS(60), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(62), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(88), 2,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
    ACTIONS(171), 2,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
    ACTIONS(222), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1042), 2,
      sym__address_expression,
      sym__parenthesized_address_expression,
    ACTIONS(218), 3,
      sym_float,
      sym_time,
      sym_frequency,
    ACTIONS(220), 3,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
    STATE(1454), 13,
      sym__expression,
      sym__parenthesized_expression,
      sym__path_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_assignment_expression,
      sym__literal,
      sym_address,
      sym_bitmask,
      sym_string,
      sym_character,
      sym_symbol,
      sym__special_command_operator,
  [14259] = 40,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(76), 1,
      anon_sym_BSLASH,
    ACTIONS(78), 1,
      anon_sym_SQUOTE,
    ACTIONS(80), 1,
      anon_sym_DQUOTE,
    ACTIONS(82), 1,
      sym_access_class,
    ACTIONS(90), 1,
      aux_sym_symbol_token1,
    ACTIONS(92), 1,
      aux_sym_symbol_token2,
    ACTIONS(98), 1,
      sym_path,
    ACTIONS(120), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(140), 1,
      sym_identifier,
    ACTIONS(167), 1,
      anon_sym_STAR,
    ACTIONS(169), 1,
      anon_sym_AMP,
    ACTIONS(177), 1,
      sym__decimal_number_pre_hook,
    ACTIONS(216), 1,
      anon_sym_LBRACE,
    ACTIONS(1135), 1,
      anon_sym_LPAREN,
    STATE(236), 1,
      sym_memory_space,
    STATE(967), 1,
      sym_macro,
    STATE(1034), 1,
      sym_call_expression,
    STATE(1035), 1,
      sym_integer,
    STATE(1049), 1,
      sym__hll_var_call_expression,
    STATE(1053), 1,
      aux_sym__path_expression_repeat2,
    STATE(1109), 1,
      sym__address_binary_expression,
    STATE(1218), 1,
      aux_sym__path_expression_repeat1,
    STATE(1399), 1,
      sym__unary_expression,
    STATE(1400), 1,
      sym__prefix_postfix_expression,
    STATE(1404), 1,
      sym__binary_expression,
    STATE(1406), 1,
      sym__and_expression,
    STATE(1412), 1,
      sym_trace32_hll_variable,
    STATE(1417), 1,
      sym__file_dialog,
    STATE(2257), 1,
      sym__function_identifier,
    STATE(2260), 1,
      sym__hll_var_call_expression_function,
    ACTIONS(60), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(62), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(88), 2,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
    ACTIONS(171), 2,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
    ACTIONS(222), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1044), 2,
      sym__address_expression,
      sym__parenthesized_address_expression,
    ACTIONS(218), 3,
      sym_float,
      sym_time,
      sym_frequency,
    ACTIONS(220), 3,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
    STATE(1454), 13,
      sym__expression,
      sym__parenthesized_expression,
      sym__path_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_assignment_expression,
      sym__literal,
      sym_address,
      sym_bitmask,
      sym_string,
      sym_character,
      sym_symbol,
      sym__special_command_operator,
  [14402] = 40,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(120), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(147), 1,
      anon_sym_AMP,
    ACTIONS(155), 1,
      sym__decimal_number_pre_hook,
    ACTIONS(179), 1,
      sym_identifier,
    ACTIONS(181), 1,
      anon_sym_LPAREN,
    ACTIONS(183), 1,
      anon_sym_LBRACE,
    ACTIONS(191), 1,
      anon_sym_STAR,
    ACTIONS(193), 1,
      anon_sym_BSLASH,
    ACTIONS(195), 1,
      anon_sym_SQUOTE,
    ACTIONS(197), 1,
      anon_sym_DQUOTE,
    ACTIONS(199), 1,
      sym_access_class,
    ACTIONS(205), 1,
      aux_sym_symbol_token1,
    ACTIONS(207), 1,
      aux_sym_symbol_token2,
    ACTIONS(211), 1,
      sym_path,
    STATE(228), 1,
      sym_memory_space,
    STATE(980), 1,
      sym_macro,
    STATE(1060), 1,
      sym_call_expression,
    STATE(1061), 1,
      sym__hll_var_call_expression,
    STATE(1080), 1,
      sym_integer,
    STATE(1100), 1,
      aux_sym__path_expression_repeat2,
    STATE(1172), 1,
      aux_sym__path_expression_repeat1,
    STATE(1371), 1,
      sym__and_expression,
    STATE(1374), 1,
      sym__file_dialog,
    STATE(1377), 1,
      sym_trace32_hll_variable,
    STATE(1378), 1,
      sym__unary_expression,
    STATE(1392), 1,
      sym__prefix_postfix_expression,
    STATE(1394), 1,
      sym__binary_expression,
    STATE(1550), 1,
      sym__address_binary_expression,
    STATE(2349), 1,
      sym__function_identifier,
    STATE(2359), 1,
      sym__hll_var_call_expression_function,
    ACTIONS(149), 2,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
    ACTIONS(185), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(187), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(189), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(203), 2,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
    STATE(1575), 2,
      sym__address_expression,
      sym__parenthesized_address_expression,
    ACTIONS(1137), 3,
      sym_float,
      sym_time,
      sym_frequency,
    ACTIONS(1139), 3,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
    STATE(1196), 13,
      sym__expression,
      sym__parenthesized_expression,
      sym__path_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_assignment_expression,
      sym__literal,
      sym_address,
      sym_bitmask,
      sym_string,
      sym_character,
      sym_symbol,
      sym__special_command_operator,
  [14545] = 40,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(120), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(147), 1,
      anon_sym_AMP,
    ACTIONS(155), 1,
      sym__decimal_number_pre_hook,
    ACTIONS(179), 1,
      sym_identifier,
    ACTIONS(181), 1,
      anon_sym_LPAREN,
    ACTIONS(183), 1,
      anon_sym_LBRACE,
    ACTIONS(191), 1,
      anon_sym_STAR,
    ACTIONS(193), 1,
      anon_sym_BSLASH,
    ACTIONS(195), 1,
      anon_sym_SQUOTE,
    ACTIONS(197), 1,
      anon_sym_DQUOTE,
    ACTIONS(199), 1,
      sym_access_class,
    ACTIONS(205), 1,
      aux_sym_symbol_token1,
    ACTIONS(207), 1,
      aux_sym_symbol_token2,
    ACTIONS(211), 1,
      sym_path,
    STATE(228), 1,
      sym_memory_space,
    STATE(980), 1,
      sym_macro,
    STATE(1060), 1,
      sym_call_expression,
    STATE(1061), 1,
      sym__hll_var_call_expression,
    STATE(1080), 1,
      sym_integer,
    STATE(1100), 1,
      aux_sym__path_expression_repeat2,
    STATE(1172), 1,
      aux_sym__path_expression_repeat1,
    STATE(1371), 1,
      sym__and_expression,
    STATE(1374), 1,
      sym__file_dialog,
    STATE(1377), 1,
      sym_trace32_hll_variable,
    STATE(1378), 1,
      sym__unary_expression,
    STATE(1392), 1,
      sym__prefix_postfix_expression,
    STATE(1394), 1,
      sym__binary_expression,
    STATE(1550), 1,
      sym__address_binary_expression,
    STATE(2349), 1,
      sym__function_identifier,
    STATE(2359), 1,
      sym__hll_var_call_expression_function,
    ACTIONS(149), 2,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
    ACTIONS(185), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(187), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(189), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(203), 2,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
    STATE(1575), 2,
      sym__address_expression,
      sym__parenthesized_address_expression,
    ACTIONS(1141), 3,
      sym_float,
      sym_time,
      sym_frequency,
    ACTIONS(1143), 3,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
    STATE(1208), 13,
      sym__expression,
      sym__parenthesized_expression,
      sym__path_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_assignment_expression,
      sym__literal,
      sym_address,
      sym_bitmask,
      sym_string,
      sym_character,
      sym_symbol,
      sym__special_command_operator,
  [14688] = 38,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(96), 1,
      sym__decimal_number_pre_hook,
    ACTIONS(100), 1,
      sym_identifier,
    ACTIONS(102), 1,
      anon_sym_LPAREN,
    ACTIONS(104), 1,
      anon_sym_LBRACE,
    ACTIONS(116), 1,
      anon_sym_STAR,
    ACTIONS(120), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(122), 1,
      anon_sym_BSLASH,
    ACTIONS(124), 1,
      anon_sym_SQUOTE,
    ACTIONS(126), 1,
      anon_sym_DQUOTE,
    ACTIONS(128), 1,
      sym_access_class,
    ACTIONS(134), 1,
      aux_sym_symbol_token1,
    ACTIONS(136), 1,
      aux_sym_symbol_token2,
    ACTIONS(695), 1,
      anon_sym_AMP,
    STATE(224), 1,
      sym_memory_space,
    STATE(328), 1,
      sym_macro,
    STATE(345), 1,
      sym__hll_var_call_expression,
    STATE(347), 1,
      sym_call_expression,
    STATE(350), 1,
      sym_integer,
    STATE(371), 1,
      aux_sym__path_expression_repeat1,
    STATE(450), 1,
      sym__unary_expression,
    STATE(451), 1,
      sym__prefix_postfix_expression,
    STATE(452), 1,
      sym__binary_expression,
    STATE(453), 1,
      sym__and_expression,
    STATE(457), 1,
      sym_trace32_hll_variable,
    STATE(459), 1,
      sym__file_dialog,
    STATE(1550), 1,
      sym__address_binary_expression,
    STATE(2354), 1,
      sym__function_identifier,
    STATE(2355), 1,
      sym__hll_var_call_expression_function,
    ACTIONS(84), 2,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
    ACTIONS(110), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(112), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(114), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(132), 2,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
    STATE(1575), 2,
      sym__address_expression,
      sym__parenthesized_address_expression,
    ACTIONS(1145), 3,
      sym_float,
      sym_time,
      sym_frequency,
    ACTIONS(1147), 4,
      sym_path,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
    STATE(385), 14,
      sym__expression,
      sym__parenthesized_expression,
      sym__path_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_assignment_expression,
      sym__literal,
      sym_address,
      sym_bitmask,
      sym_string,
      sym_character,
      sym_symbol,
      sym__special_command_operator,
      aux_sym__path_expression_repeat2,
  [14827] = 40,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(76), 1,
      anon_sym_BSLASH,
    ACTIONS(78), 1,
      anon_sym_SQUOTE,
    ACTIONS(80), 1,
      anon_sym_DQUOTE,
    ACTIONS(82), 1,
      sym_access_class,
    ACTIONS(90), 1,
      aux_sym_symbol_token1,
    ACTIONS(92), 1,
      aux_sym_symbol_token2,
    ACTIONS(98), 1,
      sym_path,
    ACTIONS(120), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(140), 1,
      sym_identifier,
    ACTIONS(157), 1,
      anon_sym_LPAREN,
    ACTIONS(159), 1,
      anon_sym_LBRACE,
    ACTIONS(167), 1,
      anon_sym_STAR,
    ACTIONS(169), 1,
      anon_sym_AMP,
    ACTIONS(177), 1,
      sym__decimal_number_pre_hook,
    STATE(236), 1,
      sym_memory_space,
    STATE(975), 1,
      sym_macro,
    STATE(1046), 1,
      sym_call_expression,
    STATE(1049), 1,
      sym__hll_var_call_expression,
    STATE(1052), 1,
      sym_integer,
    STATE(1053), 1,
      aux_sym__path_expression_repeat2,
    STATE(1218), 1,
      aux_sym__path_expression_repeat1,
    STATE(1399), 1,
      sym__unary_expression,
    STATE(1400), 1,
      sym__prefix_postfix_expression,
    STATE(1404), 1,
      sym__binary_expression,
    STATE(1406), 1,
      sym__and_expression,
    STATE(1412), 1,
      sym_trace32_hll_variable,
    STATE(1417), 1,
      sym__file_dialog,
    STATE(1550), 1,
      sym__address_binary_expression,
    STATE(2257), 1,
      sym__function_identifier,
    STATE(2260), 1,
      sym__hll_var_call_expression_function,
    ACTIONS(88), 2,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
    ACTIONS(161), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(163), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(165), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(171), 2,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
    STATE(1572), 2,
      sym__address_expression,
      sym__parenthesized_address_expression,
    ACTIONS(1149), 3,
      sym_float,
      sym_time,
      sym_frequency,
    ACTIONS(1151), 3,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
    STATE(1360), 13,
      sym__expression,
      sym__parenthesized_expression,
      sym__path_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_assignment_expression,
      sym__literal,
      sym_address,
      sym_bitmask,
      sym_string,
      sym_character,
      sym_symbol,
      sym__special_command_operator,
  [14970] = 40,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(76), 1,
      anon_sym_BSLASH,
    ACTIONS(78), 1,
      anon_sym_SQUOTE,
    ACTIONS(80), 1,
      anon_sym_DQUOTE,
    ACTIONS(82), 1,
      sym_access_class,
    ACTIONS(90), 1,
      aux_sym_symbol_token1,
    ACTIONS(92), 1,
      aux_sym_symbol_token2,
    ACTIONS(98), 1,
      sym_path,
    ACTIONS(120), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(140), 1,
      sym_identifier,
    ACTIONS(157), 1,
      anon_sym_LPAREN,
    ACTIONS(159), 1,
      anon_sym_LBRACE,
    ACTIONS(167), 1,
      anon_sym_STAR,
    ACTIONS(169), 1,
      anon_sym_AMP,
    ACTIONS(177), 1,
      sym__decimal_number_pre_hook,
    STATE(236), 1,
      sym_memory_space,
    STATE(975), 1,
      sym_macro,
    STATE(1046), 1,
      sym_call_expression,
    STATE(1049), 1,
      sym__hll_var_call_expression,
    STATE(1052), 1,
      sym_integer,
    STATE(1053), 1,
      aux_sym__path_expression_repeat2,
    STATE(1218), 1,
      aux_sym__path_expression_repeat1,
    STATE(1399), 1,
      sym__unary_expression,
    STATE(1400), 1,
      sym__prefix_postfix_expression,
    STATE(1404), 1,
      sym__binary_expression,
    STATE(1406), 1,
      sym__and_expression,
    STATE(1412), 1,
      sym_trace32_hll_variable,
    STATE(1417), 1,
      sym__file_dialog,
    STATE(1550), 1,
      sym__address_binary_expression,
    STATE(2257), 1,
      sym__function_identifier,
    STATE(2260), 1,
      sym__hll_var_call_expression_function,
    ACTIONS(88), 2,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
    ACTIONS(161), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(163), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(165), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(171), 2,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
    STATE(1557), 2,
      sym__address_expression,
      sym__parenthesized_address_expression,
    ACTIONS(1153), 3,
      sym_float,
      sym_time,
      sym_frequency,
    ACTIONS(1155), 3,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
    STATE(1361), 13,
      sym__expression,
      sym__parenthesized_expression,
      sym__path_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_assignment_expression,
      sym__literal,
      sym_address,
      sym_bitmask,
      sym_string,
      sym_character,
      sym_symbol,
      sym__special_command_operator,
  [15113] = 40,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(76), 1,
      anon_sym_BSLASH,
    ACTIONS(78), 1,
      anon_sym_SQUOTE,
    ACTIONS(80), 1,
      anon_sym_DQUOTE,
    ACTIONS(82), 1,
      sym_access_class,
    ACTIONS(90), 1,
      aux_sym_symbol_token1,
    ACTIONS(92), 1,
      aux_sym_symbol_token2,
    ACTIONS(98), 1,
      sym_path,
    ACTIONS(120), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(140), 1,
      sym_identifier,
    ACTIONS(145), 1,
      anon_sym_LBRACE,
    ACTIONS(147), 1,
      anon_sym_AMP,
    ACTIONS(155), 1,
      sym__decimal_number_pre_hook,
    ACTIONS(167), 1,
      anon_sym_STAR,
    ACTIONS(1127), 1,
      anon_sym_LPAREN,
    STATE(236), 1,
      sym_memory_space,
    STATE(972), 1,
      sym_macro,
    STATE(1053), 1,
      aux_sym__path_expression_repeat2,
    STATE(1061), 1,
      sym__hll_var_call_expression,
    STATE(1107), 1,
      sym__address_binary_expression,
    STATE(1108), 1,
      sym_call_expression,
    STATE(1110), 1,
      sym_integer,
    STATE(1218), 1,
      aux_sym__path_expression_repeat1,
    STATE(1399), 1,
      sym__unary_expression,
    STATE(1400), 1,
      sym__prefix_postfix_expression,
    STATE(1404), 1,
      sym__binary_expression,
    STATE(1406), 1,
      sym__and_expression,
    STATE(1412), 1,
      sym_trace32_hll_variable,
    STATE(1417), 1,
      sym__file_dialog,
    STATE(2349), 1,
      sym__function_identifier,
    STATE(2359), 1,
      sym__hll_var_call_expression_function,
    ACTIONS(60), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(62), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(88), 2,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
    ACTIONS(149), 2,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
    ACTIONS(222), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1128), 2,
      sym__address_expression,
      sym__parenthesized_address_expression,
    ACTIONS(151), 3,
      sym_float,
      sym_time,
      sym_frequency,
    ACTIONS(153), 3,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
    STATE(1501), 13,
      sym__expression,
      sym__parenthesized_expression,
      sym__path_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_assignment_expression,
      sym__literal,
      sym_address,
      sym_bitmask,
      sym_string,
      sym_character,
      sym_symbol,
      sym__special_command_operator,
  [15256] = 40,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(120), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(147), 1,
      anon_sym_AMP,
    ACTIONS(155), 1,
      sym__decimal_number_pre_hook,
    ACTIONS(179), 1,
      sym_identifier,
    ACTIONS(181), 1,
      anon_sym_LPAREN,
    ACTIONS(183), 1,
      anon_sym_LBRACE,
    ACTIONS(191), 1,
      anon_sym_STAR,
    ACTIONS(193), 1,
      anon_sym_BSLASH,
    ACTIONS(195), 1,
      anon_sym_SQUOTE,
    ACTIONS(197), 1,
      anon_sym_DQUOTE,
    ACTIONS(199), 1,
      sym_access_class,
    ACTIONS(205), 1,
      aux_sym_symbol_token1,
    ACTIONS(207), 1,
      aux_sym_symbol_token2,
    ACTIONS(211), 1,
      sym_path,
    STATE(228), 1,
      sym_memory_space,
    STATE(980), 1,
      sym_macro,
    STATE(1060), 1,
      sym_call_expression,
    STATE(1061), 1,
      sym__hll_var_call_expression,
    STATE(1080), 1,
      sym_integer,
    STATE(1100), 1,
      aux_sym__path_expression_repeat2,
    STATE(1172), 1,
      aux_sym__path_expression_repeat1,
    STATE(1371), 1,
      sym__and_expression,
    STATE(1374), 1,
      sym__file_dialog,
    STATE(1377), 1,
      sym_trace32_hll_variable,
    STATE(1378), 1,
      sym__unary_expression,
    STATE(1392), 1,
      sym__prefix_postfix_expression,
    STATE(1394), 1,
      sym__binary_expression,
    STATE(1550), 1,
      sym__address_binary_expression,
    STATE(2349), 1,
      sym__function_identifier,
    STATE(2359), 1,
      sym__hll_var_call_expression_function,
    ACTIONS(149), 2,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
    ACTIONS(185), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(187), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(189), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(203), 2,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
    STATE(1575), 2,
      sym__address_expression,
      sym__parenthesized_address_expression,
    ACTIONS(1157), 3,
      sym_float,
      sym_time,
      sym_frequency,
    ACTIONS(1159), 3,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
    STATE(1248), 13,
      sym__expression,
      sym__parenthesized_expression,
      sym__path_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_assignment_expression,
      sym__literal,
      sym_address,
      sym_bitmask,
      sym_string,
      sym_character,
      sym_symbol,
      sym__special_command_operator,
  [15399] = 40,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(76), 1,
      anon_sym_BSLASH,
    ACTIONS(78), 1,
      anon_sym_SQUOTE,
    ACTIONS(80), 1,
      anon_sym_DQUOTE,
    ACTIONS(82), 1,
      sym_access_class,
    ACTIONS(90), 1,
      aux_sym_symbol_token1,
    ACTIONS(92), 1,
      aux_sym_symbol_token2,
    ACTIONS(98), 1,
      sym_path,
    ACTIONS(120), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(140), 1,
      sym_identifier,
    ACTIONS(145), 1,
      anon_sym_LBRACE,
    ACTIONS(147), 1,
      anon_sym_AMP,
    ACTIONS(155), 1,
      sym__decimal_number_pre_hook,
    ACTIONS(167), 1,
      anon_sym_STAR,
    ACTIONS(1127), 1,
      anon_sym_LPAREN,
    STATE(236), 1,
      sym_memory_space,
    STATE(972), 1,
      sym_macro,
    STATE(1053), 1,
      aux_sym__path_expression_repeat2,
    STATE(1061), 1,
      sym__hll_var_call_expression,
    STATE(1107), 1,
      sym__address_binary_expression,
    STATE(1108), 1,
      sym_call_expression,
    STATE(1110), 1,
      sym_integer,
    STATE(1218), 1,
      aux_sym__path_expression_repeat1,
    STATE(1399), 1,
      sym__unary_expression,
    STATE(1400), 1,
      sym__prefix_postfix_expression,
    STATE(1404), 1,
      sym__binary_expression,
    STATE(1406), 1,
      sym__and_expression,
    STATE(1412), 1,
      sym_trace32_hll_variable,
    STATE(1417), 1,
      sym__file_dialog,
    STATE(2349), 1,
      sym__function_identifier,
    STATE(2359), 1,
      sym__hll_var_call_expression_function,
    ACTIONS(60), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(62), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(88), 2,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
    ACTIONS(149), 2,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
    ACTIONS(222), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1130), 2,
      sym__address_expression,
      sym__parenthesized_address_expression,
    ACTIONS(151), 3,
      sym_float,
      sym_time,
      sym_frequency,
    ACTIONS(153), 3,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
    STATE(1501), 13,
      sym__expression,
      sym__parenthesized_expression,
      sym__path_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_assignment_expression,
      sym__literal,
      sym_address,
      sym_bitmask,
      sym_string,
      sym_character,
      sym_symbol,
      sym__special_command_operator,
  [15542] = 40,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(120), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(147), 1,
      anon_sym_AMP,
    ACTIONS(155), 1,
      sym__decimal_number_pre_hook,
    ACTIONS(179), 1,
      sym_identifier,
    ACTIONS(181), 1,
      anon_sym_LPAREN,
    ACTIONS(183), 1,
      anon_sym_LBRACE,
    ACTIONS(191), 1,
      anon_sym_STAR,
    ACTIONS(193), 1,
      anon_sym_BSLASH,
    ACTIONS(195), 1,
      anon_sym_SQUOTE,
    ACTIONS(197), 1,
      anon_sym_DQUOTE,
    ACTIONS(199), 1,
      sym_access_class,
    ACTIONS(205), 1,
      aux_sym_symbol_token1,
    ACTIONS(207), 1,
      aux_sym_symbol_token2,
    ACTIONS(211), 1,
      sym_path,
    STATE(228), 1,
      sym_memory_space,
    STATE(980), 1,
      sym_macro,
    STATE(1060), 1,
      sym_call_expression,
    STATE(1061), 1,
      sym__hll_var_call_expression,
    STATE(1080), 1,
      sym_integer,
    STATE(1100), 1,
      aux_sym__path_expression_repeat2,
    STATE(1172), 1,
      aux_sym__path_expression_repeat1,
    STATE(1371), 1,
      sym__and_expression,
    STATE(1374), 1,
      sym__file_dialog,
    STATE(1377), 1,
      sym_trace32_hll_variable,
    STATE(1378), 1,
      sym__unary_expression,
    STATE(1392), 1,
      sym__prefix_postfix_expression,
    STATE(1394), 1,
      sym__binary_expression,
    STATE(1550), 1,
      sym__address_binary_expression,
    STATE(2349), 1,
      sym__function_identifier,
    STATE(2359), 1,
      sym__hll_var_call_expression_function,
    ACTIONS(149), 2,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
    ACTIONS(185), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(187), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(189), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(203), 2,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
    STATE(1575), 2,
      sym__address_expression,
      sym__parenthesized_address_expression,
    ACTIONS(1161), 3,
      sym_float,
      sym_time,
      sym_frequency,
    ACTIONS(1163), 3,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
    STATE(1251), 13,
      sym__expression,
      sym__parenthesized_expression,
      sym__path_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_assignment_expression,
      sym__literal,
      sym_address,
      sym_bitmask,
      sym_string,
      sym_character,
      sym_symbol,
      sym__special_command_operator,
  [15685] = 40,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(76), 1,
      anon_sym_BSLASH,
    ACTIONS(78), 1,
      anon_sym_SQUOTE,
    ACTIONS(80), 1,
      anon_sym_DQUOTE,
    ACTIONS(82), 1,
      sym_access_class,
    ACTIONS(90), 1,
      aux_sym_symbol_token1,
    ACTIONS(92), 1,
      aux_sym_symbol_token2,
    ACTIONS(98), 1,
      sym_path,
    ACTIONS(120), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(140), 1,
      sym_identifier,
    ACTIONS(145), 1,
      anon_sym_LBRACE,
    ACTIONS(147), 1,
      anon_sym_AMP,
    ACTIONS(155), 1,
      sym__decimal_number_pre_hook,
    ACTIONS(167), 1,
      anon_sym_STAR,
    ACTIONS(1127), 1,
      anon_sym_LPAREN,
    STATE(236), 1,
      sym_memory_space,
    STATE(972), 1,
      sym_macro,
    STATE(1053), 1,
      aux_sym__path_expression_repeat2,
    STATE(1061), 1,
      sym__hll_var_call_expression,
    STATE(1107), 1,
      sym__address_binary_expression,
    STATE(1108), 1,
      sym_call_expression,
    STATE(1110), 1,
      sym_integer,
    STATE(1218), 1,
      aux_sym__path_expression_repeat1,
    STATE(1399), 1,
      sym__unary_expression,
    STATE(1400), 1,
      sym__prefix_postfix_expression,
    STATE(1404), 1,
      sym__binary_expression,
    STATE(1406), 1,
      sym__and_expression,
    STATE(1412), 1,
      sym_trace32_hll_variable,
    STATE(1417), 1,
      sym__file_dialog,
    STATE(2349), 1,
      sym__function_identifier,
    STATE(2359), 1,
      sym__hll_var_call_expression_function,
    ACTIONS(60), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(62), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(88), 2,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
    ACTIONS(149), 2,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
    ACTIONS(222), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1129), 2,
      sym__address_expression,
      sym__parenthesized_address_expression,
    ACTIONS(151), 3,
      sym_float,
      sym_time,
      sym_frequency,
    ACTIONS(153), 3,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
    STATE(1501), 13,
      sym__expression,
      sym__parenthesized_expression,
      sym__path_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_assignment_expression,
      sym__literal,
      sym_address,
      sym_bitmask,
      sym_string,
      sym_character,
      sym_symbol,
      sym__special_command_operator,
  [15828] = 38,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(96), 1,
      sym__decimal_number_pre_hook,
    ACTIONS(100), 1,
      sym_identifier,
    ACTIONS(102), 1,
      anon_sym_LPAREN,
    ACTIONS(104), 1,
      anon_sym_LBRACE,
    ACTIONS(116), 1,
      anon_sym_STAR,
    ACTIONS(120), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(122), 1,
      anon_sym_BSLASH,
    ACTIONS(124), 1,
      anon_sym_SQUOTE,
    ACTIONS(126), 1,
      anon_sym_DQUOTE,
    ACTIONS(128), 1,
      sym_access_class,
    ACTIONS(134), 1,
      aux_sym_symbol_token1,
    ACTIONS(136), 1,
      aux_sym_symbol_token2,
    ACTIONS(695), 1,
      anon_sym_AMP,
    STATE(224), 1,
      sym_memory_space,
    STATE(328), 1,
      sym_macro,
    STATE(345), 1,
      sym__hll_var_call_expression,
    STATE(347), 1,
      sym_call_expression,
    STATE(350), 1,
      sym_integer,
    STATE(371), 1,
      aux_sym__path_expression_repeat1,
    STATE(450), 1,
      sym__unary_expression,
    STATE(451), 1,
      sym__prefix_postfix_expression,
    STATE(452), 1,
      sym__binary_expression,
    STATE(453), 1,
      sym__and_expression,
    STATE(457), 1,
      sym_trace32_hll_variable,
    STATE(459), 1,
      sym__file_dialog,
    STATE(1550), 1,
      sym__address_binary_expression,
    STATE(2354), 1,
      sym__function_identifier,
    STATE(2355), 1,
      sym__hll_var_call_expression_function,
    ACTIONS(84), 2,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
    ACTIONS(110), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(112), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(114), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(132), 2,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
    STATE(1575), 2,
      sym__address_expression,
      sym__parenthesized_address_expression,
    ACTIONS(1165), 3,
      sym_float,
      sym_time,
      sym_frequency,
    ACTIONS(1167), 4,
      sym_path,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
    STATE(379), 14,
      sym__expression,
      sym__parenthesized_expression,
      sym__path_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_assignment_expression,
      sym__literal,
      sym_address,
      sym_bitmask,
      sym_string,
      sym_character,
      sym_symbol,
      sym__special_command_operator,
      aux_sym__path_expression_repeat2,
  [15967] = 40,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(120), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(147), 1,
      anon_sym_AMP,
    ACTIONS(155), 1,
      sym__decimal_number_pre_hook,
    ACTIONS(179), 1,
      sym_identifier,
    ACTIONS(181), 1,
      anon_sym_LPAREN,
    ACTIONS(183), 1,
      anon_sym_LBRACE,
    ACTIONS(191), 1,
      anon_sym_STAR,
    ACTIONS(193), 1,
      anon_sym_BSLASH,
    ACTIONS(195), 1,
      anon_sym_SQUOTE,
    ACTIONS(197), 1,
      anon_sym_DQUOTE,
    ACTIONS(199), 1,
      sym_access_class,
    ACTIONS(205), 1,
      aux_sym_symbol_token1,
    ACTIONS(207), 1,
      aux_sym_symbol_token2,
    ACTIONS(211), 1,
      sym_path,
    STATE(228), 1,
      sym_memory_space,
    STATE(980), 1,
      sym_macro,
    STATE(1060), 1,
      sym_call_expression,
    STATE(1061), 1,
      sym__hll_var_call_expression,
    STATE(1080), 1,
      sym_integer,
    STATE(1100), 1,
      aux_sym__path_expression_repeat2,
    STATE(1172), 1,
      aux_sym__path_expression_repeat1,
    STATE(1371), 1,
      sym__and_expression,
    STATE(1374), 1,
      sym__file_dialog,
    STATE(1377), 1,
      sym_trace32_hll_variable,
    STATE(1378), 1,
      sym__unary_expression,
    STATE(1392), 1,
      sym__prefix_postfix_expression,
    STATE(1394), 1,
      sym__binary_expression,
    STATE(1550), 1,
      sym__address_binary_expression,
    STATE(2349), 1,
      sym__function_identifier,
    STATE(2359), 1,
      sym__hll_var_call_expression_function,
    ACTIONS(149), 2,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
    ACTIONS(185), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(187), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(189), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(203), 2,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
    STATE(1575), 2,
      sym__address_expression,
      sym__parenthesized_address_expression,
    ACTIONS(1169), 3,
      sym_float,
      sym_time,
      sym_frequency,
    ACTIONS(1171), 3,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
    STATE(1163), 13,
      sym__expression,
      sym__parenthesized_expression,
      sym__path_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_assignment_expression,
      sym__literal,
      sym_address,
      sym_bitmask,
      sym_string,
      sym_character,
      sym_symbol,
      sym__special_command_operator,
  [16110] = 40,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1173), 1,
      sym_identifier,
    ACTIONS(1177), 1,
      anon_sym_LPAREN,
    ACTIONS(1181), 1,
      anon_sym_LBRACE,
    ACTIONS(1197), 1,
      anon_sym_STAR,
    ACTIONS(1201), 1,
      anon_sym_AMP,
    ACTIONS(1205), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(1209), 1,
      anon_sym_BSLASH,
    ACTIONS(1213), 1,
      anon_sym_SQUOTE,
    ACTIONS(1217), 1,
      anon_sym_DQUOTE,
    ACTIONS(1221), 1,
      sym_access_class,
    ACTIONS(1237), 1,
      aux_sym_symbol_token1,
    ACTIONS(1241), 1,
      aux_sym_symbol_token2,
    ACTIONS(1249), 1,
      sym__decimal_number_pre_hook,
    ACTIONS(1253), 1,
      sym_path,
    STATE(236), 1,
      sym_memory_space,
    STATE(975), 1,
      sym_macro,
    STATE(1046), 1,
      sym_call_expression,
    STATE(1049), 1,
      sym__hll_var_call_expression,
    STATE(1052), 1,
      sym_integer,
    STATE(1053), 1,
      aux_sym__path_expression_repeat2,
    STATE(1218), 1,
      aux_sym__path_expression_repeat1,
    STATE(1399), 1,
      sym__unary_expression,
    STATE(1400), 1,
      sym__prefix_postfix_expression,
    STATE(1404), 1,
      sym__binary_expression,
    STATE(1406), 1,
      sym__and_expression,
    STATE(1412), 1,
      sym_trace32_hll_variable,
    STATE(1417), 1,
      sym__file_dialog,
    STATE(1550), 1,
      sym__address_binary_expression,
    STATE(2257), 1,
      sym__function_identifier,
    STATE(2260), 1,
      sym__hll_var_call_expression_function,
    ACTIONS(1185), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1189), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(1193), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1225), 2,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
    ACTIONS(1233), 2,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
    STATE(1650), 2,
      sym__address_expression,
      sym__parenthesized_address_expression,
    ACTIONS(1229), 3,
      sym_float,
      sym_time,
      sym_frequency,
    ACTIONS(1245), 3,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
    STATE(1454), 13,
      sym__expression,
      sym__parenthesized_expression,
      sym__path_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_assignment_expression,
      sym__literal,
      sym_address,
      sym_bitmask,
      sym_string,
      sym_character,
      sym_symbol,
      sym__special_command_operator,
  [16253] = 40,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(76), 1,
      anon_sym_BSLASH,
    ACTIONS(78), 1,
      anon_sym_SQUOTE,
    ACTIONS(80), 1,
      anon_sym_DQUOTE,
    ACTIONS(82), 1,
      sym_access_class,
    ACTIONS(90), 1,
      aux_sym_symbol_token1,
    ACTIONS(92), 1,
      aux_sym_symbol_token2,
    ACTIONS(98), 1,
      sym_path,
    ACTIONS(120), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(140), 1,
      sym_identifier,
    ACTIONS(157), 1,
      anon_sym_LPAREN,
    ACTIONS(159), 1,
      anon_sym_LBRACE,
    ACTIONS(167), 1,
      anon_sym_STAR,
    ACTIONS(169), 1,
      anon_sym_AMP,
    ACTIONS(177), 1,
      sym__decimal_number_pre_hook,
    STATE(236), 1,
      sym_memory_space,
    STATE(975), 1,
      sym_macro,
    STATE(1046), 1,
      sym_call_expression,
    STATE(1049), 1,
      sym__hll_var_call_expression,
    STATE(1052), 1,
      sym_integer,
    STATE(1053), 1,
      aux_sym__path_expression_repeat2,
    STATE(1218), 1,
      aux_sym__path_expression_repeat1,
    STATE(1399), 1,
      sym__unary_expression,
    STATE(1400), 1,
      sym__prefix_postfix_expression,
    STATE(1404), 1,
      sym__binary_expression,
    STATE(1406), 1,
      sym__and_expression,
    STATE(1412), 1,
      sym_trace32_hll_variable,
    STATE(1417), 1,
      sym__file_dialog,
    STATE(1550), 1,
      sym__address_binary_expression,
    STATE(2257), 1,
      sym__function_identifier,
    STATE(2260), 1,
      sym__hll_var_call_expression_function,
    ACTIONS(88), 2,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
    ACTIONS(161), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(163), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(165), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(171), 2,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
    STATE(1572), 2,
      sym__address_expression,
      sym__parenthesized_address_expression,
    ACTIONS(1257), 3,
      sym_float,
      sym_time,
      sym_frequency,
    ACTIONS(1259), 3,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
    STATE(1426), 13,
      sym__expression,
      sym__parenthesized_expression,
      sym__path_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_assignment_expression,
      sym__literal,
      sym_address,
      sym_bitmask,
      sym_string,
      sym_character,
      sym_symbol,
      sym__special_command_operator,
  [16396] = 40,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(76), 1,
      anon_sym_BSLASH,
    ACTIONS(78), 1,
      anon_sym_SQUOTE,
    ACTIONS(80), 1,
      anon_sym_DQUOTE,
    ACTIONS(82), 1,
      sym_access_class,
    ACTIONS(90), 1,
      aux_sym_symbol_token1,
    ACTIONS(92), 1,
      aux_sym_symbol_token2,
    ACTIONS(98), 1,
      sym_path,
    ACTIONS(120), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(140), 1,
      sym_identifier,
    ACTIONS(157), 1,
      anon_sym_LPAREN,
    ACTIONS(159), 1,
      anon_sym_LBRACE,
    ACTIONS(167), 1,
      anon_sym_STAR,
    ACTIONS(169), 1,
      anon_sym_AMP,
    ACTIONS(177), 1,
      sym__decimal_number_pre_hook,
    STATE(236), 1,
      sym_memory_space,
    STATE(975), 1,
      sym_macro,
    STATE(1046), 1,
      sym_call_expression,
    STATE(1049), 1,
      sym__hll_var_call_expression,
    STATE(1052), 1,
      sym_integer,
    STATE(1053), 1,
      aux_sym__path_expression_repeat2,
    STATE(1218), 1,
      aux_sym__path_expression_repeat1,
    STATE(1399), 1,
      sym__unary_expression,
    STATE(1400), 1,
      sym__prefix_postfix_expression,
    STATE(1404), 1,
      sym__binary_expression,
    STATE(1406), 1,
      sym__and_expression,
    STATE(1412), 1,
      sym_trace32_hll_variable,
    STATE(1417), 1,
      sym__file_dialog,
    STATE(1550), 1,
      sym__address_binary_expression,
    STATE(2257), 1,
      sym__function_identifier,
    STATE(2260), 1,
      sym__hll_var_call_expression_function,
    ACTIONS(88), 2,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
    ACTIONS(161), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(163), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(165), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(171), 2,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
    STATE(1557), 2,
      sym__address_expression,
      sym__parenthesized_address_expression,
    ACTIONS(1261), 3,
      sym_float,
      sym_time,
      sym_frequency,
    ACTIONS(1263), 3,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
    STATE(1427), 13,
      sym__expression,
      sym__parenthesized_expression,
      sym__path_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_assignment_expression,
      sym__literal,
      sym_address,
      sym_bitmask,
      sym_string,
      sym_character,
      sym_symbol,
      sym__special_command_operator,
  [16539] = 40,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(120), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(147), 1,
      anon_sym_AMP,
    ACTIONS(155), 1,
      sym__decimal_number_pre_hook,
    ACTIONS(179), 1,
      sym_identifier,
    ACTIONS(181), 1,
      anon_sym_LPAREN,
    ACTIONS(183), 1,
      anon_sym_LBRACE,
    ACTIONS(191), 1,
      anon_sym_STAR,
    ACTIONS(193), 1,
      anon_sym_BSLASH,
    ACTIONS(195), 1,
      anon_sym_SQUOTE,
    ACTIONS(197), 1,
      anon_sym_DQUOTE,
    ACTIONS(199), 1,
      sym_access_class,
    ACTIONS(205), 1,
      aux_sym_symbol_token1,
    ACTIONS(207), 1,
      aux_sym_symbol_token2,
    ACTIONS(211), 1,
      sym_path,
    STATE(228), 1,
      sym_memory_space,
    STATE(980), 1,
      sym_macro,
    STATE(1060), 1,
      sym_call_expression,
    STATE(1061), 1,
      sym__hll_var_call_expression,
    STATE(1080), 1,
      sym_integer,
    STATE(1100), 1,
      aux_sym__path_expression_repeat2,
    STATE(1172), 1,
      aux_sym__path_expression_repeat1,
    STATE(1371), 1,
      sym__and_expression,
    STATE(1374), 1,
      sym__file_dialog,
    STATE(1377), 1,
      sym_trace32_hll_variable,
    STATE(1378), 1,
      sym__unary_expression,
    STATE(1392), 1,
      sym__prefix_postfix_expression,
    STATE(1394), 1,
      sym__binary_expression,
    STATE(1550), 1,
      sym__address_binary_expression,
    STATE(2349), 1,
      sym__function_identifier,
    STATE(2359), 1,
      sym__hll_var_call_expression_function,
    ACTIONS(149), 2,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
    ACTIONS(185), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(187), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(189), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(203), 2,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
    STATE(1575), 2,
      sym__address_expression,
      sym__parenthesized_address_expression,
    ACTIONS(1265), 3,
      sym_float,
      sym_time,
      sym_frequency,
    ACTIONS(1267), 3,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
    STATE(1228), 13,
      sym__expression,
      sym__parenthesized_expression,
      sym__path_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_assignment_expression,
      sym__literal,
      sym_address,
      sym_bitmask,
      sym_string,
      sym_character,
      sym_symbol,
      sym__special_command_operator,
  [16682] = 40,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(120), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(147), 1,
      anon_sym_AMP,
    ACTIONS(155), 1,
      sym__decimal_number_pre_hook,
    ACTIONS(179), 1,
      sym_identifier,
    ACTIONS(181), 1,
      anon_sym_LPAREN,
    ACTIONS(183), 1,
      anon_sym_LBRACE,
    ACTIONS(191), 1,
      anon_sym_STAR,
    ACTIONS(193), 1,
      anon_sym_BSLASH,
    ACTIONS(195), 1,
      anon_sym_SQUOTE,
    ACTIONS(197), 1,
      anon_sym_DQUOTE,
    ACTIONS(199), 1,
      sym_access_class,
    ACTIONS(205), 1,
      aux_sym_symbol_token1,
    ACTIONS(207), 1,
      aux_sym_symbol_token2,
    ACTIONS(211), 1,
      sym_path,
    STATE(228), 1,
      sym_memory_space,
    STATE(980), 1,
      sym_macro,
    STATE(1060), 1,
      sym_call_expression,
    STATE(1061), 1,
      sym__hll_var_call_expression,
    STATE(1080), 1,
      sym_integer,
    STATE(1100), 1,
      aux_sym__path_expression_repeat2,
    STATE(1172), 1,
      aux_sym__path_expression_repeat1,
    STATE(1371), 1,
      sym__and_expression,
    STATE(1374), 1,
      sym__file_dialog,
    STATE(1377), 1,
      sym_trace32_hll_variable,
    STATE(1378), 1,
      sym__unary_expression,
    STATE(1392), 1,
      sym__prefix_postfix_expression,
    STATE(1394), 1,
      sym__binary_expression,
    STATE(1550), 1,
      sym__address_binary_expression,
    STATE(2349), 1,
      sym__function_identifier,
    STATE(2359), 1,
      sym__hll_var_call_expression_function,
    ACTIONS(149), 2,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
    ACTIONS(185), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(187), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(189), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(203), 2,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
    STATE(1575), 2,
      sym__address_expression,
      sym__parenthesized_address_expression,
    ACTIONS(1269), 3,
      sym_float,
      sym_time,
      sym_frequency,
    ACTIONS(1271), 3,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
    STATE(1149), 13,
      sym__expression,
      sym__parenthesized_expression,
      sym__path_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_assignment_expression,
      sym__literal,
      sym_address,
      sym_bitmask,
      sym_string,
      sym_character,
      sym_symbol,
      sym__special_command_operator,
  [16825] = 40,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(120), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(147), 1,
      anon_sym_AMP,
    ACTIONS(155), 1,
      sym__decimal_number_pre_hook,
    ACTIONS(179), 1,
      sym_identifier,
    ACTIONS(181), 1,
      anon_sym_LPAREN,
    ACTIONS(183), 1,
      anon_sym_LBRACE,
    ACTIONS(191), 1,
      anon_sym_STAR,
    ACTIONS(193), 1,
      anon_sym_BSLASH,
    ACTIONS(195), 1,
      anon_sym_SQUOTE,
    ACTIONS(197), 1,
      anon_sym_DQUOTE,
    ACTIONS(199), 1,
      sym_access_class,
    ACTIONS(205), 1,
      aux_sym_symbol_token1,
    ACTIONS(207), 1,
      aux_sym_symbol_token2,
    ACTIONS(211), 1,
      sym_path,
    STATE(228), 1,
      sym_memory_space,
    STATE(980), 1,
      sym_macro,
    STATE(1060), 1,
      sym_call_expression,
    STATE(1061), 1,
      sym__hll_var_call_expression,
    STATE(1080), 1,
      sym_integer,
    STATE(1100), 1,
      aux_sym__path_expression_repeat2,
    STATE(1172), 1,
      aux_sym__path_expression_repeat1,
    STATE(1371), 1,
      sym__and_expression,
    STATE(1374), 1,
      sym__file_dialog,
    STATE(1377), 1,
      sym_trace32_hll_variable,
    STATE(1378), 1,
      sym__unary_expression,
    STATE(1392), 1,
      sym__prefix_postfix_expression,
    STATE(1394), 1,
      sym__binary_expression,
    STATE(1550), 1,
      sym__address_binary_expression,
    STATE(2349), 1,
      sym__function_identifier,
    STATE(2359), 1,
      sym__hll_var_call_expression_function,
    ACTIONS(149), 2,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
    ACTIONS(185), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(187), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(189), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(203), 2,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
    STATE(1575), 2,
      sym__address_expression,
      sym__parenthesized_address_expression,
    ACTIONS(1273), 3,
      sym_float,
      sym_time,
      sym_frequency,
    ACTIONS(1275), 3,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
    STATE(1157), 13,
      sym__expression,
      sym__parenthesized_expression,
      sym__path_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_assignment_expression,
      sym__literal,
      sym_address,
      sym_bitmask,
      sym_string,
      sym_character,
      sym_symbol,
      sym__special_command_operator,
  [16968] = 40,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(120), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(147), 1,
      anon_sym_AMP,
    ACTIONS(155), 1,
      sym__decimal_number_pre_hook,
    ACTIONS(179), 1,
      sym_identifier,
    ACTIONS(181), 1,
      anon_sym_LPAREN,
    ACTIONS(183), 1,
      anon_sym_LBRACE,
    ACTIONS(191), 1,
      anon_sym_STAR,
    ACTIONS(193), 1,
      anon_sym_BSLASH,
    ACTIONS(195), 1,
      anon_sym_SQUOTE,
    ACTIONS(197), 1,
      anon_sym_DQUOTE,
    ACTIONS(199), 1,
      sym_access_class,
    ACTIONS(205), 1,
      aux_sym_symbol_token1,
    ACTIONS(207), 1,
      aux_sym_symbol_token2,
    ACTIONS(211), 1,
      sym_path,
    STATE(228), 1,
      sym_memory_space,
    STATE(980), 1,
      sym_macro,
    STATE(1060), 1,
      sym_call_expression,
    STATE(1061), 1,
      sym__hll_var_call_expression,
    STATE(1080), 1,
      sym_integer,
    STATE(1100), 1,
      aux_sym__path_expression_repeat2,
    STATE(1172), 1,
      aux_sym__path_expression_repeat1,
    STATE(1371), 1,
      sym__and_expression,
    STATE(1374), 1,
      sym__file_dialog,
    STATE(1377), 1,
      sym_trace32_hll_variable,
    STATE(1378), 1,
      sym__unary_expression,
    STATE(1392), 1,
      sym__prefix_postfix_expression,
    STATE(1394), 1,
      sym__binary_expression,
    STATE(1550), 1,
      sym__address_binary_expression,
    STATE(2349), 1,
      sym__function_identifier,
    STATE(2359), 1,
      sym__hll_var_call_expression_function,
    ACTIONS(149), 2,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
    ACTIONS(185), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(187), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(189), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(203), 2,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
    STATE(1575), 2,
      sym__address_expression,
      sym__parenthesized_address_expression,
    ACTIONS(1277), 3,
      sym_float,
      sym_time,
      sym_frequency,
    ACTIONS(1279), 3,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
    STATE(1170), 13,
      sym__expression,
      sym__parenthesized_expression,
      sym__path_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_assignment_expression,
      sym__literal,
      sym_address,
      sym_bitmask,
      sym_string,
      sym_character,
      sym_symbol,
      sym__special_command_operator,
  [17111] = 40,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(120), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(147), 1,
      anon_sym_AMP,
    ACTIONS(155), 1,
      sym__decimal_number_pre_hook,
    ACTIONS(179), 1,
      sym_identifier,
    ACTIONS(181), 1,
      anon_sym_LPAREN,
    ACTIONS(183), 1,
      anon_sym_LBRACE,
    ACTIONS(191), 1,
      anon_sym_STAR,
    ACTIONS(193), 1,
      anon_sym_BSLASH,
    ACTIONS(195), 1,
      anon_sym_SQUOTE,
    ACTIONS(197), 1,
      anon_sym_DQUOTE,
    ACTIONS(199), 1,
      sym_access_class,
    ACTIONS(205), 1,
      aux_sym_symbol_token1,
    ACTIONS(207), 1,
      aux_sym_symbol_token2,
    ACTIONS(211), 1,
      sym_path,
    STATE(228), 1,
      sym_memory_space,
    STATE(980), 1,
      sym_macro,
    STATE(1060), 1,
      sym_call_expression,
    STATE(1061), 1,
      sym__hll_var_call_expression,
    STATE(1080), 1,
      sym_integer,
    STATE(1100), 1,
      aux_sym__path_expression_repeat2,
    STATE(1172), 1,
      aux_sym__path_expression_repeat1,
    STATE(1371), 1,
      sym__and_expression,
    STATE(1374), 1,
      sym__file_dialog,
    STATE(1377), 1,
      sym_trace32_hll_variable,
    STATE(1378), 1,
      sym__unary_expression,
    STATE(1392), 1,
      sym__prefix_postfix_expression,
    STATE(1394), 1,
      sym__binary_expression,
    STATE(1550), 1,
      sym__address_binary_expression,
    STATE(2349), 1,
      sym__function_identifier,
    STATE(2359), 1,
      sym__hll_var_call_expression_function,
    ACTIONS(149), 2,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
    ACTIONS(185), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(187), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(189), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(203), 2,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
    STATE(1575), 2,
      sym__address_expression,
      sym__parenthesized_address_expression,
    ACTIONS(1281), 3,
      sym_float,
      sym_time,
      sym_frequency,
    ACTIONS(1283), 3,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
    STATE(1239), 13,
      sym__expression,
      sym__parenthesized_expression,
      sym__path_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_assignment_expression,
      sym__literal,
      sym_address,
      sym_bitmask,
      sym_string,
      sym_character,
      sym_symbol,
      sym__special_command_operator,
  [17254] = 40,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(120), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(147), 1,
      anon_sym_AMP,
    ACTIONS(155), 1,
      sym__decimal_number_pre_hook,
    ACTIONS(179), 1,
      sym_identifier,
    ACTIONS(181), 1,
      anon_sym_LPAREN,
    ACTIONS(183), 1,
      anon_sym_LBRACE,
    ACTIONS(191), 1,
      anon_sym_STAR,
    ACTIONS(193), 1,
      anon_sym_BSLASH,
    ACTIONS(195), 1,
      anon_sym_SQUOTE,
    ACTIONS(197), 1,
      anon_sym_DQUOTE,
    ACTIONS(199), 1,
      sym_access_class,
    ACTIONS(205), 1,
      aux_sym_symbol_token1,
    ACTIONS(207), 1,
      aux_sym_symbol_token2,
    ACTIONS(211), 1,
      sym_path,
    STATE(228), 1,
      sym_memory_space,
    STATE(980), 1,
      sym_macro,
    STATE(1060), 1,
      sym_call_expression,
    STATE(1061), 1,
      sym__hll_var_call_expression,
    STATE(1080), 1,
      sym_integer,
    STATE(1100), 1,
      aux_sym__path_expression_repeat2,
    STATE(1172), 1,
      aux_sym__path_expression_repeat1,
    STATE(1371), 1,
      sym__and_expression,
    STATE(1374), 1,
      sym__file_dialog,
    STATE(1377), 1,
      sym_trace32_hll_variable,
    STATE(1378), 1,
      sym__unary_expression,
    STATE(1392), 1,
      sym__prefix_postfix_expression,
    STATE(1394), 1,
      sym__binary_expression,
    STATE(1550), 1,
      sym__address_binary_expression,
    STATE(2349), 1,
      sym__function_identifier,
    STATE(2359), 1,
      sym__hll_var_call_expression_function,
    ACTIONS(149), 2,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
    ACTIONS(185), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(187), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(189), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(203), 2,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
    STATE(1575), 2,
      sym__address_expression,
      sym__parenthesized_address_expression,
    ACTIONS(1285), 3,
      sym_float,
      sym_time,
      sym_frequency,
    ACTIONS(1287), 3,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
    STATE(1245), 13,
      sym__expression,
      sym__parenthesized_expression,
      sym__path_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_assignment_expression,
      sym__literal,
      sym_address,
      sym_bitmask,
      sym_string,
      sym_character,
      sym_symbol,
      sym__special_command_operator,
  [17397] = 40,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(76), 1,
      anon_sym_BSLASH,
    ACTIONS(78), 1,
      anon_sym_SQUOTE,
    ACTIONS(80), 1,
      anon_sym_DQUOTE,
    ACTIONS(82), 1,
      sym_access_class,
    ACTIONS(90), 1,
      aux_sym_symbol_token1,
    ACTIONS(92), 1,
      aux_sym_symbol_token2,
    ACTIONS(98), 1,
      sym_path,
    ACTIONS(120), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(140), 1,
      sym_identifier,
    ACTIONS(157), 1,
      anon_sym_LPAREN,
    ACTIONS(159), 1,
      anon_sym_LBRACE,
    ACTIONS(167), 1,
      anon_sym_STAR,
    ACTIONS(169), 1,
      anon_sym_AMP,
    ACTIONS(177), 1,
      sym__decimal_number_pre_hook,
    STATE(236), 1,
      sym_memory_space,
    STATE(975), 1,
      sym_macro,
    STATE(1046), 1,
      sym_call_expression,
    STATE(1049), 1,
      sym__hll_var_call_expression,
    STATE(1052), 1,
      sym_integer,
    STATE(1053), 1,
      aux_sym__path_expression_repeat2,
    STATE(1218), 1,
      aux_sym__path_expression_repeat1,
    STATE(1399), 1,
      sym__unary_expression,
    STATE(1400), 1,
      sym__prefix_postfix_expression,
    STATE(1404), 1,
      sym__binary_expression,
    STATE(1406), 1,
      sym__and_expression,
    STATE(1412), 1,
      sym_trace32_hll_variable,
    STATE(1417), 1,
      sym__file_dialog,
    STATE(1550), 1,
      sym__address_binary_expression,
    STATE(2257), 1,
      sym__function_identifier,
    STATE(2260), 1,
      sym__hll_var_call_expression_function,
    ACTIONS(88), 2,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
    ACTIONS(161), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(163), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(165), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(171), 2,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
    STATE(1568), 2,
      sym__address_expression,
      sym__parenthesized_address_expression,
    ACTIONS(1257), 3,
      sym_float,
      sym_time,
      sym_frequency,
    ACTIONS(1259), 3,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
    STATE(1426), 13,
      sym__expression,
      sym__parenthesized_expression,
      sym__path_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_assignment_expression,
      sym__literal,
      sym_address,
      sym_bitmask,
      sym_string,
      sym_character,
      sym_symbol,
      sym__special_command_operator,
  [17540] = 40,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(76), 1,
      anon_sym_BSLASH,
    ACTIONS(78), 1,
      anon_sym_SQUOTE,
    ACTIONS(80), 1,
      anon_sym_DQUOTE,
    ACTIONS(82), 1,
      sym_access_class,
    ACTIONS(90), 1,
      aux_sym_symbol_token1,
    ACTIONS(92), 1,
      aux_sym_symbol_token2,
    ACTIONS(98), 1,
      sym_path,
    ACTIONS(120), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(140), 1,
      sym_identifier,
    ACTIONS(157), 1,
      anon_sym_LPAREN,
    ACTIONS(159), 1,
      anon_sym_LBRACE,
    ACTIONS(167), 1,
      anon_sym_STAR,
    ACTIONS(169), 1,
      anon_sym_AMP,
    ACTIONS(177), 1,
      sym__decimal_number_pre_hook,
    STATE(236), 1,
      sym_memory_space,
    STATE(975), 1,
      sym_macro,
    STATE(1046), 1,
      sym_call_expression,
    STATE(1049), 1,
      sym__hll_var_call_expression,
    STATE(1052), 1,
      sym_integer,
    STATE(1053), 1,
      aux_sym__path_expression_repeat2,
    STATE(1218), 1,
      aux_sym__path_expression_repeat1,
    STATE(1399), 1,
      sym__unary_expression,
    STATE(1400), 1,
      sym__prefix_postfix_expression,
    STATE(1404), 1,
      sym__binary_expression,
    STATE(1406), 1,
      sym__and_expression,
    STATE(1412), 1,
      sym_trace32_hll_variable,
    STATE(1417), 1,
      sym__file_dialog,
    STATE(1550), 1,
      sym__address_binary_expression,
    STATE(2257), 1,
      sym__function_identifier,
    STATE(2260), 1,
      sym__hll_var_call_expression_function,
    ACTIONS(88), 2,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
    ACTIONS(161), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(163), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(165), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(171), 2,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
    STATE(1560), 2,
      sym__address_expression,
      sym__parenthesized_address_expression,
    ACTIONS(1261), 3,
      sym_float,
      sym_time,
      sym_frequency,
    ACTIONS(1263), 3,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
    STATE(1427), 13,
      sym__expression,
      sym__parenthesized_expression,
      sym__path_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_assignment_expression,
      sym__literal,
      sym_address,
      sym_bitmask,
      sym_string,
      sym_character,
      sym_symbol,
      sym__special_command_operator,
  [17683] = 40,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(120), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(147), 1,
      anon_sym_AMP,
    ACTIONS(155), 1,
      sym__decimal_number_pre_hook,
    ACTIONS(179), 1,
      sym_identifier,
    ACTIONS(181), 1,
      anon_sym_LPAREN,
    ACTIONS(183), 1,
      anon_sym_LBRACE,
    ACTIONS(191), 1,
      anon_sym_STAR,
    ACTIONS(193), 1,
      anon_sym_BSLASH,
    ACTIONS(195), 1,
      anon_sym_SQUOTE,
    ACTIONS(197), 1,
      anon_sym_DQUOTE,
    ACTIONS(199), 1,
      sym_access_class,
    ACTIONS(205), 1,
      aux_sym_symbol_token1,
    ACTIONS(207), 1,
      aux_sym_symbol_token2,
    ACTIONS(211), 1,
      sym_path,
    STATE(228), 1,
      sym_memory_space,
    STATE(980), 1,
      sym_macro,
    STATE(1060), 1,
      sym_call_expression,
    STATE(1061), 1,
      sym__hll_var_call_expression,
    STATE(1080), 1,
      sym_integer,
    STATE(1100), 1,
      aux_sym__path_expression_repeat2,
    STATE(1172), 1,
      aux_sym__path_expression_repeat1,
    STATE(1371), 1,
      sym__and_expression,
    STATE(1374), 1,
      sym__file_dialog,
    STATE(1377), 1,
      sym_trace32_hll_variable,
    STATE(1378), 1,
      sym__unary_expression,
    STATE(1392), 1,
      sym__prefix_postfix_expression,
    STATE(1394), 1,
      sym__binary_expression,
    STATE(1550), 1,
      sym__address_binary_expression,
    STATE(2349), 1,
      sym__function_identifier,
    STATE(2359), 1,
      sym__hll_var_call_expression_function,
    ACTIONS(149), 2,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
    ACTIONS(185), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(187), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(189), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(203), 2,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
    STATE(1575), 2,
      sym__address_expression,
      sym__parenthesized_address_expression,
    ACTIONS(1289), 3,
      sym_float,
      sym_time,
      sym_frequency,
    ACTIONS(1291), 3,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
    STATE(1160), 13,
      sym__expression,
      sym__parenthesized_expression,
      sym__path_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_assignment_expression,
      sym__literal,
      sym_address,
      sym_bitmask,
      sym_string,
      sym_character,
      sym_symbol,
      sym__special_command_operator,
  [17826] = 38,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(96), 1,
      sym__decimal_number_pre_hook,
    ACTIONS(100), 1,
      sym_identifier,
    ACTIONS(102), 1,
      anon_sym_LPAREN,
    ACTIONS(104), 1,
      anon_sym_LBRACE,
    ACTIONS(116), 1,
      anon_sym_STAR,
    ACTIONS(120), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(122), 1,
      anon_sym_BSLASH,
    ACTIONS(124), 1,
      anon_sym_SQUOTE,
    ACTIONS(126), 1,
      anon_sym_DQUOTE,
    ACTIONS(128), 1,
      sym_access_class,
    ACTIONS(134), 1,
      aux_sym_symbol_token1,
    ACTIONS(136), 1,
      aux_sym_symbol_token2,
    ACTIONS(695), 1,
      anon_sym_AMP,
    STATE(224), 1,
      sym_memory_space,
    STATE(328), 1,
      sym_macro,
    STATE(345), 1,
      sym__hll_var_call_expression,
    STATE(347), 1,
      sym_call_expression,
    STATE(350), 1,
      sym_integer,
    STATE(371), 1,
      aux_sym__path_expression_repeat1,
    STATE(450), 1,
      sym__unary_expression,
    STATE(451), 1,
      sym__prefix_postfix_expression,
    STATE(452), 1,
      sym__binary_expression,
    STATE(453), 1,
      sym__and_expression,
    STATE(457), 1,
      sym_trace32_hll_variable,
    STATE(459), 1,
      sym__file_dialog,
    STATE(1550), 1,
      sym__address_binary_expression,
    STATE(2354), 1,
      sym__function_identifier,
    STATE(2355), 1,
      sym__hll_var_call_expression_function,
    ACTIONS(84), 2,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
    ACTIONS(110), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(112), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(114), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(132), 2,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
    STATE(1575), 2,
      sym__address_expression,
      sym__parenthesized_address_expression,
    ACTIONS(1293), 3,
      sym_float,
      sym_time,
      sym_frequency,
    ACTIONS(1295), 4,
      sym_path,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
    STATE(378), 14,
      sym__expression,
      sym__parenthesized_expression,
      sym__path_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_assignment_expression,
      sym__literal,
      sym_address,
      sym_bitmask,
      sym_string,
      sym_character,
      sym_symbol,
      sym__special_command_operator,
      aux_sym__path_expression_repeat2,
  [17965] = 40,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(76), 1,
      anon_sym_BSLASH,
    ACTIONS(78), 1,
      anon_sym_SQUOTE,
    ACTIONS(80), 1,
      anon_sym_DQUOTE,
    ACTIONS(82), 1,
      sym_access_class,
    ACTIONS(90), 1,
      aux_sym_symbol_token1,
    ACTIONS(92), 1,
      aux_sym_symbol_token2,
    ACTIONS(98), 1,
      sym_path,
    ACTIONS(120), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(140), 1,
      sym_identifier,
    ACTIONS(157), 1,
      anon_sym_LPAREN,
    ACTIONS(159), 1,
      anon_sym_LBRACE,
    ACTIONS(167), 1,
      anon_sym_STAR,
    ACTIONS(169), 1,
      anon_sym_AMP,
    ACTIONS(177), 1,
      sym__decimal_number_pre_hook,
    STATE(236), 1,
      sym_memory_space,
    STATE(975), 1,
      sym_macro,
    STATE(1046), 1,
      sym_call_expression,
    STATE(1049), 1,
      sym__hll_var_call_expression,
    STATE(1052), 1,
      sym_integer,
    STATE(1053), 1,
      aux_sym__path_expression_repeat2,
    STATE(1218), 1,
      aux_sym__path_expression_repeat1,
    STATE(1399), 1,
      sym__unary_expression,
    STATE(1400), 1,
      sym__prefix_postfix_expression,
    STATE(1404), 1,
      sym__binary_expression,
    STATE(1406), 1,
      sym__and_expression,
    STATE(1412), 1,
      sym_trace32_hll_variable,
    STATE(1417), 1,
      sym__file_dialog,
    STATE(1550), 1,
      sym__address_binary_expression,
    STATE(2257), 1,
      sym__function_identifier,
    STATE(2260), 1,
      sym__hll_var_call_expression_function,
    ACTIONS(88), 2,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
    ACTIONS(161), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(163), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(165), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(171), 2,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
    STATE(1564), 2,
      sym__address_expression,
      sym__parenthesized_address_expression,
    ACTIONS(1257), 3,
      sym_float,
      sym_time,
      sym_frequency,
    ACTIONS(1259), 3,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
    STATE(1426), 13,
      sym__expression,
      sym__parenthesized_expression,
      sym__path_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_assignment_expression,
      sym__literal,
      sym_address,
      sym_bitmask,
      sym_string,
      sym_character,
      sym_symbol,
      sym__special_command_operator,
  [18108] = 40,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(76), 1,
      anon_sym_BSLASH,
    ACTIONS(78), 1,
      anon_sym_SQUOTE,
    ACTIONS(80), 1,
      anon_sym_DQUOTE,
    ACTIONS(82), 1,
      sym_access_class,
    ACTIONS(90), 1,
      aux_sym_symbol_token1,
    ACTIONS(92), 1,
      aux_sym_symbol_token2,
    ACTIONS(98), 1,
      sym_path,
    ACTIONS(120), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(140), 1,
      sym_identifier,
    ACTIONS(157), 1,
      anon_sym_LPAREN,
    ACTIONS(159), 1,
      anon_sym_LBRACE,
    ACTIONS(167), 1,
      anon_sym_STAR,
    ACTIONS(169), 1,
      anon_sym_AMP,
    ACTIONS(177), 1,
      sym__decimal_number_pre_hook,
    STATE(236), 1,
      sym_memory_space,
    STATE(975), 1,
      sym_macro,
    STATE(1046), 1,
      sym_call_expression,
    STATE(1049), 1,
      sym__hll_var_call_expression,
    STATE(1052), 1,
      sym_integer,
    STATE(1053), 1,
      aux_sym__path_expression_repeat2,
    STATE(1218), 1,
      aux_sym__path_expression_repeat1,
    STATE(1399), 1,
      sym__unary_expression,
    STATE(1400), 1,
      sym__prefix_postfix_expression,
    STATE(1404), 1,
      sym__binary_expression,
    STATE(1406), 1,
      sym__and_expression,
    STATE(1412), 1,
      sym_trace32_hll_variable,
    STATE(1417), 1,
      sym__file_dialog,
    STATE(1550), 1,
      sym__address_binary_expression,
    STATE(2257), 1,
      sym__function_identifier,
    STATE(2260), 1,
      sym__hll_var_call_expression_function,
    ACTIONS(88), 2,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
    ACTIONS(161), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(163), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(165), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(171), 2,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
    STATE(1559), 2,
      sym__address_expression,
      sym__parenthesized_address_expression,
    ACTIONS(1261), 3,
      sym_float,
      sym_time,
      sym_frequency,
    ACTIONS(1263), 3,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
    STATE(1427), 13,
      sym__expression,
      sym__parenthesized_expression,
      sym__path_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_assignment_expression,
      sym__literal,
      sym_address,
      sym_bitmask,
      sym_string,
      sym_character,
      sym_symbol,
      sym__special_command_operator,
  [18251] = 40,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(76), 1,
      anon_sym_BSLASH,
    ACTIONS(78), 1,
      anon_sym_SQUOTE,
    ACTIONS(80), 1,
      anon_sym_DQUOTE,
    ACTIONS(82), 1,
      sym_access_class,
    ACTIONS(90), 1,
      aux_sym_symbol_token1,
    ACTIONS(92), 1,
      aux_sym_symbol_token2,
    ACTIONS(98), 1,
      sym_path,
    ACTIONS(120), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(140), 1,
      sym_identifier,
    ACTIONS(157), 1,
      anon_sym_LPAREN,
    ACTIONS(159), 1,
      anon_sym_LBRACE,
    ACTIONS(167), 1,
      anon_sym_STAR,
    ACTIONS(169), 1,
      anon_sym_AMP,
    ACTIONS(177), 1,
      sym__decimal_number_pre_hook,
    STATE(236), 1,
      sym_memory_space,
    STATE(970), 1,
      sym_macro,
    STATE(1049), 1,
      sym__hll_var_call_expression,
    STATE(1053), 1,
      aux_sym__path_expression_repeat2,
    STATE(1097), 1,
      sym_call_expression,
    STATE(1098), 1,
      sym_integer,
    STATE(1218), 1,
      aux_sym__path_expression_repeat1,
    STATE(1399), 1,
      sym__unary_expression,
    STATE(1400), 1,
      sym__prefix_postfix_expression,
    STATE(1404), 1,
      sym__binary_expression,
    STATE(1406), 1,
      sym__and_expression,
    STATE(1412), 1,
      sym_trace32_hll_variable,
    STATE(1417), 1,
      sym__file_dialog,
    STATE(1550), 1,
      sym__address_binary_expression,
    STATE(2257), 1,
      sym__function_identifier,
    STATE(2260), 1,
      sym__hll_var_call_expression_function,
    ACTIONS(88), 2,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
    ACTIONS(161), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(163), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(165), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(171), 2,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
    STATE(1575), 2,
      sym__address_expression,
      sym__parenthesized_address_expression,
    ACTIONS(1297), 3,
      sym_float,
      sym_time,
      sym_frequency,
    ACTIONS(1299), 3,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
    STATE(1238), 13,
      sym__expression,
      sym__parenthesized_expression,
      sym__path_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_assignment_expression,
      sym__literal,
      sym_address,
      sym_bitmask,
      sym_string,
      sym_character,
      sym_symbol,
      sym__special_command_operator,
  [18394] = 38,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(96), 1,
      sym__decimal_number_pre_hook,
    ACTIONS(100), 1,
      sym_identifier,
    ACTIONS(102), 1,
      anon_sym_LPAREN,
    ACTIONS(104), 1,
      anon_sym_LBRACE,
    ACTIONS(116), 1,
      anon_sym_STAR,
    ACTIONS(120), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(122), 1,
      anon_sym_BSLASH,
    ACTIONS(124), 1,
      anon_sym_SQUOTE,
    ACTIONS(126), 1,
      anon_sym_DQUOTE,
    ACTIONS(128), 1,
      sym_access_class,
    ACTIONS(134), 1,
      aux_sym_symbol_token1,
    ACTIONS(136), 1,
      aux_sym_symbol_token2,
    ACTIONS(695), 1,
      anon_sym_AMP,
    STATE(224), 1,
      sym_memory_space,
    STATE(328), 1,
      sym_macro,
    STATE(345), 1,
      sym__hll_var_call_expression,
    STATE(347), 1,
      sym_call_expression,
    STATE(350), 1,
      sym_integer,
    STATE(371), 1,
      aux_sym__path_expression_repeat1,
    STATE(450), 1,
      sym__unary_expression,
    STATE(451), 1,
      sym__prefix_postfix_expression,
    STATE(452), 1,
      sym__binary_expression,
    STATE(453), 1,
      sym__and_expression,
    STATE(457), 1,
      sym_trace32_hll_variable,
    STATE(459), 1,
      sym__file_dialog,
    STATE(1550), 1,
      sym__address_binary_expression,
    STATE(2354), 1,
      sym__function_identifier,
    STATE(2355), 1,
      sym__hll_var_call_expression_function,
    ACTIONS(84), 2,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
    ACTIONS(110), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(112), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(114), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(132), 2,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
    STATE(1575), 2,
      sym__address_expression,
      sym__parenthesized_address_expression,
    ACTIONS(1301), 3,
      sym_float,
      sym_time,
      sym_frequency,
    ACTIONS(1303), 4,
      sym_path,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
    STATE(368), 14,
      sym__expression,
      sym__parenthesized_expression,
      sym__path_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_assignment_expression,
      sym__literal,
      sym_address,
      sym_bitmask,
      sym_string,
      sym_character,
      sym_symbol,
      sym__special_command_operator,
      aux_sym__path_expression_repeat2,
  [18533] = 40,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(76), 1,
      anon_sym_BSLASH,
    ACTIONS(78), 1,
      anon_sym_SQUOTE,
    ACTIONS(80), 1,
      anon_sym_DQUOTE,
    ACTIONS(82), 1,
      sym_access_class,
    ACTIONS(90), 1,
      aux_sym_symbol_token1,
    ACTIONS(92), 1,
      aux_sym_symbol_token2,
    ACTIONS(98), 1,
      sym_path,
    ACTIONS(120), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(140), 1,
      sym_identifier,
    ACTIONS(157), 1,
      anon_sym_LPAREN,
    ACTIONS(159), 1,
      anon_sym_LBRACE,
    ACTIONS(167), 1,
      anon_sym_STAR,
    ACTIONS(169), 1,
      anon_sym_AMP,
    ACTIONS(177), 1,
      sym__decimal_number_pre_hook,
    STATE(236), 1,
      sym_memory_space,
    STATE(975), 1,
      sym_macro,
    STATE(1046), 1,
      sym_call_expression,
    STATE(1049), 1,
      sym__hll_var_call_expression,
    STATE(1052), 1,
      sym_integer,
    STATE(1053), 1,
      aux_sym__path_expression_repeat2,
    STATE(1218), 1,
      aux_sym__path_expression_repeat1,
    STATE(1399), 1,
      sym__unary_expression,
    STATE(1400), 1,
      sym__prefix_postfix_expression,
    STATE(1404), 1,
      sym__binary_expression,
    STATE(1406), 1,
      sym__and_expression,
    STATE(1412), 1,
      sym_trace32_hll_variable,
    STATE(1417), 1,
      sym__file_dialog,
    STATE(1550), 1,
      sym__address_binary_expression,
    STATE(2257), 1,
      sym__function_identifier,
    STATE(2260), 1,
      sym__hll_var_call_expression_function,
    ACTIONS(88), 2,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
    ACTIONS(161), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(163), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(165), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(171), 2,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
    STATE(1556), 2,
      sym__address_expression,
      sym__parenthesized_address_expression,
    ACTIONS(1257), 3,
      sym_float,
      sym_time,
      sym_frequency,
    ACTIONS(1259), 3,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
    STATE(1426), 13,
      sym__expression,
      sym__parenthesized_expression,
      sym__path_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_assignment_expression,
      sym__literal,
      sym_address,
      sym_bitmask,
      sym_string,
      sym_character,
      sym_symbol,
      sym__special_command_operator,
  [18676] = 40,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(76), 1,
      anon_sym_BSLASH,
    ACTIONS(78), 1,
      anon_sym_SQUOTE,
    ACTIONS(80), 1,
      anon_sym_DQUOTE,
    ACTIONS(82), 1,
      sym_access_class,
    ACTIONS(90), 1,
      aux_sym_symbol_token1,
    ACTIONS(92), 1,
      aux_sym_symbol_token2,
    ACTIONS(98), 1,
      sym_path,
    ACTIONS(120), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(140), 1,
      sym_identifier,
    ACTIONS(157), 1,
      anon_sym_LPAREN,
    ACTIONS(159), 1,
      anon_sym_LBRACE,
    ACTIONS(167), 1,
      anon_sym_STAR,
    ACTIONS(169), 1,
      anon_sym_AMP,
    ACTIONS(177), 1,
      sym__decimal_number_pre_hook,
    STATE(236), 1,
      sym_memory_space,
    STATE(975), 1,
      sym_macro,
    STATE(1046), 1,
      sym_call_expression,
    STATE(1049), 1,
      sym__hll_var_call_expression,
    STATE(1052), 1,
      sym_integer,
    STATE(1053), 1,
      aux_sym__path_expression_repeat2,
    STATE(1218), 1,
      aux_sym__path_expression_repeat1,
    STATE(1399), 1,
      sym__unary_expression,
    STATE(1400), 1,
      sym__prefix_postfix_expression,
    STATE(1404), 1,
      sym__binary_expression,
    STATE(1406), 1,
      sym__and_expression,
    STATE(1412), 1,
      sym_trace32_hll_variable,
    STATE(1417), 1,
      sym__file_dialog,
    STATE(1550), 1,
      sym__address_binary_expression,
    STATE(2257), 1,
      sym__function_identifier,
    STATE(2260), 1,
      sym__hll_var_call_expression_function,
    ACTIONS(88), 2,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
    ACTIONS(161), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(163), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(165), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(171), 2,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
    STATE(1570), 2,
      sym__address_expression,
      sym__parenthesized_address_expression,
    ACTIONS(1261), 3,
      sym_float,
      sym_time,
      sym_frequency,
    ACTIONS(1263), 3,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
    STATE(1427), 13,
      sym__expression,
      sym__parenthesized_expression,
      sym__path_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_assignment_expression,
      sym__literal,
      sym_address,
      sym_bitmask,
      sym_string,
      sym_character,
      sym_symbol,
      sym__special_command_operator,
  [18819] = 38,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(96), 1,
      sym__decimal_number_pre_hook,
    ACTIONS(100), 1,
      sym_identifier,
    ACTIONS(102), 1,
      anon_sym_LPAREN,
    ACTIONS(104), 1,
      anon_sym_LBRACE,
    ACTIONS(116), 1,
      anon_sym_STAR,
    ACTIONS(120), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(122), 1,
      anon_sym_BSLASH,
    ACTIONS(124), 1,
      anon_sym_SQUOTE,
    ACTIONS(126), 1,
      anon_sym_DQUOTE,
    ACTIONS(128), 1,
      sym_access_class,
    ACTIONS(134), 1,
      aux_sym_symbol_token1,
    ACTIONS(136), 1,
      aux_sym_symbol_token2,
    ACTIONS(695), 1,
      anon_sym_AMP,
    STATE(224), 1,
      sym_memory_space,
    STATE(328), 1,
      sym_macro,
    STATE(345), 1,
      sym__hll_var_call_expression,
    STATE(347), 1,
      sym_call_expression,
    STATE(350), 1,
      sym_integer,
    STATE(371), 1,
      aux_sym__path_expression_repeat1,
    STATE(450), 1,
      sym__unary_expression,
    STATE(451), 1,
      sym__prefix_postfix_expression,
    STATE(452), 1,
      sym__binary_expression,
    STATE(453), 1,
      sym__and_expression,
    STATE(457), 1,
      sym_trace32_hll_variable,
    STATE(459), 1,
      sym__file_dialog,
    STATE(1550), 1,
      sym__address_binary_expression,
    STATE(2354), 1,
      sym__function_identifier,
    STATE(2355), 1,
      sym__hll_var_call_expression_function,
    ACTIONS(84), 2,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
    ACTIONS(110), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(112), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(114), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(132), 2,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
    STATE(1575), 2,
      sym__address_expression,
      sym__parenthesized_address_expression,
    ACTIONS(1305), 3,
      sym_float,
      sym_time,
      sym_frequency,
    ACTIONS(1307), 4,
      sym_path,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
    STATE(375), 14,
      sym__expression,
      sym__parenthesized_expression,
      sym__path_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_assignment_expression,
      sym__literal,
      sym_address,
      sym_bitmask,
      sym_string,
      sym_character,
      sym_symbol,
      sym__special_command_operator,
      aux_sym__path_expression_repeat2,
  [18958] = 40,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(76), 1,
      anon_sym_BSLASH,
    ACTIONS(78), 1,
      anon_sym_SQUOTE,
    ACTIONS(80), 1,
      anon_sym_DQUOTE,
    ACTIONS(82), 1,
      sym_access_class,
    ACTIONS(90), 1,
      aux_sym_symbol_token1,
    ACTIONS(92), 1,
      aux_sym_symbol_token2,
    ACTIONS(98), 1,
      sym_path,
    ACTIONS(120), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(140), 1,
      sym_identifier,
    ACTIONS(157), 1,
      anon_sym_LPAREN,
    ACTIONS(159), 1,
      anon_sym_LBRACE,
    ACTIONS(167), 1,
      anon_sym_STAR,
    ACTIONS(169), 1,
      anon_sym_AMP,
    ACTIONS(177), 1,
      sym__decimal_number_pre_hook,
    STATE(236), 1,
      sym_memory_space,
    STATE(970), 1,
      sym_macro,
    STATE(1049), 1,
      sym__hll_var_call_expression,
    STATE(1053), 1,
      aux_sym__path_expression_repeat2,
    STATE(1097), 1,
      sym_call_expression,
    STATE(1098), 1,
      sym_integer,
    STATE(1218), 1,
      aux_sym__path_expression_repeat1,
    STATE(1399), 1,
      sym__unary_expression,
    STATE(1400), 1,
      sym__prefix_postfix_expression,
    STATE(1404), 1,
      sym__binary_expression,
    STATE(1406), 1,
      sym__and_expression,
    STATE(1412), 1,
      sym_trace32_hll_variable,
    STATE(1417), 1,
      sym__file_dialog,
    STATE(1550), 1,
      sym__address_binary_expression,
    STATE(2257), 1,
      sym__function_identifier,
    STATE(2260), 1,
      sym__hll_var_call_expression_function,
    ACTIONS(88), 2,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
    ACTIONS(161), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(163), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(165), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(171), 2,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
    STATE(1575), 2,
      sym__address_expression,
      sym__parenthesized_address_expression,
    ACTIONS(1309), 3,
      sym_float,
      sym_time,
      sym_frequency,
    ACTIONS(1311), 3,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
    STATE(1243), 13,
      sym__expression,
      sym__parenthesized_expression,
      sym__path_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_assignment_expression,
      sym__literal,
      sym_address,
      sym_bitmask,
      sym_string,
      sym_character,
      sym_symbol,
      sym__special_command_operator,
  [19101] = 40,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(51), 1,
      anon_sym_LBRACE,
    ACTIONS(76), 1,
      anon_sym_BSLASH,
    ACTIONS(78), 1,
      anon_sym_SQUOTE,
    ACTIONS(80), 1,
      anon_sym_DQUOTE,
    ACTIONS(82), 1,
      sym_access_class,
    ACTIONS(90), 1,
      aux_sym_symbol_token1,
    ACTIONS(92), 1,
      aux_sym_symbol_token2,
    ACTIONS(96), 1,
      sym__decimal_number_pre_hook,
    ACTIONS(98), 1,
      sym_path,
    ACTIONS(120), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(140), 1,
      sym_identifier,
    ACTIONS(167), 1,
      anon_sym_STAR,
    ACTIONS(695), 1,
      anon_sym_AMP,
    ACTIONS(1129), 1,
      anon_sym_LPAREN,
    STATE(236), 1,
      sym_memory_space,
    STATE(341), 1,
      sym_macro,
    STATE(345), 1,
      sym__hll_var_call_expression,
    STATE(354), 1,
      sym__address_binary_expression,
    STATE(364), 1,
      sym_call_expression,
    STATE(365), 1,
      sym_integer,
    STATE(1053), 1,
      aux_sym__path_expression_repeat2,
    STATE(1218), 1,
      aux_sym__path_expression_repeat1,
    STATE(1399), 1,
      sym__unary_expression,
    STATE(1400), 1,
      sym__prefix_postfix_expression,
    STATE(1404), 1,
      sym__binary_expression,
    STATE(1406), 1,
      sym__and_expression,
    STATE(1412), 1,
      sym_trace32_hll_variable,
    STATE(1417), 1,
      sym__file_dialog,
    STATE(2354), 1,
      sym__function_identifier,
    STATE(2355), 1,
      sym__hll_var_call_expression_function,
    ACTIONS(60), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(62), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(84), 2,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
    ACTIONS(88), 2,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
    ACTIONS(222), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(351), 2,
      sym__address_expression,
      sym__parenthesized_address_expression,
    ACTIONS(86), 3,
      sym_float,
      sym_time,
      sym_frequency,
    ACTIONS(94), 3,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
    STATE(1435), 13,
      sym__expression,
      sym__parenthesized_expression,
      sym__path_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_assignment_expression,
      sym__literal,
      sym_address,
      sym_bitmask,
      sym_string,
      sym_character,
      sym_symbol,
      sym__special_command_operator,
  [19244] = 40,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(51), 1,
      anon_sym_LBRACE,
    ACTIONS(76), 1,
      anon_sym_BSLASH,
    ACTIONS(78), 1,
      anon_sym_SQUOTE,
    ACTIONS(80), 1,
      anon_sym_DQUOTE,
    ACTIONS(82), 1,
      sym_access_class,
    ACTIONS(90), 1,
      aux_sym_symbol_token1,
    ACTIONS(92), 1,
      aux_sym_symbol_token2,
    ACTIONS(96), 1,
      sym__decimal_number_pre_hook,
    ACTIONS(98), 1,
      sym_path,
    ACTIONS(120), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(140), 1,
      sym_identifier,
    ACTIONS(167), 1,
      anon_sym_STAR,
    ACTIONS(695), 1,
      anon_sym_AMP,
    ACTIONS(1129), 1,
      anon_sym_LPAREN,
    STATE(236), 1,
      sym_memory_space,
    STATE(341), 1,
      sym_macro,
    STATE(345), 1,
      sym__hll_var_call_expression,
    STATE(354), 1,
      sym__address_binary_expression,
    STATE(364), 1,
      sym_call_expression,
    STATE(365), 1,
      sym_integer,
    STATE(1053), 1,
      aux_sym__path_expression_repeat2,
    STATE(1218), 1,
      aux_sym__path_expression_repeat1,
    STATE(1399), 1,
      sym__unary_expression,
    STATE(1400), 1,
      sym__prefix_postfix_expression,
    STATE(1404), 1,
      sym__binary_expression,
    STATE(1406), 1,
      sym__and_expression,
    STATE(1412), 1,
      sym_trace32_hll_variable,
    STATE(1417), 1,
      sym__file_dialog,
    STATE(2354), 1,
      sym__function_identifier,
    STATE(2355), 1,
      sym__hll_var_call_expression_function,
    ACTIONS(60), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(62), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(84), 2,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
    ACTIONS(88), 2,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
    ACTIONS(222), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(352), 2,
      sym__address_expression,
      sym__parenthesized_address_expression,
    ACTIONS(86), 3,
      sym_float,
      sym_time,
      sym_frequency,
    ACTIONS(94), 3,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
    STATE(1435), 13,
      sym__expression,
      sym__parenthesized_expression,
      sym__path_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_assignment_expression,
      sym__literal,
      sym_address,
      sym_bitmask,
      sym_string,
      sym_character,
      sym_symbol,
      sym__special_command_operator,
  [19387] = 38,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(96), 1,
      sym__decimal_number_pre_hook,
    ACTIONS(100), 1,
      sym_identifier,
    ACTIONS(102), 1,
      anon_sym_LPAREN,
    ACTIONS(104), 1,
      anon_sym_LBRACE,
    ACTIONS(116), 1,
      anon_sym_STAR,
    ACTIONS(120), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(122), 1,
      anon_sym_BSLASH,
    ACTIONS(124), 1,
      anon_sym_SQUOTE,
    ACTIONS(126), 1,
      anon_sym_DQUOTE,
    ACTIONS(128), 1,
      sym_access_class,
    ACTIONS(134), 1,
      aux_sym_symbol_token1,
    ACTIONS(136), 1,
      aux_sym_symbol_token2,
    ACTIONS(695), 1,
      anon_sym_AMP,
    STATE(224), 1,
      sym_memory_space,
    STATE(328), 1,
      sym_macro,
    STATE(345), 1,
      sym__hll_var_call_expression,
    STATE(347), 1,
      sym_call_expression,
    STATE(350), 1,
      sym_integer,
    STATE(371), 1,
      aux_sym__path_expression_repeat1,
    STATE(450), 1,
      sym__unary_expression,
    STATE(451), 1,
      sym__prefix_postfix_expression,
    STATE(452), 1,
      sym__binary_expression,
    STATE(453), 1,
      sym__and_expression,
    STATE(457), 1,
      sym_trace32_hll_variable,
    STATE(459), 1,
      sym__file_dialog,
    STATE(1550), 1,
      sym__address_binary_expression,
    STATE(2354), 1,
      sym__function_identifier,
    STATE(2355), 1,
      sym__hll_var_call_expression_function,
    ACTIONS(84), 2,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
    ACTIONS(110), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(112), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(114), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(132), 2,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
    STATE(1575), 2,
      sym__address_expression,
      sym__parenthesized_address_expression,
    ACTIONS(130), 3,
      sym_float,
      sym_time,
      sym_frequency,
    ACTIONS(138), 4,
      sym_path,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
    STATE(388), 14,
      sym__expression,
      sym__parenthesized_expression,
      sym__path_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_assignment_expression,
      sym__literal,
      sym_address,
      sym_bitmask,
      sym_string,
      sym_character,
      sym_symbol,
      sym__special_command_operator,
      aux_sym__path_expression_repeat2,
  [19526] = 38,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(96), 1,
      sym__decimal_number_pre_hook,
    ACTIONS(100), 1,
      sym_identifier,
    ACTIONS(102), 1,
      anon_sym_LPAREN,
    ACTIONS(104), 1,
      anon_sym_LBRACE,
    ACTIONS(116), 1,
      anon_sym_STAR,
    ACTIONS(120), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(122), 1,
      anon_sym_BSLASH,
    ACTIONS(124), 1,
      anon_sym_SQUOTE,
    ACTIONS(126), 1,
      anon_sym_DQUOTE,
    ACTIONS(128), 1,
      sym_access_class,
    ACTIONS(134), 1,
      aux_sym_symbol_token1,
    ACTIONS(136), 1,
      aux_sym_symbol_token2,
    ACTIONS(695), 1,
      anon_sym_AMP,
    STATE(224), 1,
      sym_memory_space,
    STATE(328), 1,
      sym_macro,
    STATE(345), 1,
      sym__hll_var_call_expression,
    STATE(347), 1,
      sym_call_expression,
    STATE(350), 1,
      sym_integer,
    STATE(371), 1,
      aux_sym__path_expression_repeat1,
    STATE(450), 1,
      sym__unary_expression,
    STATE(451), 1,
      sym__prefix_postfix_expression,
    STATE(452), 1,
      sym__binary_expression,
    STATE(453), 1,
      sym__and_expression,
    STATE(457), 1,
      sym_trace32_hll_variable,
    STATE(459), 1,
      sym__file_dialog,
    STATE(1550), 1,
      sym__address_binary_expression,
    STATE(2354), 1,
      sym__function_identifier,
    STATE(2355), 1,
      sym__hll_var_call_expression_function,
    ACTIONS(84), 2,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
    ACTIONS(110), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(112), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(114), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(132), 2,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
    STATE(1575), 2,
      sym__address_expression,
      sym__parenthesized_address_expression,
    ACTIONS(1313), 3,
      sym_float,
      sym_time,
      sym_frequency,
    ACTIONS(1315), 4,
      sym_path,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
    STATE(387), 14,
      sym__expression,
      sym__parenthesized_expression,
      sym__path_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_assignment_expression,
      sym__literal,
      sym_address,
      sym_bitmask,
      sym_string,
      sym_character,
      sym_symbol,
      sym__special_command_operator,
      aux_sym__path_expression_repeat2,
  [19665] = 40,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(76), 1,
      anon_sym_BSLASH,
    ACTIONS(78), 1,
      anon_sym_SQUOTE,
    ACTIONS(80), 1,
      anon_sym_DQUOTE,
    ACTIONS(82), 1,
      sym_access_class,
    ACTIONS(90), 1,
      aux_sym_symbol_token1,
    ACTIONS(92), 1,
      aux_sym_symbol_token2,
    ACTIONS(98), 1,
      sym_path,
    ACTIONS(120), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(140), 1,
      sym_identifier,
    ACTIONS(145), 1,
      anon_sym_LBRACE,
    ACTIONS(147), 1,
      anon_sym_AMP,
    ACTIONS(155), 1,
      sym__decimal_number_pre_hook,
    ACTIONS(167), 1,
      anon_sym_STAR,
    ACTIONS(1127), 1,
      anon_sym_LPAREN,
    STATE(236), 1,
      sym_memory_space,
    STATE(972), 1,
      sym_macro,
    STATE(1053), 1,
      aux_sym__path_expression_repeat2,
    STATE(1061), 1,
      sym__hll_var_call_expression,
    STATE(1107), 1,
      sym__address_binary_expression,
    STATE(1108), 1,
      sym_call_expression,
    STATE(1110), 1,
      sym_integer,
    STATE(1218), 1,
      aux_sym__path_expression_repeat1,
    STATE(1399), 1,
      sym__unary_expression,
    STATE(1400), 1,
      sym__prefix_postfix_expression,
    STATE(1404), 1,
      sym__binary_expression,
    STATE(1406), 1,
      sym__and_expression,
    STATE(1412), 1,
      sym_trace32_hll_variable,
    STATE(1417), 1,
      sym__file_dialog,
    STATE(2349), 1,
      sym__function_identifier,
    STATE(2359), 1,
      sym__hll_var_call_expression_function,
    ACTIONS(60), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(62), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(88), 2,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
    ACTIONS(149), 2,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
    ACTIONS(222), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1064), 2,
      sym__address_expression,
      sym__parenthesized_address_expression,
    ACTIONS(151), 3,
      sym_float,
      sym_time,
      sym_frequency,
    ACTIONS(153), 3,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
    STATE(1501), 13,
      sym__expression,
      sym__parenthesized_expression,
      sym__path_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_assignment_expression,
      sym__literal,
      sym_address,
      sym_bitmask,
      sym_string,
      sym_character,
      sym_symbol,
      sym__special_command_operator,
  [19808] = 38,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(96), 1,
      sym__decimal_number_pre_hook,
    ACTIONS(100), 1,
      sym_identifier,
    ACTIONS(102), 1,
      anon_sym_LPAREN,
    ACTIONS(104), 1,
      anon_sym_LBRACE,
    ACTIONS(116), 1,
      anon_sym_STAR,
    ACTIONS(120), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(122), 1,
      anon_sym_BSLASH,
    ACTIONS(124), 1,
      anon_sym_SQUOTE,
    ACTIONS(126), 1,
      anon_sym_DQUOTE,
    ACTIONS(128), 1,
      sym_access_class,
    ACTIONS(134), 1,
      aux_sym_symbol_token1,
    ACTIONS(136), 1,
      aux_sym_symbol_token2,
    ACTIONS(695), 1,
      anon_sym_AMP,
    STATE(224), 1,
      sym_memory_space,
    STATE(328), 1,
      sym_macro,
    STATE(345), 1,
      sym__hll_var_call_expression,
    STATE(347), 1,
      sym_call_expression,
    STATE(350), 1,
      sym_integer,
    STATE(371), 1,
      aux_sym__path_expression_repeat1,
    STATE(450), 1,
      sym__unary_expression,
    STATE(451), 1,
      sym__prefix_postfix_expression,
    STATE(452), 1,
      sym__binary_expression,
    STATE(453), 1,
      sym__and_expression,
    STATE(457), 1,
      sym_trace32_hll_variable,
    STATE(459), 1,
      sym__file_dialog,
    STATE(1550), 1,
      sym__address_binary_expression,
    STATE(2354), 1,
      sym__function_identifier,
    STATE(2355), 1,
      sym__hll_var_call_expression_function,
    ACTIONS(84), 2,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
    ACTIONS(110), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(112), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(114), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(132), 2,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
    STATE(1575), 2,
      sym__address_expression,
      sym__parenthesized_address_expression,
    ACTIONS(1317), 3,
      sym_float,
      sym_time,
      sym_frequency,
    ACTIONS(1319), 4,
      sym_path,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
    STATE(389), 14,
      sym__expression,
      sym__parenthesized_expression,
      sym__path_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_assignment_expression,
      sym__literal,
      sym_address,
      sym_bitmask,
      sym_string,
      sym_character,
      sym_symbol,
      sym__special_command_operator,
      aux_sym__path_expression_repeat2,
  [19947] = 38,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(96), 1,
      sym__decimal_number_pre_hook,
    ACTIONS(100), 1,
      sym_identifier,
    ACTIONS(102), 1,
      anon_sym_LPAREN,
    ACTIONS(104), 1,
      anon_sym_LBRACE,
    ACTIONS(116), 1,
      anon_sym_STAR,
    ACTIONS(120), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(122), 1,
      anon_sym_BSLASH,
    ACTIONS(124), 1,
      anon_sym_SQUOTE,
    ACTIONS(126), 1,
      anon_sym_DQUOTE,
    ACTIONS(128), 1,
      sym_access_class,
    ACTIONS(134), 1,
      aux_sym_symbol_token1,
    ACTIONS(136), 1,
      aux_sym_symbol_token2,
    ACTIONS(695), 1,
      anon_sym_AMP,
    STATE(224), 1,
      sym_memory_space,
    STATE(328), 1,
      sym_macro,
    STATE(345), 1,
      sym__hll_var_call_expression,
    STATE(347), 1,
      sym_call_expression,
    STATE(350), 1,
      sym_integer,
    STATE(371), 1,
      aux_sym__path_expression_repeat1,
    STATE(450), 1,
      sym__unary_expression,
    STATE(451), 1,
      sym__prefix_postfix_expression,
    STATE(452), 1,
      sym__binary_expression,
    STATE(453), 1,
      sym__and_expression,
    STATE(457), 1,
      sym_trace32_hll_variable,
    STATE(459), 1,
      sym__file_dialog,
    STATE(1550), 1,
      sym__address_binary_expression,
    STATE(2354), 1,
      sym__function_identifier,
    STATE(2355), 1,
      sym__hll_var_call_expression_function,
    ACTIONS(84), 2,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
    ACTIONS(110), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(112), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(114), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(132), 2,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
    STATE(1575), 2,
      sym__address_expression,
      sym__parenthesized_address_expression,
    ACTIONS(1321), 3,
      sym_float,
      sym_time,
      sym_frequency,
    ACTIONS(1323), 4,
      sym_path,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
    STATE(372), 14,
      sym__expression,
      sym__parenthesized_expression,
      sym__path_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_assignment_expression,
      sym__literal,
      sym_address,
      sym_bitmask,
      sym_string,
      sym_character,
      sym_symbol,
      sym__special_command_operator,
      aux_sym__path_expression_repeat2,
  [20086] = 38,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(96), 1,
      sym__decimal_number_pre_hook,
    ACTIONS(100), 1,
      sym_identifier,
    ACTIONS(102), 1,
      anon_sym_LPAREN,
    ACTIONS(104), 1,
      anon_sym_LBRACE,
    ACTIONS(116), 1,
      anon_sym_STAR,
    ACTIONS(120), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(122), 1,
      anon_sym_BSLASH,
    ACTIONS(124), 1,
      anon_sym_SQUOTE,
    ACTIONS(126), 1,
      anon_sym_DQUOTE,
    ACTIONS(128), 1,
      sym_access_class,
    ACTIONS(134), 1,
      aux_sym_symbol_token1,
    ACTIONS(136), 1,
      aux_sym_symbol_token2,
    ACTIONS(695), 1,
      anon_sym_AMP,
    STATE(224), 1,
      sym_memory_space,
    STATE(328), 1,
      sym_macro,
    STATE(345), 1,
      sym__hll_var_call_expression,
    STATE(347), 1,
      sym_call_expression,
    STATE(350), 1,
      sym_integer,
    STATE(371), 1,
      aux_sym__path_expression_repeat1,
    STATE(450), 1,
      sym__unary_expression,
    STATE(451), 1,
      sym__prefix_postfix_expression,
    STATE(452), 1,
      sym__binary_expression,
    STATE(453), 1,
      sym__and_expression,
    STATE(457), 1,
      sym_trace32_hll_variable,
    STATE(459), 1,
      sym__file_dialog,
    STATE(1550), 1,
      sym__address_binary_expression,
    STATE(2354), 1,
      sym__function_identifier,
    STATE(2355), 1,
      sym__hll_var_call_expression_function,
    ACTIONS(84), 2,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
    ACTIONS(110), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(112), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(114), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(132), 2,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
    STATE(1575), 2,
      sym__address_expression,
      sym__parenthesized_address_expression,
    ACTIONS(1325), 3,
      sym_float,
      sym_time,
      sym_frequency,
    ACTIONS(1327), 4,
      sym_path,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
    STATE(381), 14,
      sym__expression,
      sym__parenthesized_expression,
      sym__path_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_assignment_expression,
      sym__literal,
      sym_address,
      sym_bitmask,
      sym_string,
      sym_character,
      sym_symbol,
      sym__special_command_operator,
      aux_sym__path_expression_repeat2,
  [20225] = 40,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(120), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(147), 1,
      anon_sym_AMP,
    ACTIONS(155), 1,
      sym__decimal_number_pre_hook,
    ACTIONS(179), 1,
      sym_identifier,
    ACTIONS(181), 1,
      anon_sym_LPAREN,
    ACTIONS(183), 1,
      anon_sym_LBRACE,
    ACTIONS(191), 1,
      anon_sym_STAR,
    ACTIONS(193), 1,
      anon_sym_BSLASH,
    ACTIONS(195), 1,
      anon_sym_SQUOTE,
    ACTIONS(197), 1,
      anon_sym_DQUOTE,
    ACTIONS(199), 1,
      sym_access_class,
    ACTIONS(205), 1,
      aux_sym_symbol_token1,
    ACTIONS(207), 1,
      aux_sym_symbol_token2,
    ACTIONS(211), 1,
      sym_path,
    STATE(228), 1,
      sym_memory_space,
    STATE(980), 1,
      sym_macro,
    STATE(1060), 1,
      sym_call_expression,
    STATE(1061), 1,
      sym__hll_var_call_expression,
    STATE(1080), 1,
      sym_integer,
    STATE(1100), 1,
      aux_sym__path_expression_repeat2,
    STATE(1172), 1,
      aux_sym__path_expression_repeat1,
    STATE(1371), 1,
      sym__and_expression,
    STATE(1374), 1,
      sym__file_dialog,
    STATE(1377), 1,
      sym_trace32_hll_variable,
    STATE(1378), 1,
      sym__unary_expression,
    STATE(1392), 1,
      sym__prefix_postfix_expression,
    STATE(1394), 1,
      sym__binary_expression,
    STATE(1550), 1,
      sym__address_binary_expression,
    STATE(2349), 1,
      sym__function_identifier,
    STATE(2359), 1,
      sym__hll_var_call_expression_function,
    ACTIONS(149), 2,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
    ACTIONS(185), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(187), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(189), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(203), 2,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
    STATE(1575), 2,
      sym__address_expression,
      sym__parenthesized_address_expression,
    ACTIONS(201), 3,
      sym_float,
      sym_time,
      sym_frequency,
    ACTIONS(209), 3,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
    STATE(1166), 13,
      sym__expression,
      sym__parenthesized_expression,
      sym__path_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_assignment_expression,
      sym__literal,
      sym_address,
      sym_bitmask,
      sym_string,
      sym_character,
      sym_symbol,
      sym__special_command_operator,
  [20368] = 40,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(76), 1,
      anon_sym_BSLASH,
    ACTIONS(78), 1,
      anon_sym_SQUOTE,
    ACTIONS(80), 1,
      anon_sym_DQUOTE,
    ACTIONS(82), 1,
      sym_access_class,
    ACTIONS(90), 1,
      aux_sym_symbol_token1,
    ACTIONS(92), 1,
      aux_sym_symbol_token2,
    ACTIONS(98), 1,
      sym_path,
    ACTIONS(120), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(140), 1,
      sym_identifier,
    ACTIONS(157), 1,
      anon_sym_LPAREN,
    ACTIONS(159), 1,
      anon_sym_LBRACE,
    ACTIONS(167), 1,
      anon_sym_STAR,
    ACTIONS(169), 1,
      anon_sym_AMP,
    ACTIONS(177), 1,
      sym__decimal_number_pre_hook,
    STATE(236), 1,
      sym_memory_space,
    STATE(975), 1,
      sym_macro,
    STATE(1046), 1,
      sym_call_expression,
    STATE(1049), 1,
      sym__hll_var_call_expression,
    STATE(1052), 1,
      sym_integer,
    STATE(1053), 1,
      aux_sym__path_expression_repeat2,
    STATE(1218), 1,
      aux_sym__path_expression_repeat1,
    STATE(1399), 1,
      sym__unary_expression,
    STATE(1400), 1,
      sym__prefix_postfix_expression,
    STATE(1404), 1,
      sym__binary_expression,
    STATE(1406), 1,
      sym__and_expression,
    STATE(1412), 1,
      sym_trace32_hll_variable,
    STATE(1417), 1,
      sym__file_dialog,
    STATE(1550), 1,
      sym__address_binary_expression,
    STATE(2257), 1,
      sym__function_identifier,
    STATE(2260), 1,
      sym__hll_var_call_expression_function,
    ACTIONS(60), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(62), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(88), 2,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
    ACTIONS(171), 2,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
    ACTIONS(222), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1604), 2,
      sym__address_expression,
      sym__parenthesized_address_expression,
    ACTIONS(218), 3,
      sym_float,
      sym_time,
      sym_frequency,
    ACTIONS(220), 3,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
    STATE(1454), 13,
      sym__expression,
      sym__parenthesized_expression,
      sym__path_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_assignment_expression,
      sym__literal,
      sym_address,
      sym_bitmask,
      sym_string,
      sym_character,
      sym_symbol,
      sym__special_command_operator,
  [20511] = 40,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(76), 1,
      anon_sym_BSLASH,
    ACTIONS(78), 1,
      anon_sym_SQUOTE,
    ACTIONS(80), 1,
      anon_sym_DQUOTE,
    ACTIONS(82), 1,
      sym_access_class,
    ACTIONS(90), 1,
      aux_sym_symbol_token1,
    ACTIONS(92), 1,
      aux_sym_symbol_token2,
    ACTIONS(98), 1,
      sym_path,
    ACTIONS(120), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(140), 1,
      sym_identifier,
    ACTIONS(157), 1,
      anon_sym_LPAREN,
    ACTIONS(159), 1,
      anon_sym_LBRACE,
    ACTIONS(167), 1,
      anon_sym_STAR,
    ACTIONS(169), 1,
      anon_sym_AMP,
    ACTIONS(177), 1,
      sym__decimal_number_pre_hook,
    STATE(236), 1,
      sym_memory_space,
    STATE(975), 1,
      sym_macro,
    STATE(1046), 1,
      sym_call_expression,
    STATE(1049), 1,
      sym__hll_var_call_expression,
    STATE(1052), 1,
      sym_integer,
    STATE(1053), 1,
      aux_sym__path_expression_repeat2,
    STATE(1218), 1,
      aux_sym__path_expression_repeat1,
    STATE(1399), 1,
      sym__unary_expression,
    STATE(1400), 1,
      sym__prefix_postfix_expression,
    STATE(1404), 1,
      sym__binary_expression,
    STATE(1406), 1,
      sym__and_expression,
    STATE(1412), 1,
      sym_trace32_hll_variable,
    STATE(1417), 1,
      sym__file_dialog,
    STATE(1550), 1,
      sym__address_binary_expression,
    STATE(2257), 1,
      sym__function_identifier,
    STATE(2260), 1,
      sym__hll_var_call_expression_function,
    ACTIONS(60), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(62), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(88), 2,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
    ACTIONS(171), 2,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
    ACTIONS(222), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1551), 2,
      sym__address_expression,
      sym__parenthesized_address_expression,
    ACTIONS(218), 3,
      sym_float,
      sym_time,
      sym_frequency,
    ACTIONS(220), 3,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
    STATE(1454), 13,
      sym__expression,
      sym__parenthesized_expression,
      sym__path_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_assignment_expression,
      sym__literal,
      sym_address,
      sym_bitmask,
      sym_string,
      sym_character,
      sym_symbol,
      sym__special_command_operator,
  [20654] = 40,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(76), 1,
      anon_sym_BSLASH,
    ACTIONS(78), 1,
      anon_sym_SQUOTE,
    ACTIONS(80), 1,
      anon_sym_DQUOTE,
    ACTIONS(82), 1,
      sym_access_class,
    ACTIONS(90), 1,
      aux_sym_symbol_token1,
    ACTIONS(92), 1,
      aux_sym_symbol_token2,
    ACTIONS(98), 1,
      sym_path,
    ACTIONS(120), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(140), 1,
      sym_identifier,
    ACTIONS(157), 1,
      anon_sym_LPAREN,
    ACTIONS(159), 1,
      anon_sym_LBRACE,
    ACTIONS(167), 1,
      anon_sym_STAR,
    ACTIONS(169), 1,
      anon_sym_AMP,
    ACTIONS(177), 1,
      sym__decimal_number_pre_hook,
    STATE(236), 1,
      sym_memory_space,
    STATE(975), 1,
      sym_macro,
    STATE(1046), 1,
      sym_call_expression,
    STATE(1049), 1,
      sym__hll_var_call_expression,
    STATE(1052), 1,
      sym_integer,
    STATE(1053), 1,
      aux_sym__path_expression_repeat2,
    STATE(1218), 1,
      aux_sym__path_expression_repeat1,
    STATE(1399), 1,
      sym__unary_expression,
    STATE(1400), 1,
      sym__prefix_postfix_expression,
    STATE(1404), 1,
      sym__binary_expression,
    STATE(1406), 1,
      sym__and_expression,
    STATE(1412), 1,
      sym_trace32_hll_variable,
    STATE(1417), 1,
      sym__file_dialog,
    STATE(1550), 1,
      sym__address_binary_expression,
    STATE(2257), 1,
      sym__function_identifier,
    STATE(2260), 1,
      sym__hll_var_call_expression_function,
    ACTIONS(60), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(62), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(88), 2,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
    ACTIONS(171), 2,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
    ACTIONS(222), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1654), 2,
      sym__address_expression,
      sym__parenthesized_address_expression,
    ACTIONS(218), 3,
      sym_float,
      sym_time,
      sym_frequency,
    ACTIONS(220), 3,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
    STATE(1454), 13,
      sym__expression,
      sym__parenthesized_expression,
      sym__path_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_assignment_expression,
      sym__literal,
      sym_address,
      sym_bitmask,
      sym_string,
      sym_character,
      sym_symbol,
      sym__special_command_operator,
  [20797] = 40,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(76), 1,
      anon_sym_BSLASH,
    ACTIONS(78), 1,
      anon_sym_SQUOTE,
    ACTIONS(80), 1,
      anon_sym_DQUOTE,
    ACTIONS(82), 1,
      sym_access_class,
    ACTIONS(90), 1,
      aux_sym_symbol_token1,
    ACTIONS(92), 1,
      aux_sym_symbol_token2,
    ACTIONS(98), 1,
      sym_path,
    ACTIONS(120), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(140), 1,
      sym_identifier,
    ACTIONS(167), 1,
      anon_sym_STAR,
    ACTIONS(169), 1,
      anon_sym_AMP,
    ACTIONS(177), 1,
      sym__decimal_number_pre_hook,
    ACTIONS(216), 1,
      anon_sym_LBRACE,
    ACTIONS(1135), 1,
      anon_sym_LPAREN,
    STATE(236), 1,
      sym_memory_space,
    STATE(967), 1,
      sym_macro,
    STATE(1034), 1,
      sym_call_expression,
    STATE(1035), 1,
      sym_integer,
    STATE(1049), 1,
      sym__hll_var_call_expression,
    STATE(1053), 1,
      aux_sym__path_expression_repeat2,
    STATE(1109), 1,
      sym__address_binary_expression,
    STATE(1218), 1,
      aux_sym__path_expression_repeat1,
    STATE(1399), 1,
      sym__unary_expression,
    STATE(1400), 1,
      sym__prefix_postfix_expression,
    STATE(1404), 1,
      sym__binary_expression,
    STATE(1406), 1,
      sym__and_expression,
    STATE(1412), 1,
      sym_trace32_hll_variable,
    STATE(1417), 1,
      sym__file_dialog,
    STATE(2257), 1,
      sym__function_identifier,
    STATE(2260), 1,
      sym__hll_var_call_expression_function,
    ACTIONS(60), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(62), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(88), 2,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
    ACTIONS(171), 2,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
    ACTIONS(222), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1071), 2,
      sym__address_expression,
      sym__parenthesized_address_expression,
    ACTIONS(218), 3,
      sym_float,
      sym_time,
      sym_frequency,
    ACTIONS(220), 3,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
    STATE(1454), 13,
      sym__expression,
      sym__parenthesized_expression,
      sym__path_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_assignment_expression,
      sym__literal,
      sym_address,
      sym_bitmask,
      sym_string,
      sym_character,
      sym_symbol,
      sym__special_command_operator,
  [20940] = 38,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(96), 1,
      sym__decimal_number_pre_hook,
    ACTIONS(100), 1,
      sym_identifier,
    ACTIONS(102), 1,
      anon_sym_LPAREN,
    ACTIONS(104), 1,
      anon_sym_LBRACE,
    ACTIONS(116), 1,
      anon_sym_STAR,
    ACTIONS(120), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(122), 1,
      anon_sym_BSLASH,
    ACTIONS(124), 1,
      anon_sym_SQUOTE,
    ACTIONS(126), 1,
      anon_sym_DQUOTE,
    ACTIONS(128), 1,
      sym_access_class,
    ACTIONS(134), 1,
      aux_sym_symbol_token1,
    ACTIONS(136), 1,
      aux_sym_symbol_token2,
    ACTIONS(695), 1,
      anon_sym_AMP,
    STATE(224), 1,
      sym_memory_space,
    STATE(328), 1,
      sym_macro,
    STATE(345), 1,
      sym__hll_var_call_expression,
    STATE(347), 1,
      sym_call_expression,
    STATE(350), 1,
      sym_integer,
    STATE(371), 1,
      aux_sym__path_expression_repeat1,
    STATE(450), 1,
      sym__unary_expression,
    STATE(451), 1,
      sym__prefix_postfix_expression,
    STATE(452), 1,
      sym__binary_expression,
    STATE(453), 1,
      sym__and_expression,
    STATE(457), 1,
      sym_trace32_hll_variable,
    STATE(459), 1,
      sym__file_dialog,
    STATE(1550), 1,
      sym__address_binary_expression,
    STATE(2354), 1,
      sym__function_identifier,
    STATE(2355), 1,
      sym__hll_var_call_expression_function,
    ACTIONS(84), 2,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
    ACTIONS(110), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(112), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(114), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(132), 2,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
    STATE(1575), 2,
      sym__address_expression,
      sym__parenthesized_address_expression,
    ACTIONS(1329), 3,
      sym_float,
      sym_time,
      sym_frequency,
    ACTIONS(1331), 4,
      sym_path,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
    STATE(374), 14,
      sym__expression,
      sym__parenthesized_expression,
      sym__path_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_assignment_expression,
      sym__literal,
      sym_address,
      sym_bitmask,
      sym_string,
      sym_character,
      sym_symbol,
      sym__special_command_operator,
      aux_sym__path_expression_repeat2,
  [21079] = 40,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(76), 1,
      anon_sym_BSLASH,
    ACTIONS(78), 1,
      anon_sym_SQUOTE,
    ACTIONS(80), 1,
      anon_sym_DQUOTE,
    ACTIONS(82), 1,
      sym_access_class,
    ACTIONS(90), 1,
      aux_sym_symbol_token1,
    ACTIONS(92), 1,
      aux_sym_symbol_token2,
    ACTIONS(98), 1,
      sym_path,
    ACTIONS(120), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(140), 1,
      sym_identifier,
    ACTIONS(167), 1,
      anon_sym_STAR,
    ACTIONS(169), 1,
      anon_sym_AMP,
    ACTIONS(177), 1,
      sym__decimal_number_pre_hook,
    ACTIONS(216), 1,
      anon_sym_LBRACE,
    ACTIONS(1135), 1,
      anon_sym_LPAREN,
    STATE(236), 1,
      sym_memory_space,
    STATE(967), 1,
      sym_macro,
    STATE(1034), 1,
      sym_call_expression,
    STATE(1035), 1,
      sym_integer,
    STATE(1049), 1,
      sym__hll_var_call_expression,
    STATE(1053), 1,
      aux_sym__path_expression_repeat2,
    STATE(1109), 1,
      sym__address_binary_expression,
    STATE(1218), 1,
      aux_sym__path_expression_repeat1,
    STATE(1399), 1,
      sym__unary_expression,
    STATE(1400), 1,
      sym__prefix_postfix_expression,
    STATE(1404), 1,
      sym__binary_expression,
    STATE(1406), 1,
      sym__and_expression,
    STATE(1412), 1,
      sym_trace32_hll_variable,
    STATE(1417), 1,
      sym__file_dialog,
    STATE(2257), 1,
      sym__function_identifier,
    STATE(2260), 1,
      sym__hll_var_call_expression_function,
    ACTIONS(60), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(62), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(88), 2,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
    ACTIONS(171), 2,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
    ACTIONS(222), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1099), 2,
      sym__address_expression,
      sym__parenthesized_address_expression,
    ACTIONS(218), 3,
      sym_float,
      sym_time,
      sym_frequency,
    ACTIONS(220), 3,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
    STATE(1454), 13,
      sym__expression,
      sym__parenthesized_expression,
      sym__path_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_assignment_expression,
      sym__literal,
      sym_address,
      sym_bitmask,
      sym_string,
      sym_character,
      sym_symbol,
      sym__special_command_operator,
  [21222] = 38,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(96), 1,
      sym__decimal_number_pre_hook,
    ACTIONS(100), 1,
      sym_identifier,
    ACTIONS(102), 1,
      anon_sym_LPAREN,
    ACTIONS(104), 1,
      anon_sym_LBRACE,
    ACTIONS(116), 1,
      anon_sym_STAR,
    ACTIONS(120), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(122), 1,
      anon_sym_BSLASH,
    ACTIONS(124), 1,
      anon_sym_SQUOTE,
    ACTIONS(126), 1,
      anon_sym_DQUOTE,
    ACTIONS(128), 1,
      sym_access_class,
    ACTIONS(134), 1,
      aux_sym_symbol_token1,
    ACTIONS(136), 1,
      aux_sym_symbol_token2,
    ACTIONS(695), 1,
      anon_sym_AMP,
    STATE(224), 1,
      sym_memory_space,
    STATE(328), 1,
      sym_macro,
    STATE(345), 1,
      sym__hll_var_call_expression,
    STATE(347), 1,
      sym_call_expression,
    STATE(350), 1,
      sym_integer,
    STATE(371), 1,
      aux_sym__path_expression_repeat1,
    STATE(450), 1,
      sym__unary_expression,
    STATE(451), 1,
      sym__prefix_postfix_expression,
    STATE(452), 1,
      sym__binary_expression,
    STATE(453), 1,
      sym__and_expression,
    STATE(457), 1,
      sym_trace32_hll_variable,
    STATE(459), 1,
      sym__file_dialog,
    STATE(1550), 1,
      sym__address_binary_expression,
    STATE(2354), 1,
      sym__function_identifier,
    STATE(2355), 1,
      sym__hll_var_call_expression_function,
    ACTIONS(84), 2,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
    ACTIONS(110), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(112), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(114), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(132), 2,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
    STATE(1575), 2,
      sym__address_expression,
      sym__parenthesized_address_expression,
    ACTIONS(1333), 3,
      sym_float,
      sym_time,
      sym_frequency,
    ACTIONS(1335), 4,
      sym_path,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
    STATE(384), 14,
      sym__expression,
      sym__parenthesized_expression,
      sym__path_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_assignment_expression,
      sym__literal,
      sym_address,
      sym_bitmask,
      sym_string,
      sym_character,
      sym_symbol,
      sym__special_command_operator,
      aux_sym__path_expression_repeat2,
  [21361] = 40,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(76), 1,
      anon_sym_BSLASH,
    ACTIONS(78), 1,
      anon_sym_SQUOTE,
    ACTIONS(80), 1,
      anon_sym_DQUOTE,
    ACTIONS(82), 1,
      sym_access_class,
    ACTIONS(90), 1,
      aux_sym_symbol_token1,
    ACTIONS(92), 1,
      aux_sym_symbol_token2,
    ACTIONS(98), 1,
      sym_path,
    ACTIONS(120), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(140), 1,
      sym_identifier,
    ACTIONS(145), 1,
      anon_sym_LBRACE,
    ACTIONS(147), 1,
      anon_sym_AMP,
    ACTIONS(155), 1,
      sym__decimal_number_pre_hook,
    ACTIONS(167), 1,
      anon_sym_STAR,
    ACTIONS(1127), 1,
      anon_sym_LPAREN,
    STATE(236), 1,
      sym_memory_space,
    STATE(972), 1,
      sym_macro,
    STATE(1053), 1,
      aux_sym__path_expression_repeat2,
    STATE(1061), 1,
      sym__hll_var_call_expression,
    STATE(1107), 1,
      sym__address_binary_expression,
    STATE(1108), 1,
      sym_call_expression,
    STATE(1110), 1,
      sym_integer,
    STATE(1218), 1,
      aux_sym__path_expression_repeat1,
    STATE(1399), 1,
      sym__unary_expression,
    STATE(1400), 1,
      sym__prefix_postfix_expression,
    STATE(1404), 1,
      sym__binary_expression,
    STATE(1406), 1,
      sym__and_expression,
    STATE(1412), 1,
      sym_trace32_hll_variable,
    STATE(1417), 1,
      sym__file_dialog,
    STATE(2349), 1,
      sym__function_identifier,
    STATE(2359), 1,
      sym__hll_var_call_expression_function,
    ACTIONS(60), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(62), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(88), 2,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
    ACTIONS(149), 2,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
    ACTIONS(222), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1125), 2,
      sym__address_expression,
      sym__parenthesized_address_expression,
    ACTIONS(151), 3,
      sym_float,
      sym_time,
      sym_frequency,
    ACTIONS(153), 3,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
    STATE(1501), 13,
      sym__expression,
      sym__parenthesized_expression,
      sym__path_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_assignment_expression,
      sym__literal,
      sym_address,
      sym_bitmask,
      sym_string,
      sym_character,
      sym_symbol,
      sym__special_command_operator,
  [21504] = 38,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(96), 1,
      sym__decimal_number_pre_hook,
    ACTIONS(100), 1,
      sym_identifier,
    ACTIONS(102), 1,
      anon_sym_LPAREN,
    ACTIONS(104), 1,
      anon_sym_LBRACE,
    ACTIONS(116), 1,
      anon_sym_STAR,
    ACTIONS(120), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(122), 1,
      anon_sym_BSLASH,
    ACTIONS(124), 1,
      anon_sym_SQUOTE,
    ACTIONS(126), 1,
      anon_sym_DQUOTE,
    ACTIONS(128), 1,
      sym_access_class,
    ACTIONS(134), 1,
      aux_sym_symbol_token1,
    ACTIONS(136), 1,
      aux_sym_symbol_token2,
    ACTIONS(695), 1,
      anon_sym_AMP,
    STATE(224), 1,
      sym_memory_space,
    STATE(328), 1,
      sym_macro,
    STATE(345), 1,
      sym__hll_var_call_expression,
    STATE(347), 1,
      sym_call_expression,
    STATE(350), 1,
      sym_integer,
    STATE(371), 1,
      aux_sym__path_expression_repeat1,
    STATE(450), 1,
      sym__unary_expression,
    STATE(451), 1,
      sym__prefix_postfix_expression,
    STATE(452), 1,
      sym__binary_expression,
    STATE(453), 1,
      sym__and_expression,
    STATE(457), 1,
      sym_trace32_hll_variable,
    STATE(459), 1,
      sym__file_dialog,
    STATE(1550), 1,
      sym__address_binary_expression,
    STATE(2354), 1,
      sym__function_identifier,
    STATE(2355), 1,
      sym__hll_var_call_expression_function,
    ACTIONS(84), 2,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
    ACTIONS(110), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(112), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(114), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(132), 2,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
    STATE(1575), 2,
      sym__address_expression,
      sym__parenthesized_address_expression,
    ACTIONS(1337), 3,
      sym_float,
      sym_time,
      sym_frequency,
    ACTIONS(1339), 4,
      sym_path,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
    STATE(376), 14,
      sym__expression,
      sym__parenthesized_expression,
      sym__path_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_assignment_expression,
      sym__literal,
      sym_address,
      sym_bitmask,
      sym_string,
      sym_character,
      sym_symbol,
      sym__special_command_operator,
      aux_sym__path_expression_repeat2,
  [21643] = 40,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(76), 1,
      anon_sym_BSLASH,
    ACTIONS(78), 1,
      anon_sym_SQUOTE,
    ACTIONS(80), 1,
      anon_sym_DQUOTE,
    ACTIONS(82), 1,
      sym_access_class,
    ACTIONS(90), 1,
      aux_sym_symbol_token1,
    ACTIONS(92), 1,
      aux_sym_symbol_token2,
    ACTIONS(98), 1,
      sym_path,
    ACTIONS(120), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(140), 1,
      sym_identifier,
    ACTIONS(145), 1,
      anon_sym_LBRACE,
    ACTIONS(147), 1,
      anon_sym_AMP,
    ACTIONS(155), 1,
      sym__decimal_number_pre_hook,
    ACTIONS(167), 1,
      anon_sym_STAR,
    ACTIONS(1127), 1,
      anon_sym_LPAREN,
    STATE(236), 1,
      sym_memory_space,
    STATE(972), 1,
      sym_macro,
    STATE(1053), 1,
      aux_sym__path_expression_repeat2,
    STATE(1061), 1,
      sym__hll_var_call_expression,
    STATE(1107), 1,
      sym__address_binary_expression,
    STATE(1108), 1,
      sym_call_expression,
    STATE(1110), 1,
      sym_integer,
    STATE(1218), 1,
      aux_sym__path_expression_repeat1,
    STATE(1399), 1,
      sym__unary_expression,
    STATE(1400), 1,
      sym__prefix_postfix_expression,
    STATE(1404), 1,
      sym__binary_expression,
    STATE(1406), 1,
      sym__and_expression,
    STATE(1412), 1,
      sym_trace32_hll_variable,
    STATE(1417), 1,
      sym__file_dialog,
    STATE(2349), 1,
      sym__function_identifier,
    STATE(2359), 1,
      sym__hll_var_call_expression_function,
    ACTIONS(60), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(62), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(88), 2,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
    ACTIONS(149), 2,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
    ACTIONS(222), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(1127), 2,
      sym__address_expression,
      sym__parenthesized_address_expression,
    ACTIONS(151), 3,
      sym_float,
      sym_time,
      sym_frequency,
    ACTIONS(153), 3,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
    STATE(1501), 13,
      sym__expression,
      sym__parenthesized_expression,
      sym__path_expression,
      sym_unary_expression,
      sym_binary_expression,
      sym_assignment_expression,
      sym__literal,
      sym_address,
      sym_bitmask,
      sym_string,
      sym_character,
      sym_symbol,
      sym__special_command_operator,
  [21786] = 43,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7), 1,
      sym_identifier,
    ACTIONS(9), 1,
      aux_sym_block_token1,
    ACTIONS(11), 1,
      aux_sym_subroutine_block_token1,
    ACTIONS(23), 1,
      anon_sym_AMP,
    ACTIONS(25), 1,
      aux_sym_macro_definition_token1,
    ACTIONS(29), 1,
      aux_sym_parameter_declaration_token3,
    ACTIONS(31), 1,
      aux_sym_subroutine_call_expression_token1,
    ACTIONS(35), 1,
      aux_sym__host_command_with_default_format_token1,
    ACTIONS(37), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(43), 1,
      sym_label_identifier,
    ACTIONS(262), 1,
      aux_sym_if_block_token1,
    ACTIONS(264), 1,
      aux_sym_while_block_token1,
    ACTIONS(266), 1,
      aux_sym_while_block_token2,
    ACTIONS(268), 1,
      aux_sym__repeat_block_pre_condition_format_token1,
    ACTIONS(270), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1341), 1,
      anon_sym_RPAREN,
    ACTIONS(1345), 1,
      sym__blank,
    STATE(294), 1,
      sym__label,
    STATE(298), 1,
      aux_sym_block_repeat1,
    STATE(1333), 1,
      sym_recursive_macro_expansion,
    STATE(1432), 1,
      sym__repeat_block_pre_condition_format,
    STATE(1469), 1,
      sym__repeat_block_post_condition_format,
    STATE(1981), 1,
      sym__hll_var_command_with_default_format,
    STATE(1982), 1,
      sym__var_command_with_non_hll_format,
    STATE(2020), 1,
      sym__command_identifier,
    STATE(2059), 1,
      sym_macro,
    STATE(2082), 1,
      sym_macro_definition_command,
    STATE(2243), 1,
      sym__hll_default_format_var_command,
    STATE(2271), 1,
      sym__hll_var_definition_command_expression,
    STATE(2285), 1,
      sym__hll_non_default_format_var_command,
    STATE(2298), 1,
      sym__hll_var_command,
    STATE(2308), 1,
      sym__host_command,
    STATE(2312), 1,
      sym__hll_var_if_command,
    STATE(2314), 1,
      sym__non_hll_var_command,
    STATE(2336), 1,
      sym__hll_var_definition_command,
    STATE(2340), 1,
      sym__host_command_with_default_format,
    STATE(2344), 1,
      sym__other_command,
    STATE(2360), 1,
      sym__var_command,
    ACTIONS(27), 2,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
    ACTIONS(1343), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(33), 3,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
    STATE(244), 14,
      sym_block,
      sym__statement,
      sym__non_labeled_statement,
      sym_labeled_expression,
      sym_subroutine_block,
      sym_if_block,
      sym_while_block,
      sym_repeat_block,
      sym_macro_assignment_expression,
      sym_macro_definition,
      sym_parameter_declaration,
      sym_subroutine_call_expression,
      sym_command_expression,
      aux_sym_block_repeat2,
  [21933] = 43,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7), 1,
      sym_identifier,
    ACTIONS(9), 1,
      aux_sym_block_token1,
    ACTIONS(11), 1,
      aux_sym_subroutine_block_token1,
    ACTIONS(23), 1,
      anon_sym_AMP,
    ACTIONS(25), 1,
      aux_sym_macro_definition_token1,
    ACTIONS(29), 1,
      aux_sym_parameter_declaration_token3,
    ACTIONS(31), 1,
      aux_sym_subroutine_call_expression_token1,
    ACTIONS(35), 1,
      aux_sym__host_command_with_default_format_token1,
    ACTIONS(37), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(43), 1,
      sym_label_identifier,
    ACTIONS(262), 1,
      aux_sym_if_block_token1,
    ACTIONS(264), 1,
      aux_sym_while_block_token1,
    ACTIONS(266), 1,
      aux_sym_while_block_token2,
    ACTIONS(268), 1,
      aux_sym__repeat_block_pre_condition_format_token1,
    ACTIONS(270), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1347), 1,
      anon_sym_RPAREN,
    ACTIONS(1351), 1,
      sym__blank,
    STATE(294), 1,
      sym__label,
    STATE(300), 1,
      aux_sym_block_repeat1,
    STATE(1333), 1,
      sym_recursive_macro_expansion,
    STATE(1432), 1,
      sym__repeat_block_pre_condition_format,
    STATE(1469), 1,
      sym__repeat_block_post_condition_format,
    STATE(1981), 1,
      sym__hll_var_command_with_default_format,
    STATE(1982), 1,
      sym__var_command_with_non_hll_format,
    STATE(2020), 1,
      sym__command_identifier,
    STATE(2059), 1,
      sym_macro,
    STATE(2082), 1,
      sym_macro_definition_command,
    STATE(2243), 1,
      sym__hll_default_format_var_command,
    STATE(2271), 1,
      sym__hll_var_definition_command_expression,
    STATE(2285), 1,
      sym__hll_non_default_format_var_command,
    STATE(2298), 1,
      sym__hll_var_command,
    STATE(2308), 1,
      sym__host_command,
    STATE(2312), 1,
      sym__hll_var_if_command,
    STATE(2314), 1,
      sym__non_hll_var_command,
    STATE(2336), 1,
      sym__hll_var_definition_command,
    STATE(2340), 1,
      sym__host_command_with_default_format,
    STATE(2344), 1,
      sym__other_command,
    STATE(2360), 1,
      sym__var_command,
    ACTIONS(27), 2,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
    ACTIONS(1349), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(33), 3,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
    STATE(249), 14,
      sym_block,
      sym__statement,
      sym__non_labeled_statement,
      sym_labeled_expression,
      sym_subroutine_block,
      sym_if_block,
      sym_while_block,
      sym_repeat_block,
      sym_macro_assignment_expression,
      sym_macro_definition,
      sym_parameter_declaration,
      sym_subroutine_call_expression,
      sym_command_expression,
      aux_sym_block_repeat2,
  [22080] = 43,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1353), 1,
      ts_builtin_sym_end,
    ACTIONS(1355), 1,
      sym_identifier,
    ACTIONS(1358), 1,
      aux_sym_block_token1,
    ACTIONS(1361), 1,
      aux_sym_subroutine_block_token1,
    ACTIONS(1364), 1,
      aux_sym_if_block_token1,
    ACTIONS(1367), 1,
      aux_sym_while_block_token1,
    ACTIONS(1370), 1,
      aux_sym_while_block_token2,
    ACTIONS(1373), 1,
      aux_sym__repeat_block_pre_condition_format_token1,
    ACTIONS(1376), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1379), 1,
      anon_sym_AMP,
    ACTIONS(1382), 1,
      aux_sym_macro_definition_token1,
    ACTIONS(1388), 1,
      aux_sym_parameter_declaration_token3,
    ACTIONS(1391), 1,
      aux_sym_subroutine_call_expression_token1,
    ACTIONS(1397), 1,
      aux_sym__host_command_with_default_format_token1,
    ACTIONS(1400), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(1406), 1,
      sym__blank,
    ACTIONS(1409), 1,
      sym_label_identifier,
    STATE(295), 1,
      sym__label,
    STATE(304), 1,
      aux_sym_block_repeat1,
    STATE(1333), 1,
      sym_recursive_macro_expansion,
    STATE(1432), 1,
      sym__repeat_block_pre_condition_format,
    STATE(1469), 1,
      sym__repeat_block_post_condition_format,
    STATE(1981), 1,
      sym__hll_var_command_with_default_format,
    STATE(1982), 1,
      sym__var_command_with_non_hll_format,
    STATE(2020), 1,
      sym__command_identifier,
    STATE(2059), 1,
      sym_macro,
    STATE(2082), 1,
      sym_macro_definition_command,
    STATE(2243), 1,
      sym__hll_default_format_var_command,
    STATE(2271), 1,
      sym__hll_var_definition_command_expression,
    STATE(2272), 1,
      sym__hll_var_if_command,
    STATE(2285), 1,
      sym__hll_non_default_format_var_command,
    STATE(2298), 1,
      sym__hll_var_command,
    STATE(2308), 1,
      sym__host_command,
    STATE(2314), 1,
      sym__non_hll_var_command,
    STATE(2336), 1,
      sym__hll_var_definition_command,
    STATE(2340), 1,
      sym__host_command_with_default_format,
    STATE(2344), 1,
      sym__other_command,
    STATE(2360), 1,
      sym__var_command,
    ACTIONS(1385), 2,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
    ACTIONS(1403), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(1394), 3,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
    STATE(245), 14,
      sym_block,
      sym__statement,
      sym__non_labeled_statement,
      sym_labeled_expression,
      sym_subroutine_block,
      sym_if_block,
      sym_while_block,
      sym_repeat_block,
      sym_macro_assignment_expression,
      sym_macro_definition,
      sym_parameter_declaration,
      sym_subroutine_call_expression,
      sym_command_expression,
      aux_sym_script_repeat1,
  [22227] = 43,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7), 1,
      sym_identifier,
    ACTIONS(9), 1,
      aux_sym_block_token1,
    ACTIONS(11), 1,
      aux_sym_subroutine_block_token1,
    ACTIONS(23), 1,
      anon_sym_AMP,
    ACTIONS(25), 1,
      aux_sym_macro_definition_token1,
    ACTIONS(29), 1,
      aux_sym_parameter_declaration_token3,
    ACTIONS(31), 1,
      aux_sym_subroutine_call_expression_token1,
    ACTIONS(35), 1,
      aux_sym__host_command_with_default_format_token1,
    ACTIONS(37), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(43), 1,
      sym_label_identifier,
    ACTIONS(262), 1,
      aux_sym_if_block_token1,
    ACTIONS(264), 1,
      aux_sym_while_block_token1,
    ACTIONS(266), 1,
      aux_sym_while_block_token2,
    ACTIONS(268), 1,
      aux_sym__repeat_block_pre_condition_format_token1,
    ACTIONS(270), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1412), 1,
      anon_sym_RPAREN,
    ACTIONS(1416), 1,
      sym__blank,
    STATE(294), 1,
      sym__label,
    STATE(299), 1,
      aux_sym_block_repeat1,
    STATE(1333), 1,
      sym_recursive_macro_expansion,
    STATE(1432), 1,
      sym__repeat_block_pre_condition_format,
    STATE(1469), 1,
      sym__repeat_block_post_condition_format,
    STATE(1981), 1,
      sym__hll_var_command_with_default_format,
    STATE(1982), 1,
      sym__var_command_with_non_hll_format,
    STATE(2020), 1,
      sym__command_identifier,
    STATE(2059), 1,
      sym_macro,
    STATE(2082), 1,
      sym_macro_definition_command,
    STATE(2243), 1,
      sym__hll_default_format_var_command,
    STATE(2271), 1,
      sym__hll_var_definition_command_expression,
    STATE(2285), 1,
      sym__hll_non_default_format_var_command,
    STATE(2298), 1,
      sym__hll_var_command,
    STATE(2308), 1,
      sym__host_command,
    STATE(2312), 1,
      sym__hll_var_if_command,
    STATE(2314), 1,
      sym__non_hll_var_command,
    STATE(2336), 1,
      sym__hll_var_definition_command,
    STATE(2340), 1,
      sym__host_command_with_default_format,
    STATE(2344), 1,
      sym__other_command,
    STATE(2360), 1,
      sym__var_command,
    ACTIONS(27), 2,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
    ACTIONS(1414), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(33), 3,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
    STATE(247), 14,
      sym_block,
      sym__statement,
      sym__non_labeled_statement,
      sym_labeled_expression,
      sym_subroutine_block,
      sym_if_block,
      sym_while_block,
      sym_repeat_block,
      sym_macro_assignment_expression,
      sym_macro_definition,
      sym_parameter_declaration,
      sym_subroutine_call_expression,
      sym_command_expression,
      aux_sym_block_repeat2,
  [22374] = 43,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7), 1,
      sym_identifier,
    ACTIONS(9), 1,
      aux_sym_block_token1,
    ACTIONS(11), 1,
      aux_sym_subroutine_block_token1,
    ACTIONS(23), 1,
      anon_sym_AMP,
    ACTIONS(25), 1,
      aux_sym_macro_definition_token1,
    ACTIONS(29), 1,
      aux_sym_parameter_declaration_token3,
    ACTIONS(31), 1,
      aux_sym_subroutine_call_expression_token1,
    ACTIONS(35), 1,
      aux_sym__host_command_with_default_format_token1,
    ACTIONS(37), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(43), 1,
      sym_label_identifier,
    ACTIONS(262), 1,
      aux_sym_if_block_token1,
    ACTIONS(264), 1,
      aux_sym_while_block_token1,
    ACTIONS(266), 1,
      aux_sym_while_block_token2,
    ACTIONS(268), 1,
      aux_sym__repeat_block_pre_condition_format_token1,
    ACTIONS(270), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1341), 1,
      anon_sym_RPAREN,
    ACTIONS(1345), 1,
      sym__blank,
    STATE(294), 1,
      sym__label,
    STATE(298), 1,
      aux_sym_block_repeat1,
    STATE(1333), 1,
      sym_recursive_macro_expansion,
    STATE(1432), 1,
      sym__repeat_block_pre_condition_format,
    STATE(1469), 1,
      sym__repeat_block_post_condition_format,
    STATE(1981), 1,
      sym__hll_var_command_with_default_format,
    STATE(1982), 1,
      sym__var_command_with_non_hll_format,
    STATE(2020), 1,
      sym__command_identifier,
    STATE(2059), 1,
      sym_macro,
    STATE(2082), 1,
      sym_macro_definition_command,
    STATE(2243), 1,
      sym__hll_default_format_var_command,
    STATE(2271), 1,
      sym__hll_var_definition_command_expression,
    STATE(2285), 1,
      sym__hll_non_default_format_var_command,
    STATE(2298), 1,
      sym__hll_var_command,
    STATE(2308), 1,
      sym__host_command,
    STATE(2312), 1,
      sym__hll_var_if_command,
    STATE(2314), 1,
      sym__non_hll_var_command,
    STATE(2336), 1,
      sym__hll_var_definition_command,
    STATE(2340), 1,
      sym__host_command_with_default_format,
    STATE(2344), 1,
      sym__other_command,
    STATE(2360), 1,
      sym__var_command,
    ACTIONS(27), 2,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
    ACTIONS(1349), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(33), 3,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
    STATE(249), 14,
      sym_block,
      sym__statement,
      sym__non_labeled_statement,
      sym_labeled_expression,
      sym_subroutine_block,
      sym_if_block,
      sym_while_block,
      sym_repeat_block,
      sym_macro_assignment_expression,
      sym_macro_definition,
      sym_parameter_declaration,
      sym_subroutine_call_expression,
      sym_command_expression,
      aux_sym_block_repeat2,
  [22521] = 43,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7), 1,
      sym_identifier,
    ACTIONS(9), 1,
      aux_sym_block_token1,
    ACTIONS(11), 1,
      aux_sym_subroutine_block_token1,
    ACTIONS(13), 1,
      aux_sym_if_block_token1,
    ACTIONS(15), 1,
      aux_sym_while_block_token1,
    ACTIONS(17), 1,
      aux_sym_while_block_token2,
    ACTIONS(19), 1,
      aux_sym__repeat_block_pre_condition_format_token1,
    ACTIONS(21), 1,
      anon_sym_AMP_AMP,
    ACTIONS(23), 1,
      anon_sym_AMP,
    ACTIONS(25), 1,
      aux_sym_macro_definition_token1,
    ACTIONS(29), 1,
      aux_sym_parameter_declaration_token3,
    ACTIONS(31), 1,
      aux_sym_subroutine_call_expression_token1,
    ACTIONS(35), 1,
      aux_sym__host_command_with_default_format_token1,
    ACTIONS(37), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(41), 1,
      sym__blank,
    ACTIONS(43), 1,
      sym_label_identifier,
    ACTIONS(1418), 1,
      ts_builtin_sym_end,
    STATE(295), 1,
      sym__label,
    STATE(304), 1,
      aux_sym_block_repeat1,
    STATE(1333), 1,
      sym_recursive_macro_expansion,
    STATE(1432), 1,
      sym__repeat_block_pre_condition_format,
    STATE(1469), 1,
      sym__repeat_block_post_condition_format,
    STATE(1981), 1,
      sym__hll_var_command_with_default_format,
    STATE(1982), 1,
      sym__var_command_with_non_hll_format,
    STATE(2020), 1,
      sym__command_identifier,
    STATE(2059), 1,
      sym_macro,
    STATE(2082), 1,
      sym_macro_definition_command,
    STATE(2243), 1,
      sym__hll_default_format_var_command,
    STATE(2271), 1,
      sym__hll_var_definition_command_expression,
    STATE(2272), 1,
      sym__hll_var_if_command,
    STATE(2285), 1,
      sym__hll_non_default_format_var_command,
    STATE(2298), 1,
      sym__hll_var_command,
    STATE(2308), 1,
      sym__host_command,
    STATE(2314), 1,
      sym__non_hll_var_command,
    STATE(2336), 1,
      sym__hll_var_definition_command,
    STATE(2340), 1,
      sym__host_command_with_default_format,
    STATE(2344), 1,
      sym__other_command,
    STATE(2360), 1,
      sym__var_command,
    ACTIONS(27), 2,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
    ACTIONS(1420), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(33), 3,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
    STATE(245), 14,
      sym_block,
      sym__statement,
      sym__non_labeled_statement,
      sym_labeled_expression,
      sym_subroutine_block,
      sym_if_block,
      sym_while_block,
      sym_repeat_block,
      sym_macro_assignment_expression,
      sym_macro_definition,
      sym_parameter_declaration,
      sym_subroutine_call_expression,
      sym_command_expression,
      aux_sym_script_repeat1,
  [22668] = 43,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1422), 1,
      sym_identifier,
    ACTIONS(1425), 1,
      aux_sym_block_token1,
    ACTIONS(1428), 1,
      anon_sym_RPAREN,
    ACTIONS(1430), 1,
      aux_sym_subroutine_block_token1,
    ACTIONS(1433), 1,
      aux_sym_if_block_token1,
    ACTIONS(1436), 1,
      aux_sym_while_block_token1,
    ACTIONS(1439), 1,
      aux_sym_while_block_token2,
    ACTIONS(1442), 1,
      aux_sym__repeat_block_pre_condition_format_token1,
    ACTIONS(1445), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1448), 1,
      anon_sym_AMP,
    ACTIONS(1451), 1,
      aux_sym_macro_definition_token1,
    ACTIONS(1457), 1,
      aux_sym_parameter_declaration_token3,
    ACTIONS(1460), 1,
      aux_sym_subroutine_call_expression_token1,
    ACTIONS(1466), 1,
      aux_sym__host_command_with_default_format_token1,
    ACTIONS(1469), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(1475), 1,
      sym__blank,
    ACTIONS(1478), 1,
      sym_label_identifier,
    STATE(294), 1,
      sym__label,
    STATE(301), 1,
      aux_sym_block_repeat1,
    STATE(1333), 1,
      sym_recursive_macro_expansion,
    STATE(1432), 1,
      sym__repeat_block_pre_condition_format,
    STATE(1469), 1,
      sym__repeat_block_post_condition_format,
    STATE(1981), 1,
      sym__hll_var_command_with_default_format,
    STATE(1982), 1,
      sym__var_command_with_non_hll_format,
    STATE(2020), 1,
      sym__command_identifier,
    STATE(2059), 1,
      sym_macro,
    STATE(2082), 1,
      sym_macro_definition_command,
    STATE(2243), 1,
      sym__hll_default_format_var_command,
    STATE(2271), 1,
      sym__hll_var_definition_command_expression,
    STATE(2285), 1,
      sym__hll_non_default_format_var_command,
    STATE(2298), 1,
      sym__hll_var_command,
    STATE(2308), 1,
      sym__host_command,
    STATE(2312), 1,
      sym__hll_var_if_command,
    STATE(2314), 1,
      sym__non_hll_var_command,
    STATE(2336), 1,
      sym__hll_var_definition_command,
    STATE(2340), 1,
      sym__host_command_with_default_format,
    STATE(2344), 1,
      sym__other_command,
    STATE(2360), 1,
      sym__var_command,
    ACTIONS(1454), 2,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
    ACTIONS(1472), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(1463), 3,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
    STATE(249), 14,
      sym_block,
      sym__statement,
      sym__non_labeled_statement,
      sym_labeled_expression,
      sym_subroutine_block,
      sym_if_block,
      sym_while_block,
      sym_repeat_block,
      sym_macro_assignment_expression,
      sym_macro_definition,
      sym_parameter_declaration,
      sym_subroutine_call_expression,
      sym_command_expression,
      aux_sym_block_repeat2,
  [22815] = 43,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7), 1,
      sym_identifier,
    ACTIONS(9), 1,
      aux_sym_block_token1,
    ACTIONS(11), 1,
      aux_sym_subroutine_block_token1,
    ACTIONS(21), 1,
      anon_sym_AMP_AMP,
    ACTIONS(23), 1,
      anon_sym_AMP,
    ACTIONS(25), 1,
      aux_sym_macro_definition_token1,
    ACTIONS(29), 1,
      aux_sym_parameter_declaration_token3,
    ACTIONS(31), 1,
      aux_sym_subroutine_call_expression_token1,
    ACTIONS(35), 1,
      aux_sym__host_command_with_default_format_token1,
    ACTIONS(37), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(43), 1,
      sym_label_identifier,
    ACTIONS(276), 1,
      aux_sym_if_block_token1,
    ACTIONS(278), 1,
      aux_sym_while_block_token1,
    ACTIONS(280), 1,
      aux_sym_while_block_token2,
    ACTIONS(282), 1,
      aux_sym__repeat_block_pre_condition_format_token1,
    ACTIONS(1483), 1,
      sym__blank,
    STATE(296), 1,
      sym__label,
    STATE(307), 1,
      aux_sym_block_repeat1,
    STATE(1333), 1,
      sym_recursive_macro_expansion,
    STATE(1432), 1,
      sym__repeat_block_pre_condition_format,
    STATE(1469), 1,
      sym__repeat_block_post_condition_format,
    STATE(1511), 1,
      aux_sym_subroutine_block_repeat1,
    STATE(1981), 1,
      sym__hll_var_command_with_default_format,
    STATE(1982), 1,
      sym__var_command_with_non_hll_format,
    STATE(2020), 1,
      sym__command_identifier,
    STATE(2059), 1,
      sym_macro,
    STATE(2082), 1,
      sym_macro_definition_command,
    STATE(2243), 1,
      sym__hll_default_format_var_command,
    STATE(2271), 1,
      sym__hll_var_definition_command_expression,
    STATE(2285), 1,
      sym__hll_non_default_format_var_command,
    STATE(2298), 1,
      sym__hll_var_command,
    STATE(2308), 1,
      sym__host_command,
    STATE(2314), 1,
      sym__non_hll_var_command,
    STATE(2325), 1,
      sym__hll_var_if_command,
    STATE(2336), 1,
      sym__hll_var_definition_command,
    STATE(2340), 1,
      sym__host_command_with_default_format,
    STATE(2344), 1,
      sym__other_command,
    STATE(2360), 1,
      sym__var_command,
    ACTIONS(27), 2,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
    ACTIONS(1481), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(33), 3,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
    STATE(1072), 13,
      sym_block,
      sym__statement,
      sym__non_labeled_statement,
      sym_labeled_expression,
      sym_subroutine_block,
      sym_if_block,
      sym_while_block,
      sym_repeat_block,
      sym_macro_assignment_expression,
      sym_macro_definition,
      sym_parameter_declaration,
      sym_subroutine_call_expression,
      sym_command_expression,
  [22961] = 43,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7), 1,
      sym_identifier,
    ACTIONS(9), 1,
      aux_sym_block_token1,
    ACTIONS(11), 1,
      aux_sym_subroutine_block_token1,
    ACTIONS(23), 1,
      anon_sym_AMP,
    ACTIONS(25), 1,
      aux_sym_macro_definition_token1,
    ACTIONS(29), 1,
      aux_sym_parameter_declaration_token3,
    ACTIONS(31), 1,
      aux_sym_subroutine_call_expression_token1,
    ACTIONS(35), 1,
      aux_sym__host_command_with_default_format_token1,
    ACTIONS(37), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(43), 1,
      sym_label_identifier,
    ACTIONS(270), 1,
      anon_sym_AMP_AMP,
    ACTIONS(288), 1,
      aux_sym_if_block_token1,
    ACTIONS(290), 1,
      aux_sym_while_block_token1,
    ACTIONS(292), 1,
      aux_sym_while_block_token2,
    ACTIONS(294), 1,
      aux_sym__repeat_block_pre_condition_format_token1,
    ACTIONS(1485), 1,
      sym__blank,
    STATE(297), 1,
      sym__label,
    STATE(308), 1,
      aux_sym_block_repeat1,
    STATE(1333), 1,
      sym_recursive_macro_expansion,
    STATE(1432), 1,
      sym__repeat_block_pre_condition_format,
    STATE(1469), 1,
      sym__repeat_block_post_condition_format,
    STATE(1511), 1,
      aux_sym_subroutine_block_repeat1,
    STATE(1981), 1,
      sym__hll_var_command_with_default_format,
    STATE(1982), 1,
      sym__var_command_with_non_hll_format,
    STATE(2020), 1,
      sym__command_identifier,
    STATE(2059), 1,
      sym_macro,
    STATE(2082), 1,
      sym_macro_definition_command,
    STATE(2243), 1,
      sym__hll_default_format_var_command,
    STATE(2271), 1,
      sym__hll_var_definition_command_expression,
    STATE(2285), 1,
      sym__hll_non_default_format_var_command,
    STATE(2298), 1,
      sym__hll_var_command,
    STATE(2308), 1,
      sym__host_command,
    STATE(2314), 1,
      sym__non_hll_var_command,
    STATE(2327), 1,
      sym__hll_var_if_command,
    STATE(2336), 1,
      sym__hll_var_definition_command,
    STATE(2340), 1,
      sym__host_command_with_default_format,
    STATE(2344), 1,
      sym__other_command,
    STATE(2360), 1,
      sym__var_command,
    ACTIONS(27), 2,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
    ACTIONS(1481), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(33), 3,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
    STATE(1434), 13,
      sym_block,
      sym__statement,
      sym__non_labeled_statement,
      sym_labeled_expression,
      sym_subroutine_block,
      sym_if_block,
      sym_while_block,
      sym_repeat_block,
      sym_macro_assignment_expression,
      sym_macro_definition,
      sym_parameter_declaration,
      sym_subroutine_call_expression,
      sym_command_expression,
  [23107] = 43,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7), 1,
      sym_identifier,
    ACTIONS(9), 1,
      aux_sym_block_token1,
    ACTIONS(11), 1,
      aux_sym_subroutine_block_token1,
    ACTIONS(13), 1,
      aux_sym_if_block_token1,
    ACTIONS(15), 1,
      aux_sym_while_block_token1,
    ACTIONS(17), 1,
      aux_sym_while_block_token2,
    ACTIONS(19), 1,
      aux_sym__repeat_block_pre_condition_format_token1,
    ACTIONS(21), 1,
      anon_sym_AMP_AMP,
    ACTIONS(23), 1,
      anon_sym_AMP,
    ACTIONS(25), 1,
      aux_sym_macro_definition_token1,
    ACTIONS(29), 1,
      aux_sym_parameter_declaration_token3,
    ACTIONS(31), 1,
      aux_sym_subroutine_call_expression_token1,
    ACTIONS(35), 1,
      aux_sym__host_command_with_default_format_token1,
    ACTIONS(37), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(41), 1,
      sym__blank,
    ACTIONS(43), 1,
      sym_label_identifier,
    STATE(295), 1,
      sym__label,
    STATE(304), 1,
      aux_sym_block_repeat1,
    STATE(1333), 1,
      sym_recursive_macro_expansion,
    STATE(1432), 1,
      sym__repeat_block_pre_condition_format,
    STATE(1469), 1,
      sym__repeat_block_post_condition_format,
    STATE(1511), 1,
      aux_sym_subroutine_block_repeat1,
    STATE(1981), 1,
      sym__hll_var_command_with_default_format,
    STATE(1982), 1,
      sym__var_command_with_non_hll_format,
    STATE(2020), 1,
      sym__command_identifier,
    STATE(2059), 1,
      sym_macro,
    STATE(2082), 1,
      sym_macro_definition_command,
    STATE(2243), 1,
      sym__hll_default_format_var_command,
    STATE(2271), 1,
      sym__hll_var_definition_command_expression,
    STATE(2272), 1,
      sym__hll_var_if_command,
    STATE(2285), 1,
      sym__hll_non_default_format_var_command,
    STATE(2298), 1,
      sym__hll_var_command,
    STATE(2308), 1,
      sym__host_command,
    STATE(2314), 1,
      sym__non_hll_var_command,
    STATE(2336), 1,
      sym__hll_var_definition_command,
    STATE(2340), 1,
      sym__host_command_with_default_format,
    STATE(2344), 1,
      sym__other_command,
    STATE(2360), 1,
      sym__var_command,
    ACTIONS(27), 2,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
    ACTIONS(1481), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(33), 3,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
    STATE(1438), 13,
      sym_block,
      sym__statement,
      sym__non_labeled_statement,
      sym_labeled_expression,
      sym_subroutine_block,
      sym_if_block,
      sym_while_block,
      sym_repeat_block,
      sym_macro_assignment_expression,
      sym_macro_definition,
      sym_parameter_declaration,
      sym_subroutine_call_expression,
      sym_command_expression,
  [23253] = 43,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7), 1,
      sym_identifier,
    ACTIONS(9), 1,
      aux_sym_block_token1,
    ACTIONS(11), 1,
      aux_sym_subroutine_block_token1,
    ACTIONS(13), 1,
      aux_sym_if_block_token1,
    ACTIONS(15), 1,
      aux_sym_while_block_token1,
    ACTIONS(17), 1,
      aux_sym_while_block_token2,
    ACTIONS(19), 1,
      aux_sym__repeat_block_pre_condition_format_token1,
    ACTIONS(21), 1,
      anon_sym_AMP_AMP,
    ACTIONS(23), 1,
      anon_sym_AMP,
    ACTIONS(25), 1,
      aux_sym_macro_definition_token1,
    ACTIONS(29), 1,
      aux_sym_parameter_declaration_token3,
    ACTIONS(31), 1,
      aux_sym_subroutine_call_expression_token1,
    ACTIONS(35), 1,
      aux_sym__host_command_with_default_format_token1,
    ACTIONS(37), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(41), 1,
      sym__blank,
    ACTIONS(43), 1,
      sym_label_identifier,
    STATE(279), 1,
      aux_sym_subroutine_block_repeat1,
    STATE(295), 1,
      sym__label,
    STATE(304), 1,
      aux_sym_block_repeat1,
    STATE(1333), 1,
      sym_recursive_macro_expansion,
    STATE(1432), 1,
      sym__repeat_block_pre_condition_format,
    STATE(1469), 1,
      sym__repeat_block_post_condition_format,
    STATE(1981), 1,
      sym__hll_var_command_with_default_format,
    STATE(1982), 1,
      sym__var_command_with_non_hll_format,
    STATE(2020), 1,
      sym__command_identifier,
    STATE(2059), 1,
      sym_macro,
    STATE(2082), 1,
      sym_macro_definition_command,
    STATE(2243), 1,
      sym__hll_default_format_var_command,
    STATE(2271), 1,
      sym__hll_var_definition_command_expression,
    STATE(2272), 1,
      sym__hll_var_if_command,
    STATE(2285), 1,
      sym__hll_non_default_format_var_command,
    STATE(2298), 1,
      sym__hll_var_command,
    STATE(2308), 1,
      sym__host_command,
    STATE(2314), 1,
      sym__non_hll_var_command,
    STATE(2336), 1,
      sym__hll_var_definition_command,
    STATE(2340), 1,
      sym__host_command_with_default_format,
    STATE(2344), 1,
      sym__other_command,
    STATE(2360), 1,
      sym__var_command,
    ACTIONS(27), 2,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
    ACTIONS(1487), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(33), 3,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
    STATE(1468), 13,
      sym_block,
      sym__statement,
      sym__non_labeled_statement,
      sym_labeled_expression,
      sym_subroutine_block,
      sym_if_block,
      sym_while_block,
      sym_repeat_block,
      sym_macro_assignment_expression,
      sym_macro_definition,
      sym_parameter_declaration,
      sym_subroutine_call_expression,
      sym_command_expression,
  [23399] = 43,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7), 1,
      sym_identifier,
    ACTIONS(9), 1,
      aux_sym_block_token1,
    ACTIONS(11), 1,
      aux_sym_subroutine_block_token1,
    ACTIONS(13), 1,
      aux_sym_if_block_token1,
    ACTIONS(15), 1,
      aux_sym_while_block_token1,
    ACTIONS(17), 1,
      aux_sym_while_block_token2,
    ACTIONS(19), 1,
      aux_sym__repeat_block_pre_condition_format_token1,
    ACTIONS(21), 1,
      anon_sym_AMP_AMP,
    ACTIONS(23), 1,
      anon_sym_AMP,
    ACTIONS(25), 1,
      aux_sym_macro_definition_token1,
    ACTIONS(29), 1,
      aux_sym_parameter_declaration_token3,
    ACTIONS(31), 1,
      aux_sym_subroutine_call_expression_token1,
    ACTIONS(35), 1,
      aux_sym__host_command_with_default_format_token1,
    ACTIONS(37), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(41), 1,
      sym__blank,
    ACTIONS(43), 1,
      sym_label_identifier,
    STATE(295), 1,
      sym__label,
    STATE(304), 1,
      aux_sym_block_repeat1,
    STATE(1333), 1,
      sym_recursive_macro_expansion,
    STATE(1432), 1,
      sym__repeat_block_pre_condition_format,
    STATE(1469), 1,
      sym__repeat_block_post_condition_format,
    STATE(1511), 1,
      aux_sym_subroutine_block_repeat1,
    STATE(1981), 1,
      sym__hll_var_command_with_default_format,
    STATE(1982), 1,
      sym__var_command_with_non_hll_format,
    STATE(2020), 1,
      sym__command_identifier,
    STATE(2059), 1,
      sym_macro,
    STATE(2082), 1,
      sym_macro_definition_command,
    STATE(2243), 1,
      sym__hll_default_format_var_command,
    STATE(2271), 1,
      sym__hll_var_definition_command_expression,
    STATE(2272), 1,
      sym__hll_var_if_command,
    STATE(2285), 1,
      sym__hll_non_default_format_var_command,
    STATE(2298), 1,
      sym__hll_var_command,
    STATE(2308), 1,
      sym__host_command,
    STATE(2314), 1,
      sym__non_hll_var_command,
    STATE(2336), 1,
      sym__hll_var_definition_command,
    STATE(2340), 1,
      sym__host_command_with_default_format,
    STATE(2344), 1,
      sym__other_command,
    STATE(2360), 1,
      sym__var_command,
    ACTIONS(27), 2,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
    ACTIONS(1481), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(33), 3,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
    STATE(1384), 13,
      sym_block,
      sym__statement,
      sym__non_labeled_statement,
      sym_labeled_expression,
      sym_subroutine_block,
      sym_if_block,
      sym_while_block,
      sym_repeat_block,
      sym_macro_assignment_expression,
      sym_macro_definition,
      sym_parameter_declaration,
      sym_subroutine_call_expression,
      sym_command_expression,
  [23545] = 43,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7), 1,
      sym_identifier,
    ACTIONS(9), 1,
      aux_sym_block_token1,
    ACTIONS(11), 1,
      aux_sym_subroutine_block_token1,
    ACTIONS(13), 1,
      aux_sym_if_block_token1,
    ACTIONS(15), 1,
      aux_sym_while_block_token1,
    ACTIONS(17), 1,
      aux_sym_while_block_token2,
    ACTIONS(19), 1,
      aux_sym__repeat_block_pre_condition_format_token1,
    ACTIONS(21), 1,
      anon_sym_AMP_AMP,
    ACTIONS(23), 1,
      anon_sym_AMP,
    ACTIONS(25), 1,
      aux_sym_macro_definition_token1,
    ACTIONS(29), 1,
      aux_sym_parameter_declaration_token3,
    ACTIONS(31), 1,
      aux_sym_subroutine_call_expression_token1,
    ACTIONS(35), 1,
      aux_sym__host_command_with_default_format_token1,
    ACTIONS(37), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(41), 1,
      sym__blank,
    ACTIONS(43), 1,
      sym_label_identifier,
    STATE(256), 1,
      aux_sym_subroutine_block_repeat1,
    STATE(295), 1,
      sym__label,
    STATE(304), 1,
      aux_sym_block_repeat1,
    STATE(1333), 1,
      sym_recursive_macro_expansion,
    STATE(1432), 1,
      sym__repeat_block_pre_condition_format,
    STATE(1469), 1,
      sym__repeat_block_post_condition_format,
    STATE(1981), 1,
      sym__hll_var_command_with_default_format,
    STATE(1982), 1,
      sym__var_command_with_non_hll_format,
    STATE(2020), 1,
      sym__command_identifier,
    STATE(2059), 1,
      sym_macro,
    STATE(2082), 1,
      sym_macro_definition_command,
    STATE(2243), 1,
      sym__hll_default_format_var_command,
    STATE(2271), 1,
      sym__hll_var_definition_command_expression,
    STATE(2272), 1,
      sym__hll_var_if_command,
    STATE(2285), 1,
      sym__hll_non_default_format_var_command,
    STATE(2298), 1,
      sym__hll_var_command,
    STATE(2308), 1,
      sym__host_command,
    STATE(2314), 1,
      sym__non_hll_var_command,
    STATE(2336), 1,
      sym__hll_var_definition_command,
    STATE(2340), 1,
      sym__host_command_with_default_format,
    STATE(2344), 1,
      sym__other_command,
    STATE(2360), 1,
      sym__var_command,
    ACTIONS(27), 2,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
    ACTIONS(1489), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(33), 3,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
    STATE(1448), 13,
      sym_block,
      sym__statement,
      sym__non_labeled_statement,
      sym_labeled_expression,
      sym_subroutine_block,
      sym_if_block,
      sym_while_block,
      sym_repeat_block,
      sym_macro_assignment_expression,
      sym_macro_definition,
      sym_parameter_declaration,
      sym_subroutine_call_expression,
      sym_command_expression,
  [23691] = 43,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7), 1,
      sym_identifier,
    ACTIONS(9), 1,
      aux_sym_block_token1,
    ACTIONS(11), 1,
      aux_sym_subroutine_block_token1,
    ACTIONS(13), 1,
      aux_sym_if_block_token1,
    ACTIONS(15), 1,
      aux_sym_while_block_token1,
    ACTIONS(17), 1,
      aux_sym_while_block_token2,
    ACTIONS(19), 1,
      aux_sym__repeat_block_pre_condition_format_token1,
    ACTIONS(21), 1,
      anon_sym_AMP_AMP,
    ACTIONS(23), 1,
      anon_sym_AMP,
    ACTIONS(25), 1,
      aux_sym_macro_definition_token1,
    ACTIONS(29), 1,
      aux_sym_parameter_declaration_token3,
    ACTIONS(31), 1,
      aux_sym_subroutine_call_expression_token1,
    ACTIONS(35), 1,
      aux_sym__host_command_with_default_format_token1,
    ACTIONS(37), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(41), 1,
      sym__blank,
    ACTIONS(43), 1,
      sym_label_identifier,
    STATE(295), 1,
      sym__label,
    STATE(304), 1,
      aux_sym_block_repeat1,
    STATE(1333), 1,
      sym_recursive_macro_expansion,
    STATE(1432), 1,
      sym__repeat_block_pre_condition_format,
    STATE(1469), 1,
      sym__repeat_block_post_condition_format,
    STATE(1511), 1,
      aux_sym_subroutine_block_repeat1,
    STATE(1981), 1,
      sym__hll_var_command_with_default_format,
    STATE(1982), 1,
      sym__var_command_with_non_hll_format,
    STATE(2020), 1,
      sym__command_identifier,
    STATE(2059), 1,
      sym_macro,
    STATE(2082), 1,
      sym_macro_definition_command,
    STATE(2243), 1,
      sym__hll_default_format_var_command,
    STATE(2271), 1,
      sym__hll_var_definition_command_expression,
    STATE(2272), 1,
      sym__hll_var_if_command,
    STATE(2285), 1,
      sym__hll_non_default_format_var_command,
    STATE(2298), 1,
      sym__hll_var_command,
    STATE(2308), 1,
      sym__host_command,
    STATE(2314), 1,
      sym__non_hll_var_command,
    STATE(2336), 1,
      sym__hll_var_definition_command,
    STATE(2340), 1,
      sym__host_command_with_default_format,
    STATE(2344), 1,
      sym__other_command,
    STATE(2360), 1,
      sym__var_command,
    ACTIONS(27), 2,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
    ACTIONS(1481), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(33), 3,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
    STATE(1434), 13,
      sym_block,
      sym__statement,
      sym__non_labeled_statement,
      sym_labeled_expression,
      sym_subroutine_block,
      sym_if_block,
      sym_while_block,
      sym_repeat_block,
      sym_macro_assignment_expression,
      sym_macro_definition,
      sym_parameter_declaration,
      sym_subroutine_call_expression,
      sym_command_expression,
  [23837] = 43,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7), 1,
      sym_identifier,
    ACTIONS(9), 1,
      aux_sym_block_token1,
    ACTIONS(11), 1,
      aux_sym_subroutine_block_token1,
    ACTIONS(23), 1,
      anon_sym_AMP,
    ACTIONS(25), 1,
      aux_sym_macro_definition_token1,
    ACTIONS(29), 1,
      aux_sym_parameter_declaration_token3,
    ACTIONS(31), 1,
      aux_sym_subroutine_call_expression_token1,
    ACTIONS(35), 1,
      aux_sym__host_command_with_default_format_token1,
    ACTIONS(37), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(43), 1,
      sym_label_identifier,
    ACTIONS(262), 1,
      aux_sym_if_block_token1,
    ACTIONS(264), 1,
      aux_sym_while_block_token1,
    ACTIONS(266), 1,
      aux_sym_while_block_token2,
    ACTIONS(268), 1,
      aux_sym__repeat_block_pre_condition_format_token1,
    ACTIONS(270), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1493), 1,
      sym__blank,
    STATE(258), 1,
      aux_sym_subroutine_block_repeat1,
    STATE(294), 1,
      sym__label,
    STATE(301), 1,
      aux_sym_block_repeat1,
    STATE(1333), 1,
      sym_recursive_macro_expansion,
    STATE(1432), 1,
      sym__repeat_block_pre_condition_format,
    STATE(1469), 1,
      sym__repeat_block_post_condition_format,
    STATE(1981), 1,
      sym__hll_var_command_with_default_format,
    STATE(1982), 1,
      sym__var_command_with_non_hll_format,
    STATE(2020), 1,
      sym__command_identifier,
    STATE(2059), 1,
      sym_macro,
    STATE(2082), 1,
      sym_macro_definition_command,
    STATE(2243), 1,
      sym__hll_default_format_var_command,
    STATE(2271), 1,
      sym__hll_var_definition_command_expression,
    STATE(2285), 1,
      sym__hll_non_default_format_var_command,
    STATE(2298), 1,
      sym__hll_var_command,
    STATE(2308), 1,
      sym__host_command,
    STATE(2312), 1,
      sym__hll_var_if_command,
    STATE(2314), 1,
      sym__non_hll_var_command,
    STATE(2336), 1,
      sym__hll_var_definition_command,
    STATE(2340), 1,
      sym__host_command_with_default_format,
    STATE(2344), 1,
      sym__other_command,
    STATE(2360), 1,
      sym__var_command,
    ACTIONS(27), 2,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
    ACTIONS(1491), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(33), 3,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
    STATE(1379), 13,
      sym_block,
      sym__statement,
      sym__non_labeled_statement,
      sym_labeled_expression,
      sym_subroutine_block,
      sym_if_block,
      sym_while_block,
      sym_repeat_block,
      sym_macro_assignment_expression,
      sym_macro_definition,
      sym_parameter_declaration,
      sym_subroutine_call_expression,
      sym_command_expression,
  [23983] = 43,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7), 1,
      sym_identifier,
    ACTIONS(9), 1,
      aux_sym_block_token1,
    ACTIONS(11), 1,
      aux_sym_subroutine_block_token1,
    ACTIONS(23), 1,
      anon_sym_AMP,
    ACTIONS(25), 1,
      aux_sym_macro_definition_token1,
    ACTIONS(29), 1,
      aux_sym_parameter_declaration_token3,
    ACTIONS(31), 1,
      aux_sym_subroutine_call_expression_token1,
    ACTIONS(35), 1,
      aux_sym__host_command_with_default_format_token1,
    ACTIONS(37), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(43), 1,
      sym_label_identifier,
    ACTIONS(262), 1,
      aux_sym_if_block_token1,
    ACTIONS(264), 1,
      aux_sym_while_block_token1,
    ACTIONS(266), 1,
      aux_sym_while_block_token2,
    ACTIONS(268), 1,
      aux_sym__repeat_block_pre_condition_format_token1,
    ACTIONS(270), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1493), 1,
      sym__blank,
    STATE(294), 1,
      sym__label,
    STATE(301), 1,
      aux_sym_block_repeat1,
    STATE(1333), 1,
      sym_recursive_macro_expansion,
    STATE(1432), 1,
      sym__repeat_block_pre_condition_format,
    STATE(1469), 1,
      sym__repeat_block_post_condition_format,
    STATE(1511), 1,
      aux_sym_subroutine_block_repeat1,
    STATE(1981), 1,
      sym__hll_var_command_with_default_format,
    STATE(1982), 1,
      sym__var_command_with_non_hll_format,
    STATE(2020), 1,
      sym__command_identifier,
    STATE(2059), 1,
      sym_macro,
    STATE(2082), 1,
      sym_macro_definition_command,
    STATE(2243), 1,
      sym__hll_default_format_var_command,
    STATE(2271), 1,
      sym__hll_var_definition_command_expression,
    STATE(2285), 1,
      sym__hll_non_default_format_var_command,
    STATE(2298), 1,
      sym__hll_var_command,
    STATE(2308), 1,
      sym__host_command,
    STATE(2312), 1,
      sym__hll_var_if_command,
    STATE(2314), 1,
      sym__non_hll_var_command,
    STATE(2336), 1,
      sym__hll_var_definition_command,
    STATE(2340), 1,
      sym__host_command_with_default_format,
    STATE(2344), 1,
      sym__other_command,
    STATE(2360), 1,
      sym__var_command,
    ACTIONS(27), 2,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
    ACTIONS(1481), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(33), 3,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
    STATE(1384), 13,
      sym_block,
      sym__statement,
      sym__non_labeled_statement,
      sym_labeled_expression,
      sym_subroutine_block,
      sym_if_block,
      sym_while_block,
      sym_repeat_block,
      sym_macro_assignment_expression,
      sym_macro_definition,
      sym_parameter_declaration,
      sym_subroutine_call_expression,
      sym_command_expression,
  [24129] = 43,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7), 1,
      sym_identifier,
    ACTIONS(9), 1,
      aux_sym_block_token1,
    ACTIONS(11), 1,
      aux_sym_subroutine_block_token1,
    ACTIONS(23), 1,
      anon_sym_AMP,
    ACTIONS(25), 1,
      aux_sym_macro_definition_token1,
    ACTIONS(29), 1,
      aux_sym_parameter_declaration_token3,
    ACTIONS(31), 1,
      aux_sym_subroutine_call_expression_token1,
    ACTIONS(35), 1,
      aux_sym__host_command_with_default_format_token1,
    ACTIONS(37), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(43), 1,
      sym_label_identifier,
    ACTIONS(270), 1,
      anon_sym_AMP_AMP,
    ACTIONS(288), 1,
      aux_sym_if_block_token1,
    ACTIONS(290), 1,
      aux_sym_while_block_token1,
    ACTIONS(292), 1,
      aux_sym_while_block_token2,
    ACTIONS(294), 1,
      aux_sym__repeat_block_pre_condition_format_token1,
    ACTIONS(1485), 1,
      sym__blank,
    STATE(262), 1,
      aux_sym_subroutine_block_repeat1,
    STATE(297), 1,
      sym__label,
    STATE(308), 1,
      aux_sym_block_repeat1,
    STATE(1333), 1,
      sym_recursive_macro_expansion,
    STATE(1432), 1,
      sym__repeat_block_pre_condition_format,
    STATE(1469), 1,
      sym__repeat_block_post_condition_format,
    STATE(1981), 1,
      sym__hll_var_command_with_default_format,
    STATE(1982), 1,
      sym__var_command_with_non_hll_format,
    STATE(2020), 1,
      sym__command_identifier,
    STATE(2059), 1,
      sym_macro,
    STATE(2082), 1,
      sym_macro_definition_command,
    STATE(2243), 1,
      sym__hll_default_format_var_command,
    STATE(2271), 1,
      sym__hll_var_definition_command_expression,
    STATE(2285), 1,
      sym__hll_non_default_format_var_command,
    STATE(2298), 1,
      sym__hll_var_command,
    STATE(2308), 1,
      sym__host_command,
    STATE(2314), 1,
      sym__non_hll_var_command,
    STATE(2327), 1,
      sym__hll_var_if_command,
    STATE(2336), 1,
      sym__hll_var_definition_command,
    STATE(2340), 1,
      sym__host_command_with_default_format,
    STATE(2344), 1,
      sym__other_command,
    STATE(2360), 1,
      sym__var_command,
    ACTIONS(27), 2,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
    ACTIONS(1495), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(33), 3,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
    STATE(1123), 13,
      sym_block,
      sym__statement,
      sym__non_labeled_statement,
      sym_labeled_expression,
      sym_subroutine_block,
      sym_if_block,
      sym_while_block,
      sym_repeat_block,
      sym_macro_assignment_expression,
      sym_macro_definition,
      sym_parameter_declaration,
      sym_subroutine_call_expression,
      sym_command_expression,
  [24275] = 43,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7), 1,
      sym_identifier,
    ACTIONS(9), 1,
      aux_sym_block_token1,
    ACTIONS(11), 1,
      aux_sym_subroutine_block_token1,
    ACTIONS(23), 1,
      anon_sym_AMP,
    ACTIONS(25), 1,
      aux_sym_macro_definition_token1,
    ACTIONS(29), 1,
      aux_sym_parameter_declaration_token3,
    ACTIONS(31), 1,
      aux_sym_subroutine_call_expression_token1,
    ACTIONS(35), 1,
      aux_sym__host_command_with_default_format_token1,
    ACTIONS(37), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(43), 1,
      sym_label_identifier,
    ACTIONS(262), 1,
      aux_sym_if_block_token1,
    ACTIONS(264), 1,
      aux_sym_while_block_token1,
    ACTIONS(266), 1,
      aux_sym_while_block_token2,
    ACTIONS(268), 1,
      aux_sym__repeat_block_pre_condition_format_token1,
    ACTIONS(270), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1493), 1,
      sym__blank,
    STATE(263), 1,
      aux_sym_subroutine_block_repeat1,
    STATE(294), 1,
      sym__label,
    STATE(301), 1,
      aux_sym_block_repeat1,
    STATE(1333), 1,
      sym_recursive_macro_expansion,
    STATE(1432), 1,
      sym__repeat_block_pre_condition_format,
    STATE(1469), 1,
      sym__repeat_block_post_condition_format,
    STATE(1981), 1,
      sym__hll_var_command_with_default_format,
    STATE(1982), 1,
      sym__var_command_with_non_hll_format,
    STATE(2020), 1,
      sym__command_identifier,
    STATE(2059), 1,
      sym_macro,
    STATE(2082), 1,
      sym_macro_definition_command,
    STATE(2243), 1,
      sym__hll_default_format_var_command,
    STATE(2271), 1,
      sym__hll_var_definition_command_expression,
    STATE(2285), 1,
      sym__hll_non_default_format_var_command,
    STATE(2298), 1,
      sym__hll_var_command,
    STATE(2308), 1,
      sym__host_command,
    STATE(2312), 1,
      sym__hll_var_if_command,
    STATE(2314), 1,
      sym__non_hll_var_command,
    STATE(2336), 1,
      sym__hll_var_definition_command,
    STATE(2340), 1,
      sym__host_command_with_default_format,
    STATE(2344), 1,
      sym__other_command,
    STATE(2360), 1,
      sym__var_command,
    ACTIONS(27), 2,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
    ACTIONS(1497), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(33), 3,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
    STATE(1468), 13,
      sym_block,
      sym__statement,
      sym__non_labeled_statement,
      sym_labeled_expression,
      sym_subroutine_block,
      sym_if_block,
      sym_while_block,
      sym_repeat_block,
      sym_macro_assignment_expression,
      sym_macro_definition,
      sym_parameter_declaration,
      sym_subroutine_call_expression,
      sym_command_expression,
  [24421] = 43,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7), 1,
      sym_identifier,
    ACTIONS(9), 1,
      aux_sym_block_token1,
    ACTIONS(11), 1,
      aux_sym_subroutine_block_token1,
    ACTIONS(23), 1,
      anon_sym_AMP,
    ACTIONS(25), 1,
      aux_sym_macro_definition_token1,
    ACTIONS(29), 1,
      aux_sym_parameter_declaration_token3,
    ACTIONS(31), 1,
      aux_sym_subroutine_call_expression_token1,
    ACTIONS(35), 1,
      aux_sym__host_command_with_default_format_token1,
    ACTIONS(37), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(43), 1,
      sym_label_identifier,
    ACTIONS(262), 1,
      aux_sym_if_block_token1,
    ACTIONS(264), 1,
      aux_sym_while_block_token1,
    ACTIONS(266), 1,
      aux_sym_while_block_token2,
    ACTIONS(268), 1,
      aux_sym__repeat_block_pre_condition_format_token1,
    ACTIONS(270), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1493), 1,
      sym__blank,
    STATE(264), 1,
      aux_sym_subroutine_block_repeat1,
    STATE(294), 1,
      sym__label,
    STATE(301), 1,
      aux_sym_block_repeat1,
    STATE(1333), 1,
      sym_recursive_macro_expansion,
    STATE(1432), 1,
      sym__repeat_block_pre_condition_format,
    STATE(1469), 1,
      sym__repeat_block_post_condition_format,
    STATE(1981), 1,
      sym__hll_var_command_with_default_format,
    STATE(1982), 1,
      sym__var_command_with_non_hll_format,
    STATE(2020), 1,
      sym__command_identifier,
    STATE(2059), 1,
      sym_macro,
    STATE(2082), 1,
      sym_macro_definition_command,
    STATE(2243), 1,
      sym__hll_default_format_var_command,
    STATE(2271), 1,
      sym__hll_var_definition_command_expression,
    STATE(2285), 1,
      sym__hll_non_default_format_var_command,
    STATE(2298), 1,
      sym__hll_var_command,
    STATE(2308), 1,
      sym__host_command,
    STATE(2312), 1,
      sym__hll_var_if_command,
    STATE(2314), 1,
      sym__non_hll_var_command,
    STATE(2336), 1,
      sym__hll_var_definition_command,
    STATE(2340), 1,
      sym__host_command_with_default_format,
    STATE(2344), 1,
      sym__other_command,
    STATE(2360), 1,
      sym__var_command,
    ACTIONS(27), 2,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
    ACTIONS(1499), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(33), 3,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
    STATE(1504), 13,
      sym_block,
      sym__statement,
      sym__non_labeled_statement,
      sym_labeled_expression,
      sym_subroutine_block,
      sym_if_block,
      sym_while_block,
      sym_repeat_block,
      sym_macro_assignment_expression,
      sym_macro_definition,
      sym_parameter_declaration,
      sym_subroutine_call_expression,
      sym_command_expression,
  [24567] = 43,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7), 1,
      sym_identifier,
    ACTIONS(9), 1,
      aux_sym_block_token1,
    ACTIONS(11), 1,
      aux_sym_subroutine_block_token1,
    ACTIONS(23), 1,
      anon_sym_AMP,
    ACTIONS(25), 1,
      aux_sym_macro_definition_token1,
    ACTIONS(29), 1,
      aux_sym_parameter_declaration_token3,
    ACTIONS(31), 1,
      aux_sym_subroutine_call_expression_token1,
    ACTIONS(35), 1,
      aux_sym__host_command_with_default_format_token1,
    ACTIONS(37), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(43), 1,
      sym_label_identifier,
    ACTIONS(270), 1,
      anon_sym_AMP_AMP,
    ACTIONS(288), 1,
      aux_sym_if_block_token1,
    ACTIONS(290), 1,
      aux_sym_while_block_token1,
    ACTIONS(292), 1,
      aux_sym_while_block_token2,
    ACTIONS(294), 1,
      aux_sym__repeat_block_pre_condition_format_token1,
    ACTIONS(1485), 1,
      sym__blank,
    STATE(297), 1,
      sym__label,
    STATE(308), 1,
      aux_sym_block_repeat1,
    STATE(1333), 1,
      sym_recursive_macro_expansion,
    STATE(1432), 1,
      sym__repeat_block_pre_condition_format,
    STATE(1469), 1,
      sym__repeat_block_post_condition_format,
    STATE(1511), 1,
      aux_sym_subroutine_block_repeat1,
    STATE(1981), 1,
      sym__hll_var_command_with_default_format,
    STATE(1982), 1,
      sym__var_command_with_non_hll_format,
    STATE(2020), 1,
      sym__command_identifier,
    STATE(2059), 1,
      sym_macro,
    STATE(2082), 1,
      sym_macro_definition_command,
    STATE(2243), 1,
      sym__hll_default_format_var_command,
    STATE(2271), 1,
      sym__hll_var_definition_command_expression,
    STATE(2285), 1,
      sym__hll_non_default_format_var_command,
    STATE(2298), 1,
      sym__hll_var_command,
    STATE(2308), 1,
      sym__host_command,
    STATE(2314), 1,
      sym__non_hll_var_command,
    STATE(2327), 1,
      sym__hll_var_if_command,
    STATE(2336), 1,
      sym__hll_var_definition_command,
    STATE(2340), 1,
      sym__host_command_with_default_format,
    STATE(2344), 1,
      sym__other_command,
    STATE(2360), 1,
      sym__var_command,
    ACTIONS(27), 2,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
    ACTIONS(1481), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(33), 3,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
    STATE(1112), 13,
      sym_block,
      sym__statement,
      sym__non_labeled_statement,
      sym_labeled_expression,
      sym_subroutine_block,
      sym_if_block,
      sym_while_block,
      sym_repeat_block,
      sym_macro_assignment_expression,
      sym_macro_definition,
      sym_parameter_declaration,
      sym_subroutine_call_expression,
      sym_command_expression,
  [24713] = 43,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7), 1,
      sym_identifier,
    ACTIONS(9), 1,
      aux_sym_block_token1,
    ACTIONS(11), 1,
      aux_sym_subroutine_block_token1,
    ACTIONS(23), 1,
      anon_sym_AMP,
    ACTIONS(25), 1,
      aux_sym_macro_definition_token1,
    ACTIONS(29), 1,
      aux_sym_parameter_declaration_token3,
    ACTIONS(31), 1,
      aux_sym_subroutine_call_expression_token1,
    ACTIONS(35), 1,
      aux_sym__host_command_with_default_format_token1,
    ACTIONS(37), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(43), 1,
      sym_label_identifier,
    ACTIONS(262), 1,
      aux_sym_if_block_token1,
    ACTIONS(264), 1,
      aux_sym_while_block_token1,
    ACTIONS(266), 1,
      aux_sym_while_block_token2,
    ACTIONS(268), 1,
      aux_sym__repeat_block_pre_condition_format_token1,
    ACTIONS(270), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1493), 1,
      sym__blank,
    STATE(294), 1,
      sym__label,
    STATE(301), 1,
      aux_sym_block_repeat1,
    STATE(1333), 1,
      sym_recursive_macro_expansion,
    STATE(1432), 1,
      sym__repeat_block_pre_condition_format,
    STATE(1469), 1,
      sym__repeat_block_post_condition_format,
    STATE(1511), 1,
      aux_sym_subroutine_block_repeat1,
    STATE(1981), 1,
      sym__hll_var_command_with_default_format,
    STATE(1982), 1,
      sym__var_command_with_non_hll_format,
    STATE(2020), 1,
      sym__command_identifier,
    STATE(2059), 1,
      sym_macro,
    STATE(2082), 1,
      sym_macro_definition_command,
    STATE(2243), 1,
      sym__hll_default_format_var_command,
    STATE(2271), 1,
      sym__hll_var_definition_command_expression,
    STATE(2285), 1,
      sym__hll_non_default_format_var_command,
    STATE(2298), 1,
      sym__hll_var_command,
    STATE(2308), 1,
      sym__host_command,
    STATE(2312), 1,
      sym__hll_var_if_command,
    STATE(2314), 1,
      sym__non_hll_var_command,
    STATE(2336), 1,
      sym__hll_var_definition_command,
    STATE(2340), 1,
      sym__host_command_with_default_format,
    STATE(2344), 1,
      sym__other_command,
    STATE(2360), 1,
      sym__var_command,
    ACTIONS(27), 2,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
    ACTIONS(1481), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(33), 3,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
    STATE(1458), 13,
      sym_block,
      sym__statement,
      sym__non_labeled_statement,
      sym_labeled_expression,
      sym_subroutine_block,
      sym_if_block,
      sym_while_block,
      sym_repeat_block,
      sym_macro_assignment_expression,
      sym_macro_definition,
      sym_parameter_declaration,
      sym_subroutine_call_expression,
      sym_command_expression,
  [24859] = 43,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7), 1,
      sym_identifier,
    ACTIONS(9), 1,
      aux_sym_block_token1,
    ACTIONS(11), 1,
      aux_sym_subroutine_block_token1,
    ACTIONS(23), 1,
      anon_sym_AMP,
    ACTIONS(25), 1,
      aux_sym_macro_definition_token1,
    ACTIONS(29), 1,
      aux_sym_parameter_declaration_token3,
    ACTIONS(31), 1,
      aux_sym_subroutine_call_expression_token1,
    ACTIONS(35), 1,
      aux_sym__host_command_with_default_format_token1,
    ACTIONS(37), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(43), 1,
      sym_label_identifier,
    ACTIONS(262), 1,
      aux_sym_if_block_token1,
    ACTIONS(264), 1,
      aux_sym_while_block_token1,
    ACTIONS(266), 1,
      aux_sym_while_block_token2,
    ACTIONS(268), 1,
      aux_sym__repeat_block_pre_condition_format_token1,
    ACTIONS(270), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1493), 1,
      sym__blank,
    STATE(294), 1,
      sym__label,
    STATE(301), 1,
      aux_sym_block_repeat1,
    STATE(1333), 1,
      sym_recursive_macro_expansion,
    STATE(1432), 1,
      sym__repeat_block_pre_condition_format,
    STATE(1469), 1,
      sym__repeat_block_post_condition_format,
    STATE(1511), 1,
      aux_sym_subroutine_block_repeat1,
    STATE(1981), 1,
      sym__hll_var_command_with_default_format,
    STATE(1982), 1,
      sym__var_command_with_non_hll_format,
    STATE(2020), 1,
      sym__command_identifier,
    STATE(2059), 1,
      sym_macro,
    STATE(2082), 1,
      sym_macro_definition_command,
    STATE(2243), 1,
      sym__hll_default_format_var_command,
    STATE(2271), 1,
      sym__hll_var_definition_command_expression,
    STATE(2285), 1,
      sym__hll_non_default_format_var_command,
    STATE(2298), 1,
      sym__hll_var_command,
    STATE(2308), 1,
      sym__host_command,
    STATE(2312), 1,
      sym__hll_var_if_command,
    STATE(2314), 1,
      sym__non_hll_var_command,
    STATE(2336), 1,
      sym__hll_var_definition_command,
    STATE(2340), 1,
      sym__host_command_with_default_format,
    STATE(2344), 1,
      sym__other_command,
    STATE(2360), 1,
      sym__var_command,
    ACTIONS(27), 2,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
    ACTIONS(1481), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(33), 3,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
    STATE(1438), 13,
      sym_block,
      sym__statement,
      sym__non_labeled_statement,
      sym_labeled_expression,
      sym_subroutine_block,
      sym_if_block,
      sym_while_block,
      sym_repeat_block,
      sym_macro_assignment_expression,
      sym_macro_definition,
      sym_parameter_declaration,
      sym_subroutine_call_expression,
      sym_command_expression,
  [25005] = 43,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7), 1,
      sym_identifier,
    ACTIONS(9), 1,
      aux_sym_block_token1,
    ACTIONS(11), 1,
      aux_sym_subroutine_block_token1,
    ACTIONS(23), 1,
      anon_sym_AMP,
    ACTIONS(25), 1,
      aux_sym_macro_definition_token1,
    ACTIONS(29), 1,
      aux_sym_parameter_declaration_token3,
    ACTIONS(31), 1,
      aux_sym_subroutine_call_expression_token1,
    ACTIONS(35), 1,
      aux_sym__host_command_with_default_format_token1,
    ACTIONS(37), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(43), 1,
      sym_label_identifier,
    ACTIONS(262), 1,
      aux_sym_if_block_token1,
    ACTIONS(264), 1,
      aux_sym_while_block_token1,
    ACTIONS(266), 1,
      aux_sym_while_block_token2,
    ACTIONS(268), 1,
      aux_sym__repeat_block_pre_condition_format_token1,
    ACTIONS(270), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1493), 1,
      sym__blank,
    STATE(266), 1,
      aux_sym_subroutine_block_repeat1,
    STATE(294), 1,
      sym__label,
    STATE(301), 1,
      aux_sym_block_repeat1,
    STATE(1333), 1,
      sym_recursive_macro_expansion,
    STATE(1432), 1,
      sym__repeat_block_pre_condition_format,
    STATE(1469), 1,
      sym__repeat_block_post_condition_format,
    STATE(1981), 1,
      sym__hll_var_command_with_default_format,
    STATE(1982), 1,
      sym__var_command_with_non_hll_format,
    STATE(2020), 1,
      sym__command_identifier,
    STATE(2059), 1,
      sym_macro,
    STATE(2082), 1,
      sym_macro_definition_command,
    STATE(2243), 1,
      sym__hll_default_format_var_command,
    STATE(2271), 1,
      sym__hll_var_definition_command_expression,
    STATE(2285), 1,
      sym__hll_non_default_format_var_command,
    STATE(2298), 1,
      sym__hll_var_command,
    STATE(2308), 1,
      sym__host_command,
    STATE(2312), 1,
      sym__hll_var_if_command,
    STATE(2314), 1,
      sym__non_hll_var_command,
    STATE(2336), 1,
      sym__hll_var_definition_command,
    STATE(2340), 1,
      sym__host_command_with_default_format,
    STATE(2344), 1,
      sym__other_command,
    STATE(2360), 1,
      sym__var_command,
    ACTIONS(27), 2,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
    ACTIONS(1501), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(33), 3,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
    STATE(1448), 13,
      sym_block,
      sym__statement,
      sym__non_labeled_statement,
      sym_labeled_expression,
      sym_subroutine_block,
      sym_if_block,
      sym_while_block,
      sym_repeat_block,
      sym_macro_assignment_expression,
      sym_macro_definition,
      sym_parameter_declaration,
      sym_subroutine_call_expression,
      sym_command_expression,
  [25151] = 43,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7), 1,
      sym_identifier,
    ACTIONS(9), 1,
      aux_sym_block_token1,
    ACTIONS(11), 1,
      aux_sym_subroutine_block_token1,
    ACTIONS(23), 1,
      anon_sym_AMP,
    ACTIONS(25), 1,
      aux_sym_macro_definition_token1,
    ACTIONS(29), 1,
      aux_sym_parameter_declaration_token3,
    ACTIONS(31), 1,
      aux_sym_subroutine_call_expression_token1,
    ACTIONS(35), 1,
      aux_sym__host_command_with_default_format_token1,
    ACTIONS(37), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(43), 1,
      sym_label_identifier,
    ACTIONS(262), 1,
      aux_sym_if_block_token1,
    ACTIONS(264), 1,
      aux_sym_while_block_token1,
    ACTIONS(266), 1,
      aux_sym_while_block_token2,
    ACTIONS(268), 1,
      aux_sym__repeat_block_pre_condition_format_token1,
    ACTIONS(270), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1493), 1,
      sym__blank,
    STATE(294), 1,
      sym__label,
    STATE(301), 1,
      aux_sym_block_repeat1,
    STATE(1333), 1,
      sym_recursive_macro_expansion,
    STATE(1432), 1,
      sym__repeat_block_pre_condition_format,
    STATE(1469), 1,
      sym__repeat_block_post_condition_format,
    STATE(1511), 1,
      aux_sym_subroutine_block_repeat1,
    STATE(1981), 1,
      sym__hll_var_command_with_default_format,
    STATE(1982), 1,
      sym__var_command_with_non_hll_format,
    STATE(2020), 1,
      sym__command_identifier,
    STATE(2059), 1,
      sym_macro,
    STATE(2082), 1,
      sym_macro_definition_command,
    STATE(2243), 1,
      sym__hll_default_format_var_command,
    STATE(2271), 1,
      sym__hll_var_definition_command_expression,
    STATE(2285), 1,
      sym__hll_non_default_format_var_command,
    STATE(2298), 1,
      sym__hll_var_command,
    STATE(2308), 1,
      sym__host_command,
    STATE(2312), 1,
      sym__hll_var_if_command,
    STATE(2314), 1,
      sym__non_hll_var_command,
    STATE(2336), 1,
      sym__hll_var_definition_command,
    STATE(2340), 1,
      sym__host_command_with_default_format,
    STATE(2344), 1,
      sym__other_command,
    STATE(2360), 1,
      sym__var_command,
    ACTIONS(27), 2,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
    ACTIONS(1481), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(33), 3,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
    STATE(1434), 13,
      sym_block,
      sym__statement,
      sym__non_labeled_statement,
      sym_labeled_expression,
      sym_subroutine_block,
      sym_if_block,
      sym_while_block,
      sym_repeat_block,
      sym_macro_assignment_expression,
      sym_macro_definition,
      sym_parameter_declaration,
      sym_subroutine_call_expression,
      sym_command_expression,
  [25297] = 43,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7), 1,
      sym_identifier,
    ACTIONS(9), 1,
      aux_sym_block_token1,
    ACTIONS(11), 1,
      aux_sym_subroutine_block_token1,
    ACTIONS(23), 1,
      anon_sym_AMP,
    ACTIONS(25), 1,
      aux_sym_macro_definition_token1,
    ACTIONS(29), 1,
      aux_sym_parameter_declaration_token3,
    ACTIONS(31), 1,
      aux_sym_subroutine_call_expression_token1,
    ACTIONS(35), 1,
      aux_sym__host_command_with_default_format_token1,
    ACTIONS(37), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(43), 1,
      sym_label_identifier,
    ACTIONS(270), 1,
      anon_sym_AMP_AMP,
    ACTIONS(288), 1,
      aux_sym_if_block_token1,
    ACTIONS(290), 1,
      aux_sym_while_block_token1,
    ACTIONS(292), 1,
      aux_sym_while_block_token2,
    ACTIONS(294), 1,
      aux_sym__repeat_block_pre_condition_format_token1,
    ACTIONS(1485), 1,
      sym__blank,
    STATE(297), 1,
      sym__label,
    STATE(308), 1,
      aux_sym_block_repeat1,
    STATE(1333), 1,
      sym_recursive_macro_expansion,
    STATE(1432), 1,
      sym__repeat_block_pre_condition_format,
    STATE(1469), 1,
      sym__repeat_block_post_condition_format,
    STATE(1511), 1,
      aux_sym_subroutine_block_repeat1,
    STATE(1981), 1,
      sym__hll_var_command_with_default_format,
    STATE(1982), 1,
      sym__var_command_with_non_hll_format,
    STATE(2020), 1,
      sym__command_identifier,
    STATE(2059), 1,
      sym_macro,
    STATE(2082), 1,
      sym_macro_definition_command,
    STATE(2243), 1,
      sym__hll_default_format_var_command,
    STATE(2271), 1,
      sym__hll_var_definition_command_expression,
    STATE(2285), 1,
      sym__hll_non_default_format_var_command,
    STATE(2298), 1,
      sym__hll_var_command,
    STATE(2308), 1,
      sym__host_command,
    STATE(2314), 1,
      sym__non_hll_var_command,
    STATE(2327), 1,
      sym__hll_var_if_command,
    STATE(2336), 1,
      sym__hll_var_definition_command,
    STATE(2340), 1,
      sym__host_command_with_default_format,
    STATE(2344), 1,
      sym__other_command,
    STATE(2360), 1,
      sym__var_command,
    ACTIONS(27), 2,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
    ACTIONS(1481), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(33), 3,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
    STATE(1459), 13,
      sym_block,
      sym__statement,
      sym__non_labeled_statement,
      sym_labeled_expression,
      sym_subroutine_block,
      sym_if_block,
      sym_while_block,
      sym_repeat_block,
      sym_macro_assignment_expression,
      sym_macro_definition,
      sym_parameter_declaration,
      sym_subroutine_call_expression,
      sym_command_expression,
  [25443] = 43,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7), 1,
      sym_identifier,
    ACTIONS(9), 1,
      aux_sym_block_token1,
    ACTIONS(11), 1,
      aux_sym_subroutine_block_token1,
    ACTIONS(21), 1,
      anon_sym_AMP_AMP,
    ACTIONS(23), 1,
      anon_sym_AMP,
    ACTIONS(25), 1,
      aux_sym_macro_definition_token1,
    ACTIONS(29), 1,
      aux_sym_parameter_declaration_token3,
    ACTIONS(31), 1,
      aux_sym_subroutine_call_expression_token1,
    ACTIONS(35), 1,
      aux_sym__host_command_with_default_format_token1,
    ACTIONS(37), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(43), 1,
      sym_label_identifier,
    ACTIONS(276), 1,
      aux_sym_if_block_token1,
    ACTIONS(278), 1,
      aux_sym_while_block_token1,
    ACTIONS(280), 1,
      aux_sym_while_block_token2,
    ACTIONS(282), 1,
      aux_sym__repeat_block_pre_condition_format_token1,
    ACTIONS(1483), 1,
      sym__blank,
    STATE(269), 1,
      aux_sym_subroutine_block_repeat1,
    STATE(296), 1,
      sym__label,
    STATE(307), 1,
      aux_sym_block_repeat1,
    STATE(1333), 1,
      sym_recursive_macro_expansion,
    STATE(1432), 1,
      sym__repeat_block_pre_condition_format,
    STATE(1469), 1,
      sym__repeat_block_post_condition_format,
    STATE(1981), 1,
      sym__hll_var_command_with_default_format,
    STATE(1982), 1,
      sym__var_command_with_non_hll_format,
    STATE(2020), 1,
      sym__command_identifier,
    STATE(2059), 1,
      sym_macro,
    STATE(2082), 1,
      sym_macro_definition_command,
    STATE(2243), 1,
      sym__hll_default_format_var_command,
    STATE(2271), 1,
      sym__hll_var_definition_command_expression,
    STATE(2285), 1,
      sym__hll_non_default_format_var_command,
    STATE(2298), 1,
      sym__hll_var_command,
    STATE(2308), 1,
      sym__host_command,
    STATE(2314), 1,
      sym__non_hll_var_command,
    STATE(2325), 1,
      sym__hll_var_if_command,
    STATE(2336), 1,
      sym__hll_var_definition_command,
    STATE(2340), 1,
      sym__host_command_with_default_format,
    STATE(2344), 1,
      sym__other_command,
    STATE(2360), 1,
      sym__var_command,
    ACTIONS(27), 2,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
    ACTIONS(1503), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(33), 3,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
    STATE(1456), 13,
      sym_block,
      sym__statement,
      sym__non_labeled_statement,
      sym_labeled_expression,
      sym_subroutine_block,
      sym_if_block,
      sym_while_block,
      sym_repeat_block,
      sym_macro_assignment_expression,
      sym_macro_definition,
      sym_parameter_declaration,
      sym_subroutine_call_expression,
      sym_command_expression,
  [25589] = 43,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7), 1,
      sym_identifier,
    ACTIONS(9), 1,
      aux_sym_block_token1,
    ACTIONS(11), 1,
      aux_sym_subroutine_block_token1,
    ACTIONS(21), 1,
      anon_sym_AMP_AMP,
    ACTIONS(23), 1,
      anon_sym_AMP,
    ACTIONS(25), 1,
      aux_sym_macro_definition_token1,
    ACTIONS(29), 1,
      aux_sym_parameter_declaration_token3,
    ACTIONS(31), 1,
      aux_sym_subroutine_call_expression_token1,
    ACTIONS(35), 1,
      aux_sym__host_command_with_default_format_token1,
    ACTIONS(37), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(43), 1,
      sym_label_identifier,
    ACTIONS(276), 1,
      aux_sym_if_block_token1,
    ACTIONS(278), 1,
      aux_sym_while_block_token1,
    ACTIONS(280), 1,
      aux_sym_while_block_token2,
    ACTIONS(282), 1,
      aux_sym__repeat_block_pre_condition_format_token1,
    ACTIONS(1483), 1,
      sym__blank,
    STATE(296), 1,
      sym__label,
    STATE(307), 1,
      aux_sym_block_repeat1,
    STATE(1333), 1,
      sym_recursive_macro_expansion,
    STATE(1432), 1,
      sym__repeat_block_pre_condition_format,
    STATE(1469), 1,
      sym__repeat_block_post_condition_format,
    STATE(1511), 1,
      aux_sym_subroutine_block_repeat1,
    STATE(1981), 1,
      sym__hll_var_command_with_default_format,
    STATE(1982), 1,
      sym__var_command_with_non_hll_format,
    STATE(2020), 1,
      sym__command_identifier,
    STATE(2059), 1,
      sym_macro,
    STATE(2082), 1,
      sym_macro_definition_command,
    STATE(2243), 1,
      sym__hll_default_format_var_command,
    STATE(2271), 1,
      sym__hll_var_definition_command_expression,
    STATE(2285), 1,
      sym__hll_non_default_format_var_command,
    STATE(2298), 1,
      sym__hll_var_command,
    STATE(2308), 1,
      sym__host_command,
    STATE(2314), 1,
      sym__non_hll_var_command,
    STATE(2325), 1,
      sym__hll_var_if_command,
    STATE(2336), 1,
      sym__hll_var_definition_command,
    STATE(2340), 1,
      sym__host_command_with_default_format,
    STATE(2344), 1,
      sym__other_command,
    STATE(2360), 1,
      sym__var_command,
    ACTIONS(27), 2,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
    ACTIONS(1481), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(33), 3,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
    STATE(1459), 13,
      sym_block,
      sym__statement,
      sym__non_labeled_statement,
      sym_labeled_expression,
      sym_subroutine_block,
      sym_if_block,
      sym_while_block,
      sym_repeat_block,
      sym_macro_assignment_expression,
      sym_macro_definition,
      sym_parameter_declaration,
      sym_subroutine_call_expression,
      sym_command_expression,
  [25735] = 43,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7), 1,
      sym_identifier,
    ACTIONS(9), 1,
      aux_sym_block_token1,
    ACTIONS(11), 1,
      aux_sym_subroutine_block_token1,
    ACTIONS(21), 1,
      anon_sym_AMP_AMP,
    ACTIONS(23), 1,
      anon_sym_AMP,
    ACTIONS(25), 1,
      aux_sym_macro_definition_token1,
    ACTIONS(29), 1,
      aux_sym_parameter_declaration_token3,
    ACTIONS(31), 1,
      aux_sym_subroutine_call_expression_token1,
    ACTIONS(35), 1,
      aux_sym__host_command_with_default_format_token1,
    ACTIONS(37), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(43), 1,
      sym_label_identifier,
    ACTIONS(276), 1,
      aux_sym_if_block_token1,
    ACTIONS(278), 1,
      aux_sym_while_block_token1,
    ACTIONS(280), 1,
      aux_sym_while_block_token2,
    ACTIONS(282), 1,
      aux_sym__repeat_block_pre_condition_format_token1,
    ACTIONS(1483), 1,
      sym__blank,
    STATE(271), 1,
      aux_sym_subroutine_block_repeat1,
    STATE(296), 1,
      sym__label,
    STATE(307), 1,
      aux_sym_block_repeat1,
    STATE(1333), 1,
      sym_recursive_macro_expansion,
    STATE(1432), 1,
      sym__repeat_block_pre_condition_format,
    STATE(1469), 1,
      sym__repeat_block_post_condition_format,
    STATE(1981), 1,
      sym__hll_var_command_with_default_format,
    STATE(1982), 1,
      sym__var_command_with_non_hll_format,
    STATE(2020), 1,
      sym__command_identifier,
    STATE(2059), 1,
      sym_macro,
    STATE(2082), 1,
      sym_macro_definition_command,
    STATE(2243), 1,
      sym__hll_default_format_var_command,
    STATE(2271), 1,
      sym__hll_var_definition_command_expression,
    STATE(2285), 1,
      sym__hll_non_default_format_var_command,
    STATE(2298), 1,
      sym__hll_var_command,
    STATE(2308), 1,
      sym__host_command,
    STATE(2314), 1,
      sym__non_hll_var_command,
    STATE(2325), 1,
      sym__hll_var_if_command,
    STATE(2336), 1,
      sym__hll_var_definition_command,
    STATE(2340), 1,
      sym__host_command_with_default_format,
    STATE(2344), 1,
      sym__other_command,
    STATE(2360), 1,
      sym__var_command,
    ACTIONS(27), 2,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
    ACTIONS(1505), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(33), 3,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
    STATE(1124), 13,
      sym_block,
      sym__statement,
      sym__non_labeled_statement,
      sym_labeled_expression,
      sym_subroutine_block,
      sym_if_block,
      sym_while_block,
      sym_repeat_block,
      sym_macro_assignment_expression,
      sym_macro_definition,
      sym_parameter_declaration,
      sym_subroutine_call_expression,
      sym_command_expression,
  [25881] = 43,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7), 1,
      sym_identifier,
    ACTIONS(9), 1,
      aux_sym_block_token1,
    ACTIONS(11), 1,
      aux_sym_subroutine_block_token1,
    ACTIONS(21), 1,
      anon_sym_AMP_AMP,
    ACTIONS(23), 1,
      anon_sym_AMP,
    ACTIONS(25), 1,
      aux_sym_macro_definition_token1,
    ACTIONS(29), 1,
      aux_sym_parameter_declaration_token3,
    ACTIONS(31), 1,
      aux_sym_subroutine_call_expression_token1,
    ACTIONS(35), 1,
      aux_sym__host_command_with_default_format_token1,
    ACTIONS(37), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(43), 1,
      sym_label_identifier,
    ACTIONS(276), 1,
      aux_sym_if_block_token1,
    ACTIONS(278), 1,
      aux_sym_while_block_token1,
    ACTIONS(280), 1,
      aux_sym_while_block_token2,
    ACTIONS(282), 1,
      aux_sym__repeat_block_pre_condition_format_token1,
    ACTIONS(1483), 1,
      sym__blank,
    STATE(296), 1,
      sym__label,
    STATE(307), 1,
      aux_sym_block_repeat1,
    STATE(1333), 1,
      sym_recursive_macro_expansion,
    STATE(1432), 1,
      sym__repeat_block_pre_condition_format,
    STATE(1469), 1,
      sym__repeat_block_post_condition_format,
    STATE(1511), 1,
      aux_sym_subroutine_block_repeat1,
    STATE(1981), 1,
      sym__hll_var_command_with_default_format,
    STATE(1982), 1,
      sym__var_command_with_non_hll_format,
    STATE(2020), 1,
      sym__command_identifier,
    STATE(2059), 1,
      sym_macro,
    STATE(2082), 1,
      sym_macro_definition_command,
    STATE(2243), 1,
      sym__hll_default_format_var_command,
    STATE(2271), 1,
      sym__hll_var_definition_command_expression,
    STATE(2285), 1,
      sym__hll_non_default_format_var_command,
    STATE(2298), 1,
      sym__hll_var_command,
    STATE(2308), 1,
      sym__host_command,
    STATE(2314), 1,
      sym__non_hll_var_command,
    STATE(2325), 1,
      sym__hll_var_if_command,
    STATE(2336), 1,
      sym__hll_var_definition_command,
    STATE(2340), 1,
      sym__host_command_with_default_format,
    STATE(2344), 1,
      sym__other_command,
    STATE(2360), 1,
      sym__var_command,
    ACTIONS(27), 2,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
    ACTIONS(1481), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(33), 3,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
    STATE(1091), 13,
      sym_block,
      sym__statement,
      sym__non_labeled_statement,
      sym_labeled_expression,
      sym_subroutine_block,
      sym_if_block,
      sym_while_block,
      sym_repeat_block,
      sym_macro_assignment_expression,
      sym_macro_definition,
      sym_parameter_declaration,
      sym_subroutine_call_expression,
      sym_command_expression,
  [26027] = 43,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7), 1,
      sym_identifier,
    ACTIONS(9), 1,
      aux_sym_block_token1,
    ACTIONS(11), 1,
      aux_sym_subroutine_block_token1,
    ACTIONS(23), 1,
      anon_sym_AMP,
    ACTIONS(25), 1,
      aux_sym_macro_definition_token1,
    ACTIONS(29), 1,
      aux_sym_parameter_declaration_token3,
    ACTIONS(31), 1,
      aux_sym_subroutine_call_expression_token1,
    ACTIONS(35), 1,
      aux_sym__host_command_with_default_format_token1,
    ACTIONS(37), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(43), 1,
      sym_label_identifier,
    ACTIONS(270), 1,
      anon_sym_AMP_AMP,
    ACTIONS(288), 1,
      aux_sym_if_block_token1,
    ACTIONS(290), 1,
      aux_sym_while_block_token1,
    ACTIONS(292), 1,
      aux_sym_while_block_token2,
    ACTIONS(294), 1,
      aux_sym__repeat_block_pre_condition_format_token1,
    ACTIONS(1485), 1,
      sym__blank,
    STATE(273), 1,
      aux_sym_subroutine_block_repeat1,
    STATE(297), 1,
      sym__label,
    STATE(308), 1,
      aux_sym_block_repeat1,
    STATE(1333), 1,
      sym_recursive_macro_expansion,
    STATE(1432), 1,
      sym__repeat_block_pre_condition_format,
    STATE(1469), 1,
      sym__repeat_block_post_condition_format,
    STATE(1981), 1,
      sym__hll_var_command_with_default_format,
    STATE(1982), 1,
      sym__var_command_with_non_hll_format,
    STATE(2020), 1,
      sym__command_identifier,
    STATE(2059), 1,
      sym_macro,
    STATE(2082), 1,
      sym_macro_definition_command,
    STATE(2243), 1,
      sym__hll_default_format_var_command,
    STATE(2271), 1,
      sym__hll_var_definition_command_expression,
    STATE(2285), 1,
      sym__hll_non_default_format_var_command,
    STATE(2298), 1,
      sym__hll_var_command,
    STATE(2308), 1,
      sym__host_command,
    STATE(2314), 1,
      sym__non_hll_var_command,
    STATE(2327), 1,
      sym__hll_var_if_command,
    STATE(2336), 1,
      sym__hll_var_definition_command,
    STATE(2340), 1,
      sym__host_command_with_default_format,
    STATE(2344), 1,
      sym__other_command,
    STATE(2360), 1,
      sym__var_command,
    ACTIONS(27), 2,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
    ACTIONS(1507), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(33), 3,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
    STATE(1115), 13,
      sym_block,
      sym__statement,
      sym__non_labeled_statement,
      sym_labeled_expression,
      sym_subroutine_block,
      sym_if_block,
      sym_while_block,
      sym_repeat_block,
      sym_macro_assignment_expression,
      sym_macro_definition,
      sym_parameter_declaration,
      sym_subroutine_call_expression,
      sym_command_expression,
  [26173] = 43,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7), 1,
      sym_identifier,
    ACTIONS(9), 1,
      aux_sym_block_token1,
    ACTIONS(11), 1,
      aux_sym_subroutine_block_token1,
    ACTIONS(23), 1,
      anon_sym_AMP,
    ACTIONS(25), 1,
      aux_sym_macro_definition_token1,
    ACTIONS(29), 1,
      aux_sym_parameter_declaration_token3,
    ACTIONS(31), 1,
      aux_sym_subroutine_call_expression_token1,
    ACTIONS(35), 1,
      aux_sym__host_command_with_default_format_token1,
    ACTIONS(37), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(43), 1,
      sym_label_identifier,
    ACTIONS(270), 1,
      anon_sym_AMP_AMP,
    ACTIONS(288), 1,
      aux_sym_if_block_token1,
    ACTIONS(290), 1,
      aux_sym_while_block_token1,
    ACTIONS(292), 1,
      aux_sym_while_block_token2,
    ACTIONS(294), 1,
      aux_sym__repeat_block_pre_condition_format_token1,
    ACTIONS(1485), 1,
      sym__blank,
    STATE(297), 1,
      sym__label,
    STATE(308), 1,
      aux_sym_block_repeat1,
    STATE(1333), 1,
      sym_recursive_macro_expansion,
    STATE(1432), 1,
      sym__repeat_block_pre_condition_format,
    STATE(1469), 1,
      sym__repeat_block_post_condition_format,
    STATE(1511), 1,
      aux_sym_subroutine_block_repeat1,
    STATE(1981), 1,
      sym__hll_var_command_with_default_format,
    STATE(1982), 1,
      sym__var_command_with_non_hll_format,
    STATE(2020), 1,
      sym__command_identifier,
    STATE(2059), 1,
      sym_macro,
    STATE(2082), 1,
      sym_macro_definition_command,
    STATE(2243), 1,
      sym__hll_default_format_var_command,
    STATE(2271), 1,
      sym__hll_var_definition_command_expression,
    STATE(2285), 1,
      sym__hll_non_default_format_var_command,
    STATE(2298), 1,
      sym__hll_var_command,
    STATE(2308), 1,
      sym__host_command,
    STATE(2314), 1,
      sym__non_hll_var_command,
    STATE(2327), 1,
      sym__hll_var_if_command,
    STATE(2336), 1,
      sym__hll_var_definition_command,
    STATE(2340), 1,
      sym__host_command_with_default_format,
    STATE(2344), 1,
      sym__other_command,
    STATE(2360), 1,
      sym__var_command,
    ACTIONS(27), 2,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
    ACTIONS(1481), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(33), 3,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
    STATE(1117), 13,
      sym_block,
      sym__statement,
      sym__non_labeled_statement,
      sym_labeled_expression,
      sym_subroutine_block,
      sym_if_block,
      sym_while_block,
      sym_repeat_block,
      sym_macro_assignment_expression,
      sym_macro_definition,
      sym_parameter_declaration,
      sym_subroutine_call_expression,
      sym_command_expression,
  [26319] = 43,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7), 1,
      sym_identifier,
    ACTIONS(9), 1,
      aux_sym_block_token1,
    ACTIONS(11), 1,
      aux_sym_subroutine_block_token1,
    ACTIONS(13), 1,
      aux_sym_if_block_token1,
    ACTIONS(15), 1,
      aux_sym_while_block_token1,
    ACTIONS(17), 1,
      aux_sym_while_block_token2,
    ACTIONS(19), 1,
      aux_sym__repeat_block_pre_condition_format_token1,
    ACTIONS(21), 1,
      anon_sym_AMP_AMP,
    ACTIONS(23), 1,
      anon_sym_AMP,
    ACTIONS(25), 1,
      aux_sym_macro_definition_token1,
    ACTIONS(29), 1,
      aux_sym_parameter_declaration_token3,
    ACTIONS(31), 1,
      aux_sym_subroutine_call_expression_token1,
    ACTIONS(35), 1,
      aux_sym__host_command_with_default_format_token1,
    ACTIONS(37), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(41), 1,
      sym__blank,
    ACTIONS(43), 1,
      sym_label_identifier,
    STATE(252), 1,
      aux_sym_subroutine_block_repeat1,
    STATE(295), 1,
      sym__label,
    STATE(304), 1,
      aux_sym_block_repeat1,
    STATE(1333), 1,
      sym_recursive_macro_expansion,
    STATE(1432), 1,
      sym__repeat_block_pre_condition_format,
    STATE(1469), 1,
      sym__repeat_block_post_condition_format,
    STATE(1981), 1,
      sym__hll_var_command_with_default_format,
    STATE(1982), 1,
      sym__var_command_with_non_hll_format,
    STATE(2020), 1,
      sym__command_identifier,
    STATE(2059), 1,
      sym_macro,
    STATE(2082), 1,
      sym_macro_definition_command,
    STATE(2243), 1,
      sym__hll_default_format_var_command,
    STATE(2271), 1,
      sym__hll_var_definition_command_expression,
    STATE(2272), 1,
      sym__hll_var_if_command,
    STATE(2285), 1,
      sym__hll_non_default_format_var_command,
    STATE(2298), 1,
      sym__hll_var_command,
    STATE(2308), 1,
      sym__host_command,
    STATE(2314), 1,
      sym__non_hll_var_command,
    STATE(2336), 1,
      sym__hll_var_definition_command,
    STATE(2340), 1,
      sym__host_command_with_default_format,
    STATE(2344), 1,
      sym__other_command,
    STATE(2360), 1,
      sym__var_command,
    ACTIONS(27), 2,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
    ACTIONS(1509), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(33), 3,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
    STATE(1504), 13,
      sym_block,
      sym__statement,
      sym__non_labeled_statement,
      sym_labeled_expression,
      sym_subroutine_block,
      sym_if_block,
      sym_while_block,
      sym_repeat_block,
      sym_macro_assignment_expression,
      sym_macro_definition,
      sym_parameter_declaration,
      sym_subroutine_call_expression,
      sym_command_expression,
  [26465] = 43,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7), 1,
      sym_identifier,
    ACTIONS(9), 1,
      aux_sym_block_token1,
    ACTIONS(11), 1,
      aux_sym_subroutine_block_token1,
    ACTIONS(13), 1,
      aux_sym_if_block_token1,
    ACTIONS(15), 1,
      aux_sym_while_block_token1,
    ACTIONS(17), 1,
      aux_sym_while_block_token2,
    ACTIONS(19), 1,
      aux_sym__repeat_block_pre_condition_format_token1,
    ACTIONS(21), 1,
      anon_sym_AMP_AMP,
    ACTIONS(23), 1,
      anon_sym_AMP,
    ACTIONS(25), 1,
      aux_sym_macro_definition_token1,
    ACTIONS(29), 1,
      aux_sym_parameter_declaration_token3,
    ACTIONS(31), 1,
      aux_sym_subroutine_call_expression_token1,
    ACTIONS(35), 1,
      aux_sym__host_command_with_default_format_token1,
    ACTIONS(37), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(41), 1,
      sym__blank,
    ACTIONS(43), 1,
      sym_label_identifier,
    STATE(254), 1,
      aux_sym_subroutine_block_repeat1,
    STATE(295), 1,
      sym__label,
    STATE(304), 1,
      aux_sym_block_repeat1,
    STATE(1333), 1,
      sym_recursive_macro_expansion,
    STATE(1432), 1,
      sym__repeat_block_pre_condition_format,
    STATE(1469), 1,
      sym__repeat_block_post_condition_format,
    STATE(1981), 1,
      sym__hll_var_command_with_default_format,
    STATE(1982), 1,
      sym__var_command_with_non_hll_format,
    STATE(2020), 1,
      sym__command_identifier,
    STATE(2059), 1,
      sym_macro,
    STATE(2082), 1,
      sym_macro_definition_command,
    STATE(2243), 1,
      sym__hll_default_format_var_command,
    STATE(2271), 1,
      sym__hll_var_definition_command_expression,
    STATE(2272), 1,
      sym__hll_var_if_command,
    STATE(2285), 1,
      sym__hll_non_default_format_var_command,
    STATE(2298), 1,
      sym__hll_var_command,
    STATE(2308), 1,
      sym__host_command,
    STATE(2314), 1,
      sym__non_hll_var_command,
    STATE(2336), 1,
      sym__hll_var_definition_command,
    STATE(2340), 1,
      sym__host_command_with_default_format,
    STATE(2344), 1,
      sym__other_command,
    STATE(2360), 1,
      sym__var_command,
    ACTIONS(27), 2,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
    ACTIONS(1511), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(33), 3,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
    STATE(1379), 13,
      sym_block,
      sym__statement,
      sym__non_labeled_statement,
      sym_labeled_expression,
      sym_subroutine_block,
      sym_if_block,
      sym_while_block,
      sym_repeat_block,
      sym_macro_assignment_expression,
      sym_macro_definition,
      sym_parameter_declaration,
      sym_subroutine_call_expression,
      sym_command_expression,
  [26611] = 43,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7), 1,
      sym_identifier,
    ACTIONS(9), 1,
      aux_sym_block_token1,
    ACTIONS(11), 1,
      aux_sym_subroutine_block_token1,
    ACTIONS(21), 1,
      anon_sym_AMP_AMP,
    ACTIONS(23), 1,
      anon_sym_AMP,
    ACTIONS(25), 1,
      aux_sym_macro_definition_token1,
    ACTIONS(29), 1,
      aux_sym_parameter_declaration_token3,
    ACTIONS(31), 1,
      aux_sym_subroutine_call_expression_token1,
    ACTIONS(35), 1,
      aux_sym__host_command_with_default_format_token1,
    ACTIONS(37), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(43), 1,
      sym_label_identifier,
    ACTIONS(276), 1,
      aux_sym_if_block_token1,
    ACTIONS(278), 1,
      aux_sym_while_block_token1,
    ACTIONS(280), 1,
      aux_sym_while_block_token2,
    ACTIONS(282), 1,
      aux_sym__repeat_block_pre_condition_format_token1,
    ACTIONS(1483), 1,
      sym__blank,
    STATE(250), 1,
      aux_sym_subroutine_block_repeat1,
    STATE(296), 1,
      sym__label,
    STATE(307), 1,
      aux_sym_block_repeat1,
    STATE(1333), 1,
      sym_recursive_macro_expansion,
    STATE(1432), 1,
      sym__repeat_block_pre_condition_format,
    STATE(1469), 1,
      sym__repeat_block_post_condition_format,
    STATE(1981), 1,
      sym__hll_var_command_with_default_format,
    STATE(1982), 1,
      sym__var_command_with_non_hll_format,
    STATE(2020), 1,
      sym__command_identifier,
    STATE(2059), 1,
      sym_macro,
    STATE(2082), 1,
      sym_macro_definition_command,
    STATE(2243), 1,
      sym__hll_default_format_var_command,
    STATE(2271), 1,
      sym__hll_var_definition_command_expression,
    STATE(2285), 1,
      sym__hll_non_default_format_var_command,
    STATE(2298), 1,
      sym__hll_var_command,
    STATE(2308), 1,
      sym__host_command,
    STATE(2314), 1,
      sym__non_hll_var_command,
    STATE(2325), 1,
      sym__hll_var_if_command,
    STATE(2336), 1,
      sym__hll_var_definition_command,
    STATE(2340), 1,
      sym__host_command_with_default_format,
    STATE(2344), 1,
      sym__other_command,
    STATE(2360), 1,
      sym__var_command,
    ACTIONS(27), 2,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
    ACTIONS(1513), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(33), 3,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
    STATE(1101), 13,
      sym_block,
      sym__statement,
      sym__non_labeled_statement,
      sym_labeled_expression,
      sym_subroutine_block,
      sym_if_block,
      sym_while_block,
      sym_repeat_block,
      sym_macro_assignment_expression,
      sym_macro_definition,
      sym_parameter_declaration,
      sym_subroutine_call_expression,
      sym_command_expression,
  [26757] = 43,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7), 1,
      sym_identifier,
    ACTIONS(9), 1,
      aux_sym_block_token1,
    ACTIONS(11), 1,
      aux_sym_subroutine_block_token1,
    ACTIONS(21), 1,
      anon_sym_AMP_AMP,
    ACTIONS(23), 1,
      anon_sym_AMP,
    ACTIONS(25), 1,
      aux_sym_macro_definition_token1,
    ACTIONS(29), 1,
      aux_sym_parameter_declaration_token3,
    ACTIONS(31), 1,
      aux_sym_subroutine_call_expression_token1,
    ACTIONS(35), 1,
      aux_sym__host_command_with_default_format_token1,
    ACTIONS(37), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(43), 1,
      sym_label_identifier,
    ACTIONS(276), 1,
      aux_sym_if_block_token1,
    ACTIONS(278), 1,
      aux_sym_while_block_token1,
    ACTIONS(280), 1,
      aux_sym_while_block_token2,
    ACTIONS(282), 1,
      aux_sym__repeat_block_pre_condition_format_token1,
    ACTIONS(1483), 1,
      sym__blank,
    STATE(278), 1,
      aux_sym_subroutine_block_repeat1,
    STATE(296), 1,
      sym__label,
    STATE(307), 1,
      aux_sym_block_repeat1,
    STATE(1333), 1,
      sym_recursive_macro_expansion,
    STATE(1432), 1,
      sym__repeat_block_pre_condition_format,
    STATE(1469), 1,
      sym__repeat_block_post_condition_format,
    STATE(1981), 1,
      sym__hll_var_command_with_default_format,
    STATE(1982), 1,
      sym__var_command_with_non_hll_format,
    STATE(2020), 1,
      sym__command_identifier,
    STATE(2059), 1,
      sym_macro,
    STATE(2082), 1,
      sym_macro_definition_command,
    STATE(2243), 1,
      sym__hll_default_format_var_command,
    STATE(2271), 1,
      sym__hll_var_definition_command_expression,
    STATE(2285), 1,
      sym__hll_non_default_format_var_command,
    STATE(2298), 1,
      sym__hll_var_command,
    STATE(2308), 1,
      sym__host_command,
    STATE(2314), 1,
      sym__non_hll_var_command,
    STATE(2325), 1,
      sym__hll_var_if_command,
    STATE(2336), 1,
      sym__hll_var_definition_command,
    STATE(2340), 1,
      sym__host_command_with_default_format,
    STATE(2344), 1,
      sym__other_command,
    STATE(2360), 1,
      sym__var_command,
    ACTIONS(27), 2,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
    ACTIONS(1515), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(33), 3,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
    STATE(1379), 13,
      sym_block,
      sym__statement,
      sym__non_labeled_statement,
      sym_labeled_expression,
      sym_subroutine_block,
      sym_if_block,
      sym_while_block,
      sym_repeat_block,
      sym_macro_assignment_expression,
      sym_macro_definition,
      sym_parameter_declaration,
      sym_subroutine_call_expression,
      sym_command_expression,
  [26903] = 43,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7), 1,
      sym_identifier,
    ACTIONS(9), 1,
      aux_sym_block_token1,
    ACTIONS(11), 1,
      aux_sym_subroutine_block_token1,
    ACTIONS(21), 1,
      anon_sym_AMP_AMP,
    ACTIONS(23), 1,
      anon_sym_AMP,
    ACTIONS(25), 1,
      aux_sym_macro_definition_token1,
    ACTIONS(29), 1,
      aux_sym_parameter_declaration_token3,
    ACTIONS(31), 1,
      aux_sym_subroutine_call_expression_token1,
    ACTIONS(35), 1,
      aux_sym__host_command_with_default_format_token1,
    ACTIONS(37), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(43), 1,
      sym_label_identifier,
    ACTIONS(276), 1,
      aux_sym_if_block_token1,
    ACTIONS(278), 1,
      aux_sym_while_block_token1,
    ACTIONS(280), 1,
      aux_sym_while_block_token2,
    ACTIONS(282), 1,
      aux_sym__repeat_block_pre_condition_format_token1,
    ACTIONS(1483), 1,
      sym__blank,
    STATE(296), 1,
      sym__label,
    STATE(307), 1,
      aux_sym_block_repeat1,
    STATE(1333), 1,
      sym_recursive_macro_expansion,
    STATE(1432), 1,
      sym__repeat_block_pre_condition_format,
    STATE(1469), 1,
      sym__repeat_block_post_condition_format,
    STATE(1511), 1,
      aux_sym_subroutine_block_repeat1,
    STATE(1981), 1,
      sym__hll_var_command_with_default_format,
    STATE(1982), 1,
      sym__var_command_with_non_hll_format,
    STATE(2020), 1,
      sym__command_identifier,
    STATE(2059), 1,
      sym_macro,
    STATE(2082), 1,
      sym_macro_definition_command,
    STATE(2243), 1,
      sym__hll_default_format_var_command,
    STATE(2271), 1,
      sym__hll_var_definition_command_expression,
    STATE(2285), 1,
      sym__hll_non_default_format_var_command,
    STATE(2298), 1,
      sym__hll_var_command,
    STATE(2308), 1,
      sym__host_command,
    STATE(2314), 1,
      sym__non_hll_var_command,
    STATE(2325), 1,
      sym__hll_var_if_command,
    STATE(2336), 1,
      sym__hll_var_definition_command,
    STATE(2340), 1,
      sym__host_command_with_default_format,
    STATE(2344), 1,
      sym__other_command,
    STATE(2360), 1,
      sym__var_command,
    ACTIONS(27), 2,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
    ACTIONS(1481), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(33), 3,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
    STATE(1384), 13,
      sym_block,
      sym__statement,
      sym__non_labeled_statement,
      sym_labeled_expression,
      sym_subroutine_block,
      sym_if_block,
      sym_while_block,
      sym_repeat_block,
      sym_macro_assignment_expression,
      sym_macro_definition,
      sym_parameter_declaration,
      sym_subroutine_call_expression,
      sym_command_expression,
  [27049] = 43,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7), 1,
      sym_identifier,
    ACTIONS(9), 1,
      aux_sym_block_token1,
    ACTIONS(11), 1,
      aux_sym_subroutine_block_token1,
    ACTIONS(13), 1,
      aux_sym_if_block_token1,
    ACTIONS(15), 1,
      aux_sym_while_block_token1,
    ACTIONS(17), 1,
      aux_sym_while_block_token2,
    ACTIONS(19), 1,
      aux_sym__repeat_block_pre_condition_format_token1,
    ACTIONS(21), 1,
      anon_sym_AMP_AMP,
    ACTIONS(23), 1,
      anon_sym_AMP,
    ACTIONS(25), 1,
      aux_sym_macro_definition_token1,
    ACTIONS(29), 1,
      aux_sym_parameter_declaration_token3,
    ACTIONS(31), 1,
      aux_sym_subroutine_call_expression_token1,
    ACTIONS(35), 1,
      aux_sym__host_command_with_default_format_token1,
    ACTIONS(37), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(41), 1,
      sym__blank,
    ACTIONS(43), 1,
      sym_label_identifier,
    STATE(295), 1,
      sym__label,
    STATE(304), 1,
      aux_sym_block_repeat1,
    STATE(1333), 1,
      sym_recursive_macro_expansion,
    STATE(1432), 1,
      sym__repeat_block_pre_condition_format,
    STATE(1469), 1,
      sym__repeat_block_post_condition_format,
    STATE(1511), 1,
      aux_sym_subroutine_block_repeat1,
    STATE(1981), 1,
      sym__hll_var_command_with_default_format,
    STATE(1982), 1,
      sym__var_command_with_non_hll_format,
    STATE(2020), 1,
      sym__command_identifier,
    STATE(2059), 1,
      sym_macro,
    STATE(2082), 1,
      sym_macro_definition_command,
    STATE(2243), 1,
      sym__hll_default_format_var_command,
    STATE(2271), 1,
      sym__hll_var_definition_command_expression,
    STATE(2272), 1,
      sym__hll_var_if_command,
    STATE(2285), 1,
      sym__hll_non_default_format_var_command,
    STATE(2298), 1,
      sym__hll_var_command,
    STATE(2308), 1,
      sym__host_command,
    STATE(2314), 1,
      sym__non_hll_var_command,
    STATE(2336), 1,
      sym__hll_var_definition_command,
    STATE(2340), 1,
      sym__host_command_with_default_format,
    STATE(2344), 1,
      sym__other_command,
    STATE(2360), 1,
      sym__var_command,
    ACTIONS(27), 2,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
    ACTIONS(1481), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(33), 3,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
    STATE(1458), 13,
      sym_block,
      sym__statement,
      sym__non_labeled_statement,
      sym_labeled_expression,
      sym_subroutine_block,
      sym_if_block,
      sym_while_block,
      sym_repeat_block,
      sym_macro_assignment_expression,
      sym_macro_definition,
      sym_parameter_declaration,
      sym_subroutine_call_expression,
      sym_command_expression,
  [27195] = 43,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7), 1,
      sym_identifier,
    ACTIONS(9), 1,
      aux_sym_block_token1,
    ACTIONS(11), 1,
      aux_sym_subroutine_block_token1,
    ACTIONS(21), 1,
      anon_sym_AMP_AMP,
    ACTIONS(23), 1,
      anon_sym_AMP,
    ACTIONS(25), 1,
      aux_sym_macro_definition_token1,
    ACTIONS(29), 1,
      aux_sym_parameter_declaration_token3,
    ACTIONS(31), 1,
      aux_sym_subroutine_call_expression_token1,
    ACTIONS(35), 1,
      aux_sym__host_command_with_default_format_token1,
    ACTIONS(37), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(43), 1,
      sym_label_identifier,
    ACTIONS(276), 1,
      aux_sym_if_block_token1,
    ACTIONS(278), 1,
      aux_sym_while_block_token1,
    ACTIONS(280), 1,
      aux_sym_while_block_token2,
    ACTIONS(282), 1,
      aux_sym__repeat_block_pre_condition_format_token1,
    ACTIONS(1483), 1,
      sym__blank,
    STATE(282), 1,
      aux_sym_subroutine_block_repeat1,
    STATE(296), 1,
      sym__label,
    STATE(307), 1,
      aux_sym_block_repeat1,
    STATE(1333), 1,
      sym_recursive_macro_expansion,
    STATE(1432), 1,
      sym__repeat_block_pre_condition_format,
    STATE(1469), 1,
      sym__repeat_block_post_condition_format,
    STATE(1981), 1,
      sym__hll_var_command_with_default_format,
    STATE(1982), 1,
      sym__var_command_with_non_hll_format,
    STATE(2020), 1,
      sym__command_identifier,
    STATE(2059), 1,
      sym_macro,
    STATE(2082), 1,
      sym_macro_definition_command,
    STATE(2243), 1,
      sym__hll_default_format_var_command,
    STATE(2271), 1,
      sym__hll_var_definition_command_expression,
    STATE(2285), 1,
      sym__hll_non_default_format_var_command,
    STATE(2298), 1,
      sym__hll_var_command,
    STATE(2308), 1,
      sym__host_command,
    STATE(2314), 1,
      sym__non_hll_var_command,
    STATE(2325), 1,
      sym__hll_var_if_command,
    STATE(2336), 1,
      sym__hll_var_definition_command,
    STATE(2340), 1,
      sym__host_command_with_default_format,
    STATE(2344), 1,
      sym__other_command,
    STATE(2360), 1,
      sym__var_command,
    ACTIONS(27), 2,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
    ACTIONS(1517), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(33), 3,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
    STATE(1468), 13,
      sym_block,
      sym__statement,
      sym__non_labeled_statement,
      sym_labeled_expression,
      sym_subroutine_block,
      sym_if_block,
      sym_while_block,
      sym_repeat_block,
      sym_macro_assignment_expression,
      sym_macro_definition,
      sym_parameter_declaration,
      sym_subroutine_call_expression,
      sym_command_expression,
  [27341] = 43,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7), 1,
      sym_identifier,
    ACTIONS(9), 1,
      aux_sym_block_token1,
    ACTIONS(11), 1,
      aux_sym_subroutine_block_token1,
    ACTIONS(21), 1,
      anon_sym_AMP_AMP,
    ACTIONS(23), 1,
      anon_sym_AMP,
    ACTIONS(25), 1,
      aux_sym_macro_definition_token1,
    ACTIONS(29), 1,
      aux_sym_parameter_declaration_token3,
    ACTIONS(31), 1,
      aux_sym_subroutine_call_expression_token1,
    ACTIONS(35), 1,
      aux_sym__host_command_with_default_format_token1,
    ACTIONS(37), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(43), 1,
      sym_label_identifier,
    ACTIONS(276), 1,
      aux_sym_if_block_token1,
    ACTIONS(278), 1,
      aux_sym_while_block_token1,
    ACTIONS(280), 1,
      aux_sym_while_block_token2,
    ACTIONS(282), 1,
      aux_sym__repeat_block_pre_condition_format_token1,
    ACTIONS(1483), 1,
      sym__blank,
    STATE(283), 1,
      aux_sym_subroutine_block_repeat1,
    STATE(296), 1,
      sym__label,
    STATE(307), 1,
      aux_sym_block_repeat1,
    STATE(1333), 1,
      sym_recursive_macro_expansion,
    STATE(1432), 1,
      sym__repeat_block_pre_condition_format,
    STATE(1469), 1,
      sym__repeat_block_post_condition_format,
    STATE(1981), 1,
      sym__hll_var_command_with_default_format,
    STATE(1982), 1,
      sym__var_command_with_non_hll_format,
    STATE(2020), 1,
      sym__command_identifier,
    STATE(2059), 1,
      sym_macro,
    STATE(2082), 1,
      sym_macro_definition_command,
    STATE(2243), 1,
      sym__hll_default_format_var_command,
    STATE(2271), 1,
      sym__hll_var_definition_command_expression,
    STATE(2285), 1,
      sym__hll_non_default_format_var_command,
    STATE(2298), 1,
      sym__hll_var_command,
    STATE(2308), 1,
      sym__host_command,
    STATE(2314), 1,
      sym__non_hll_var_command,
    STATE(2325), 1,
      sym__hll_var_if_command,
    STATE(2336), 1,
      sym__hll_var_definition_command,
    STATE(2340), 1,
      sym__host_command_with_default_format,
    STATE(2344), 1,
      sym__other_command,
    STATE(2360), 1,
      sym__var_command,
    ACTIONS(27), 2,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
    ACTIONS(1519), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(33), 3,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
    STATE(1504), 13,
      sym_block,
      sym__statement,
      sym__non_labeled_statement,
      sym_labeled_expression,
      sym_subroutine_block,
      sym_if_block,
      sym_while_block,
      sym_repeat_block,
      sym_macro_assignment_expression,
      sym_macro_definition,
      sym_parameter_declaration,
      sym_subroutine_call_expression,
      sym_command_expression,
  [27487] = 43,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7), 1,
      sym_identifier,
    ACTIONS(9), 1,
      aux_sym_block_token1,
    ACTIONS(11), 1,
      aux_sym_subroutine_block_token1,
    ACTIONS(21), 1,
      anon_sym_AMP_AMP,
    ACTIONS(23), 1,
      anon_sym_AMP,
    ACTIONS(25), 1,
      aux_sym_macro_definition_token1,
    ACTIONS(29), 1,
      aux_sym_parameter_declaration_token3,
    ACTIONS(31), 1,
      aux_sym_subroutine_call_expression_token1,
    ACTIONS(35), 1,
      aux_sym__host_command_with_default_format_token1,
    ACTIONS(37), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(43), 1,
      sym_label_identifier,
    ACTIONS(276), 1,
      aux_sym_if_block_token1,
    ACTIONS(278), 1,
      aux_sym_while_block_token1,
    ACTIONS(280), 1,
      aux_sym_while_block_token2,
    ACTIONS(282), 1,
      aux_sym__repeat_block_pre_condition_format_token1,
    ACTIONS(1483), 1,
      sym__blank,
    STATE(296), 1,
      sym__label,
    STATE(307), 1,
      aux_sym_block_repeat1,
    STATE(1333), 1,
      sym_recursive_macro_expansion,
    STATE(1432), 1,
      sym__repeat_block_pre_condition_format,
    STATE(1469), 1,
      sym__repeat_block_post_condition_format,
    STATE(1511), 1,
      aux_sym_subroutine_block_repeat1,
    STATE(1981), 1,
      sym__hll_var_command_with_default_format,
    STATE(1982), 1,
      sym__var_command_with_non_hll_format,
    STATE(2020), 1,
      sym__command_identifier,
    STATE(2059), 1,
      sym_macro,
    STATE(2082), 1,
      sym_macro_definition_command,
    STATE(2243), 1,
      sym__hll_default_format_var_command,
    STATE(2271), 1,
      sym__hll_var_definition_command_expression,
    STATE(2285), 1,
      sym__hll_non_default_format_var_command,
    STATE(2298), 1,
      sym__hll_var_command,
    STATE(2308), 1,
      sym__host_command,
    STATE(2314), 1,
      sym__non_hll_var_command,
    STATE(2325), 1,
      sym__hll_var_if_command,
    STATE(2336), 1,
      sym__hll_var_definition_command,
    STATE(2340), 1,
      sym__host_command_with_default_format,
    STATE(2344), 1,
      sym__other_command,
    STATE(2360), 1,
      sym__var_command,
    ACTIONS(27), 2,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
    ACTIONS(1481), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(33), 3,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
    STATE(1458), 13,
      sym_block,
      sym__statement,
      sym__non_labeled_statement,
      sym_labeled_expression,
      sym_subroutine_block,
      sym_if_block,
      sym_while_block,
      sym_repeat_block,
      sym_macro_assignment_expression,
      sym_macro_definition,
      sym_parameter_declaration,
      sym_subroutine_call_expression,
      sym_command_expression,
  [27633] = 43,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7), 1,
      sym_identifier,
    ACTIONS(9), 1,
      aux_sym_block_token1,
    ACTIONS(11), 1,
      aux_sym_subroutine_block_token1,
    ACTIONS(21), 1,
      anon_sym_AMP_AMP,
    ACTIONS(23), 1,
      anon_sym_AMP,
    ACTIONS(25), 1,
      aux_sym_macro_definition_token1,
    ACTIONS(29), 1,
      aux_sym_parameter_declaration_token3,
    ACTIONS(31), 1,
      aux_sym_subroutine_call_expression_token1,
    ACTIONS(35), 1,
      aux_sym__host_command_with_default_format_token1,
    ACTIONS(37), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(43), 1,
      sym_label_identifier,
    ACTIONS(276), 1,
      aux_sym_if_block_token1,
    ACTIONS(278), 1,
      aux_sym_while_block_token1,
    ACTIONS(280), 1,
      aux_sym_while_block_token2,
    ACTIONS(282), 1,
      aux_sym__repeat_block_pre_condition_format_token1,
    ACTIONS(1483), 1,
      sym__blank,
    STATE(296), 1,
      sym__label,
    STATE(307), 1,
      aux_sym_block_repeat1,
    STATE(1333), 1,
      sym_recursive_macro_expansion,
    STATE(1432), 1,
      sym__repeat_block_pre_condition_format,
    STATE(1469), 1,
      sym__repeat_block_post_condition_format,
    STATE(1511), 1,
      aux_sym_subroutine_block_repeat1,
    STATE(1981), 1,
      sym__hll_var_command_with_default_format,
    STATE(1982), 1,
      sym__var_command_with_non_hll_format,
    STATE(2020), 1,
      sym__command_identifier,
    STATE(2059), 1,
      sym_macro,
    STATE(2082), 1,
      sym_macro_definition_command,
    STATE(2243), 1,
      sym__hll_default_format_var_command,
    STATE(2271), 1,
      sym__hll_var_definition_command_expression,
    STATE(2285), 1,
      sym__hll_non_default_format_var_command,
    STATE(2298), 1,
      sym__hll_var_command,
    STATE(2308), 1,
      sym__host_command,
    STATE(2314), 1,
      sym__non_hll_var_command,
    STATE(2325), 1,
      sym__hll_var_if_command,
    STATE(2336), 1,
      sym__hll_var_definition_command,
    STATE(2340), 1,
      sym__host_command_with_default_format,
    STATE(2344), 1,
      sym__other_command,
    STATE(2360), 1,
      sym__var_command,
    ACTIONS(27), 2,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
    ACTIONS(1481), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(33), 3,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
    STATE(1438), 13,
      sym_block,
      sym__statement,
      sym__non_labeled_statement,
      sym_labeled_expression,
      sym_subroutine_block,
      sym_if_block,
      sym_while_block,
      sym_repeat_block,
      sym_macro_assignment_expression,
      sym_macro_definition,
      sym_parameter_declaration,
      sym_subroutine_call_expression,
      sym_command_expression,
  [27779] = 43,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7), 1,
      sym_identifier,
    ACTIONS(9), 1,
      aux_sym_block_token1,
    ACTIONS(11), 1,
      aux_sym_subroutine_block_token1,
    ACTIONS(21), 1,
      anon_sym_AMP_AMP,
    ACTIONS(23), 1,
      anon_sym_AMP,
    ACTIONS(25), 1,
      aux_sym_macro_definition_token1,
    ACTIONS(29), 1,
      aux_sym_parameter_declaration_token3,
    ACTIONS(31), 1,
      aux_sym_subroutine_call_expression_token1,
    ACTIONS(35), 1,
      aux_sym__host_command_with_default_format_token1,
    ACTIONS(37), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(43), 1,
      sym_label_identifier,
    ACTIONS(276), 1,
      aux_sym_if_block_token1,
    ACTIONS(278), 1,
      aux_sym_while_block_token1,
    ACTIONS(280), 1,
      aux_sym_while_block_token2,
    ACTIONS(282), 1,
      aux_sym__repeat_block_pre_condition_format_token1,
    ACTIONS(1483), 1,
      sym__blank,
    STATE(285), 1,
      aux_sym_subroutine_block_repeat1,
    STATE(296), 1,
      sym__label,
    STATE(307), 1,
      aux_sym_block_repeat1,
    STATE(1333), 1,
      sym_recursive_macro_expansion,
    STATE(1432), 1,
      sym__repeat_block_pre_condition_format,
    STATE(1469), 1,
      sym__repeat_block_post_condition_format,
    STATE(1981), 1,
      sym__hll_var_command_with_default_format,
    STATE(1982), 1,
      sym__var_command_with_non_hll_format,
    STATE(2020), 1,
      sym__command_identifier,
    STATE(2059), 1,
      sym_macro,
    STATE(2082), 1,
      sym_macro_definition_command,
    STATE(2243), 1,
      sym__hll_default_format_var_command,
    STATE(2271), 1,
      sym__hll_var_definition_command_expression,
    STATE(2285), 1,
      sym__hll_non_default_format_var_command,
    STATE(2298), 1,
      sym__hll_var_command,
    STATE(2308), 1,
      sym__host_command,
    STATE(2314), 1,
      sym__non_hll_var_command,
    STATE(2325), 1,
      sym__hll_var_if_command,
    STATE(2336), 1,
      sym__hll_var_definition_command,
    STATE(2340), 1,
      sym__host_command_with_default_format,
    STATE(2344), 1,
      sym__other_command,
    STATE(2360), 1,
      sym__var_command,
    ACTIONS(27), 2,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
    ACTIONS(1521), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(33), 3,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
    STATE(1448), 13,
      sym_block,
      sym__statement,
      sym__non_labeled_statement,
      sym_labeled_expression,
      sym_subroutine_block,
      sym_if_block,
      sym_while_block,
      sym_repeat_block,
      sym_macro_assignment_expression,
      sym_macro_definition,
      sym_parameter_declaration,
      sym_subroutine_call_expression,
      sym_command_expression,
  [27925] = 43,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7), 1,
      sym_identifier,
    ACTIONS(9), 1,
      aux_sym_block_token1,
    ACTIONS(11), 1,
      aux_sym_subroutine_block_token1,
    ACTIONS(21), 1,
      anon_sym_AMP_AMP,
    ACTIONS(23), 1,
      anon_sym_AMP,
    ACTIONS(25), 1,
      aux_sym_macro_definition_token1,
    ACTIONS(29), 1,
      aux_sym_parameter_declaration_token3,
    ACTIONS(31), 1,
      aux_sym_subroutine_call_expression_token1,
    ACTIONS(35), 1,
      aux_sym__host_command_with_default_format_token1,
    ACTIONS(37), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(43), 1,
      sym_label_identifier,
    ACTIONS(276), 1,
      aux_sym_if_block_token1,
    ACTIONS(278), 1,
      aux_sym_while_block_token1,
    ACTIONS(280), 1,
      aux_sym_while_block_token2,
    ACTIONS(282), 1,
      aux_sym__repeat_block_pre_condition_format_token1,
    ACTIONS(1483), 1,
      sym__blank,
    STATE(296), 1,
      sym__label,
    STATE(307), 1,
      aux_sym_block_repeat1,
    STATE(1333), 1,
      sym_recursive_macro_expansion,
    STATE(1432), 1,
      sym__repeat_block_pre_condition_format,
    STATE(1469), 1,
      sym__repeat_block_post_condition_format,
    STATE(1511), 1,
      aux_sym_subroutine_block_repeat1,
    STATE(1981), 1,
      sym__hll_var_command_with_default_format,
    STATE(1982), 1,
      sym__var_command_with_non_hll_format,
    STATE(2020), 1,
      sym__command_identifier,
    STATE(2059), 1,
      sym_macro,
    STATE(2082), 1,
      sym_macro_definition_command,
    STATE(2243), 1,
      sym__hll_default_format_var_command,
    STATE(2271), 1,
      sym__hll_var_definition_command_expression,
    STATE(2285), 1,
      sym__hll_non_default_format_var_command,
    STATE(2298), 1,
      sym__hll_var_command,
    STATE(2308), 1,
      sym__host_command,
    STATE(2314), 1,
      sym__non_hll_var_command,
    STATE(2325), 1,
      sym__hll_var_if_command,
    STATE(2336), 1,
      sym__hll_var_definition_command,
    STATE(2340), 1,
      sym__host_command_with_default_format,
    STATE(2344), 1,
      sym__other_command,
    STATE(2360), 1,
      sym__var_command,
    ACTIONS(27), 2,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
    ACTIONS(1481), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(33), 3,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
    STATE(1434), 13,
      sym_block,
      sym__statement,
      sym__non_labeled_statement,
      sym_labeled_expression,
      sym_subroutine_block,
      sym_if_block,
      sym_while_block,
      sym_repeat_block,
      sym_macro_assignment_expression,
      sym_macro_definition,
      sym_parameter_declaration,
      sym_subroutine_call_expression,
      sym_command_expression,
  [28071] = 43,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7), 1,
      sym_identifier,
    ACTIONS(9), 1,
      aux_sym_block_token1,
    ACTIONS(11), 1,
      aux_sym_subroutine_block_token1,
    ACTIONS(23), 1,
      anon_sym_AMP,
    ACTIONS(25), 1,
      aux_sym_macro_definition_token1,
    ACTIONS(29), 1,
      aux_sym_parameter_declaration_token3,
    ACTIONS(31), 1,
      aux_sym_subroutine_call_expression_token1,
    ACTIONS(35), 1,
      aux_sym__host_command_with_default_format_token1,
    ACTIONS(37), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(43), 1,
      sym_label_identifier,
    ACTIONS(270), 1,
      anon_sym_AMP_AMP,
    ACTIONS(288), 1,
      aux_sym_if_block_token1,
    ACTIONS(290), 1,
      aux_sym_while_block_token1,
    ACTIONS(292), 1,
      aux_sym_while_block_token2,
    ACTIONS(294), 1,
      aux_sym__repeat_block_pre_condition_format_token1,
    ACTIONS(1485), 1,
      sym__blank,
    STATE(287), 1,
      aux_sym_subroutine_block_repeat1,
    STATE(297), 1,
      sym__label,
    STATE(308), 1,
      aux_sym_block_repeat1,
    STATE(1333), 1,
      sym_recursive_macro_expansion,
    STATE(1432), 1,
      sym__repeat_block_pre_condition_format,
    STATE(1469), 1,
      sym__repeat_block_post_condition_format,
    STATE(1981), 1,
      sym__hll_var_command_with_default_format,
    STATE(1982), 1,
      sym__var_command_with_non_hll_format,
    STATE(2020), 1,
      sym__command_identifier,
    STATE(2059), 1,
      sym_macro,
    STATE(2082), 1,
      sym_macro_definition_command,
    STATE(2243), 1,
      sym__hll_default_format_var_command,
    STATE(2271), 1,
      sym__hll_var_definition_command_expression,
    STATE(2285), 1,
      sym__hll_non_default_format_var_command,
    STATE(2298), 1,
      sym__hll_var_command,
    STATE(2308), 1,
      sym__host_command,
    STATE(2314), 1,
      sym__non_hll_var_command,
    STATE(2327), 1,
      sym__hll_var_if_command,
    STATE(2336), 1,
      sym__hll_var_definition_command,
    STATE(2340), 1,
      sym__host_command_with_default_format,
    STATE(2344), 1,
      sym__other_command,
    STATE(2360), 1,
      sym__var_command,
    ACTIONS(27), 2,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
    ACTIONS(1523), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(33), 3,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
    STATE(1379), 13,
      sym_block,
      sym__statement,
      sym__non_labeled_statement,
      sym_labeled_expression,
      sym_subroutine_block,
      sym_if_block,
      sym_while_block,
      sym_repeat_block,
      sym_macro_assignment_expression,
      sym_macro_definition,
      sym_parameter_declaration,
      sym_subroutine_call_expression,
      sym_command_expression,
  [28217] = 43,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7), 1,
      sym_identifier,
    ACTIONS(9), 1,
      aux_sym_block_token1,
    ACTIONS(11), 1,
      aux_sym_subroutine_block_token1,
    ACTIONS(23), 1,
      anon_sym_AMP,
    ACTIONS(25), 1,
      aux_sym_macro_definition_token1,
    ACTIONS(29), 1,
      aux_sym_parameter_declaration_token3,
    ACTIONS(31), 1,
      aux_sym_subroutine_call_expression_token1,
    ACTIONS(35), 1,
      aux_sym__host_command_with_default_format_token1,
    ACTIONS(37), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(43), 1,
      sym_label_identifier,
    ACTIONS(270), 1,
      anon_sym_AMP_AMP,
    ACTIONS(288), 1,
      aux_sym_if_block_token1,
    ACTIONS(290), 1,
      aux_sym_while_block_token1,
    ACTIONS(292), 1,
      aux_sym_while_block_token2,
    ACTIONS(294), 1,
      aux_sym__repeat_block_pre_condition_format_token1,
    ACTIONS(1485), 1,
      sym__blank,
    STATE(297), 1,
      sym__label,
    STATE(308), 1,
      aux_sym_block_repeat1,
    STATE(1333), 1,
      sym_recursive_macro_expansion,
    STATE(1432), 1,
      sym__repeat_block_pre_condition_format,
    STATE(1469), 1,
      sym__repeat_block_post_condition_format,
    STATE(1511), 1,
      aux_sym_subroutine_block_repeat1,
    STATE(1981), 1,
      sym__hll_var_command_with_default_format,
    STATE(1982), 1,
      sym__var_command_with_non_hll_format,
    STATE(2020), 1,
      sym__command_identifier,
    STATE(2059), 1,
      sym_macro,
    STATE(2082), 1,
      sym_macro_definition_command,
    STATE(2243), 1,
      sym__hll_default_format_var_command,
    STATE(2271), 1,
      sym__hll_var_definition_command_expression,
    STATE(2285), 1,
      sym__hll_non_default_format_var_command,
    STATE(2298), 1,
      sym__hll_var_command,
    STATE(2308), 1,
      sym__host_command,
    STATE(2314), 1,
      sym__non_hll_var_command,
    STATE(2327), 1,
      sym__hll_var_if_command,
    STATE(2336), 1,
      sym__hll_var_definition_command,
    STATE(2340), 1,
      sym__host_command_with_default_format,
    STATE(2344), 1,
      sym__other_command,
    STATE(2360), 1,
      sym__var_command,
    ACTIONS(27), 2,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
    ACTIONS(1481), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(33), 3,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
    STATE(1384), 13,
      sym_block,
      sym__statement,
      sym__non_labeled_statement,
      sym_labeled_expression,
      sym_subroutine_block,
      sym_if_block,
      sym_while_block,
      sym_repeat_block,
      sym_macro_assignment_expression,
      sym_macro_definition,
      sym_parameter_declaration,
      sym_subroutine_call_expression,
      sym_command_expression,
  [28363] = 43,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7), 1,
      sym_identifier,
    ACTIONS(9), 1,
      aux_sym_block_token1,
    ACTIONS(11), 1,
      aux_sym_subroutine_block_token1,
    ACTIONS(23), 1,
      anon_sym_AMP,
    ACTIONS(25), 1,
      aux_sym_macro_definition_token1,
    ACTIONS(29), 1,
      aux_sym_parameter_declaration_token3,
    ACTIONS(31), 1,
      aux_sym_subroutine_call_expression_token1,
    ACTIONS(35), 1,
      aux_sym__host_command_with_default_format_token1,
    ACTIONS(37), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(43), 1,
      sym_label_identifier,
    ACTIONS(270), 1,
      anon_sym_AMP_AMP,
    ACTIONS(288), 1,
      aux_sym_if_block_token1,
    ACTIONS(290), 1,
      aux_sym_while_block_token1,
    ACTIONS(292), 1,
      aux_sym_while_block_token2,
    ACTIONS(294), 1,
      aux_sym__repeat_block_pre_condition_format_token1,
    ACTIONS(1485), 1,
      sym__blank,
    STATE(290), 1,
      aux_sym_subroutine_block_repeat1,
    STATE(297), 1,
      sym__label,
    STATE(308), 1,
      aux_sym_block_repeat1,
    STATE(1333), 1,
      sym_recursive_macro_expansion,
    STATE(1432), 1,
      sym__repeat_block_pre_condition_format,
    STATE(1469), 1,
      sym__repeat_block_post_condition_format,
    STATE(1981), 1,
      sym__hll_var_command_with_default_format,
    STATE(1982), 1,
      sym__var_command_with_non_hll_format,
    STATE(2020), 1,
      sym__command_identifier,
    STATE(2059), 1,
      sym_macro,
    STATE(2082), 1,
      sym_macro_definition_command,
    STATE(2243), 1,
      sym__hll_default_format_var_command,
    STATE(2271), 1,
      sym__hll_var_definition_command_expression,
    STATE(2285), 1,
      sym__hll_non_default_format_var_command,
    STATE(2298), 1,
      sym__hll_var_command,
    STATE(2308), 1,
      sym__host_command,
    STATE(2314), 1,
      sym__non_hll_var_command,
    STATE(2327), 1,
      sym__hll_var_if_command,
    STATE(2336), 1,
      sym__hll_var_definition_command,
    STATE(2340), 1,
      sym__host_command_with_default_format,
    STATE(2344), 1,
      sym__other_command,
    STATE(2360), 1,
      sym__var_command,
    ACTIONS(27), 2,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
    ACTIONS(1525), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(33), 3,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
    STATE(1468), 13,
      sym_block,
      sym__statement,
      sym__non_labeled_statement,
      sym_labeled_expression,
      sym_subroutine_block,
      sym_if_block,
      sym_while_block,
      sym_repeat_block,
      sym_macro_assignment_expression,
      sym_macro_definition,
      sym_parameter_declaration,
      sym_subroutine_call_expression,
      sym_command_expression,
  [28509] = 43,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7), 1,
      sym_identifier,
    ACTIONS(9), 1,
      aux_sym_block_token1,
    ACTIONS(11), 1,
      aux_sym_subroutine_block_token1,
    ACTIONS(23), 1,
      anon_sym_AMP,
    ACTIONS(25), 1,
      aux_sym_macro_definition_token1,
    ACTIONS(29), 1,
      aux_sym_parameter_declaration_token3,
    ACTIONS(31), 1,
      aux_sym_subroutine_call_expression_token1,
    ACTIONS(35), 1,
      aux_sym__host_command_with_default_format_token1,
    ACTIONS(37), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(43), 1,
      sym_label_identifier,
    ACTIONS(270), 1,
      anon_sym_AMP_AMP,
    ACTIONS(288), 1,
      aux_sym_if_block_token1,
    ACTIONS(290), 1,
      aux_sym_while_block_token1,
    ACTIONS(292), 1,
      aux_sym_while_block_token2,
    ACTIONS(294), 1,
      aux_sym__repeat_block_pre_condition_format_token1,
    ACTIONS(1485), 1,
      sym__blank,
    STATE(291), 1,
      aux_sym_subroutine_block_repeat1,
    STATE(297), 1,
      sym__label,
    STATE(308), 1,
      aux_sym_block_repeat1,
    STATE(1333), 1,
      sym_recursive_macro_expansion,
    STATE(1432), 1,
      sym__repeat_block_pre_condition_format,
    STATE(1469), 1,
      sym__repeat_block_post_condition_format,
    STATE(1981), 1,
      sym__hll_var_command_with_default_format,
    STATE(1982), 1,
      sym__var_command_with_non_hll_format,
    STATE(2020), 1,
      sym__command_identifier,
    STATE(2059), 1,
      sym_macro,
    STATE(2082), 1,
      sym_macro_definition_command,
    STATE(2243), 1,
      sym__hll_default_format_var_command,
    STATE(2271), 1,
      sym__hll_var_definition_command_expression,
    STATE(2285), 1,
      sym__hll_non_default_format_var_command,
    STATE(2298), 1,
      sym__hll_var_command,
    STATE(2308), 1,
      sym__host_command,
    STATE(2314), 1,
      sym__non_hll_var_command,
    STATE(2327), 1,
      sym__hll_var_if_command,
    STATE(2336), 1,
      sym__hll_var_definition_command,
    STATE(2340), 1,
      sym__host_command_with_default_format,
    STATE(2344), 1,
      sym__other_command,
    STATE(2360), 1,
      sym__var_command,
    ACTIONS(27), 2,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
    ACTIONS(1527), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(33), 3,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
    STATE(1504), 13,
      sym_block,
      sym__statement,
      sym__non_labeled_statement,
      sym_labeled_expression,
      sym_subroutine_block,
      sym_if_block,
      sym_while_block,
      sym_repeat_block,
      sym_macro_assignment_expression,
      sym_macro_definition,
      sym_parameter_declaration,
      sym_subroutine_call_expression,
      sym_command_expression,
  [28655] = 43,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7), 1,
      sym_identifier,
    ACTIONS(9), 1,
      aux_sym_block_token1,
    ACTIONS(11), 1,
      aux_sym_subroutine_block_token1,
    ACTIONS(23), 1,
      anon_sym_AMP,
    ACTIONS(25), 1,
      aux_sym_macro_definition_token1,
    ACTIONS(29), 1,
      aux_sym_parameter_declaration_token3,
    ACTIONS(31), 1,
      aux_sym_subroutine_call_expression_token1,
    ACTIONS(35), 1,
      aux_sym__host_command_with_default_format_token1,
    ACTIONS(37), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(43), 1,
      sym_label_identifier,
    ACTIONS(270), 1,
      anon_sym_AMP_AMP,
    ACTIONS(288), 1,
      aux_sym_if_block_token1,
    ACTIONS(290), 1,
      aux_sym_while_block_token1,
    ACTIONS(292), 1,
      aux_sym_while_block_token2,
    ACTIONS(294), 1,
      aux_sym__repeat_block_pre_condition_format_token1,
    ACTIONS(1485), 1,
      sym__blank,
    STATE(297), 1,
      sym__label,
    STATE(308), 1,
      aux_sym_block_repeat1,
    STATE(1333), 1,
      sym_recursive_macro_expansion,
    STATE(1432), 1,
      sym__repeat_block_pre_condition_format,
    STATE(1469), 1,
      sym__repeat_block_post_condition_format,
    STATE(1511), 1,
      aux_sym_subroutine_block_repeat1,
    STATE(1981), 1,
      sym__hll_var_command_with_default_format,
    STATE(1982), 1,
      sym__var_command_with_non_hll_format,
    STATE(2020), 1,
      sym__command_identifier,
    STATE(2059), 1,
      sym_macro,
    STATE(2082), 1,
      sym_macro_definition_command,
    STATE(2243), 1,
      sym__hll_default_format_var_command,
    STATE(2271), 1,
      sym__hll_var_definition_command_expression,
    STATE(2285), 1,
      sym__hll_non_default_format_var_command,
    STATE(2298), 1,
      sym__hll_var_command,
    STATE(2308), 1,
      sym__host_command,
    STATE(2314), 1,
      sym__non_hll_var_command,
    STATE(2327), 1,
      sym__hll_var_if_command,
    STATE(2336), 1,
      sym__hll_var_definition_command,
    STATE(2340), 1,
      sym__host_command_with_default_format,
    STATE(2344), 1,
      sym__other_command,
    STATE(2360), 1,
      sym__var_command,
    ACTIONS(27), 2,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
    ACTIONS(1481), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(33), 3,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
    STATE(1458), 13,
      sym_block,
      sym__statement,
      sym__non_labeled_statement,
      sym_labeled_expression,
      sym_subroutine_block,
      sym_if_block,
      sym_while_block,
      sym_repeat_block,
      sym_macro_assignment_expression,
      sym_macro_definition,
      sym_parameter_declaration,
      sym_subroutine_call_expression,
      sym_command_expression,
  [28801] = 43,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7), 1,
      sym_identifier,
    ACTIONS(9), 1,
      aux_sym_block_token1,
    ACTIONS(11), 1,
      aux_sym_subroutine_block_token1,
    ACTIONS(23), 1,
      anon_sym_AMP,
    ACTIONS(25), 1,
      aux_sym_macro_definition_token1,
    ACTIONS(29), 1,
      aux_sym_parameter_declaration_token3,
    ACTIONS(31), 1,
      aux_sym_subroutine_call_expression_token1,
    ACTIONS(35), 1,
      aux_sym__host_command_with_default_format_token1,
    ACTIONS(37), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(43), 1,
      sym_label_identifier,
    ACTIONS(270), 1,
      anon_sym_AMP_AMP,
    ACTIONS(288), 1,
      aux_sym_if_block_token1,
    ACTIONS(290), 1,
      aux_sym_while_block_token1,
    ACTIONS(292), 1,
      aux_sym_while_block_token2,
    ACTIONS(294), 1,
      aux_sym__repeat_block_pre_condition_format_token1,
    ACTIONS(1485), 1,
      sym__blank,
    STATE(297), 1,
      sym__label,
    STATE(308), 1,
      aux_sym_block_repeat1,
    STATE(1333), 1,
      sym_recursive_macro_expansion,
    STATE(1432), 1,
      sym__repeat_block_pre_condition_format,
    STATE(1469), 1,
      sym__repeat_block_post_condition_format,
    STATE(1511), 1,
      aux_sym_subroutine_block_repeat1,
    STATE(1981), 1,
      sym__hll_var_command_with_default_format,
    STATE(1982), 1,
      sym__var_command_with_non_hll_format,
    STATE(2020), 1,
      sym__command_identifier,
    STATE(2059), 1,
      sym_macro,
    STATE(2082), 1,
      sym_macro_definition_command,
    STATE(2243), 1,
      sym__hll_default_format_var_command,
    STATE(2271), 1,
      sym__hll_var_definition_command_expression,
    STATE(2285), 1,
      sym__hll_non_default_format_var_command,
    STATE(2298), 1,
      sym__hll_var_command,
    STATE(2308), 1,
      sym__host_command,
    STATE(2314), 1,
      sym__non_hll_var_command,
    STATE(2327), 1,
      sym__hll_var_if_command,
    STATE(2336), 1,
      sym__hll_var_definition_command,
    STATE(2340), 1,
      sym__host_command_with_default_format,
    STATE(2344), 1,
      sym__other_command,
    STATE(2360), 1,
      sym__var_command,
    ACTIONS(27), 2,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
    ACTIONS(1481), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(33), 3,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
    STATE(1438), 13,
      sym_block,
      sym__statement,
      sym__non_labeled_statement,
      sym_labeled_expression,
      sym_subroutine_block,
      sym_if_block,
      sym_while_block,
      sym_repeat_block,
      sym_macro_assignment_expression,
      sym_macro_definition,
      sym_parameter_declaration,
      sym_subroutine_call_expression,
      sym_command_expression,
  [28947] = 43,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7), 1,
      sym_identifier,
    ACTIONS(9), 1,
      aux_sym_block_token1,
    ACTIONS(11), 1,
      aux_sym_subroutine_block_token1,
    ACTIONS(23), 1,
      anon_sym_AMP,
    ACTIONS(25), 1,
      aux_sym_macro_definition_token1,
    ACTIONS(29), 1,
      aux_sym_parameter_declaration_token3,
    ACTIONS(31), 1,
      aux_sym_subroutine_call_expression_token1,
    ACTIONS(35), 1,
      aux_sym__host_command_with_default_format_token1,
    ACTIONS(37), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(43), 1,
      sym_label_identifier,
    ACTIONS(270), 1,
      anon_sym_AMP_AMP,
    ACTIONS(288), 1,
      aux_sym_if_block_token1,
    ACTIONS(290), 1,
      aux_sym_while_block_token1,
    ACTIONS(292), 1,
      aux_sym_while_block_token2,
    ACTIONS(294), 1,
      aux_sym__repeat_block_pre_condition_format_token1,
    ACTIONS(1485), 1,
      sym__blank,
    STATE(251), 1,
      aux_sym_subroutine_block_repeat1,
    STATE(297), 1,
      sym__label,
    STATE(308), 1,
      aux_sym_block_repeat1,
    STATE(1333), 1,
      sym_recursive_macro_expansion,
    STATE(1432), 1,
      sym__repeat_block_pre_condition_format,
    STATE(1469), 1,
      sym__repeat_block_post_condition_format,
    STATE(1981), 1,
      sym__hll_var_command_with_default_format,
    STATE(1982), 1,
      sym__var_command_with_non_hll_format,
    STATE(2020), 1,
      sym__command_identifier,
    STATE(2059), 1,
      sym_macro,
    STATE(2082), 1,
      sym_macro_definition_command,
    STATE(2243), 1,
      sym__hll_default_format_var_command,
    STATE(2271), 1,
      sym__hll_var_definition_command_expression,
    STATE(2285), 1,
      sym__hll_non_default_format_var_command,
    STATE(2298), 1,
      sym__hll_var_command,
    STATE(2308), 1,
      sym__host_command,
    STATE(2314), 1,
      sym__non_hll_var_command,
    STATE(2327), 1,
      sym__hll_var_if_command,
    STATE(2336), 1,
      sym__hll_var_definition_command,
    STATE(2340), 1,
      sym__host_command_with_default_format,
    STATE(2344), 1,
      sym__other_command,
    STATE(2360), 1,
      sym__var_command,
    ACTIONS(27), 2,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
    ACTIONS(1529), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(33), 3,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
    STATE(1448), 13,
      sym_block,
      sym__statement,
      sym__non_labeled_statement,
      sym_labeled_expression,
      sym_subroutine_block,
      sym_if_block,
      sym_while_block,
      sym_repeat_block,
      sym_macro_assignment_expression,
      sym_macro_definition,
      sym_parameter_declaration,
      sym_subroutine_call_expression,
      sym_command_expression,
  [29093] = 43,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7), 1,
      sym_identifier,
    ACTIONS(9), 1,
      aux_sym_block_token1,
    ACTIONS(11), 1,
      aux_sym_subroutine_block_token1,
    ACTIONS(23), 1,
      anon_sym_AMP,
    ACTIONS(25), 1,
      aux_sym_macro_definition_token1,
    ACTIONS(29), 1,
      aux_sym_parameter_declaration_token3,
    ACTIONS(31), 1,
      aux_sym_subroutine_call_expression_token1,
    ACTIONS(35), 1,
      aux_sym__host_command_with_default_format_token1,
    ACTIONS(37), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(43), 1,
      sym_label_identifier,
    ACTIONS(270), 1,
      anon_sym_AMP_AMP,
    ACTIONS(288), 1,
      aux_sym_if_block_token1,
    ACTIONS(290), 1,
      aux_sym_while_block_token1,
    ACTIONS(292), 1,
      aux_sym_while_block_token2,
    ACTIONS(294), 1,
      aux_sym__repeat_block_pre_condition_format_token1,
    ACTIONS(1485), 1,
      sym__blank,
    STATE(267), 1,
      aux_sym_subroutine_block_repeat1,
    STATE(297), 1,
      sym__label,
    STATE(308), 1,
      aux_sym_block_repeat1,
    STATE(1333), 1,
      sym_recursive_macro_expansion,
    STATE(1432), 1,
      sym__repeat_block_pre_condition_format,
    STATE(1469), 1,
      sym__repeat_block_post_condition_format,
    STATE(1981), 1,
      sym__hll_var_command_with_default_format,
    STATE(1982), 1,
      sym__var_command_with_non_hll_format,
    STATE(2020), 1,
      sym__command_identifier,
    STATE(2059), 1,
      sym_macro,
    STATE(2082), 1,
      sym_macro_definition_command,
    STATE(2243), 1,
      sym__hll_default_format_var_command,
    STATE(2271), 1,
      sym__hll_var_definition_command_expression,
    STATE(2285), 1,
      sym__hll_non_default_format_var_command,
    STATE(2298), 1,
      sym__hll_var_command,
    STATE(2308), 1,
      sym__host_command,
    STATE(2314), 1,
      sym__non_hll_var_command,
    STATE(2327), 1,
      sym__hll_var_if_command,
    STATE(2336), 1,
      sym__hll_var_definition_command,
    STATE(2340), 1,
      sym__host_command_with_default_format,
    STATE(2344), 1,
      sym__other_command,
    STATE(2360), 1,
      sym__var_command,
    ACTIONS(27), 2,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
    ACTIONS(1531), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(33), 3,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
    STATE(1456), 13,
      sym_block,
      sym__statement,
      sym__non_labeled_statement,
      sym_labeled_expression,
      sym_subroutine_block,
      sym_if_block,
      sym_while_block,
      sym_repeat_block,
      sym_macro_assignment_expression,
      sym_macro_definition,
      sym_parameter_declaration,
      sym_subroutine_call_expression,
      sym_command_expression,
  [29239] = 42,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7), 1,
      sym_identifier,
    ACTIONS(11), 1,
      aux_sym_subroutine_block_token1,
    ACTIONS(23), 1,
      anon_sym_AMP,
    ACTIONS(25), 1,
      aux_sym_macro_definition_token1,
    ACTIONS(29), 1,
      aux_sym_parameter_declaration_token3,
    ACTIONS(31), 1,
      aux_sym_subroutine_call_expression_token1,
    ACTIONS(35), 1,
      aux_sym__host_command_with_default_format_token1,
    ACTIONS(37), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(43), 1,
      sym_label_identifier,
    ACTIONS(262), 1,
      aux_sym_if_block_token1,
    ACTIONS(264), 1,
      aux_sym_while_block_token1,
    ACTIONS(266), 1,
      aux_sym_while_block_token2,
    ACTIONS(268), 1,
      aux_sym__repeat_block_pre_condition_format_token1,
    ACTIONS(270), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1533), 1,
      sym_comment,
    ACTIONS(1535), 1,
      sym__blank_line,
    ACTIONS(1537), 1,
      sym__blank,
    STATE(294), 1,
      sym__label,
    STATE(309), 1,
      aux_sym_block_repeat1,
    STATE(1333), 1,
      sym_recursive_macro_expansion,
    STATE(1432), 1,
      sym__repeat_block_pre_condition_format,
    STATE(1469), 1,
      sym__repeat_block_post_condition_format,
    STATE(1981), 1,
      sym__hll_var_command_with_default_format,
    STATE(1982), 1,
      sym__var_command_with_non_hll_format,
    STATE(2020), 1,
      sym__command_identifier,
    STATE(2059), 1,
      sym_macro,
    STATE(2082), 1,
      sym_macro_definition_command,
    STATE(2243), 1,
      sym__hll_default_format_var_command,
    STATE(2271), 1,
      sym__hll_var_definition_command_expression,
    STATE(2285), 1,
      sym__hll_non_default_format_var_command,
    STATE(2298), 1,
      sym__hll_var_command,
    STATE(2308), 1,
      sym__host_command,
    STATE(2312), 1,
      sym__hll_var_if_command,
    STATE(2314), 1,
      sym__non_hll_var_command,
    STATE(2336), 1,
      sym__hll_var_definition_command,
    STATE(2340), 1,
      sym__host_command_with_default_format,
    STATE(2344), 1,
      sym__other_command,
    STATE(2360), 1,
      sym__var_command,
    ACTIONS(27), 2,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
    ACTIONS(33), 3,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
    STATE(1503), 12,
      sym__statement,
      sym__non_labeled_statement,
      sym_labeled_expression,
      sym_subroutine_block,
      sym_if_block,
      sym_while_block,
      sym_repeat_block,
      sym_macro_assignment_expression,
      sym_macro_definition,
      sym_parameter_declaration,
      sym_subroutine_call_expression,
      sym_command_expression,
  [29380] = 42,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7), 1,
      sym_identifier,
    ACTIONS(11), 1,
      aux_sym_subroutine_block_token1,
    ACTIONS(13), 1,
      aux_sym_if_block_token1,
    ACTIONS(15), 1,
      aux_sym_while_block_token1,
    ACTIONS(17), 1,
      aux_sym_while_block_token2,
    ACTIONS(19), 1,
      aux_sym__repeat_block_pre_condition_format_token1,
    ACTIONS(21), 1,
      anon_sym_AMP_AMP,
    ACTIONS(23), 1,
      anon_sym_AMP,
    ACTIONS(25), 1,
      aux_sym_macro_definition_token1,
    ACTIONS(29), 1,
      aux_sym_parameter_declaration_token3,
    ACTIONS(31), 1,
      aux_sym_subroutine_call_expression_token1,
    ACTIONS(35), 1,
      aux_sym__host_command_with_default_format_token1,
    ACTIONS(37), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(43), 1,
      sym_label_identifier,
    ACTIONS(1533), 1,
      sym_comment,
    ACTIONS(1535), 1,
      sym__blank_line,
    ACTIONS(1539), 1,
      sym__blank,
    STATE(295), 1,
      sym__label,
    STATE(310), 1,
      aux_sym_block_repeat1,
    STATE(1333), 1,
      sym_recursive_macro_expansion,
    STATE(1432), 1,
      sym__repeat_block_pre_condition_format,
    STATE(1469), 1,
      sym__repeat_block_post_condition_format,
    STATE(1981), 1,
      sym__hll_var_command_with_default_format,
    STATE(1982), 1,
      sym__var_command_with_non_hll_format,
    STATE(2020), 1,
      sym__command_identifier,
    STATE(2059), 1,
      sym_macro,
    STATE(2082), 1,
      sym_macro_definition_command,
    STATE(2243), 1,
      sym__hll_default_format_var_command,
    STATE(2271), 1,
      sym__hll_var_definition_command_expression,
    STATE(2272), 1,
      sym__hll_var_if_command,
    STATE(2285), 1,
      sym__hll_non_default_format_var_command,
    STATE(2298), 1,
      sym__hll_var_command,
    STATE(2308), 1,
      sym__host_command,
    STATE(2314), 1,
      sym__non_hll_var_command,
    STATE(2336), 1,
      sym__hll_var_definition_command,
    STATE(2340), 1,
      sym__host_command_with_default_format,
    STATE(2344), 1,
      sym__other_command,
    STATE(2360), 1,
      sym__var_command,
    ACTIONS(27), 2,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
    ACTIONS(33), 3,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
    STATE(1503), 12,
      sym__statement,
      sym__non_labeled_statement,
      sym_labeled_expression,
      sym_subroutine_block,
      sym_if_block,
      sym_while_block,
      sym_repeat_block,
      sym_macro_assignment_expression,
      sym_macro_definition,
      sym_parameter_declaration,
      sym_subroutine_call_expression,
      sym_command_expression,
  [29521] = 42,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7), 1,
      sym_identifier,
    ACTIONS(11), 1,
      aux_sym_subroutine_block_token1,
    ACTIONS(21), 1,
      anon_sym_AMP_AMP,
    ACTIONS(23), 1,
      anon_sym_AMP,
    ACTIONS(25), 1,
      aux_sym_macro_definition_token1,
    ACTIONS(29), 1,
      aux_sym_parameter_declaration_token3,
    ACTIONS(31), 1,
      aux_sym_subroutine_call_expression_token1,
    ACTIONS(35), 1,
      aux_sym__host_command_with_default_format_token1,
    ACTIONS(37), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(43), 1,
      sym_label_identifier,
    ACTIONS(276), 1,
      aux_sym_if_block_token1,
    ACTIONS(278), 1,
      aux_sym_while_block_token1,
    ACTIONS(280), 1,
      aux_sym_while_block_token2,
    ACTIONS(282), 1,
      aux_sym__repeat_block_pre_condition_format_token1,
    ACTIONS(1533), 1,
      sym_comment,
    ACTIONS(1535), 1,
      sym__blank_line,
    ACTIONS(1541), 1,
      sym__blank,
    STATE(296), 1,
      sym__label,
    STATE(311), 1,
      aux_sym_block_repeat1,
    STATE(1333), 1,
      sym_recursive_macro_expansion,
    STATE(1432), 1,
      sym__repeat_block_pre_condition_format,
    STATE(1469), 1,
      sym__repeat_block_post_condition_format,
    STATE(1981), 1,
      sym__hll_var_command_with_default_format,
    STATE(1982), 1,
      sym__var_command_with_non_hll_format,
    STATE(2020), 1,
      sym__command_identifier,
    STATE(2059), 1,
      sym_macro,
    STATE(2082), 1,
      sym_macro_definition_command,
    STATE(2243), 1,
      sym__hll_default_format_var_command,
    STATE(2271), 1,
      sym__hll_var_definition_command_expression,
    STATE(2285), 1,
      sym__hll_non_default_format_var_command,
    STATE(2298), 1,
      sym__hll_var_command,
    STATE(2308), 1,
      sym__host_command,
    STATE(2314), 1,
      sym__non_hll_var_command,
    STATE(2325), 1,
      sym__hll_var_if_command,
    STATE(2336), 1,
      sym__hll_var_definition_command,
    STATE(2340), 1,
      sym__host_command_with_default_format,
    STATE(2344), 1,
      sym__other_command,
    STATE(2360), 1,
      sym__var_command,
    ACTIONS(27), 2,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
    ACTIONS(33), 3,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
    STATE(1503), 12,
      sym__statement,
      sym__non_labeled_statement,
      sym_labeled_expression,
      sym_subroutine_block,
      sym_if_block,
      sym_while_block,
      sym_repeat_block,
      sym_macro_assignment_expression,
      sym_macro_definition,
      sym_parameter_declaration,
      sym_subroutine_call_expression,
      sym_command_expression,
  [29662] = 42,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7), 1,
      sym_identifier,
    ACTIONS(11), 1,
      aux_sym_subroutine_block_token1,
    ACTIONS(23), 1,
      anon_sym_AMP,
    ACTIONS(25), 1,
      aux_sym_macro_definition_token1,
    ACTIONS(29), 1,
      aux_sym_parameter_declaration_token3,
    ACTIONS(31), 1,
      aux_sym_subroutine_call_expression_token1,
    ACTIONS(35), 1,
      aux_sym__host_command_with_default_format_token1,
    ACTIONS(37), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(43), 1,
      sym_label_identifier,
    ACTIONS(270), 1,
      anon_sym_AMP_AMP,
    ACTIONS(288), 1,
      aux_sym_if_block_token1,
    ACTIONS(290), 1,
      aux_sym_while_block_token1,
    ACTIONS(292), 1,
      aux_sym_while_block_token2,
    ACTIONS(294), 1,
      aux_sym__repeat_block_pre_condition_format_token1,
    ACTIONS(1533), 1,
      sym_comment,
    ACTIONS(1535), 1,
      sym__blank_line,
    ACTIONS(1543), 1,
      sym__blank,
    STATE(297), 1,
      sym__label,
    STATE(312), 1,
      aux_sym_block_repeat1,
    STATE(1333), 1,
      sym_recursive_macro_expansion,
    STATE(1432), 1,
      sym__repeat_block_pre_condition_format,
    STATE(1469), 1,
      sym__repeat_block_post_condition_format,
    STATE(1981), 1,
      sym__hll_var_command_with_default_format,
    STATE(1982), 1,
      sym__var_command_with_non_hll_format,
    STATE(2020), 1,
      sym__command_identifier,
    STATE(2059), 1,
      sym_macro,
    STATE(2082), 1,
      sym_macro_definition_command,
    STATE(2243), 1,
      sym__hll_default_format_var_command,
    STATE(2271), 1,
      sym__hll_var_definition_command_expression,
    STATE(2285), 1,
      sym__hll_non_default_format_var_command,
    STATE(2298), 1,
      sym__hll_var_command,
    STATE(2308), 1,
      sym__host_command,
    STATE(2314), 1,
      sym__non_hll_var_command,
    STATE(2327), 1,
      sym__hll_var_if_command,
    STATE(2336), 1,
      sym__hll_var_definition_command,
    STATE(2340), 1,
      sym__host_command_with_default_format,
    STATE(2344), 1,
      sym__other_command,
    STATE(2360), 1,
      sym__var_command,
    ACTIONS(27), 2,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
    ACTIONS(33), 3,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
    STATE(1503), 12,
      sym__statement,
      sym__non_labeled_statement,
      sym_labeled_expression,
      sym_subroutine_block,
      sym_if_block,
      sym_while_block,
      sym_repeat_block,
      sym_macro_assignment_expression,
      sym_macro_definition,
      sym_parameter_declaration,
      sym_subroutine_call_expression,
      sym_command_expression,
  [29803] = 42,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7), 1,
      sym_identifier,
    ACTIONS(11), 1,
      aux_sym_subroutine_block_token1,
    ACTIONS(23), 1,
      anon_sym_AMP,
    ACTIONS(25), 1,
      aux_sym_macro_definition_token1,
    ACTIONS(29), 1,
      aux_sym_parameter_declaration_token3,
    ACTIONS(31), 1,
      aux_sym_subroutine_call_expression_token1,
    ACTIONS(35), 1,
      aux_sym__host_command_with_default_format_token1,
    ACTIONS(37), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(43), 1,
      sym_label_identifier,
    ACTIONS(262), 1,
      aux_sym_if_block_token1,
    ACTIONS(264), 1,
      aux_sym_while_block_token1,
    ACTIONS(266), 1,
      aux_sym_while_block_token2,
    ACTIONS(268), 1,
      aux_sym__repeat_block_pre_condition_format_token1,
    ACTIONS(270), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1347), 1,
      anon_sym_RPAREN,
    ACTIONS(1545), 1,
      aux_sym_block_token1,
    ACTIONS(1547), 1,
      sym__blank,
    STATE(294), 1,
      sym__label,
    STATE(1333), 1,
      sym_recursive_macro_expansion,
    STATE(1432), 1,
      sym__repeat_block_pre_condition_format,
    STATE(1469), 1,
      sym__repeat_block_post_condition_format,
    STATE(1516), 1,
      aux_sym_block_repeat1,
    STATE(1981), 1,
      sym__hll_var_command_with_default_format,
    STATE(1982), 1,
      sym__var_command_with_non_hll_format,
    STATE(2020), 1,
      sym__command_identifier,
    STATE(2059), 1,
      sym_macro,
    STATE(2082), 1,
      sym_macro_definition_command,
    STATE(2243), 1,
      sym__hll_default_format_var_command,
    STATE(2271), 1,
      sym__hll_var_definition_command_expression,
    STATE(2285), 1,
      sym__hll_non_default_format_var_command,
    STATE(2298), 1,
      sym__hll_var_command,
    STATE(2308), 1,
      sym__host_command,
    STATE(2312), 1,
      sym__hll_var_if_command,
    STATE(2314), 1,
      sym__non_hll_var_command,
    STATE(2336), 1,
      sym__hll_var_definition_command,
    STATE(2340), 1,
      sym__host_command_with_default_format,
    STATE(2344), 1,
      sym__other_command,
    STATE(2360), 1,
      sym__var_command,
    ACTIONS(27), 2,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
    ACTIONS(33), 3,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
    STATE(1463), 11,
      sym__non_labeled_statement,
      sym_labeled_expression,
      sym_subroutine_block,
      sym_if_block,
      sym_while_block,
      sym_repeat_block,
      sym_macro_assignment_expression,
      sym_macro_definition,
      sym_parameter_declaration,
      sym_subroutine_call_expression,
      sym_command_expression,
  [29943] = 42,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7), 1,
      sym_identifier,
    ACTIONS(11), 1,
      aux_sym_subroutine_block_token1,
    ACTIONS(23), 1,
      anon_sym_AMP,
    ACTIONS(25), 1,
      aux_sym_macro_definition_token1,
    ACTIONS(29), 1,
      aux_sym_parameter_declaration_token3,
    ACTIONS(31), 1,
      aux_sym_subroutine_call_expression_token1,
    ACTIONS(35), 1,
      aux_sym__host_command_with_default_format_token1,
    ACTIONS(37), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(43), 1,
      sym_label_identifier,
    ACTIONS(262), 1,
      aux_sym_if_block_token1,
    ACTIONS(264), 1,
      aux_sym_while_block_token1,
    ACTIONS(266), 1,
      aux_sym_while_block_token2,
    ACTIONS(268), 1,
      aux_sym__repeat_block_pre_condition_format_token1,
    ACTIONS(270), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1341), 1,
      anon_sym_RPAREN,
    ACTIONS(1545), 1,
      aux_sym_block_token1,
    ACTIONS(1547), 1,
      sym__blank,
    STATE(294), 1,
      sym__label,
    STATE(1333), 1,
      sym_recursive_macro_expansion,
    STATE(1432), 1,
      sym__repeat_block_pre_condition_format,
    STATE(1469), 1,
      sym__repeat_block_post_condition_format,
    STATE(1516), 1,
      aux_sym_block_repeat1,
    STATE(1981), 1,
      sym__hll_var_command_with_default_format,
    STATE(1982), 1,
      sym__var_command_with_non_hll_format,
    STATE(2020), 1,
      sym__command_identifier,
    STATE(2059), 1,
      sym_macro,
    STATE(2082), 1,
      sym_macro_definition_command,
    STATE(2243), 1,
      sym__hll_default_format_var_command,
    STATE(2271), 1,
      sym__hll_var_definition_command_expression,
    STATE(2285), 1,
      sym__hll_non_default_format_var_command,
    STATE(2298), 1,
      sym__hll_var_command,
    STATE(2308), 1,
      sym__host_command,
    STATE(2312), 1,
      sym__hll_var_if_command,
    STATE(2314), 1,
      sym__non_hll_var_command,
    STATE(2336), 1,
      sym__hll_var_definition_command,
    STATE(2340), 1,
      sym__host_command_with_default_format,
    STATE(2344), 1,
      sym__other_command,
    STATE(2360), 1,
      sym__var_command,
    ACTIONS(27), 2,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
    ACTIONS(33), 3,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
    STATE(1463), 11,
      sym__non_labeled_statement,
      sym_labeled_expression,
      sym_subroutine_block,
      sym_if_block,
      sym_while_block,
      sym_repeat_block,
      sym_macro_assignment_expression,
      sym_macro_definition,
      sym_parameter_declaration,
      sym_subroutine_call_expression,
      sym_command_expression,
  [30083] = 42,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7), 1,
      sym_identifier,
    ACTIONS(11), 1,
      aux_sym_subroutine_block_token1,
    ACTIONS(23), 1,
      anon_sym_AMP,
    ACTIONS(25), 1,
      aux_sym_macro_definition_token1,
    ACTIONS(29), 1,
      aux_sym_parameter_declaration_token3,
    ACTIONS(31), 1,
      aux_sym_subroutine_call_expression_token1,
    ACTIONS(35), 1,
      aux_sym__host_command_with_default_format_token1,
    ACTIONS(37), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(43), 1,
      sym_label_identifier,
    ACTIONS(262), 1,
      aux_sym_if_block_token1,
    ACTIONS(264), 1,
      aux_sym_while_block_token1,
    ACTIONS(266), 1,
      aux_sym_while_block_token2,
    ACTIONS(268), 1,
      aux_sym__repeat_block_pre_condition_format_token1,
    ACTIONS(270), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1545), 1,
      aux_sym_block_token1,
    ACTIONS(1547), 1,
      sym__blank,
    ACTIONS(1549), 1,
      anon_sym_RPAREN,
    STATE(294), 1,
      sym__label,
    STATE(1333), 1,
      sym_recursive_macro_expansion,
    STATE(1432), 1,
      sym__repeat_block_pre_condition_format,
    STATE(1469), 1,
      sym__repeat_block_post_condition_format,
    STATE(1516), 1,
      aux_sym_block_repeat1,
    STATE(1981), 1,
      sym__hll_var_command_with_default_format,
    STATE(1982), 1,
      sym__var_command_with_non_hll_format,
    STATE(2020), 1,
      sym__command_identifier,
    STATE(2059), 1,
      sym_macro,
    STATE(2082), 1,
      sym_macro_definition_command,
    STATE(2243), 1,
      sym__hll_default_format_var_command,
    STATE(2271), 1,
      sym__hll_var_definition_command_expression,
    STATE(2285), 1,
      sym__hll_non_default_format_var_command,
    STATE(2298), 1,
      sym__hll_var_command,
    STATE(2308), 1,
      sym__host_command,
    STATE(2312), 1,
      sym__hll_var_if_command,
    STATE(2314), 1,
      sym__non_hll_var_command,
    STATE(2336), 1,
      sym__hll_var_definition_command,
    STATE(2340), 1,
      sym__host_command_with_default_format,
    STATE(2344), 1,
      sym__other_command,
    STATE(2360), 1,
      sym__var_command,
    ACTIONS(27), 2,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
    ACTIONS(33), 3,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
    STATE(1463), 11,
      sym__non_labeled_statement,
      sym_labeled_expression,
      sym_subroutine_block,
      sym_if_block,
      sym_while_block,
      sym_repeat_block,
      sym_macro_assignment_expression,
      sym_macro_definition,
      sym_parameter_declaration,
      sym_subroutine_call_expression,
      sym_command_expression,
  [30223] = 41,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7), 1,
      sym_identifier,
    ACTIONS(11), 1,
      aux_sym_subroutine_block_token1,
    ACTIONS(23), 1,
      anon_sym_AMP,
    ACTIONS(25), 1,
      aux_sym_macro_definition_token1,
    ACTIONS(29), 1,
      aux_sym_parameter_declaration_token3,
    ACTIONS(31), 1,
      aux_sym_subroutine_call_expression_token1,
    ACTIONS(35), 1,
      aux_sym__host_command_with_default_format_token1,
    ACTIONS(37), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(43), 1,
      sym_label_identifier,
    ACTIONS(262), 1,
      aux_sym_if_block_token1,
    ACTIONS(264), 1,
      aux_sym_while_block_token1,
    ACTIONS(266), 1,
      aux_sym_while_block_token2,
    ACTIONS(268), 1,
      aux_sym__repeat_block_pre_condition_format_token1,
    ACTIONS(270), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1545), 1,
      aux_sym_block_token1,
    ACTIONS(1547), 1,
      sym__blank,
    STATE(294), 1,
      sym__label,
    STATE(1333), 1,
      sym_recursive_macro_expansion,
    STATE(1432), 1,
      sym__repeat_block_pre_condition_format,
    STATE(1469), 1,
      sym__repeat_block_post_condition_format,
    STATE(1516), 1,
      aux_sym_block_repeat1,
    STATE(1981), 1,
      sym__hll_var_command_with_default_format,
    STATE(1982), 1,
      sym__var_command_with_non_hll_format,
    STATE(2020), 1,
      sym__command_identifier,
    STATE(2059), 1,
      sym_macro,
    STATE(2082), 1,
      sym_macro_definition_command,
    STATE(2243), 1,
      sym__hll_default_format_var_command,
    STATE(2271), 1,
      sym__hll_var_definition_command_expression,
    STATE(2285), 1,
      sym__hll_non_default_format_var_command,
    STATE(2298), 1,
      sym__hll_var_command,
    STATE(2308), 1,
      sym__host_command,
    STATE(2312), 1,
      sym__hll_var_if_command,
    STATE(2314), 1,
      sym__non_hll_var_command,
    STATE(2336), 1,
      sym__hll_var_definition_command,
    STATE(2340), 1,
      sym__host_command_with_default_format,
    STATE(2344), 1,
      sym__other_command,
    STATE(2360), 1,
      sym__var_command,
    ACTIONS(27), 2,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
    ACTIONS(33), 3,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
    STATE(1463), 11,
      sym__non_labeled_statement,
      sym_labeled_expression,
      sym_subroutine_block,
      sym_if_block,
      sym_while_block,
      sym_repeat_block,
      sym_macro_assignment_expression,
      sym_macro_definition,
      sym_parameter_declaration,
      sym_subroutine_call_expression,
      sym_command_expression,
  [30360] = 41,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7), 1,
      sym_identifier,
    ACTIONS(11), 1,
      aux_sym_subroutine_block_token1,
    ACTIONS(23), 1,
      anon_sym_AMP,
    ACTIONS(25), 1,
      aux_sym_macro_definition_token1,
    ACTIONS(29), 1,
      aux_sym_parameter_declaration_token3,
    ACTIONS(31), 1,
      aux_sym_subroutine_call_expression_token1,
    ACTIONS(35), 1,
      aux_sym__host_command_with_default_format_token1,
    ACTIONS(37), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(43), 1,
      sym_label_identifier,
    ACTIONS(270), 1,
      anon_sym_AMP_AMP,
    ACTIONS(288), 1,
      aux_sym_if_block_token1,
    ACTIONS(290), 1,
      aux_sym_while_block_token1,
    ACTIONS(292), 1,
      aux_sym_while_block_token2,
    ACTIONS(294), 1,
      aux_sym__repeat_block_pre_condition_format_token1,
    ACTIONS(1547), 1,
      sym__blank,
    ACTIONS(1551), 1,
      anon_sym_EQ,
    STATE(297), 1,
      sym__label,
    STATE(1333), 1,
      sym_recursive_macro_expansion,
    STATE(1432), 1,
      sym__repeat_block_pre_condition_format,
    STATE(1469), 1,
      sym__repeat_block_post_condition_format,
    STATE(1516), 1,
      aux_sym_block_repeat1,
    STATE(1981), 1,
      sym__hll_var_command_with_default_format,
    STATE(1982), 1,
      sym__var_command_with_non_hll_format,
    STATE(2020), 1,
      sym__command_identifier,
    STATE(2059), 1,
      sym_macro,
    STATE(2082), 1,
      sym_macro_definition_command,
    STATE(2243), 1,
      sym__hll_default_format_var_command,
    STATE(2271), 1,
      sym__hll_var_definition_command_expression,
    STATE(2285), 1,
      sym__hll_non_default_format_var_command,
    STATE(2298), 1,
      sym__hll_var_command,
    STATE(2308), 1,
      sym__host_command,
    STATE(2314), 1,
      sym__non_hll_var_command,
    STATE(2327), 1,
      sym__hll_var_if_command,
    STATE(2336), 1,
      sym__hll_var_definition_command,
    STATE(2340), 1,
      sym__host_command_with_default_format,
    STATE(2344), 1,
      sym__other_command,
    STATE(2360), 1,
      sym__var_command,
    ACTIONS(27), 2,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
    ACTIONS(33), 3,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
    STATE(1463), 11,
      sym__non_labeled_statement,
      sym_labeled_expression,
      sym_subroutine_block,
      sym_if_block,
      sym_while_block,
      sym_repeat_block,
      sym_macro_assignment_expression,
      sym_macro_definition,
      sym_parameter_declaration,
      sym_subroutine_call_expression,
      sym_command_expression,
  [30497] = 41,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7), 1,
      sym_identifier,
    ACTIONS(11), 1,
      aux_sym_subroutine_block_token1,
    ACTIONS(23), 1,
      anon_sym_AMP,
    ACTIONS(25), 1,
      aux_sym_macro_definition_token1,
    ACTIONS(29), 1,
      aux_sym_parameter_declaration_token3,
    ACTIONS(31), 1,
      aux_sym_subroutine_call_expression_token1,
    ACTIONS(35), 1,
      aux_sym__host_command_with_default_format_token1,
    ACTIONS(37), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(43), 1,
      sym_label_identifier,
    ACTIONS(262), 1,
      aux_sym_if_block_token1,
    ACTIONS(264), 1,
      aux_sym_while_block_token1,
    ACTIONS(266), 1,
      aux_sym_while_block_token2,
    ACTIONS(268), 1,
      aux_sym__repeat_block_pre_condition_format_token1,
    ACTIONS(270), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1547), 1,
      sym__blank,
    ACTIONS(1551), 1,
      anon_sym_EQ,
    STATE(294), 1,
      sym__label,
    STATE(1333), 1,
      sym_recursive_macro_expansion,
    STATE(1432), 1,
      sym__repeat_block_pre_condition_format,
    STATE(1469), 1,
      sym__repeat_block_post_condition_format,
    STATE(1516), 1,
      aux_sym_block_repeat1,
    STATE(1981), 1,
      sym__hll_var_command_with_default_format,
    STATE(1982), 1,
      sym__var_command_with_non_hll_format,
    STATE(2020), 1,
      sym__command_identifier,
    STATE(2059), 1,
      sym_macro,
    STATE(2082), 1,
      sym_macro_definition_command,
    STATE(2243), 1,
      sym__hll_default_format_var_command,
    STATE(2271), 1,
      sym__hll_var_definition_command_expression,
    STATE(2285), 1,
      sym__hll_non_default_format_var_command,
    STATE(2298), 1,
      sym__hll_var_command,
    STATE(2308), 1,
      sym__host_command,
    STATE(2312), 1,
      sym__hll_var_if_command,
    STATE(2314), 1,
      sym__non_hll_var_command,
    STATE(2336), 1,
      sym__hll_var_definition_command,
    STATE(2340), 1,
      sym__host_command_with_default_format,
    STATE(2344), 1,
      sym__other_command,
    STATE(2360), 1,
      sym__var_command,
    ACTIONS(27), 2,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
    ACTIONS(33), 3,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
    STATE(1463), 11,
      sym__non_labeled_statement,
      sym_labeled_expression,
      sym_subroutine_block,
      sym_if_block,
      sym_while_block,
      sym_repeat_block,
      sym_macro_assignment_expression,
      sym_macro_definition,
      sym_parameter_declaration,
      sym_subroutine_call_expression,
      sym_command_expression,
  [30634] = 41,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7), 1,
      sym_identifier,
    ACTIONS(11), 1,
      aux_sym_subroutine_block_token1,
    ACTIONS(13), 1,
      aux_sym_if_block_token1,
    ACTIONS(15), 1,
      aux_sym_while_block_token1,
    ACTIONS(17), 1,
      aux_sym_while_block_token2,
    ACTIONS(19), 1,
      aux_sym__repeat_block_pre_condition_format_token1,
    ACTIONS(21), 1,
      anon_sym_AMP_AMP,
    ACTIONS(23), 1,
      anon_sym_AMP,
    ACTIONS(25), 1,
      aux_sym_macro_definition_token1,
    ACTIONS(29), 1,
      aux_sym_parameter_declaration_token3,
    ACTIONS(31), 1,
      aux_sym_subroutine_call_expression_token1,
    ACTIONS(35), 1,
      aux_sym__host_command_with_default_format_token1,
    ACTIONS(37), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(43), 1,
      sym_label_identifier,
    ACTIONS(1545), 1,
      aux_sym_block_token1,
    ACTIONS(1547), 1,
      sym__blank,
    STATE(295), 1,
      sym__label,
    STATE(1333), 1,
      sym_recursive_macro_expansion,
    STATE(1432), 1,
      sym__repeat_block_pre_condition_format,
    STATE(1469), 1,
      sym__repeat_block_post_condition_format,
    STATE(1516), 1,
      aux_sym_block_repeat1,
    STATE(1981), 1,
      sym__hll_var_command_with_default_format,
    STATE(1982), 1,
      sym__var_command_with_non_hll_format,
    STATE(2020), 1,
      sym__command_identifier,
    STATE(2059), 1,
      sym_macro,
    STATE(2082), 1,
      sym_macro_definition_command,
    STATE(2243), 1,
      sym__hll_default_format_var_command,
    STATE(2271), 1,
      sym__hll_var_definition_command_expression,
    STATE(2272), 1,
      sym__hll_var_if_command,
    STATE(2285), 1,
      sym__hll_non_default_format_var_command,
    STATE(2298), 1,
      sym__hll_var_command,
    STATE(2308), 1,
      sym__host_command,
    STATE(2314), 1,
      sym__non_hll_var_command,
    STATE(2336), 1,
      sym__hll_var_definition_command,
    STATE(2340), 1,
      sym__host_command_with_default_format,
    STATE(2344), 1,
      sym__other_command,
    STATE(2360), 1,
      sym__var_command,
    ACTIONS(27), 2,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
    ACTIONS(33), 3,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
    STATE(1463), 11,
      sym__non_labeled_statement,
      sym_labeled_expression,
      sym_subroutine_block,
      sym_if_block,
      sym_while_block,
      sym_repeat_block,
      sym_macro_assignment_expression,
      sym_macro_definition,
      sym_parameter_declaration,
      sym_subroutine_call_expression,
      sym_command_expression,
  [30771] = 41,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7), 1,
      sym_identifier,
    ACTIONS(11), 1,
      aux_sym_subroutine_block_token1,
    ACTIONS(21), 1,
      anon_sym_AMP_AMP,
    ACTIONS(23), 1,
      anon_sym_AMP,
    ACTIONS(25), 1,
      aux_sym_macro_definition_token1,
    ACTIONS(29), 1,
      aux_sym_parameter_declaration_token3,
    ACTIONS(31), 1,
      aux_sym_subroutine_call_expression_token1,
    ACTIONS(35), 1,
      aux_sym__host_command_with_default_format_token1,
    ACTIONS(37), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(43), 1,
      sym_label_identifier,
    ACTIONS(276), 1,
      aux_sym_if_block_token1,
    ACTIONS(278), 1,
      aux_sym_while_block_token1,
    ACTIONS(280), 1,
      aux_sym_while_block_token2,
    ACTIONS(282), 1,
      aux_sym__repeat_block_pre_condition_format_token1,
    ACTIONS(1547), 1,
      sym__blank,
    ACTIONS(1551), 1,
      anon_sym_EQ,
    STATE(296), 1,
      sym__label,
    STATE(1333), 1,
      sym_recursive_macro_expansion,
    STATE(1432), 1,
      sym__repeat_block_pre_condition_format,
    STATE(1469), 1,
      sym__repeat_block_post_condition_format,
    STATE(1516), 1,
      aux_sym_block_repeat1,
    STATE(1981), 1,
      sym__hll_var_command_with_default_format,
    STATE(1982), 1,
      sym__var_command_with_non_hll_format,
    STATE(2020), 1,
      sym__command_identifier,
    STATE(2059), 1,
      sym_macro,
    STATE(2082), 1,
      sym_macro_definition_command,
    STATE(2243), 1,
      sym__hll_default_format_var_command,
    STATE(2271), 1,
      sym__hll_var_definition_command_expression,
    STATE(2285), 1,
      sym__hll_non_default_format_var_command,
    STATE(2298), 1,
      sym__hll_var_command,
    STATE(2308), 1,
      sym__host_command,
    STATE(2314), 1,
      sym__non_hll_var_command,
    STATE(2325), 1,
      sym__hll_var_if_command,
    STATE(2336), 1,
      sym__hll_var_definition_command,
    STATE(2340), 1,
      sym__host_command_with_default_format,
    STATE(2344), 1,
      sym__other_command,
    STATE(2360), 1,
      sym__var_command,
    ACTIONS(27), 2,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
    ACTIONS(33), 3,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
    STATE(1463), 11,
      sym__non_labeled_statement,
      sym_labeled_expression,
      sym_subroutine_block,
      sym_if_block,
      sym_while_block,
      sym_repeat_block,
      sym_macro_assignment_expression,
      sym_macro_definition,
      sym_parameter_declaration,
      sym_subroutine_call_expression,
      sym_command_expression,
  [30908] = 41,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7), 1,
      sym_identifier,
    ACTIONS(11), 1,
      aux_sym_subroutine_block_token1,
    ACTIONS(13), 1,
      aux_sym_if_block_token1,
    ACTIONS(15), 1,
      aux_sym_while_block_token1,
    ACTIONS(17), 1,
      aux_sym_while_block_token2,
    ACTIONS(19), 1,
      aux_sym__repeat_block_pre_condition_format_token1,
    ACTIONS(21), 1,
      anon_sym_AMP_AMP,
    ACTIONS(23), 1,
      anon_sym_AMP,
    ACTIONS(25), 1,
      aux_sym_macro_definition_token1,
    ACTIONS(29), 1,
      aux_sym_parameter_declaration_token3,
    ACTIONS(31), 1,
      aux_sym_subroutine_call_expression_token1,
    ACTIONS(35), 1,
      aux_sym__host_command_with_default_format_token1,
    ACTIONS(37), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(43), 1,
      sym_label_identifier,
    ACTIONS(1547), 1,
      sym__blank,
    ACTIONS(1551), 1,
      anon_sym_EQ,
    STATE(295), 1,
      sym__label,
    STATE(1333), 1,
      sym_recursive_macro_expansion,
    STATE(1432), 1,
      sym__repeat_block_pre_condition_format,
    STATE(1469), 1,
      sym__repeat_block_post_condition_format,
    STATE(1516), 1,
      aux_sym_block_repeat1,
    STATE(1981), 1,
      sym__hll_var_command_with_default_format,
    STATE(1982), 1,
      sym__var_command_with_non_hll_format,
    STATE(2020), 1,
      sym__command_identifier,
    STATE(2059), 1,
      sym_macro,
    STATE(2082), 1,
      sym_macro_definition_command,
    STATE(2243), 1,
      sym__hll_default_format_var_command,
    STATE(2271), 1,
      sym__hll_var_definition_command_expression,
    STATE(2272), 1,
      sym__hll_var_if_command,
    STATE(2285), 1,
      sym__hll_non_default_format_var_command,
    STATE(2298), 1,
      sym__hll_var_command,
    STATE(2308), 1,
      sym__host_command,
    STATE(2314), 1,
      sym__non_hll_var_command,
    STATE(2336), 1,
      sym__hll_var_definition_command,
    STATE(2340), 1,
      sym__host_command_with_default_format,
    STATE(2344), 1,
      sym__other_command,
    STATE(2360), 1,
      sym__var_command,
    ACTIONS(27), 2,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
    ACTIONS(33), 3,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
    STATE(1463), 11,
      sym__non_labeled_statement,
      sym_labeled_expression,
      sym_subroutine_block,
      sym_if_block,
      sym_while_block,
      sym_repeat_block,
      sym_macro_assignment_expression,
      sym_macro_definition,
      sym_parameter_declaration,
      sym_subroutine_call_expression,
      sym_command_expression,
  [31045] = 41,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7), 1,
      sym_identifier,
    ACTIONS(11), 1,
      aux_sym_subroutine_block_token1,
    ACTIONS(21), 1,
      anon_sym_AMP_AMP,
    ACTIONS(23), 1,
      anon_sym_AMP,
    ACTIONS(25), 1,
      aux_sym_macro_definition_token1,
    ACTIONS(29), 1,
      aux_sym_parameter_declaration_token3,
    ACTIONS(31), 1,
      aux_sym_subroutine_call_expression_token1,
    ACTIONS(35), 1,
      aux_sym__host_command_with_default_format_token1,
    ACTIONS(37), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(43), 1,
      sym_label_identifier,
    ACTIONS(276), 1,
      aux_sym_if_block_token1,
    ACTIONS(278), 1,
      aux_sym_while_block_token1,
    ACTIONS(280), 1,
      aux_sym_while_block_token2,
    ACTIONS(282), 1,
      aux_sym__repeat_block_pre_condition_format_token1,
    ACTIONS(1545), 1,
      aux_sym_block_token1,
    ACTIONS(1547), 1,
      sym__blank,
    STATE(296), 1,
      sym__label,
    STATE(1333), 1,
      sym_recursive_macro_expansion,
    STATE(1432), 1,
      sym__repeat_block_pre_condition_format,
    STATE(1469), 1,
      sym__repeat_block_post_condition_format,
    STATE(1516), 1,
      aux_sym_block_repeat1,
    STATE(1981), 1,
      sym__hll_var_command_with_default_format,
    STATE(1982), 1,
      sym__var_command_with_non_hll_format,
    STATE(2020), 1,
      sym__command_identifier,
    STATE(2059), 1,
      sym_macro,
    STATE(2082), 1,
      sym_macro_definition_command,
    STATE(2243), 1,
      sym__hll_default_format_var_command,
    STATE(2271), 1,
      sym__hll_var_definition_command_expression,
    STATE(2285), 1,
      sym__hll_non_default_format_var_command,
    STATE(2298), 1,
      sym__hll_var_command,
    STATE(2308), 1,
      sym__host_command,
    STATE(2314), 1,
      sym__non_hll_var_command,
    STATE(2325), 1,
      sym__hll_var_if_command,
    STATE(2336), 1,
      sym__hll_var_definition_command,
    STATE(2340), 1,
      sym__host_command_with_default_format,
    STATE(2344), 1,
      sym__other_command,
    STATE(2360), 1,
      sym__var_command,
    ACTIONS(27), 2,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
    ACTIONS(33), 3,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
    STATE(1463), 11,
      sym__non_labeled_statement,
      sym_labeled_expression,
      sym_subroutine_block,
      sym_if_block,
      sym_while_block,
      sym_repeat_block,
      sym_macro_assignment_expression,
      sym_macro_definition,
      sym_parameter_declaration,
      sym_subroutine_call_expression,
      sym_command_expression,
  [31182] = 41,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7), 1,
      sym_identifier,
    ACTIONS(11), 1,
      aux_sym_subroutine_block_token1,
    ACTIONS(23), 1,
      anon_sym_AMP,
    ACTIONS(25), 1,
      aux_sym_macro_definition_token1,
    ACTIONS(29), 1,
      aux_sym_parameter_declaration_token3,
    ACTIONS(31), 1,
      aux_sym_subroutine_call_expression_token1,
    ACTIONS(35), 1,
      aux_sym__host_command_with_default_format_token1,
    ACTIONS(37), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(43), 1,
      sym_label_identifier,
    ACTIONS(270), 1,
      anon_sym_AMP_AMP,
    ACTIONS(288), 1,
      aux_sym_if_block_token1,
    ACTIONS(290), 1,
      aux_sym_while_block_token1,
    ACTIONS(292), 1,
      aux_sym_while_block_token2,
    ACTIONS(294), 1,
      aux_sym__repeat_block_pre_condition_format_token1,
    ACTIONS(1545), 1,
      aux_sym_block_token1,
    ACTIONS(1547), 1,
      sym__blank,
    STATE(297), 1,
      sym__label,
    STATE(1333), 1,
      sym_recursive_macro_expansion,
    STATE(1432), 1,
      sym__repeat_block_pre_condition_format,
    STATE(1469), 1,
      sym__repeat_block_post_condition_format,
    STATE(1516), 1,
      aux_sym_block_repeat1,
    STATE(1981), 1,
      sym__hll_var_command_with_default_format,
    STATE(1982), 1,
      sym__var_command_with_non_hll_format,
    STATE(2020), 1,
      sym__command_identifier,
    STATE(2059), 1,
      sym_macro,
    STATE(2082), 1,
      sym_macro_definition_command,
    STATE(2243), 1,
      sym__hll_default_format_var_command,
    STATE(2271), 1,
      sym__hll_var_definition_command_expression,
    STATE(2285), 1,
      sym__hll_non_default_format_var_command,
    STATE(2298), 1,
      sym__hll_var_command,
    STATE(2308), 1,
      sym__host_command,
    STATE(2314), 1,
      sym__non_hll_var_command,
    STATE(2327), 1,
      sym__hll_var_if_command,
    STATE(2336), 1,
      sym__hll_var_definition_command,
    STATE(2340), 1,
      sym__host_command_with_default_format,
    STATE(2344), 1,
      sym__other_command,
    STATE(2360), 1,
      sym__var_command,
    ACTIONS(27), 2,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
    ACTIONS(33), 3,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
    STATE(1463), 11,
      sym__non_labeled_statement,
      sym_labeled_expression,
      sym_subroutine_block,
      sym_if_block,
      sym_while_block,
      sym_repeat_block,
      sym_macro_assignment_expression,
      sym_macro_definition,
      sym_parameter_declaration,
      sym_subroutine_call_expression,
      sym_command_expression,
  [31319] = 40,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7), 1,
      sym_identifier,
    ACTIONS(11), 1,
      aux_sym_subroutine_block_token1,
    ACTIONS(23), 1,
      anon_sym_AMP,
    ACTIONS(25), 1,
      aux_sym_macro_definition_token1,
    ACTIONS(29), 1,
      aux_sym_parameter_declaration_token3,
    ACTIONS(31), 1,
      aux_sym_subroutine_call_expression_token1,
    ACTIONS(35), 1,
      aux_sym__host_command_with_default_format_token1,
    ACTIONS(37), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(43), 1,
      sym_label_identifier,
    ACTIONS(262), 1,
      aux_sym_if_block_token1,
    ACTIONS(264), 1,
      aux_sym_while_block_token1,
    ACTIONS(266), 1,
      aux_sym_while_block_token2,
    ACTIONS(268), 1,
      aux_sym__repeat_block_pre_condition_format_token1,
    ACTIONS(270), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1547), 1,
      sym__blank,
    STATE(294), 1,
      sym__label,
    STATE(1333), 1,
      sym_recursive_macro_expansion,
    STATE(1432), 1,
      sym__repeat_block_pre_condition_format,
    STATE(1469), 1,
      sym__repeat_block_post_condition_format,
    STATE(1516), 1,
      aux_sym_block_repeat1,
    STATE(1981), 1,
      sym__hll_var_command_with_default_format,
    STATE(1982), 1,
      sym__var_command_with_non_hll_format,
    STATE(2020), 1,
      sym__command_identifier,
    STATE(2059), 1,
      sym_macro,
    STATE(2082), 1,
      sym_macro_definition_command,
    STATE(2243), 1,
      sym__hll_default_format_var_command,
    STATE(2271), 1,
      sym__hll_var_definition_command_expression,
    STATE(2285), 1,
      sym__hll_non_default_format_var_command,
    STATE(2298), 1,
      sym__hll_var_command,
    STATE(2308), 1,
      sym__host_command,
    STATE(2312), 1,
      sym__hll_var_if_command,
    STATE(2314), 1,
      sym__non_hll_var_command,
    STATE(2336), 1,
      sym__hll_var_definition_command,
    STATE(2340), 1,
      sym__host_command_with_default_format,
    STATE(2344), 1,
      sym__other_command,
    STATE(2360), 1,
      sym__var_command,
    ACTIONS(27), 2,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
    ACTIONS(33), 3,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
    STATE(1463), 11,
      sym__non_labeled_statement,
      sym_labeled_expression,
      sym_subroutine_block,
      sym_if_block,
      sym_while_block,
      sym_repeat_block,
      sym_macro_assignment_expression,
      sym_macro_definition,
      sym_parameter_declaration,
      sym_subroutine_call_expression,
      sym_command_expression,
  [31453] = 40,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7), 1,
      sym_identifier,
    ACTIONS(11), 1,
      aux_sym_subroutine_block_token1,
    ACTIONS(13), 1,
      aux_sym_if_block_token1,
    ACTIONS(15), 1,
      aux_sym_while_block_token1,
    ACTIONS(17), 1,
      aux_sym_while_block_token2,
    ACTIONS(19), 1,
      aux_sym__repeat_block_pre_condition_format_token1,
    ACTIONS(21), 1,
      anon_sym_AMP_AMP,
    ACTIONS(23), 1,
      anon_sym_AMP,
    ACTIONS(25), 1,
      aux_sym_macro_definition_token1,
    ACTIONS(29), 1,
      aux_sym_parameter_declaration_token3,
    ACTIONS(31), 1,
      aux_sym_subroutine_call_expression_token1,
    ACTIONS(35), 1,
      aux_sym__host_command_with_default_format_token1,
    ACTIONS(37), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(43), 1,
      sym_label_identifier,
    ACTIONS(1547), 1,
      sym__blank,
    STATE(295), 1,
      sym__label,
    STATE(1333), 1,
      sym_recursive_macro_expansion,
    STATE(1432), 1,
      sym__repeat_block_pre_condition_format,
    STATE(1469), 1,
      sym__repeat_block_post_condition_format,
    STATE(1516), 1,
      aux_sym_block_repeat1,
    STATE(1981), 1,
      sym__hll_var_command_with_default_format,
    STATE(1982), 1,
      sym__var_command_with_non_hll_format,
    STATE(2020), 1,
      sym__command_identifier,
    STATE(2059), 1,
      sym_macro,
    STATE(2082), 1,
      sym_macro_definition_command,
    STATE(2243), 1,
      sym__hll_default_format_var_command,
    STATE(2271), 1,
      sym__hll_var_definition_command_expression,
    STATE(2272), 1,
      sym__hll_var_if_command,
    STATE(2285), 1,
      sym__hll_non_default_format_var_command,
    STATE(2298), 1,
      sym__hll_var_command,
    STATE(2308), 1,
      sym__host_command,
    STATE(2314), 1,
      sym__non_hll_var_command,
    STATE(2336), 1,
      sym__hll_var_definition_command,
    STATE(2340), 1,
      sym__host_command_with_default_format,
    STATE(2344), 1,
      sym__other_command,
    STATE(2360), 1,
      sym__var_command,
    ACTIONS(27), 2,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
    ACTIONS(33), 3,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
    STATE(1463), 11,
      sym__non_labeled_statement,
      sym_labeled_expression,
      sym_subroutine_block,
      sym_if_block,
      sym_while_block,
      sym_repeat_block,
      sym_macro_assignment_expression,
      sym_macro_definition,
      sym_parameter_declaration,
      sym_subroutine_call_expression,
      sym_command_expression,
  [31587] = 40,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7), 1,
      sym_identifier,
    ACTIONS(11), 1,
      aux_sym_subroutine_block_token1,
    ACTIONS(21), 1,
      anon_sym_AMP_AMP,
    ACTIONS(23), 1,
      anon_sym_AMP,
    ACTIONS(25), 1,
      aux_sym_macro_definition_token1,
    ACTIONS(29), 1,
      aux_sym_parameter_declaration_token3,
    ACTIONS(31), 1,
      aux_sym_subroutine_call_expression_token1,
    ACTIONS(35), 1,
      aux_sym__host_command_with_default_format_token1,
    ACTIONS(37), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(43), 1,
      sym_label_identifier,
    ACTIONS(276), 1,
      aux_sym_if_block_token1,
    ACTIONS(278), 1,
      aux_sym_while_block_token1,
    ACTIONS(280), 1,
      aux_sym_while_block_token2,
    ACTIONS(282), 1,
      aux_sym__repeat_block_pre_condition_format_token1,
    ACTIONS(1547), 1,
      sym__blank,
    STATE(296), 1,
      sym__label,
    STATE(1333), 1,
      sym_recursive_macro_expansion,
    STATE(1432), 1,
      sym__repeat_block_pre_condition_format,
    STATE(1469), 1,
      sym__repeat_block_post_condition_format,
    STATE(1516), 1,
      aux_sym_block_repeat1,
    STATE(1981), 1,
      sym__hll_var_command_with_default_format,
    STATE(1982), 1,
      sym__var_command_with_non_hll_format,
    STATE(2020), 1,
      sym__command_identifier,
    STATE(2059), 1,
      sym_macro,
    STATE(2082), 1,
      sym_macro_definition_command,
    STATE(2243), 1,
      sym__hll_default_format_var_command,
    STATE(2271), 1,
      sym__hll_var_definition_command_expression,
    STATE(2285), 1,
      sym__hll_non_default_format_var_command,
    STATE(2298), 1,
      sym__hll_var_command,
    STATE(2308), 1,
      sym__host_command,
    STATE(2314), 1,
      sym__non_hll_var_command,
    STATE(2325), 1,
      sym__hll_var_if_command,
    STATE(2336), 1,
      sym__hll_var_definition_command,
    STATE(2340), 1,
      sym__host_command_with_default_format,
    STATE(2344), 1,
      sym__other_command,
    STATE(2360), 1,
      sym__var_command,
    ACTIONS(27), 2,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
    ACTIONS(33), 3,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
    STATE(1463), 11,
      sym__non_labeled_statement,
      sym_labeled_expression,
      sym_subroutine_block,
      sym_if_block,
      sym_while_block,
      sym_repeat_block,
      sym_macro_assignment_expression,
      sym_macro_definition,
      sym_parameter_declaration,
      sym_subroutine_call_expression,
      sym_command_expression,
  [31721] = 40,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7), 1,
      sym_identifier,
    ACTIONS(11), 1,
      aux_sym_subroutine_block_token1,
    ACTIONS(23), 1,
      anon_sym_AMP,
    ACTIONS(25), 1,
      aux_sym_macro_definition_token1,
    ACTIONS(29), 1,
      aux_sym_parameter_declaration_token3,
    ACTIONS(31), 1,
      aux_sym_subroutine_call_expression_token1,
    ACTIONS(35), 1,
      aux_sym__host_command_with_default_format_token1,
    ACTIONS(37), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(43), 1,
      sym_label_identifier,
    ACTIONS(270), 1,
      anon_sym_AMP_AMP,
    ACTIONS(288), 1,
      aux_sym_if_block_token1,
    ACTIONS(290), 1,
      aux_sym_while_block_token1,
    ACTIONS(292), 1,
      aux_sym_while_block_token2,
    ACTIONS(294), 1,
      aux_sym__repeat_block_pre_condition_format_token1,
    ACTIONS(1547), 1,
      sym__blank,
    STATE(297), 1,
      sym__label,
    STATE(1333), 1,
      sym_recursive_macro_expansion,
    STATE(1432), 1,
      sym__repeat_block_pre_condition_format,
    STATE(1469), 1,
      sym__repeat_block_post_condition_format,
    STATE(1516), 1,
      aux_sym_block_repeat1,
    STATE(1981), 1,
      sym__hll_var_command_with_default_format,
    STATE(1982), 1,
      sym__var_command_with_non_hll_format,
    STATE(2020), 1,
      sym__command_identifier,
    STATE(2059), 1,
      sym_macro,
    STATE(2082), 1,
      sym_macro_definition_command,
    STATE(2243), 1,
      sym__hll_default_format_var_command,
    STATE(2271), 1,
      sym__hll_var_definition_command_expression,
    STATE(2285), 1,
      sym__hll_non_default_format_var_command,
    STATE(2298), 1,
      sym__hll_var_command,
    STATE(2308), 1,
      sym__host_command,
    STATE(2314), 1,
      sym__non_hll_var_command,
    STATE(2327), 1,
      sym__hll_var_if_command,
    STATE(2336), 1,
      sym__hll_var_definition_command,
    STATE(2340), 1,
      sym__host_command_with_default_format,
    STATE(2344), 1,
      sym__other_command,
    STATE(2360), 1,
      sym__var_command,
    ACTIONS(27), 2,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
    ACTIONS(33), 3,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
    STATE(1463), 11,
      sym__non_labeled_statement,
      sym_labeled_expression,
      sym_subroutine_block,
      sym_if_block,
      sym_while_block,
      sym_repeat_block,
      sym_macro_assignment_expression,
      sym_macro_definition,
      sym_parameter_declaration,
      sym_subroutine_call_expression,
      sym_command_expression,
  [31855] = 24,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(440), 1,
      anon_sym_LPAREN,
    ACTIONS(448), 1,
      anon_sym_AMP,
    ACTIONS(450), 1,
      anon_sym_BSLASH,
    ACTIONS(452), 1,
      anon_sym_sizeof,
    ACTIONS(470), 1,
      aux_sym_symbol_token1,
    ACTIONS(472), 1,
      aux_sym_symbol_token2,
    ACTIONS(476), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(547), 1,
      sym_identifier,
    ACTIONS(1553), 1,
      anon_sym_STAR,
    ACTIONS(1555), 1,
      anon_sym_RBRACK,
    ACTIONS(1559), 1,
      sym__blank,
    STATE(332), 1,
      aux_sym_block_repeat1,
    STATE(799), 1,
      sym_trace32_hll_variable,
    STATE(1652), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(442), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(444), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(446), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1557), 2,
      anon_sym_const,
      anon_sym_volatile,
    STATE(318), 2,
      sym_hll_type_qualifier,
      aux_sym_hll_type_descriptor_repeat2,
    ACTIONS(454), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(456), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(798), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1138), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [31955] = 24,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(440), 1,
      anon_sym_LPAREN,
    ACTIONS(448), 1,
      anon_sym_AMP,
    ACTIONS(450), 1,
      anon_sym_BSLASH,
    ACTIONS(452), 1,
      anon_sym_sizeof,
    ACTIONS(470), 1,
      aux_sym_symbol_token1,
    ACTIONS(472), 1,
      aux_sym_symbol_token2,
    ACTIONS(476), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(547), 1,
      sym_identifier,
    ACTIONS(1561), 1,
      anon_sym_STAR,
    ACTIONS(1563), 1,
      anon_sym_RBRACK,
    ACTIONS(1565), 1,
      sym__blank,
    STATE(336), 1,
      aux_sym_block_repeat1,
    STATE(799), 1,
      sym_trace32_hll_variable,
    STATE(1652), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(442), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(444), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(446), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1557), 2,
      anon_sym_const,
      anon_sym_volatile,
    STATE(959), 2,
      sym_hll_type_qualifier,
      aux_sym_hll_type_descriptor_repeat2,
    ACTIONS(454), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(456), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(798), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1146), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [32055] = 24,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(440), 1,
      anon_sym_LPAREN,
    ACTIONS(448), 1,
      anon_sym_AMP,
    ACTIONS(450), 1,
      anon_sym_BSLASH,
    ACTIONS(452), 1,
      anon_sym_sizeof,
    ACTIONS(470), 1,
      aux_sym_symbol_token1,
    ACTIONS(472), 1,
      aux_sym_symbol_token2,
    ACTIONS(476), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(547), 1,
      sym_identifier,
    ACTIONS(1567), 1,
      anon_sym_STAR,
    ACTIONS(1569), 1,
      anon_sym_RBRACK,
    ACTIONS(1571), 1,
      sym__blank,
    STATE(338), 1,
      aux_sym_block_repeat1,
    STATE(799), 1,
      sym_trace32_hll_variable,
    STATE(1652), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(442), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(444), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(446), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1557), 2,
      anon_sym_const,
      anon_sym_volatile,
    STATE(314), 2,
      sym_hll_type_qualifier,
      aux_sym_hll_type_descriptor_repeat2,
    ACTIONS(454), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(456), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(798), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1190), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [32155] = 24,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(440), 1,
      anon_sym_LPAREN,
    ACTIONS(448), 1,
      anon_sym_AMP,
    ACTIONS(450), 1,
      anon_sym_BSLASH,
    ACTIONS(452), 1,
      anon_sym_sizeof,
    ACTIONS(470), 1,
      aux_sym_symbol_token1,
    ACTIONS(472), 1,
      aux_sym_symbol_token2,
    ACTIONS(476), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(547), 1,
      sym_identifier,
    ACTIONS(1573), 1,
      anon_sym_STAR,
    ACTIONS(1575), 1,
      anon_sym_RBRACK,
    ACTIONS(1577), 1,
      sym__blank,
    STATE(335), 1,
      aux_sym_block_repeat1,
    STATE(799), 1,
      sym_trace32_hll_variable,
    STATE(1652), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(442), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(444), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(446), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1557), 2,
      anon_sym_const,
      anon_sym_volatile,
    STATE(959), 2,
      sym_hll_type_qualifier,
      aux_sym_hll_type_descriptor_repeat2,
    ACTIONS(454), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(456), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(798), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1182), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [32255] = 24,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(440), 1,
      anon_sym_LPAREN,
    ACTIONS(448), 1,
      anon_sym_AMP,
    ACTIONS(450), 1,
      anon_sym_BSLASH,
    ACTIONS(452), 1,
      anon_sym_sizeof,
    ACTIONS(470), 1,
      aux_sym_symbol_token1,
    ACTIONS(472), 1,
      aux_sym_symbol_token2,
    ACTIONS(476), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(547), 1,
      sym_identifier,
    ACTIONS(1579), 1,
      anon_sym_STAR,
    ACTIONS(1581), 1,
      anon_sym_RBRACK,
    ACTIONS(1583), 1,
      sym__blank,
    STATE(331), 1,
      aux_sym_block_repeat1,
    STATE(799), 1,
      sym_trace32_hll_variable,
    STATE(1652), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(442), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(444), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(446), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1557), 2,
      anon_sym_const,
      anon_sym_volatile,
    STATE(323), 2,
      sym_hll_type_qualifier,
      aux_sym_hll_type_descriptor_repeat2,
    ACTIONS(454), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(456), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(798), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1150), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [32355] = 24,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(440), 1,
      anon_sym_LPAREN,
    ACTIONS(448), 1,
      anon_sym_AMP,
    ACTIONS(450), 1,
      anon_sym_BSLASH,
    ACTIONS(452), 1,
      anon_sym_sizeof,
    ACTIONS(470), 1,
      aux_sym_symbol_token1,
    ACTIONS(472), 1,
      aux_sym_symbol_token2,
    ACTIONS(476), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(547), 1,
      sym_identifier,
    ACTIONS(1585), 1,
      anon_sym_STAR,
    ACTIONS(1587), 1,
      anon_sym_RBRACK,
    ACTIONS(1589), 1,
      sym__blank,
    STATE(337), 1,
      aux_sym_block_repeat1,
    STATE(799), 1,
      sym_trace32_hll_variable,
    STATE(1652), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(442), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(444), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(446), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1557), 2,
      anon_sym_const,
      anon_sym_volatile,
    STATE(959), 2,
      sym_hll_type_qualifier,
      aux_sym_hll_type_descriptor_repeat2,
    ACTIONS(454), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(456), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(798), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1135), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [32455] = 24,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(440), 1,
      anon_sym_LPAREN,
    ACTIONS(448), 1,
      anon_sym_AMP,
    ACTIONS(450), 1,
      anon_sym_BSLASH,
    ACTIONS(452), 1,
      anon_sym_sizeof,
    ACTIONS(470), 1,
      aux_sym_symbol_token1,
    ACTIONS(472), 1,
      aux_sym_symbol_token2,
    ACTIONS(476), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(547), 1,
      sym_identifier,
    ACTIONS(1591), 1,
      anon_sym_STAR,
    ACTIONS(1593), 1,
      anon_sym_RBRACK,
    ACTIONS(1595), 1,
      sym__blank,
    STATE(340), 1,
      aux_sym_block_repeat1,
    STATE(799), 1,
      sym_trace32_hll_variable,
    STATE(1652), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(442), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(444), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(446), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1557), 2,
      anon_sym_const,
      anon_sym_volatile,
    STATE(959), 2,
      sym_hll_type_qualifier,
      aux_sym_hll_type_descriptor_repeat2,
    ACTIONS(454), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(456), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(798), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1254), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [32555] = 24,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(440), 1,
      anon_sym_LPAREN,
    ACTIONS(448), 1,
      anon_sym_AMP,
    ACTIONS(450), 1,
      anon_sym_BSLASH,
    ACTIONS(452), 1,
      anon_sym_sizeof,
    ACTIONS(470), 1,
      aux_sym_symbol_token1,
    ACTIONS(472), 1,
      aux_sym_symbol_token2,
    ACTIONS(476), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(547), 1,
      sym_identifier,
    ACTIONS(1597), 1,
      anon_sym_STAR,
    ACTIONS(1599), 1,
      anon_sym_RBRACK,
    ACTIONS(1601), 1,
      sym__blank,
    STATE(330), 1,
      aux_sym_block_repeat1,
    STATE(799), 1,
      sym_trace32_hll_variable,
    STATE(1652), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(442), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(444), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(446), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1557), 2,
      anon_sym_const,
      anon_sym_volatile,
    STATE(959), 2,
      sym_hll_type_qualifier,
      aux_sym_hll_type_descriptor_repeat2,
    ACTIONS(454), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(456), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(798), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1213), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [32655] = 25,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(422), 1,
      anon_sym_PERCENT,
    ACTIONS(559), 1,
      sym_identifier,
    ACTIONS(561), 1,
      anon_sym_LPAREN,
    ACTIONS(571), 1,
      anon_sym_BSLASH,
    ACTIONS(573), 1,
      anon_sym_sizeof,
    ACTIONS(579), 1,
      aux_sym_symbol_token1,
    ACTIONS(581), 1,
      aux_sym_symbol_token2,
    ACTIONS(583), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(1603), 1,
      sym__blank,
    STATE(370), 1,
      aux_sym__hll_var_command_argument_list_default_format_repeat2,
    STATE(516), 1,
      aux_sym__hll_var_command_argument_list_default_format_repeat1,
    STATE(800), 1,
      aux_sym_block_repeat1,
    STATE(812), 1,
      sym_trace32_hll_variable,
    STATE(1655), 1,
      sym__hll_assignment_left_expression,
    STATE(1997), 1,
      sym_format_expression,
    STATE(2304), 1,
      sym__hll_var_command_argument_list_default_format,
    ACTIONS(563), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(565), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(567), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(569), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(575), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(577), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(811), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(958), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [32757] = 24,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(440), 1,
      anon_sym_LPAREN,
    ACTIONS(448), 1,
      anon_sym_AMP,
    ACTIONS(450), 1,
      anon_sym_BSLASH,
    ACTIONS(452), 1,
      anon_sym_sizeof,
    ACTIONS(470), 1,
      aux_sym_symbol_token1,
    ACTIONS(472), 1,
      aux_sym_symbol_token2,
    ACTIONS(476), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(547), 1,
      sym_identifier,
    ACTIONS(1605), 1,
      anon_sym_STAR,
    ACTIONS(1607), 1,
      anon_sym_RBRACK,
    ACTIONS(1609), 1,
      sym__blank,
    STATE(329), 1,
      aux_sym_block_repeat1,
    STATE(799), 1,
      sym_trace32_hll_variable,
    STATE(1652), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(442), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(444), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(446), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1557), 2,
      anon_sym_const,
      anon_sym_volatile,
    STATE(319), 2,
      sym_hll_type_qualifier,
      aux_sym_hll_type_descriptor_repeat2,
    ACTIONS(454), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(456), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(798), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1136), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [32857] = 24,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(440), 1,
      anon_sym_LPAREN,
    ACTIONS(448), 1,
      anon_sym_AMP,
    ACTIONS(450), 1,
      anon_sym_BSLASH,
    ACTIONS(452), 1,
      anon_sym_sizeof,
    ACTIONS(470), 1,
      aux_sym_symbol_token1,
    ACTIONS(472), 1,
      aux_sym_symbol_token2,
    ACTIONS(476), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(547), 1,
      sym_identifier,
    ACTIONS(1611), 1,
      anon_sym_STAR,
    ACTIONS(1613), 1,
      anon_sym_RBRACK,
    ACTIONS(1615), 1,
      sym__blank,
    STATE(327), 1,
      aux_sym_block_repeat1,
    STATE(799), 1,
      sym_trace32_hll_variable,
    STATE(1652), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(442), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(444), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(446), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1557), 2,
      anon_sym_const,
      anon_sym_volatile,
    STATE(959), 2,
      sym_hll_type_qualifier,
      aux_sym_hll_type_descriptor_repeat2,
    ACTIONS(454), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(456), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(798), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1209), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [32957] = 24,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(440), 1,
      anon_sym_LPAREN,
    ACTIONS(448), 1,
      anon_sym_AMP,
    ACTIONS(450), 1,
      anon_sym_BSLASH,
    ACTIONS(452), 1,
      anon_sym_sizeof,
    ACTIONS(470), 1,
      aux_sym_symbol_token1,
    ACTIONS(472), 1,
      aux_sym_symbol_token2,
    ACTIONS(476), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(547), 1,
      sym_identifier,
    ACTIONS(1617), 1,
      anon_sym_STAR,
    ACTIONS(1619), 1,
      anon_sym_RBRACK,
    ACTIONS(1621), 1,
      sym__blank,
    STATE(342), 1,
      aux_sym_block_repeat1,
    STATE(799), 1,
      sym_trace32_hll_variable,
    STATE(1652), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(442), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(444), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(446), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1557), 2,
      anon_sym_const,
      anon_sym_volatile,
    STATE(316), 2,
      sym_hll_type_qualifier,
      aux_sym_hll_type_descriptor_repeat2,
    ACTIONS(454), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(456), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(798), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1221), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [33057] = 24,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(440), 1,
      anon_sym_LPAREN,
    ACTIONS(448), 1,
      anon_sym_AMP,
    ACTIONS(450), 1,
      anon_sym_BSLASH,
    ACTIONS(452), 1,
      anon_sym_sizeof,
    ACTIONS(470), 1,
      aux_sym_symbol_token1,
    ACTIONS(472), 1,
      aux_sym_symbol_token2,
    ACTIONS(476), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(547), 1,
      sym_identifier,
    ACTIONS(1623), 1,
      anon_sym_STAR,
    ACTIONS(1625), 1,
      anon_sym_RBRACK,
    ACTIONS(1627), 1,
      sym__blank,
    STATE(326), 1,
      aux_sym_block_repeat1,
    STATE(799), 1,
      sym_trace32_hll_variable,
    STATE(1652), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(442), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(444), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(446), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1557), 2,
      anon_sym_const,
      anon_sym_volatile,
    STATE(320), 2,
      sym_hll_type_qualifier,
      aux_sym_hll_type_descriptor_repeat2,
    ACTIONS(454), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(456), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(798), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1264), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [33157] = 24,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(440), 1,
      anon_sym_LPAREN,
    ACTIONS(448), 1,
      anon_sym_AMP,
    ACTIONS(450), 1,
      anon_sym_BSLASH,
    ACTIONS(452), 1,
      anon_sym_sizeof,
    ACTIONS(470), 1,
      aux_sym_symbol_token1,
    ACTIONS(472), 1,
      aux_sym_symbol_token2,
    ACTIONS(476), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(547), 1,
      sym_identifier,
    ACTIONS(1599), 1,
      anon_sym_RBRACK,
    ACTIONS(1603), 1,
      sym__blank,
    ACTIONS(1629), 1,
      anon_sym_STAR,
    STATE(799), 1,
      sym_trace32_hll_variable,
    STATE(800), 1,
      aux_sym_block_repeat1,
    STATE(1223), 1,
      sym_hll_type_qualifier,
    STATE(1652), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(442), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(444), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(446), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1557), 2,
      anon_sym_const,
      anon_sym_volatile,
    ACTIONS(454), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(456), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(798), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1211), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [33256] = 24,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(440), 1,
      anon_sym_LPAREN,
    ACTIONS(448), 1,
      anon_sym_AMP,
    ACTIONS(450), 1,
      anon_sym_BSLASH,
    ACTIONS(452), 1,
      anon_sym_sizeof,
    ACTIONS(470), 1,
      aux_sym_symbol_token1,
    ACTIONS(472), 1,
      aux_sym_symbol_token2,
    ACTIONS(476), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(547), 1,
      sym_identifier,
    ACTIONS(1603), 1,
      sym__blank,
    ACTIONS(1631), 1,
      anon_sym_STAR,
    ACTIONS(1633), 1,
      anon_sym_RBRACK,
    STATE(799), 1,
      sym_trace32_hll_variable,
    STATE(800), 1,
      aux_sym_block_repeat1,
    STATE(1223), 1,
      sym_hll_type_qualifier,
    STATE(1652), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(442), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(444), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(446), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1557), 2,
      anon_sym_const,
      anon_sym_volatile,
    ACTIONS(454), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(456), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(798), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1168), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [33355] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1647), 1,
      anon_sym_COLON_COLON_COLON,
    ACTIONS(1649), 1,
      sym_path,
    ACTIONS(1645), 2,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
    ACTIONS(1639), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
    ACTIONS(1642), 5,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_DOT_DOT,
    ACTIONS(1637), 16,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(1635), 19,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [33422] = 24,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(440), 1,
      anon_sym_LPAREN,
    ACTIONS(448), 1,
      anon_sym_AMP,
    ACTIONS(450), 1,
      anon_sym_BSLASH,
    ACTIONS(452), 1,
      anon_sym_sizeof,
    ACTIONS(470), 1,
      aux_sym_symbol_token1,
    ACTIONS(472), 1,
      aux_sym_symbol_token2,
    ACTIONS(476), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(547), 1,
      sym_identifier,
    ACTIONS(1593), 1,
      anon_sym_RBRACK,
    ACTIONS(1603), 1,
      sym__blank,
    ACTIONS(1651), 1,
      anon_sym_STAR,
    STATE(799), 1,
      sym_trace32_hll_variable,
    STATE(800), 1,
      aux_sym_block_repeat1,
    STATE(1223), 1,
      sym_hll_type_qualifier,
    STATE(1652), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(442), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(444), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(446), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1557), 2,
      anon_sym_const,
      anon_sym_volatile,
    ACTIONS(454), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(456), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(798), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1249), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [33521] = 24,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(440), 1,
      anon_sym_LPAREN,
    ACTIONS(448), 1,
      anon_sym_AMP,
    ACTIONS(450), 1,
      anon_sym_BSLASH,
    ACTIONS(452), 1,
      anon_sym_sizeof,
    ACTIONS(470), 1,
      aux_sym_symbol_token1,
    ACTIONS(472), 1,
      aux_sym_symbol_token2,
    ACTIONS(476), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(547), 1,
      sym_identifier,
    ACTIONS(1603), 1,
      sym__blank,
    ACTIONS(1653), 1,
      anon_sym_STAR,
    ACTIONS(1655), 1,
      anon_sym_RBRACK,
    STATE(799), 1,
      sym_trace32_hll_variable,
    STATE(800), 1,
      aux_sym_block_repeat1,
    STATE(1223), 1,
      sym_hll_type_qualifier,
    STATE(1652), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(442), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(444), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(446), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1557), 2,
      anon_sym_const,
      anon_sym_volatile,
    ACTIONS(454), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(456), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(798), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1217), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [33620] = 24,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(440), 1,
      anon_sym_LPAREN,
    ACTIONS(448), 1,
      anon_sym_AMP,
    ACTIONS(450), 1,
      anon_sym_BSLASH,
    ACTIONS(452), 1,
      anon_sym_sizeof,
    ACTIONS(470), 1,
      aux_sym_symbol_token1,
    ACTIONS(472), 1,
      aux_sym_symbol_token2,
    ACTIONS(476), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(547), 1,
      sym_identifier,
    ACTIONS(1603), 1,
      sym__blank,
    ACTIONS(1613), 1,
      anon_sym_RBRACK,
    ACTIONS(1657), 1,
      anon_sym_STAR,
    STATE(799), 1,
      sym_trace32_hll_variable,
    STATE(800), 1,
      aux_sym_block_repeat1,
    STATE(1223), 1,
      sym_hll_type_qualifier,
    STATE(1652), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(442), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(444), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(446), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1557), 2,
      anon_sym_const,
      anon_sym_volatile,
    ACTIONS(454), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(456), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(798), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1192), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [33719] = 24,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(440), 1,
      anon_sym_LPAREN,
    ACTIONS(448), 1,
      anon_sym_AMP,
    ACTIONS(450), 1,
      anon_sym_BSLASH,
    ACTIONS(452), 1,
      anon_sym_sizeof,
    ACTIONS(470), 1,
      aux_sym_symbol_token1,
    ACTIONS(472), 1,
      aux_sym_symbol_token2,
    ACTIONS(476), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(547), 1,
      sym_identifier,
    ACTIONS(1587), 1,
      anon_sym_RBRACK,
    ACTIONS(1603), 1,
      sym__blank,
    ACTIONS(1659), 1,
      anon_sym_STAR,
    STATE(799), 1,
      sym_trace32_hll_variable,
    STATE(800), 1,
      aux_sym_block_repeat1,
    STATE(1223), 1,
      sym_hll_type_qualifier,
    STATE(1652), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(442), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(444), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(446), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1557), 2,
      anon_sym_const,
      anon_sym_volatile,
    ACTIONS(454), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(456), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(798), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1165), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [33818] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1663), 23,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      sym_path,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      anon_sym_COLON_COLON_COLON,
      sym_comment,
      sym__blank_line,
    ACTIONS(1661), 26,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      anon_sym_COLON,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      anon_sym_COLON_COLON,
      sym_identifier,
      sym__blank,
  [33875] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1667), 23,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      sym_path,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      anon_sym_COLON_COLON_COLON,
      sym_comment,
      sym__blank_line,
    ACTIONS(1665), 26,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      anon_sym_COLON,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      anon_sym_COLON_COLON,
      sym_identifier,
      sym__blank,
  [33932] = 24,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(440), 1,
      anon_sym_LPAREN,
    ACTIONS(448), 1,
      anon_sym_AMP,
    ACTIONS(450), 1,
      anon_sym_BSLASH,
    ACTIONS(452), 1,
      anon_sym_sizeof,
    ACTIONS(470), 1,
      aux_sym_symbol_token1,
    ACTIONS(472), 1,
      aux_sym_symbol_token2,
    ACTIONS(476), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(547), 1,
      sym_identifier,
    ACTIONS(1603), 1,
      sym__blank,
    ACTIONS(1669), 1,
      anon_sym_STAR,
    ACTIONS(1671), 1,
      anon_sym_RBRACK,
    STATE(799), 1,
      sym_trace32_hll_variable,
    STATE(800), 1,
      aux_sym_block_repeat1,
    STATE(1223), 1,
      sym_hll_type_qualifier,
    STATE(1652), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(442), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(444), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(446), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1557), 2,
      anon_sym_const,
      anon_sym_volatile,
    ACTIONS(454), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(456), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(798), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1142), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [34031] = 24,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(440), 1,
      anon_sym_LPAREN,
    ACTIONS(448), 1,
      anon_sym_AMP,
    ACTIONS(450), 1,
      anon_sym_BSLASH,
    ACTIONS(452), 1,
      anon_sym_sizeof,
    ACTIONS(470), 1,
      aux_sym_symbol_token1,
    ACTIONS(472), 1,
      aux_sym_symbol_token2,
    ACTIONS(476), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(547), 1,
      sym_identifier,
    ACTIONS(1603), 1,
      sym__blank,
    ACTIONS(1673), 1,
      anon_sym_STAR,
    ACTIONS(1675), 1,
      anon_sym_RBRACK,
    STATE(799), 1,
      sym_trace32_hll_variable,
    STATE(800), 1,
      aux_sym_block_repeat1,
    STATE(1223), 1,
      sym_hll_type_qualifier,
    STATE(1652), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(442), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(444), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(446), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1557), 2,
      anon_sym_const,
      anon_sym_volatile,
    ACTIONS(454), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(456), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(798), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1167), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [34130] = 24,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(440), 1,
      anon_sym_LPAREN,
    ACTIONS(448), 1,
      anon_sym_AMP,
    ACTIONS(450), 1,
      anon_sym_BSLASH,
    ACTIONS(452), 1,
      anon_sym_sizeof,
    ACTIONS(470), 1,
      aux_sym_symbol_token1,
    ACTIONS(472), 1,
      aux_sym_symbol_token2,
    ACTIONS(476), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(547), 1,
      sym_identifier,
    ACTIONS(1603), 1,
      sym__blank,
    ACTIONS(1677), 1,
      anon_sym_STAR,
    ACTIONS(1679), 1,
      anon_sym_RBRACK,
    STATE(799), 1,
      sym_trace32_hll_variable,
    STATE(800), 1,
      aux_sym_block_repeat1,
    STATE(1223), 1,
      sym_hll_type_qualifier,
    STATE(1652), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(442), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(444), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(446), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1557), 2,
      anon_sym_const,
      anon_sym_volatile,
    ACTIONS(454), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(456), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(798), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1171), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [34229] = 24,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(440), 1,
      anon_sym_LPAREN,
    ACTIONS(448), 1,
      anon_sym_AMP,
    ACTIONS(450), 1,
      anon_sym_BSLASH,
    ACTIONS(452), 1,
      anon_sym_sizeof,
    ACTIONS(470), 1,
      aux_sym_symbol_token1,
    ACTIONS(472), 1,
      aux_sym_symbol_token2,
    ACTIONS(476), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(547), 1,
      sym_identifier,
    ACTIONS(1563), 1,
      anon_sym_RBRACK,
    ACTIONS(1603), 1,
      sym__blank,
    ACTIONS(1681), 1,
      anon_sym_STAR,
    STATE(799), 1,
      sym_trace32_hll_variable,
    STATE(800), 1,
      aux_sym_block_repeat1,
    STATE(1223), 1,
      sym_hll_type_qualifier,
    STATE(1652), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(442), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(444), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(446), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1557), 2,
      anon_sym_const,
      anon_sym_volatile,
    ACTIONS(454), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(456), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(798), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1144), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [34328] = 24,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(422), 1,
      anon_sym_PERCENT,
    ACTIONS(559), 1,
      sym_identifier,
    ACTIONS(561), 1,
      anon_sym_LPAREN,
    ACTIONS(571), 1,
      anon_sym_BSLASH,
    ACTIONS(573), 1,
      anon_sym_sizeof,
    ACTIONS(579), 1,
      aux_sym_symbol_token1,
    ACTIONS(581), 1,
      aux_sym_symbol_token2,
    ACTIONS(583), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(1603), 1,
      sym__blank,
    STATE(386), 1,
      aux_sym__hll_var_command_argument_list_default_format_repeat2,
    STATE(503), 1,
      aux_sym__hll_var_command_argument_list_default_format_repeat1,
    STATE(800), 1,
      aux_sym_block_repeat1,
    STATE(812), 1,
      sym_trace32_hll_variable,
    STATE(1655), 1,
      sym__hll_assignment_left_expression,
    STATE(2030), 1,
      sym_format_expression,
    ACTIONS(563), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(565), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(567), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(569), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(575), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(577), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(811), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(962), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [34427] = 24,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(440), 1,
      anon_sym_LPAREN,
    ACTIONS(448), 1,
      anon_sym_AMP,
    ACTIONS(450), 1,
      anon_sym_BSLASH,
    ACTIONS(452), 1,
      anon_sym_sizeof,
    ACTIONS(470), 1,
      aux_sym_symbol_token1,
    ACTIONS(472), 1,
      aux_sym_symbol_token2,
    ACTIONS(476), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(547), 1,
      sym_identifier,
    ACTIONS(1603), 1,
      sym__blank,
    ACTIONS(1683), 1,
      anon_sym_STAR,
    ACTIONS(1685), 1,
      anon_sym_RBRACK,
    STATE(799), 1,
      sym_trace32_hll_variable,
    STATE(800), 1,
      aux_sym_block_repeat1,
    STATE(1223), 1,
      sym_hll_type_qualifier,
    STATE(1652), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(442), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(444), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(446), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1557), 2,
      anon_sym_const,
      anon_sym_volatile,
    ACTIONS(454), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(456), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(798), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1241), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [34526] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1687), 1,
      sym_path,
    ACTIONS(1647), 7,
      sym_label_identifier,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      anon_sym_COLON_COLON_COLON,
      sym_comment,
      sym__blank_line,
    ACTIONS(1639), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(1642), 15,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
    ACTIONS(1645), 17,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      anon_sym_COLON,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      anon_sym_COLON_COLON,
      sym_identifier,
  [34589] = 24,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(440), 1,
      anon_sym_LPAREN,
    ACTIONS(448), 1,
      anon_sym_AMP,
    ACTIONS(450), 1,
      anon_sym_BSLASH,
    ACTIONS(452), 1,
      anon_sym_sizeof,
    ACTIONS(470), 1,
      aux_sym_symbol_token1,
    ACTIONS(472), 1,
      aux_sym_symbol_token2,
    ACTIONS(476), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(547), 1,
      sym_identifier,
    ACTIONS(1575), 1,
      anon_sym_RBRACK,
    ACTIONS(1603), 1,
      sym__blank,
    ACTIONS(1689), 1,
      anon_sym_STAR,
    STATE(799), 1,
      sym_trace32_hll_variable,
    STATE(800), 1,
      aux_sym_block_repeat1,
    STATE(1223), 1,
      sym_hll_type_qualifier,
    STATE(1652), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(442), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(444), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(446), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1557), 2,
      anon_sym_const,
      anon_sym_volatile,
    ACTIONS(454), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(456), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(798), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1178), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [34688] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1693), 22,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      anon_sym_COLON_COLON_COLON,
      sym_comment,
      sym__blank_line,
    ACTIONS(1691), 26,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      anon_sym_COLON,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      anon_sym_COLON_COLON,
      sym_identifier,
      sym__blank,
  [34744] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1697), 22,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      anon_sym_COLON_COLON_COLON,
      sym_comment,
      sym__blank_line,
    ACTIONS(1695), 26,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      anon_sym_COLON,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      anon_sym_COLON_COLON,
      sym_identifier,
      sym__blank,
  [34800] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1701), 22,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      anon_sym_COLON_COLON_COLON,
      sym_comment,
      sym__blank_line,
    ACTIONS(1699), 26,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      anon_sym_COLON,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      anon_sym_COLON_COLON,
      sym_identifier,
      sym__blank,
  [34856] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1705), 22,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      anon_sym_COLON_COLON_COLON,
      sym_comment,
      sym__blank_line,
    ACTIONS(1703), 26,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      anon_sym_COLON,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      anon_sym_COLON_COLON,
      sym_identifier,
      sym__blank,
  [34912] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1647), 1,
      anon_sym_COLON_COLON_COLON,
    ACTIONS(1645), 2,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
    ACTIONS(1639), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
    ACTIONS(1642), 5,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_DOT_DOT,
    ACTIONS(1637), 16,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(1635), 19,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [34976] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1709), 22,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      anon_sym_COLON_COLON_COLON,
      sym_comment,
      sym__blank_line,
    ACTIONS(1707), 26,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      anon_sym_COLON,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      anon_sym_COLON_COLON,
      sym_identifier,
      sym__blank,
  [35032] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1713), 22,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      anon_sym_COLON_COLON_COLON,
      sym_comment,
      sym__blank_line,
    ACTIONS(1711), 26,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      anon_sym_COLON,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      anon_sym_COLON_COLON,
      sym_identifier,
      sym__blank,
  [35088] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1647), 1,
      anon_sym_COLON_COLON_COLON,
    ACTIONS(1645), 2,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
    ACTIONS(1719), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
    ACTIONS(1722), 5,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_DOT_DOT,
    ACTIONS(1717), 16,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(1715), 19,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [35152] = 12,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1735), 1,
      anon_sym_SLASH,
    ACTIONS(1737), 1,
      anon_sym_PIPE,
    ACTIONS(1739), 1,
      anon_sym_CARET,
    ACTIONS(1741), 1,
      anon_sym_COLON,
    ACTIONS(1743), 1,
      anon_sym_COLON_COLON_COLON,
    ACTIONS(1745), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1729), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1733), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(1731), 3,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOT_DOT,
    ACTIONS(1727), 16,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(1725), 19,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [35226] = 14,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1735), 1,
      anon_sym_SLASH,
    ACTIONS(1737), 1,
      anon_sym_PIPE,
    ACTIONS(1739), 1,
      anon_sym_CARET,
    ACTIONS(1741), 1,
      anon_sym_COLON,
    ACTIONS(1743), 1,
      anon_sym_COLON_COLON_COLON,
    ACTIONS(1745), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1729), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1733), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(1731), 3,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOT_DOT,
    ACTIONS(1754), 4,
      anon_sym_EQ,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(1752), 6,
      sym_label_identifier,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(1749), 10,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(1747), 15,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
  [35304] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1759), 22,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      anon_sym_COLON_COLON_COLON,
      sym_comment,
      sym__blank_line,
    ACTIONS(1757), 26,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      anon_sym_COLON,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      anon_sym_COLON_COLON,
      sym_identifier,
      sym__blank,
  [35360] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1763), 22,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      anon_sym_COLON_COLON_COLON,
      sym_comment,
      sym__blank_line,
    ACTIONS(1761), 26,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      anon_sym_COLON,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      anon_sym_COLON_COLON,
      sym_identifier,
      sym__blank,
  [35416] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1767), 22,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      anon_sym_COLON_COLON_COLON,
      sym_comment,
      sym__blank_line,
    ACTIONS(1765), 26,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      anon_sym_COLON,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      anon_sym_COLON_COLON,
      sym_identifier,
      sym__blank,
  [35472] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1735), 1,
      anon_sym_SLASH,
    ACTIONS(1733), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(1731), 3,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOT_DOT,
    ACTIONS(1771), 17,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      anon_sym_COLON_COLON_COLON,
      sym_comment,
      sym__blank_line,
    ACTIONS(1769), 25,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      anon_sym_COLON,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      anon_sym_COLON_COLON,
      sym_identifier,
      sym__blank,
  [35534] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1771), 22,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      anon_sym_COLON_COLON_COLON,
      sym_comment,
      sym__blank_line,
    ACTIONS(1769), 26,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      anon_sym_COLON,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      anon_sym_COLON_COLON,
      sym_identifier,
      sym__blank,
  [35590] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1731), 3,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOT_DOT,
    ACTIONS(1771), 19,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      anon_sym_COLON_COLON_COLON,
      sym_comment,
      sym__blank_line,
    ACTIONS(1769), 26,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      anon_sym_COLON,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      anon_sym_COLON_COLON,
      sym_identifier,
      sym__blank,
  [35648] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1735), 1,
      anon_sym_SLASH,
    ACTIONS(1739), 1,
      anon_sym_CARET,
    ACTIONS(1729), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1733), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(1731), 3,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOT_DOT,
    ACTIONS(1771), 17,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      anon_sym_COLON_COLON_COLON,
      sym_comment,
      sym__blank_line,
    ACTIONS(1769), 22,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      anon_sym_COLON,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      anon_sym_COLON_COLON,
      sym_identifier,
      sym__blank,
  [35714] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1735), 1,
      anon_sym_SLASH,
    ACTIONS(1729), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1733), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(1731), 3,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOT_DOT,
    ACTIONS(1771), 17,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      anon_sym_COLON_COLON_COLON,
      sym_comment,
      sym__blank_line,
    ACTIONS(1769), 23,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      anon_sym_COLON,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      anon_sym_COLON_COLON,
      sym_identifier,
      sym__blank,
  [35778] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1775), 22,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      anon_sym_COLON_COLON_COLON,
      sym_comment,
      sym__blank_line,
    ACTIONS(1773), 26,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      anon_sym_COLON,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      anon_sym_COLON_COLON,
      sym_identifier,
      sym__blank,
  [35834] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1779), 22,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      anon_sym_COLON_COLON_COLON,
      sym_comment,
      sym__blank_line,
    ACTIONS(1777), 26,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      anon_sym_COLON,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      anon_sym_COLON_COLON,
      sym_identifier,
      sym__blank,
  [35890] = 12,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1735), 1,
      anon_sym_SLASH,
    ACTIONS(1737), 1,
      anon_sym_PIPE,
    ACTIONS(1739), 1,
      anon_sym_CARET,
    ACTIONS(1741), 1,
      anon_sym_COLON,
    ACTIONS(1743), 1,
      anon_sym_COLON_COLON_COLON,
    ACTIONS(1745), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1729), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1733), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(1731), 3,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOT_DOT,
    ACTIONS(1783), 16,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(1781), 19,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [35964] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1647), 7,
      sym_label_identifier,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      anon_sym_COLON_COLON_COLON,
      sym_comment,
      sym__blank_line,
    ACTIONS(1639), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(1642), 15,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
    ACTIONS(1645), 17,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      anon_sym_COLON,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      anon_sym_COLON_COLON,
      sym_identifier,
  [36024] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1647), 7,
      sym_label_identifier,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      anon_sym_COLON_COLON_COLON,
      sym_comment,
      sym__blank_line,
    ACTIONS(1719), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(1722), 15,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
    ACTIONS(1645), 17,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      anon_sym_COLON,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      anon_sym_COLON_COLON,
      sym_identifier,
  [36084] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(228), 1,
      anon_sym_LPAREN,
    ACTIONS(230), 1,
      anon_sym_EQ,
    ACTIONS(236), 1,
      anon_sym_CARET_CARET,
    ACTIONS(238), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(242), 1,
      anon_sym_SLASH,
    ACTIONS(244), 1,
      anon_sym_PIPE,
    ACTIONS(246), 1,
      anon_sym_CARET,
    ACTIONS(254), 1,
      anon_sym_DOT_DOT,
    ACTIONS(260), 1,
      sym__and_operator_pre_hook,
    ACTIONS(1789), 1,
      sym__blank,
    STATE(348), 1,
      sym_argument_list,
    STATE(2048), 1,
      aux_sym_block_repeat1,
    ACTIONS(232), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(234), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(240), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(250), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(252), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(248), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1787), 6,
      sym_label_identifier,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(1785), 15,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
  [36175] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1795), 1,
      sym_path,
    STATE(367), 1,
      aux_sym__path_expression_repeat1,
    ACTIONS(1793), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(1791), 24,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [36234] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(228), 1,
      anon_sym_LPAREN,
    ACTIONS(254), 1,
      anon_sym_DOT_DOT,
    STATE(348), 1,
      sym_argument_list,
    STATE(2048), 1,
      aux_sym_block_repeat1,
    ACTIONS(234), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1800), 17,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      aux_sym_while_block_token2,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(1798), 24,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [36299] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1806), 1,
      anon_sym_AMP,
    STATE(369), 1,
      aux_sym__path_expression_repeat2,
    STATE(2422), 1,
      sym_macro,
    ACTIONS(1804), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(1802), 23,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [36360] = 22,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(422), 1,
      anon_sym_PERCENT,
    ACTIONS(559), 1,
      sym_identifier,
    ACTIONS(561), 1,
      anon_sym_LPAREN,
    ACTIONS(571), 1,
      anon_sym_BSLASH,
    ACTIONS(573), 1,
      anon_sym_sizeof,
    ACTIONS(579), 1,
      aux_sym_symbol_token1,
    ACTIONS(581), 1,
      aux_sym_symbol_token2,
    ACTIONS(583), 1,
      sym__hll_number_literal_pre_hook,
    STATE(377), 1,
      aux_sym__hll_var_command_argument_list_default_format_repeat2,
    STATE(510), 1,
      aux_sym__hll_var_command_argument_list_default_format_repeat1,
    STATE(812), 1,
      sym_trace32_hll_variable,
    STATE(1655), 1,
      sym__hll_assignment_left_expression,
    STATE(1952), 1,
      sym_format_expression,
    ACTIONS(563), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(565), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(567), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(569), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(575), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(577), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(811), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(961), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [36453] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1813), 1,
      sym_path,
    STATE(367), 1,
      aux_sym__path_expression_repeat1,
    ACTIONS(1811), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(1809), 24,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [36512] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(228), 1,
      anon_sym_LPAREN,
    ACTIONS(236), 1,
      anon_sym_CARET_CARET,
    ACTIONS(242), 1,
      anon_sym_SLASH,
    ACTIONS(244), 1,
      anon_sym_PIPE,
    ACTIONS(246), 1,
      anon_sym_CARET,
    ACTIONS(254), 1,
      anon_sym_DOT_DOT,
    ACTIONS(260), 1,
      sym__and_operator_pre_hook,
    STATE(348), 1,
      sym_argument_list,
    STATE(2048), 1,
      aux_sym_block_repeat1,
    ACTIONS(232), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(234), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(240), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(250), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(252), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(248), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1817), 7,
      sym_label_identifier,
      aux_sym_while_block_token2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(1815), 17,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [36597] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(228), 1,
      anon_sym_LPAREN,
    ACTIONS(230), 1,
      anon_sym_EQ,
    ACTIONS(236), 1,
      anon_sym_CARET_CARET,
    ACTIONS(238), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(242), 1,
      anon_sym_SLASH,
    ACTIONS(244), 1,
      anon_sym_PIPE,
    ACTIONS(246), 1,
      anon_sym_CARET,
    ACTIONS(254), 1,
      anon_sym_DOT_DOT,
    ACTIONS(260), 1,
      sym__and_operator_pre_hook,
    ACTIONS(1789), 1,
      sym__blank,
    STATE(348), 1,
      sym_argument_list,
    STATE(2048), 1,
      aux_sym_block_repeat1,
    ACTIONS(232), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(234), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(240), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(250), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(252), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(248), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1821), 6,
      sym_label_identifier,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(1819), 15,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
  [36688] = 16,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(228), 1,
      anon_sym_LPAREN,
    ACTIONS(242), 1,
      anon_sym_SLASH,
    ACTIONS(246), 1,
      anon_sym_CARET,
    ACTIONS(254), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1823), 1,
      sym__and_operator_pre_hook,
    STATE(348), 1,
      sym_argument_list,
    STATE(2048), 1,
      aux_sym_block_repeat1,
    ACTIONS(232), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(234), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(240), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(250), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(252), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(248), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1817), 8,
      sym_label_identifier,
      aux_sym_while_block_token2,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(1815), 18,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [36769] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(254), 1,
      anon_sym_DOT_DOT,
    STATE(348), 1,
      sym_argument_list,
    STATE(2048), 1,
      aux_sym_block_repeat1,
    ACTIONS(234), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1828), 18,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(1826), 24,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [36832] = 12,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(228), 1,
      anon_sym_LPAREN,
    ACTIONS(242), 1,
      anon_sym_SLASH,
    ACTIONS(254), 1,
      anon_sym_DOT_DOT,
    STATE(348), 1,
      sym_argument_list,
    STATE(2048), 1,
      aux_sym_block_repeat1,
    ACTIONS(232), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(234), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(240), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(252), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(1817), 13,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      aux_sym_while_block_token2,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(1815), 21,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [36905] = 22,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1830), 1,
      sym_identifier,
    ACTIONS(1833), 1,
      anon_sym_LPAREN,
    ACTIONS(1848), 1,
      anon_sym_PERCENT,
    ACTIONS(1851), 1,
      anon_sym_BSLASH,
    ACTIONS(1854), 1,
      anon_sym_sizeof,
    ACTIONS(1863), 1,
      aux_sym_symbol_token1,
    ACTIONS(1866), 1,
      aux_sym_symbol_token2,
    ACTIONS(1869), 1,
      sym__hll_number_literal_pre_hook,
    STATE(377), 1,
      aux_sym__hll_var_command_argument_list_default_format_repeat2,
    STATE(514), 1,
      aux_sym__hll_var_command_argument_list_default_format_repeat1,
    STATE(890), 1,
      sym_trace32_hll_variable,
    STATE(1609), 1,
      sym__hll_assignment_left_expression,
    STATE(2341), 1,
      sym_format_expression,
    ACTIONS(1836), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1839), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(1842), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1845), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(1857), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(1860), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(889), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1085), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [36998] = 14,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(228), 1,
      anon_sym_LPAREN,
    ACTIONS(242), 1,
      anon_sym_SLASH,
    ACTIONS(254), 1,
      anon_sym_DOT_DOT,
    STATE(348), 1,
      sym_argument_list,
    STATE(2048), 1,
      aux_sym_block_repeat1,
    ACTIONS(232), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(234), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(240), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(250), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(252), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(248), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1874), 9,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      aux_sym_while_block_token2,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(1872), 19,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [37075] = 17,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(228), 1,
      anon_sym_LPAREN,
    ACTIONS(242), 1,
      anon_sym_SLASH,
    ACTIONS(244), 1,
      anon_sym_PIPE,
    ACTIONS(246), 1,
      anon_sym_CARET,
    ACTIONS(254), 1,
      anon_sym_DOT_DOT,
    ACTIONS(260), 1,
      sym__and_operator_pre_hook,
    STATE(348), 1,
      sym_argument_list,
    STATE(2048), 1,
      aux_sym_block_repeat1,
    ACTIONS(232), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(234), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(240), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(250), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(252), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(248), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1874), 8,
      sym_label_identifier,
      aux_sym_while_block_token2,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(1872), 17,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [37158] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(228), 1,
      anon_sym_LPAREN,
    ACTIONS(230), 1,
      anon_sym_EQ,
    ACTIONS(236), 1,
      anon_sym_CARET_CARET,
    ACTIONS(238), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(242), 1,
      anon_sym_SLASH,
    ACTIONS(244), 1,
      anon_sym_PIPE,
    ACTIONS(246), 1,
      anon_sym_CARET,
    ACTIONS(254), 1,
      anon_sym_DOT_DOT,
    ACTIONS(260), 1,
      sym__and_operator_pre_hook,
    ACTIONS(1789), 1,
      sym__blank,
    STATE(348), 1,
      sym_argument_list,
    STATE(2048), 1,
      aux_sym_block_repeat1,
    ACTIONS(232), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(234), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(240), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(250), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(252), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(248), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1878), 6,
      sym_label_identifier,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(1876), 15,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
  [37249] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(228), 1,
      anon_sym_LPAREN,
    ACTIONS(254), 1,
      anon_sym_DOT_DOT,
    STATE(348), 1,
      sym_argument_list,
    STATE(2048), 1,
      aux_sym_block_repeat1,
    ACTIONS(234), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(252), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(1817), 15,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      aux_sym_while_block_token2,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(1815), 24,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [37316] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1880), 1,
      anon_sym_LPAREN,
    ACTIONS(1883), 1,
      anon_sym_DOT,
    STATE(2196), 1,
      aux_sym__function_identifier_repeat1,
    ACTIONS(1637), 20,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(1635), 24,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [37377] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(228), 1,
      anon_sym_LPAREN,
    ACTIONS(230), 1,
      anon_sym_EQ,
    ACTIONS(236), 1,
      anon_sym_CARET_CARET,
    ACTIONS(238), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(242), 1,
      anon_sym_SLASH,
    ACTIONS(244), 1,
      anon_sym_PIPE,
    ACTIONS(246), 1,
      anon_sym_CARET,
    ACTIONS(254), 1,
      anon_sym_DOT_DOT,
    ACTIONS(260), 1,
      sym__and_operator_pre_hook,
    ACTIONS(1789), 1,
      sym__blank,
    STATE(348), 1,
      sym_argument_list,
    STATE(2048), 1,
      aux_sym_block_repeat1,
    ACTIONS(232), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(234), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(240), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(250), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(252), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(248), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1887), 6,
      sym_label_identifier,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(1885), 15,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
  [37468] = 15,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(228), 1,
      anon_sym_LPAREN,
    ACTIONS(242), 1,
      anon_sym_SLASH,
    ACTIONS(254), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1823), 1,
      sym__and_operator_pre_hook,
    STATE(348), 1,
      sym_argument_list,
    STATE(2048), 1,
      aux_sym_block_repeat1,
    ACTIONS(232), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(234), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(240), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(250), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(252), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(248), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1817), 8,
      sym_label_identifier,
      aux_sym_while_block_token2,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(1815), 19,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [37547] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(228), 1,
      anon_sym_LPAREN,
    ACTIONS(254), 1,
      anon_sym_DOT_DOT,
    STATE(348), 1,
      sym_argument_list,
    STATE(2048), 1,
      aux_sym_block_repeat1,
    ACTIONS(234), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1817), 17,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      aux_sym_while_block_token2,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(1815), 24,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [37612] = 22,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(422), 1,
      anon_sym_PERCENT,
    ACTIONS(559), 1,
      sym_identifier,
    ACTIONS(561), 1,
      anon_sym_LPAREN,
    ACTIONS(571), 1,
      anon_sym_BSLASH,
    ACTIONS(573), 1,
      anon_sym_sizeof,
    ACTIONS(579), 1,
      aux_sym_symbol_token1,
    ACTIONS(581), 1,
      aux_sym_symbol_token2,
    ACTIONS(583), 1,
      sym__hll_number_literal_pre_hook,
    STATE(377), 1,
      aux_sym__hll_var_command_argument_list_default_format_repeat2,
    STATE(504), 1,
      aux_sym__hll_var_command_argument_list_default_format_repeat1,
    STATE(812), 1,
      sym_trace32_hll_variable,
    STATE(1655), 1,
      sym__hll_assignment_left_expression,
    STATE(2013), 1,
      sym_format_expression,
    ACTIONS(563), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(565), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(567), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(569), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(575), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(577), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(811), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(956), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [37705] = 11,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(228), 1,
      anon_sym_LPAREN,
    ACTIONS(242), 1,
      anon_sym_SLASH,
    ACTIONS(254), 1,
      anon_sym_DOT_DOT,
    STATE(348), 1,
      sym_argument_list,
    STATE(2048), 1,
      aux_sym_block_repeat1,
    ACTIONS(234), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(240), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(252), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(1817), 13,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      aux_sym_while_block_token2,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(1815), 23,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [37776] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    STATE(348), 1,
      sym_argument_list,
    STATE(2048), 1,
      aux_sym_block_repeat1,
    ACTIONS(1817), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(1815), 24,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [37835] = 17,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(228), 1,
      anon_sym_LPAREN,
    ACTIONS(242), 1,
      anon_sym_SLASH,
    ACTIONS(244), 1,
      anon_sym_PIPE,
    ACTIONS(246), 1,
      anon_sym_CARET,
    ACTIONS(254), 1,
      anon_sym_DOT_DOT,
    ACTIONS(260), 1,
      sym__and_operator_pre_hook,
    STATE(348), 1,
      sym_argument_list,
    STATE(2048), 1,
      aux_sym_block_repeat1,
    ACTIONS(232), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(234), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(240), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(250), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(252), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(248), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1817), 8,
      sym_label_identifier,
      aux_sym_while_block_token2,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(1815), 17,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [37918] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1893), 1,
      aux_sym_symbol_token3,
    ACTIONS(1891), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(1889), 24,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [37974] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(300), 1,
      sym_identifier,
    ACTIONS(304), 1,
      anon_sym_LPAREN,
    ACTIONS(316), 1,
      anon_sym_BSLASH,
    ACTIONS(318), 1,
      anon_sym_sizeof,
    ACTIONS(324), 1,
      aux_sym_symbol_token1,
    ACTIONS(326), 1,
      aux_sym_symbol_token2,
    ACTIONS(328), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(1895), 1,
      anon_sym_RBRACK,
    ACTIONS(1897), 1,
      sym__blank,
    STATE(781), 1,
      sym_trace32_hll_variable,
    STATE(1601), 1,
      sym__hll_assignment_left_expression,
    STATE(2188), 1,
      aux_sym_block_repeat1,
    ACTIONS(308), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(310), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(312), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(448), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(320), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(322), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(778), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(572), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [38064] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(300), 1,
      sym_identifier,
    ACTIONS(304), 1,
      anon_sym_LPAREN,
    ACTIONS(316), 1,
      anon_sym_BSLASH,
    ACTIONS(318), 1,
      anon_sym_sizeof,
    ACTIONS(324), 1,
      aux_sym_symbol_token1,
    ACTIONS(326), 1,
      aux_sym_symbol_token2,
    ACTIONS(328), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(1899), 1,
      anon_sym_RBRACK,
    ACTIONS(1901), 1,
      sym__blank,
    STATE(781), 1,
      sym_trace32_hll_variable,
    STATE(1601), 1,
      sym__hll_assignment_left_expression,
    STATE(2160), 1,
      aux_sym_block_repeat1,
    ACTIONS(308), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(310), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(312), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(448), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(320), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(322), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(778), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(572), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [38154] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(300), 1,
      sym_identifier,
    ACTIONS(304), 1,
      anon_sym_LPAREN,
    ACTIONS(316), 1,
      anon_sym_BSLASH,
    ACTIONS(318), 1,
      anon_sym_sizeof,
    ACTIONS(324), 1,
      aux_sym_symbol_token1,
    ACTIONS(326), 1,
      aux_sym_symbol_token2,
    ACTIONS(328), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(1903), 1,
      anon_sym_RBRACK,
    ACTIONS(1905), 1,
      sym__blank,
    STATE(781), 1,
      sym_trace32_hll_variable,
    STATE(1601), 1,
      sym__hll_assignment_left_expression,
    STATE(2038), 1,
      aux_sym_block_repeat1,
    ACTIONS(308), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(310), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(312), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(448), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(320), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(322), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(778), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(572), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [38244] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(300), 1,
      sym_identifier,
    ACTIONS(304), 1,
      anon_sym_LPAREN,
    ACTIONS(316), 1,
      anon_sym_BSLASH,
    ACTIONS(318), 1,
      anon_sym_sizeof,
    ACTIONS(324), 1,
      aux_sym_symbol_token1,
    ACTIONS(326), 1,
      aux_sym_symbol_token2,
    ACTIONS(328), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(1907), 1,
      anon_sym_RBRACK,
    ACTIONS(1909), 1,
      sym__blank,
    STATE(781), 1,
      sym_trace32_hll_variable,
    STATE(1601), 1,
      sym__hll_assignment_left_expression,
    STATE(2069), 1,
      aux_sym_block_repeat1,
    ACTIONS(308), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(310), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(312), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(448), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(320), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(322), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(778), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(572), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [38334] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(300), 1,
      sym_identifier,
    ACTIONS(304), 1,
      anon_sym_LPAREN,
    ACTIONS(316), 1,
      anon_sym_BSLASH,
    ACTIONS(318), 1,
      anon_sym_sizeof,
    ACTIONS(324), 1,
      aux_sym_symbol_token1,
    ACTIONS(326), 1,
      aux_sym_symbol_token2,
    ACTIONS(328), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(1911), 1,
      anon_sym_RBRACK,
    ACTIONS(1913), 1,
      sym__blank,
    STATE(781), 1,
      sym_trace32_hll_variable,
    STATE(1601), 1,
      sym__hll_assignment_left_expression,
    STATE(2199), 1,
      aux_sym_block_repeat1,
    ACTIONS(308), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(310), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(312), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(448), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(320), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(322), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(778), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(572), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [38424] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(300), 1,
      sym_identifier,
    ACTIONS(304), 1,
      anon_sym_LPAREN,
    ACTIONS(316), 1,
      anon_sym_BSLASH,
    ACTIONS(318), 1,
      anon_sym_sizeof,
    ACTIONS(324), 1,
      aux_sym_symbol_token1,
    ACTIONS(326), 1,
      aux_sym_symbol_token2,
    ACTIONS(328), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(1915), 1,
      anon_sym_RBRACK,
    ACTIONS(1917), 1,
      sym__blank,
    STATE(781), 1,
      sym_trace32_hll_variable,
    STATE(1601), 1,
      sym__hll_assignment_left_expression,
    STATE(2202), 1,
      aux_sym_block_repeat1,
    ACTIONS(308), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(310), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(312), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(448), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(320), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(322), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(778), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(572), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [38514] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(300), 1,
      sym_identifier,
    ACTIONS(304), 1,
      anon_sym_LPAREN,
    ACTIONS(316), 1,
      anon_sym_BSLASH,
    ACTIONS(318), 1,
      anon_sym_sizeof,
    ACTIONS(324), 1,
      aux_sym_symbol_token1,
    ACTIONS(326), 1,
      aux_sym_symbol_token2,
    ACTIONS(328), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(1919), 1,
      anon_sym_RBRACK,
    ACTIONS(1921), 1,
      sym__blank,
    STATE(781), 1,
      sym_trace32_hll_variable,
    STATE(1601), 1,
      sym__hll_assignment_left_expression,
    STATE(2039), 1,
      aux_sym_block_repeat1,
    ACTIONS(308), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(310), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(312), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(448), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(320), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(322), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(778), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(572), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [38604] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(300), 1,
      sym_identifier,
    ACTIONS(304), 1,
      anon_sym_LPAREN,
    ACTIONS(316), 1,
      anon_sym_BSLASH,
    ACTIONS(318), 1,
      anon_sym_sizeof,
    ACTIONS(324), 1,
      aux_sym_symbol_token1,
    ACTIONS(326), 1,
      aux_sym_symbol_token2,
    ACTIONS(328), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(1923), 1,
      anon_sym_RBRACK,
    ACTIONS(1925), 1,
      sym__blank,
    STATE(781), 1,
      sym_trace32_hll_variable,
    STATE(1601), 1,
      sym__hll_assignment_left_expression,
    STATE(2045), 1,
      aux_sym_block_repeat1,
    ACTIONS(308), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(310), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(312), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(448), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(320), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(322), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(778), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(572), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [38694] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(300), 1,
      sym_identifier,
    ACTIONS(304), 1,
      anon_sym_LPAREN,
    ACTIONS(316), 1,
      anon_sym_BSLASH,
    ACTIONS(318), 1,
      anon_sym_sizeof,
    ACTIONS(324), 1,
      aux_sym_symbol_token1,
    ACTIONS(326), 1,
      aux_sym_symbol_token2,
    ACTIONS(328), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(1927), 1,
      anon_sym_RBRACK,
    ACTIONS(1929), 1,
      sym__blank,
    STATE(781), 1,
      sym_trace32_hll_variable,
    STATE(1601), 1,
      sym__hll_assignment_left_expression,
    STATE(2046), 1,
      aux_sym_block_repeat1,
    ACTIONS(308), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(310), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(312), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(448), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(320), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(322), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(778), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(572), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [38784] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(300), 1,
      sym_identifier,
    ACTIONS(304), 1,
      anon_sym_LPAREN,
    ACTIONS(316), 1,
      anon_sym_BSLASH,
    ACTIONS(318), 1,
      anon_sym_sizeof,
    ACTIONS(324), 1,
      aux_sym_symbol_token1,
    ACTIONS(326), 1,
      aux_sym_symbol_token2,
    ACTIONS(328), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(1931), 1,
      anon_sym_RBRACK,
    ACTIONS(1933), 1,
      sym__blank,
    STATE(781), 1,
      sym_trace32_hll_variable,
    STATE(1601), 1,
      sym__hll_assignment_left_expression,
    STATE(2047), 1,
      aux_sym_block_repeat1,
    ACTIONS(308), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(310), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(312), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(448), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(320), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(322), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(778), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(572), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [38874] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(440), 1,
      anon_sym_LPAREN,
    ACTIONS(450), 1,
      anon_sym_BSLASH,
    ACTIONS(452), 1,
      anon_sym_sizeof,
    ACTIONS(470), 1,
      aux_sym_symbol_token1,
    ACTIONS(472), 1,
      aux_sym_symbol_token2,
    ACTIONS(476), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(547), 1,
      sym_identifier,
    ACTIONS(1935), 1,
      anon_sym_RPAREN,
    ACTIONS(1937), 1,
      sym__blank,
    STATE(403), 1,
      aux_sym_block_repeat1,
    STATE(799), 1,
      sym_trace32_hll_variable,
    STATE(1652), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(442), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(444), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(446), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(448), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(454), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(456), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(798), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(981), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [38964] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(300), 1,
      sym_identifier,
    ACTIONS(304), 1,
      anon_sym_LPAREN,
    ACTIONS(316), 1,
      anon_sym_BSLASH,
    ACTIONS(318), 1,
      anon_sym_sizeof,
    ACTIONS(324), 1,
      aux_sym_symbol_token1,
    ACTIONS(326), 1,
      aux_sym_symbol_token2,
    ACTIONS(328), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(1939), 1,
      anon_sym_RBRACK,
    ACTIONS(1941), 1,
      sym__blank,
    STATE(781), 1,
      sym_trace32_hll_variable,
    STATE(1601), 1,
      sym__hll_assignment_left_expression,
    STATE(2095), 1,
      aux_sym_block_repeat1,
    ACTIONS(308), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(310), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(312), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(448), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(320), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(322), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(778), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(572), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [39054] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(440), 1,
      anon_sym_LPAREN,
    ACTIONS(450), 1,
      anon_sym_BSLASH,
    ACTIONS(452), 1,
      anon_sym_sizeof,
    ACTIONS(470), 1,
      aux_sym_symbol_token1,
    ACTIONS(472), 1,
      aux_sym_symbol_token2,
    ACTIONS(476), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(547), 1,
      sym_identifier,
    ACTIONS(1603), 1,
      sym__blank,
    ACTIONS(1943), 1,
      anon_sym_RPAREN,
    STATE(799), 1,
      sym_trace32_hll_variable,
    STATE(800), 1,
      aux_sym_block_repeat1,
    STATE(1652), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(442), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(444), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(446), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(448), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(454), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(456), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(798), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(984), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [39144] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(440), 1,
      anon_sym_LPAREN,
    ACTIONS(450), 1,
      anon_sym_BSLASH,
    ACTIONS(452), 1,
      anon_sym_sizeof,
    ACTIONS(470), 1,
      aux_sym_symbol_token1,
    ACTIONS(472), 1,
      aux_sym_symbol_token2,
    ACTIONS(476), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(547), 1,
      sym_identifier,
    ACTIONS(1603), 1,
      sym__blank,
    ACTIONS(1945), 1,
      anon_sym_RPAREN,
    STATE(799), 1,
      sym_trace32_hll_variable,
    STATE(800), 1,
      aux_sym_block_repeat1,
    STATE(1652), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(442), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(444), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(446), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(448), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(454), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(456), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(798), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(990), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [39234] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(300), 1,
      sym_identifier,
    ACTIONS(304), 1,
      anon_sym_LPAREN,
    ACTIONS(316), 1,
      anon_sym_BSLASH,
    ACTIONS(318), 1,
      anon_sym_sizeof,
    ACTIONS(324), 1,
      aux_sym_symbol_token1,
    ACTIONS(326), 1,
      aux_sym_symbol_token2,
    ACTIONS(328), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(1947), 1,
      anon_sym_RBRACK,
    ACTIONS(1949), 1,
      sym__blank,
    STATE(781), 1,
      sym_trace32_hll_variable,
    STATE(1601), 1,
      sym__hll_assignment_left_expression,
    STATE(2115), 1,
      aux_sym_block_repeat1,
    ACTIONS(308), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(310), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(312), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(448), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(320), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(322), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(778), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(572), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [39324] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(300), 1,
      sym_identifier,
    ACTIONS(304), 1,
      anon_sym_LPAREN,
    ACTIONS(316), 1,
      anon_sym_BSLASH,
    ACTIONS(318), 1,
      anon_sym_sizeof,
    ACTIONS(324), 1,
      aux_sym_symbol_token1,
    ACTIONS(326), 1,
      aux_sym_symbol_token2,
    ACTIONS(328), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(1951), 1,
      anon_sym_RBRACK,
    ACTIONS(1953), 1,
      sym__blank,
    STATE(781), 1,
      sym_trace32_hll_variable,
    STATE(1601), 1,
      sym__hll_assignment_left_expression,
    STATE(2122), 1,
      aux_sym_block_repeat1,
    ACTIONS(308), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(310), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(312), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(448), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(320), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(322), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(778), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(572), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [39414] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(300), 1,
      sym_identifier,
    ACTIONS(304), 1,
      anon_sym_LPAREN,
    ACTIONS(316), 1,
      anon_sym_BSLASH,
    ACTIONS(318), 1,
      anon_sym_sizeof,
    ACTIONS(324), 1,
      aux_sym_symbol_token1,
    ACTIONS(326), 1,
      aux_sym_symbol_token2,
    ACTIONS(328), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(1955), 1,
      anon_sym_RBRACK,
    ACTIONS(1957), 1,
      sym__blank,
    STATE(781), 1,
      sym_trace32_hll_variable,
    STATE(1601), 1,
      sym__hll_assignment_left_expression,
    STATE(2124), 1,
      aux_sym_block_repeat1,
    ACTIONS(308), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(310), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(312), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(448), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(320), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(322), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(778), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(572), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [39504] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(300), 1,
      sym_identifier,
    ACTIONS(304), 1,
      anon_sym_LPAREN,
    ACTIONS(316), 1,
      anon_sym_BSLASH,
    ACTIONS(318), 1,
      anon_sym_sizeof,
    ACTIONS(324), 1,
      aux_sym_symbol_token1,
    ACTIONS(326), 1,
      aux_sym_symbol_token2,
    ACTIONS(328), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(1959), 1,
      anon_sym_RBRACK,
    ACTIONS(1961), 1,
      sym__blank,
    STATE(781), 1,
      sym_trace32_hll_variable,
    STATE(1601), 1,
      sym__hll_assignment_left_expression,
    STATE(2144), 1,
      aux_sym_block_repeat1,
    ACTIONS(308), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(310), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(312), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(448), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(320), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(322), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(778), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(572), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [39594] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(300), 1,
      sym_identifier,
    ACTIONS(304), 1,
      anon_sym_LPAREN,
    ACTIONS(316), 1,
      anon_sym_BSLASH,
    ACTIONS(318), 1,
      anon_sym_sizeof,
    ACTIONS(324), 1,
      aux_sym_symbol_token1,
    ACTIONS(326), 1,
      aux_sym_symbol_token2,
    ACTIONS(328), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(1963), 1,
      anon_sym_RBRACK,
    ACTIONS(1965), 1,
      sym__blank,
    STATE(781), 1,
      sym_trace32_hll_variable,
    STATE(1601), 1,
      sym__hll_assignment_left_expression,
    STATE(2146), 1,
      aux_sym_block_repeat1,
    ACTIONS(308), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(310), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(312), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(448), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(320), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(322), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(778), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(572), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [39684] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(300), 1,
      sym_identifier,
    ACTIONS(304), 1,
      anon_sym_LPAREN,
    ACTIONS(316), 1,
      anon_sym_BSLASH,
    ACTIONS(318), 1,
      anon_sym_sizeof,
    ACTIONS(324), 1,
      aux_sym_symbol_token1,
    ACTIONS(326), 1,
      aux_sym_symbol_token2,
    ACTIONS(328), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(1967), 1,
      anon_sym_RBRACK,
    ACTIONS(1969), 1,
      sym__blank,
    STATE(781), 1,
      sym_trace32_hll_variable,
    STATE(1601), 1,
      sym__hll_assignment_left_expression,
    STATE(2165), 1,
      aux_sym_block_repeat1,
    ACTIONS(308), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(310), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(312), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(448), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(320), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(322), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(778), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(572), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [39774] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(300), 1,
      sym_identifier,
    ACTIONS(304), 1,
      anon_sym_LPAREN,
    ACTIONS(316), 1,
      anon_sym_BSLASH,
    ACTIONS(318), 1,
      anon_sym_sizeof,
    ACTIONS(324), 1,
      aux_sym_symbol_token1,
    ACTIONS(326), 1,
      aux_sym_symbol_token2,
    ACTIONS(328), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(1971), 1,
      anon_sym_RBRACK,
    ACTIONS(1973), 1,
      sym__blank,
    STATE(781), 1,
      sym_trace32_hll_variable,
    STATE(1601), 1,
      sym__hll_assignment_left_expression,
    STATE(2168), 1,
      aux_sym_block_repeat1,
    ACTIONS(308), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(310), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(312), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(448), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(320), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(322), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(778), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(572), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [39864] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(440), 1,
      anon_sym_LPAREN,
    ACTIONS(450), 1,
      anon_sym_BSLASH,
    ACTIONS(452), 1,
      anon_sym_sizeof,
    ACTIONS(470), 1,
      aux_sym_symbol_token1,
    ACTIONS(472), 1,
      aux_sym_symbol_token2,
    ACTIONS(476), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(547), 1,
      sym_identifier,
    ACTIONS(1975), 1,
      anon_sym_RPAREN,
    ACTIONS(1977), 1,
      sym__blank,
    STATE(413), 1,
      aux_sym_block_repeat1,
    STATE(799), 1,
      sym_trace32_hll_variable,
    STATE(1652), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(442), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(444), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(446), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(448), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(454), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(456), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(798), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(989), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [39954] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(440), 1,
      anon_sym_LPAREN,
    ACTIONS(450), 1,
      anon_sym_BSLASH,
    ACTIONS(452), 1,
      anon_sym_sizeof,
    ACTIONS(470), 1,
      aux_sym_symbol_token1,
    ACTIONS(472), 1,
      aux_sym_symbol_token2,
    ACTIONS(476), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(547), 1,
      sym_identifier,
    ACTIONS(1603), 1,
      sym__blank,
    ACTIONS(1979), 1,
      anon_sym_RPAREN,
    STATE(799), 1,
      sym_trace32_hll_variable,
    STATE(800), 1,
      aux_sym_block_repeat1,
    STATE(1652), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(442), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(444), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(446), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(448), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(454), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(456), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(798), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(991), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [40044] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(440), 1,
      anon_sym_LPAREN,
    ACTIONS(450), 1,
      anon_sym_BSLASH,
    ACTIONS(452), 1,
      anon_sym_sizeof,
    ACTIONS(470), 1,
      aux_sym_symbol_token1,
    ACTIONS(472), 1,
      aux_sym_symbol_token2,
    ACTIONS(476), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(547), 1,
      sym_identifier,
    ACTIONS(1981), 1,
      anon_sym_RPAREN,
    ACTIONS(1983), 1,
      sym__blank,
    STATE(416), 1,
      aux_sym_block_repeat1,
    STATE(799), 1,
      sym_trace32_hll_variable,
    STATE(1652), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(442), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(444), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(446), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(448), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(454), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(456), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(798), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(998), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [40134] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1793), 22,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      sym_path,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(1791), 24,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [40188] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(440), 1,
      anon_sym_LPAREN,
    ACTIONS(450), 1,
      anon_sym_BSLASH,
    ACTIONS(452), 1,
      anon_sym_sizeof,
    ACTIONS(470), 1,
      aux_sym_symbol_token1,
    ACTIONS(472), 1,
      aux_sym_symbol_token2,
    ACTIONS(476), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(547), 1,
      sym_identifier,
    ACTIONS(1603), 1,
      sym__blank,
    ACTIONS(1985), 1,
      anon_sym_RPAREN,
    STATE(799), 1,
      sym_trace32_hll_variable,
    STATE(800), 1,
      aux_sym_block_repeat1,
    STATE(1652), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(442), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(444), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(446), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(448), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(454), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(456), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(798), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1032), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [40278] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1989), 22,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      aux_sym_symbol_token3,
      sym_comment,
      sym__blank_line,
    ACTIONS(1987), 24,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [40332] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(300), 1,
      sym_identifier,
    ACTIONS(304), 1,
      anon_sym_LPAREN,
    ACTIONS(316), 1,
      anon_sym_BSLASH,
    ACTIONS(318), 1,
      anon_sym_sizeof,
    ACTIONS(324), 1,
      aux_sym_symbol_token1,
    ACTIONS(326), 1,
      aux_sym_symbol_token2,
    ACTIONS(328), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(1991), 1,
      anon_sym_RBRACK,
    ACTIONS(1993), 1,
      sym__blank,
    STATE(781), 1,
      sym_trace32_hll_variable,
    STATE(1601), 1,
      sym__hll_assignment_left_expression,
    STATE(2177), 1,
      aux_sym_block_repeat1,
    ACTIONS(308), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(310), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(312), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(448), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(320), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(322), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(778), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(572), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [40422] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(300), 1,
      sym_identifier,
    ACTIONS(304), 1,
      anon_sym_LPAREN,
    ACTIONS(316), 1,
      anon_sym_BSLASH,
    ACTIONS(318), 1,
      anon_sym_sizeof,
    ACTIONS(324), 1,
      aux_sym_symbol_token1,
    ACTIONS(326), 1,
      aux_sym_symbol_token2,
    ACTIONS(328), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(1995), 1,
      anon_sym_RBRACK,
    ACTIONS(1997), 1,
      sym__blank,
    STATE(781), 1,
      sym_trace32_hll_variable,
    STATE(1601), 1,
      sym__hll_assignment_left_expression,
    STATE(2183), 1,
      aux_sym_block_repeat1,
    ACTIONS(308), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(310), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(312), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(448), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(320), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(322), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(778), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(572), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [40512] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(300), 1,
      sym_identifier,
    ACTIONS(304), 1,
      anon_sym_LPAREN,
    ACTIONS(316), 1,
      anon_sym_BSLASH,
    ACTIONS(318), 1,
      anon_sym_sizeof,
    ACTIONS(324), 1,
      aux_sym_symbol_token1,
    ACTIONS(326), 1,
      aux_sym_symbol_token2,
    ACTIONS(328), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(1999), 1,
      anon_sym_RBRACK,
    ACTIONS(2001), 1,
      sym__blank,
    STATE(781), 1,
      sym_trace32_hll_variable,
    STATE(1601), 1,
      sym__hll_assignment_left_expression,
    STATE(2184), 1,
      aux_sym_block_repeat1,
    ACTIONS(308), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(310), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(312), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(448), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(320), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(322), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(778), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(572), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [40602] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(300), 1,
      sym_identifier,
    ACTIONS(304), 1,
      anon_sym_LPAREN,
    ACTIONS(316), 1,
      anon_sym_BSLASH,
    ACTIONS(318), 1,
      anon_sym_sizeof,
    ACTIONS(324), 1,
      aux_sym_symbol_token1,
    ACTIONS(326), 1,
      aux_sym_symbol_token2,
    ACTIONS(328), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(2003), 1,
      anon_sym_RBRACK,
    ACTIONS(2005), 1,
      sym__blank,
    STATE(781), 1,
      sym_trace32_hll_variable,
    STATE(1601), 1,
      sym__hll_assignment_left_expression,
    STATE(2186), 1,
      aux_sym_block_repeat1,
    ACTIONS(308), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(310), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(312), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(448), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(320), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(322), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(778), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(572), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [40692] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    STATE(415), 1,
      sym_macro,
    ACTIONS(2009), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(2007), 24,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [40748] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1649), 1,
      sym_path,
    ACTIONS(2009), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(2007), 24,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [40804] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2013), 22,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      aux_sym_symbol_token3,
      sym_comment,
      sym__blank_line,
    ACTIONS(2011), 24,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [40858] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(300), 1,
      sym_identifier,
    ACTIONS(304), 1,
      anon_sym_LPAREN,
    ACTIONS(316), 1,
      anon_sym_BSLASH,
    ACTIONS(318), 1,
      anon_sym_sizeof,
    ACTIONS(324), 1,
      aux_sym_symbol_token1,
    ACTIONS(326), 1,
      aux_sym_symbol_token2,
    ACTIONS(328), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(2015), 1,
      anon_sym_RBRACK,
    ACTIONS(2017), 1,
      sym__blank,
    STATE(781), 1,
      sym_trace32_hll_variable,
    STATE(1601), 1,
      sym__hll_assignment_left_expression,
    STATE(2185), 1,
      aux_sym_block_repeat1,
    ACTIONS(308), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(310), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(312), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(448), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(320), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(322), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(778), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(572), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [40948] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(300), 1,
      sym_identifier,
    ACTIONS(304), 1,
      anon_sym_LPAREN,
    ACTIONS(316), 1,
      anon_sym_BSLASH,
    ACTIONS(318), 1,
      anon_sym_sizeof,
    ACTIONS(324), 1,
      aux_sym_symbol_token1,
    ACTIONS(326), 1,
      aux_sym_symbol_token2,
    ACTIONS(328), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(2019), 1,
      anon_sym_RBRACK,
    ACTIONS(2021), 1,
      sym__blank,
    STATE(781), 1,
      sym_trace32_hll_variable,
    STATE(1601), 1,
      sym__hll_assignment_left_expression,
    STATE(2228), 1,
      aux_sym_block_repeat1,
    ACTIONS(308), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(310), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(312), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(448), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(320), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(322), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(778), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(572), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [41038] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(440), 1,
      anon_sym_LPAREN,
    ACTIONS(450), 1,
      anon_sym_BSLASH,
    ACTIONS(452), 1,
      anon_sym_sizeof,
    ACTIONS(470), 1,
      aux_sym_symbol_token1,
    ACTIONS(472), 1,
      aux_sym_symbol_token2,
    ACTIONS(476), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(547), 1,
      sym_identifier,
    ACTIONS(2023), 1,
      anon_sym_RPAREN,
    ACTIONS(2025), 1,
      sym__blank,
    STATE(404), 1,
      aux_sym_block_repeat1,
    STATE(799), 1,
      sym_trace32_hll_variable,
    STATE(1652), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(442), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(444), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(446), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(448), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(454), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(456), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(798), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1012), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [41128] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(579), 1,
      aux_sym_symbol_token1,
    ACTIONS(581), 1,
      aux_sym_symbol_token2,
    ACTIONS(583), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(619), 1,
      sym_identifier,
    ACTIONS(621), 1,
      anon_sym_LPAREN,
    ACTIONS(629), 1,
      anon_sym_BSLASH,
    ACTIONS(631), 1,
      anon_sym_sizeof,
    ACTIONS(2027), 1,
      sym__blank,
    STATE(435), 1,
      aux_sym_block_repeat1,
    STATE(842), 1,
      sym_trace32_hll_variable,
    STATE(1596), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(448), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(623), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(625), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(627), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(575), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(577), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(841), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1253), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [41215] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(559), 1,
      sym_identifier,
    ACTIONS(561), 1,
      anon_sym_LPAREN,
    ACTIONS(571), 1,
      anon_sym_BSLASH,
    ACTIONS(573), 1,
      anon_sym_sizeof,
    ACTIONS(579), 1,
      aux_sym_symbol_token1,
    ACTIONS(581), 1,
      aux_sym_symbol_token2,
    ACTIONS(583), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(2029), 1,
      sym__blank,
    STATE(433), 1,
      aux_sym_block_repeat1,
    STATE(812), 1,
      sym_trace32_hll_variable,
    STATE(1655), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(563), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(565), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(567), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(569), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(575), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(577), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(811), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1001), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [41302] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(579), 1,
      aux_sym_symbol_token1,
    ACTIONS(581), 1,
      aux_sym_symbol_token2,
    ACTIONS(583), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(619), 1,
      sym_identifier,
    ACTIONS(621), 1,
      anon_sym_LPAREN,
    ACTIONS(629), 1,
      anon_sym_BSLASH,
    ACTIONS(631), 1,
      anon_sym_sizeof,
    ACTIONS(1603), 1,
      sym__blank,
    STATE(800), 1,
      aux_sym_block_repeat1,
    STATE(842), 1,
      sym_trace32_hll_variable,
    STATE(1596), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(448), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(623), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(625), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(627), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(575), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(577), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(841), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1252), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [41389] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(342), 1,
      sym_identifier,
    ACTIONS(344), 1,
      anon_sym_LPAREN,
    ACTIONS(354), 1,
      anon_sym_BSLASH,
    ACTIONS(356), 1,
      anon_sym_sizeof,
    ACTIONS(362), 1,
      aux_sym_symbol_token1,
    ACTIONS(364), 1,
      aux_sym_symbol_token2,
    ACTIONS(366), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(2031), 1,
      sym__blank,
    STATE(491), 1,
      aux_sym_block_repeat1,
    STATE(807), 1,
      sym_trace32_hll_variable,
    STATE(1593), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(346), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(348), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(350), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(569), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(358), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(360), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(806), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(742), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [41476] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(579), 1,
      aux_sym_symbol_token1,
    ACTIONS(581), 1,
      aux_sym_symbol_token2,
    ACTIONS(583), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(619), 1,
      sym_identifier,
    ACTIONS(621), 1,
      anon_sym_LPAREN,
    ACTIONS(629), 1,
      anon_sym_BSLASH,
    ACTIONS(631), 1,
      anon_sym_sizeof,
    ACTIONS(1603), 1,
      sym__blank,
    STATE(800), 1,
      aux_sym_block_repeat1,
    STATE(842), 1,
      sym_trace32_hll_variable,
    STATE(1596), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(448), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(623), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(625), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(627), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(575), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(577), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(841), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1364), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [41563] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(559), 1,
      sym_identifier,
    ACTIONS(561), 1,
      anon_sym_LPAREN,
    ACTIONS(571), 1,
      anon_sym_BSLASH,
    ACTIONS(573), 1,
      anon_sym_sizeof,
    ACTIONS(579), 1,
      aux_sym_symbol_token1,
    ACTIONS(581), 1,
      aux_sym_symbol_token2,
    ACTIONS(583), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(1603), 1,
      sym__blank,
    STATE(800), 1,
      aux_sym_block_repeat1,
    STATE(812), 1,
      sym_trace32_hll_variable,
    STATE(1655), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(563), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(565), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(567), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(569), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(575), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(577), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(811), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1018), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [41650] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(440), 1,
      anon_sym_LPAREN,
    ACTIONS(450), 1,
      anon_sym_BSLASH,
    ACTIONS(452), 1,
      anon_sym_sizeof,
    ACTIONS(470), 1,
      aux_sym_symbol_token1,
    ACTIONS(472), 1,
      aux_sym_symbol_token2,
    ACTIONS(476), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(547), 1,
      sym_identifier,
    ACTIONS(2033), 1,
      sym__blank,
    STATE(456), 1,
      aux_sym_block_repeat1,
    STATE(799), 1,
      sym_trace32_hll_variable,
    STATE(1652), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(442), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(444), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(446), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(448), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(454), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(456), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(798), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(979), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [41737] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(579), 1,
      aux_sym_symbol_token1,
    ACTIONS(581), 1,
      aux_sym_symbol_token2,
    ACTIONS(583), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(619), 1,
      sym_identifier,
    ACTIONS(621), 1,
      anon_sym_LPAREN,
    ACTIONS(629), 1,
      anon_sym_BSLASH,
    ACTIONS(631), 1,
      anon_sym_sizeof,
    ACTIONS(1603), 1,
      sym__blank,
    STATE(800), 1,
      aux_sym_block_repeat1,
    STATE(842), 1,
      sym_trace32_hll_variable,
    STATE(1596), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(448), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(623), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(625), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(627), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(575), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(577), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(841), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1258), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [41824] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(579), 1,
      aux_sym_symbol_token1,
    ACTIONS(581), 1,
      aux_sym_symbol_token2,
    ACTIONS(583), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(811), 1,
      sym_identifier,
    ACTIONS(813), 1,
      anon_sym_LPAREN,
    ACTIONS(823), 1,
      anon_sym_BSLASH,
    ACTIONS(825), 1,
      anon_sym_sizeof,
    ACTIONS(1603), 1,
      sym__blank,
    STATE(800), 1,
      aux_sym_block_repeat1,
    STATE(916), 1,
      sym_trace32_hll_variable,
    STATE(1587), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(815), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(817), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(819), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(821), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(575), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(577), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(915), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1269), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [41911] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(559), 1,
      sym_identifier,
    ACTIONS(561), 1,
      anon_sym_LPAREN,
    ACTIONS(571), 1,
      anon_sym_BSLASH,
    ACTIONS(573), 1,
      anon_sym_sizeof,
    ACTIONS(579), 1,
      aux_sym_symbol_token1,
    ACTIONS(581), 1,
      aux_sym_symbol_token2,
    ACTIONS(583), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(1603), 1,
      sym__blank,
    STATE(800), 1,
      aux_sym_block_repeat1,
    STATE(812), 1,
      sym_trace32_hll_variable,
    STATE(1655), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(563), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(565), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(567), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(569), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(575), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(577), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(811), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1006), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [41998] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2037), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(2035), 24,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [42051] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(579), 1,
      aux_sym_symbol_token1,
    ACTIONS(581), 1,
      aux_sym_symbol_token2,
    ACTIONS(583), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(811), 1,
      sym_identifier,
    ACTIONS(813), 1,
      anon_sym_LPAREN,
    ACTIONS(823), 1,
      anon_sym_BSLASH,
    ACTIONS(825), 1,
      anon_sym_sizeof,
    ACTIONS(1603), 1,
      sym__blank,
    STATE(800), 1,
      aux_sym_block_repeat1,
    STATE(916), 1,
      sym_trace32_hll_variable,
    STATE(1587), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(815), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(817), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(819), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(821), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(575), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(577), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(915), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1302), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [42138] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(300), 1,
      sym_identifier,
    ACTIONS(304), 1,
      anon_sym_LPAREN,
    ACTIONS(316), 1,
      anon_sym_BSLASH,
    ACTIONS(318), 1,
      anon_sym_sizeof,
    ACTIONS(324), 1,
      aux_sym_symbol_token1,
    ACTIONS(326), 1,
      aux_sym_symbol_token2,
    ACTIONS(328), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(2039), 1,
      sym__blank,
    STATE(441), 1,
      aux_sym_block_repeat1,
    STATE(781), 1,
      sym_trace32_hll_variable,
    STATE(1601), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(308), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(310), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(312), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(448), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(320), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(322), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(778), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(684), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [42225] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(300), 1,
      sym_identifier,
    ACTIONS(304), 1,
      anon_sym_LPAREN,
    ACTIONS(316), 1,
      anon_sym_BSLASH,
    ACTIONS(318), 1,
      anon_sym_sizeof,
    ACTIONS(324), 1,
      aux_sym_symbol_token1,
    ACTIONS(326), 1,
      aux_sym_symbol_token2,
    ACTIONS(328), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(1603), 1,
      sym__blank,
    STATE(781), 1,
      sym_trace32_hll_variable,
    STATE(800), 1,
      aux_sym_block_repeat1,
    STATE(1601), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(308), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(310), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(312), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(448), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(320), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(322), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(778), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(694), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [42312] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(300), 1,
      sym_identifier,
    ACTIONS(304), 1,
      anon_sym_LPAREN,
    ACTIONS(316), 1,
      anon_sym_BSLASH,
    ACTIONS(318), 1,
      anon_sym_sizeof,
    ACTIONS(324), 1,
      aux_sym_symbol_token1,
    ACTIONS(326), 1,
      aux_sym_symbol_token2,
    ACTIONS(328), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(2041), 1,
      sym__blank,
    STATE(444), 1,
      aux_sym_block_repeat1,
    STATE(781), 1,
      sym_trace32_hll_variable,
    STATE(1601), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(308), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(310), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(312), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(448), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(320), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(322), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(778), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(706), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [42399] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(579), 1,
      aux_sym_symbol_token1,
    ACTIONS(581), 1,
      aux_sym_symbol_token2,
    ACTIONS(583), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(811), 1,
      sym_identifier,
    ACTIONS(813), 1,
      anon_sym_LPAREN,
    ACTIONS(823), 1,
      anon_sym_BSLASH,
    ACTIONS(825), 1,
      anon_sym_sizeof,
    ACTIONS(2043), 1,
      sym__blank,
    STATE(471), 1,
      aux_sym_block_repeat1,
    STATE(916), 1,
      sym_trace32_hll_variable,
    STATE(1587), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(815), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(817), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(819), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(821), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(575), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(577), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(915), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1303), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [42486] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(300), 1,
      sym_identifier,
    ACTIONS(304), 1,
      anon_sym_LPAREN,
    ACTIONS(316), 1,
      anon_sym_BSLASH,
    ACTIONS(318), 1,
      anon_sym_sizeof,
    ACTIONS(324), 1,
      aux_sym_symbol_token1,
    ACTIONS(326), 1,
      aux_sym_symbol_token2,
    ACTIONS(328), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(1603), 1,
      sym__blank,
    STATE(781), 1,
      sym_trace32_hll_variable,
    STATE(800), 1,
      aux_sym_block_repeat1,
    STATE(1601), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(308), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(310), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(312), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(448), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(320), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(322), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(778), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(712), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [42573] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(645), 1,
      anon_sym_BSLASH,
    ACTIONS(653), 1,
      aux_sym_symbol_token1,
    ACTIONS(655), 1,
      aux_sym_symbol_token2,
    ACTIONS(657), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(717), 1,
      sym_identifier,
    ACTIONS(719), 1,
      anon_sym_LPAREN,
    ACTIONS(727), 1,
      anon_sym_sizeof,
    ACTIONS(2045), 1,
      sym__blank,
    STATE(446), 1,
      aux_sym_block_repeat1,
    STATE(885), 1,
      sym_trace32_hll_variable,
    STATE(1605), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(643), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(721), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(723), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(725), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(649), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(651), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(884), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1281), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [42660] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(645), 1,
      anon_sym_BSLASH,
    ACTIONS(653), 1,
      aux_sym_symbol_token1,
    ACTIONS(655), 1,
      aux_sym_symbol_token2,
    ACTIONS(657), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(717), 1,
      sym_identifier,
    ACTIONS(719), 1,
      anon_sym_LPAREN,
    ACTIONS(727), 1,
      anon_sym_sizeof,
    ACTIONS(1603), 1,
      sym__blank,
    STATE(800), 1,
      aux_sym_block_repeat1,
    STATE(885), 1,
      sym_trace32_hll_variable,
    STATE(1605), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(643), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(721), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(723), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(725), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(649), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(651), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(884), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1283), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [42747] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(645), 1,
      anon_sym_BSLASH,
    ACTIONS(653), 1,
      aux_sym_symbol_token1,
    ACTIONS(655), 1,
      aux_sym_symbol_token2,
    ACTIONS(657), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(717), 1,
      sym_identifier,
    ACTIONS(719), 1,
      anon_sym_LPAREN,
    ACTIONS(727), 1,
      anon_sym_sizeof,
    ACTIONS(2047), 1,
      sym__blank,
    STATE(455), 1,
      aux_sym_block_repeat1,
    STATE(885), 1,
      sym_trace32_hll_variable,
    STATE(1605), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(643), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(721), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(723), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(725), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(649), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(651), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(884), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1284), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [42834] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2051), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(2049), 24,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [42887] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2055), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(2053), 24,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [42940] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2059), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(2057), 24,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [42993] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2059), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(2057), 24,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [43046] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2063), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(2061), 24,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [43099] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2063), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(2061), 24,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [43152] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(440), 1,
      anon_sym_LPAREN,
    ACTIONS(450), 1,
      anon_sym_BSLASH,
    ACTIONS(452), 1,
      anon_sym_sizeof,
    ACTIONS(470), 1,
      aux_sym_symbol_token1,
    ACTIONS(472), 1,
      aux_sym_symbol_token2,
    ACTIONS(476), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(547), 1,
      sym_identifier,
    ACTIONS(1603), 1,
      sym__blank,
    STATE(799), 1,
      sym_trace32_hll_variable,
    STATE(800), 1,
      aux_sym_block_repeat1,
    STATE(1652), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(442), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(444), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(446), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(448), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(454), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(456), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(798), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1063), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [43239] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(645), 1,
      anon_sym_BSLASH,
    ACTIONS(653), 1,
      aux_sym_symbol_token1,
    ACTIONS(655), 1,
      aux_sym_symbol_token2,
    ACTIONS(657), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(717), 1,
      sym_identifier,
    ACTIONS(719), 1,
      anon_sym_LPAREN,
    ACTIONS(727), 1,
      anon_sym_sizeof,
    ACTIONS(1603), 1,
      sym__blank,
    STATE(800), 1,
      aux_sym_block_repeat1,
    STATE(885), 1,
      sym_trace32_hll_variable,
    STATE(1605), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(643), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(721), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(723), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(725), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(649), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(651), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(884), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1287), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [43326] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(440), 1,
      anon_sym_LPAREN,
    ACTIONS(450), 1,
      anon_sym_BSLASH,
    ACTIONS(452), 1,
      anon_sym_sizeof,
    ACTIONS(470), 1,
      aux_sym_symbol_token1,
    ACTIONS(472), 1,
      aux_sym_symbol_token2,
    ACTIONS(476), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(547), 1,
      sym_identifier,
    ACTIONS(1603), 1,
      sym__blank,
    STATE(799), 1,
      sym_trace32_hll_variable,
    STATE(800), 1,
      aux_sym_block_repeat1,
    STATE(1652), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(442), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(444), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(446), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(448), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(454), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(456), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(798), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(999), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [43413] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2067), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(2065), 24,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [43466] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(440), 1,
      anon_sym_LPAREN,
    ACTIONS(450), 1,
      anon_sym_BSLASH,
    ACTIONS(452), 1,
      anon_sym_sizeof,
    ACTIONS(470), 1,
      aux_sym_symbol_token1,
    ACTIONS(472), 1,
      aux_sym_symbol_token2,
    ACTIONS(476), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(547), 1,
      sym_identifier,
    ACTIONS(2069), 1,
      sym__blank,
    STATE(467), 1,
      aux_sym_block_repeat1,
    STATE(799), 1,
      sym_trace32_hll_variable,
    STATE(1652), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(442), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(444), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(446), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(448), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(454), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(456), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(798), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1015), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [43553] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2073), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(2071), 24,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [43606] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(440), 1,
      anon_sym_LPAREN,
    ACTIONS(450), 1,
      anon_sym_BSLASH,
    ACTIONS(452), 1,
      anon_sym_sizeof,
    ACTIONS(470), 1,
      aux_sym_symbol_token1,
    ACTIONS(472), 1,
      aux_sym_symbol_token2,
    ACTIONS(476), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(547), 1,
      sym_identifier,
    ACTIONS(2075), 1,
      sym__blank,
    STATE(454), 1,
      aux_sym_block_repeat1,
    STATE(799), 1,
      sym_trace32_hll_variable,
    STATE(1652), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(442), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(444), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(446), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(448), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(454), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(456), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(798), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1048), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [43693] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(579), 1,
      aux_sym_symbol_token1,
    ACTIONS(581), 1,
      aux_sym_symbol_token2,
    ACTIONS(583), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(619), 1,
      sym_identifier,
    ACTIONS(621), 1,
      anon_sym_LPAREN,
    ACTIONS(629), 1,
      anon_sym_BSLASH,
    ACTIONS(631), 1,
      anon_sym_sizeof,
    ACTIONS(1603), 1,
      sym__blank,
    STATE(800), 1,
      aux_sym_block_repeat1,
    STATE(842), 1,
      sym_trace32_hll_variable,
    STATE(1596), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(448), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(623), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(625), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(627), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(575), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(577), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(841), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1359), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [43780] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(579), 1,
      aux_sym_symbol_token1,
    ACTIONS(581), 1,
      aux_sym_symbol_token2,
    ACTIONS(583), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(619), 1,
      sym_identifier,
    ACTIONS(621), 1,
      anon_sym_LPAREN,
    ACTIONS(629), 1,
      anon_sym_BSLASH,
    ACTIONS(631), 1,
      anon_sym_sizeof,
    ACTIONS(2077), 1,
      sym__blank,
    STATE(432), 1,
      aux_sym_block_repeat1,
    STATE(842), 1,
      sym_trace32_hll_variable,
    STATE(1596), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(448), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(623), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(625), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(627), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(575), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(577), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(841), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1368), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [43867] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(633), 1,
      sym_identifier,
    ACTIONS(635), 1,
      anon_sym_LPAREN,
    ACTIONS(645), 1,
      anon_sym_BSLASH,
    ACTIONS(647), 1,
      anon_sym_sizeof,
    ACTIONS(653), 1,
      aux_sym_symbol_token1,
    ACTIONS(655), 1,
      aux_sym_symbol_token2,
    ACTIONS(657), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(2079), 1,
      sym__blank,
    STATE(464), 1,
      aux_sym_block_repeat1,
    STATE(890), 1,
      sym_trace32_hll_variable,
    STATE(1609), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(637), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(639), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(641), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(643), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(649), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(651), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(889), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1164), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [43954] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(633), 1,
      sym_identifier,
    ACTIONS(635), 1,
      anon_sym_LPAREN,
    ACTIONS(645), 1,
      anon_sym_BSLASH,
    ACTIONS(647), 1,
      anon_sym_sizeof,
    ACTIONS(653), 1,
      aux_sym_symbol_token1,
    ACTIONS(655), 1,
      aux_sym_symbol_token2,
    ACTIONS(657), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(1603), 1,
      sym__blank,
    STATE(800), 1,
      aux_sym_block_repeat1,
    STATE(890), 1,
      sym_trace32_hll_variable,
    STATE(1609), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(637), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(639), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(641), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(643), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(649), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(651), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(889), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1188), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [44041] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(579), 1,
      aux_sym_symbol_token1,
    ACTIONS(581), 1,
      aux_sym_symbol_token2,
    ACTIONS(583), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(811), 1,
      sym_identifier,
    ACTIONS(813), 1,
      anon_sym_LPAREN,
    ACTIONS(823), 1,
      anon_sym_BSLASH,
    ACTIONS(825), 1,
      anon_sym_sizeof,
    ACTIONS(2081), 1,
      sym__blank,
    STATE(439), 1,
      aux_sym_block_repeat1,
    STATE(916), 1,
      sym_trace32_hll_variable,
    STATE(1587), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(815), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(817), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(819), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(821), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(575), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(577), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(915), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1352), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [44128] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(633), 1,
      sym_identifier,
    ACTIONS(635), 1,
      anon_sym_LPAREN,
    ACTIONS(645), 1,
      anon_sym_BSLASH,
    ACTIONS(647), 1,
      anon_sym_sizeof,
    ACTIONS(653), 1,
      aux_sym_symbol_token1,
    ACTIONS(655), 1,
      aux_sym_symbol_token2,
    ACTIONS(657), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(2083), 1,
      sym__blank,
    STATE(468), 1,
      aux_sym_block_repeat1,
    STATE(890), 1,
      sym_trace32_hll_variable,
    STATE(1609), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(637), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(639), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(641), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(643), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(649), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(651), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(889), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1189), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [44215] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(440), 1,
      anon_sym_LPAREN,
    ACTIONS(450), 1,
      anon_sym_BSLASH,
    ACTIONS(452), 1,
      anon_sym_sizeof,
    ACTIONS(470), 1,
      aux_sym_symbol_token1,
    ACTIONS(472), 1,
      aux_sym_symbol_token2,
    ACTIONS(476), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(547), 1,
      sym_identifier,
    ACTIONS(1603), 1,
      sym__blank,
    STATE(799), 1,
      sym_trace32_hll_variable,
    STATE(800), 1,
      aux_sym_block_repeat1,
    STATE(1652), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(442), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(444), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(446), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(448), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(454), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(456), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(798), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(966), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [44302] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(633), 1,
      sym_identifier,
    ACTIONS(635), 1,
      anon_sym_LPAREN,
    ACTIONS(645), 1,
      anon_sym_BSLASH,
    ACTIONS(647), 1,
      anon_sym_sizeof,
    ACTIONS(653), 1,
      aux_sym_symbol_token1,
    ACTIONS(655), 1,
      aux_sym_symbol_token2,
    ACTIONS(657), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(1603), 1,
      sym__blank,
    STATE(800), 1,
      aux_sym_block_repeat1,
    STATE(890), 1,
      sym_trace32_hll_variable,
    STATE(1609), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(637), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(639), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(641), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(643), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(649), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(651), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(889), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1194), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [44389] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(342), 1,
      sym_identifier,
    ACTIONS(344), 1,
      anon_sym_LPAREN,
    ACTIONS(354), 1,
      anon_sym_BSLASH,
    ACTIONS(356), 1,
      anon_sym_sizeof,
    ACTIONS(362), 1,
      aux_sym_symbol_token1,
    ACTIONS(364), 1,
      aux_sym_symbol_token2,
    ACTIONS(366), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(1603), 1,
      sym__blank,
    STATE(800), 1,
      aux_sym_block_repeat1,
    STATE(807), 1,
      sym_trace32_hll_variable,
    STATE(1593), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(346), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(348), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(350), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(569), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(358), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(360), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(806), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(754), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [44476] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(579), 1,
      aux_sym_symbol_token1,
    ACTIONS(581), 1,
      aux_sym_symbol_token2,
    ACTIONS(583), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(619), 1,
      sym_identifier,
    ACTIONS(621), 1,
      anon_sym_LPAREN,
    ACTIONS(629), 1,
      anon_sym_BSLASH,
    ACTIONS(631), 1,
      anon_sym_sizeof,
    ACTIONS(2085), 1,
      sym__blank,
    STATE(461), 1,
      aux_sym_block_repeat1,
    STATE(842), 1,
      sym_trace32_hll_variable,
    STATE(1596), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(448), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(623), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(625), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(627), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(575), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(577), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(841), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1398), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [44563] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(579), 1,
      aux_sym_symbol_token1,
    ACTIONS(581), 1,
      aux_sym_symbol_token2,
    ACTIONS(583), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(811), 1,
      sym_identifier,
    ACTIONS(813), 1,
      anon_sym_LPAREN,
    ACTIONS(823), 1,
      anon_sym_BSLASH,
    ACTIONS(825), 1,
      anon_sym_sizeof,
    ACTIONS(1603), 1,
      sym__blank,
    STATE(800), 1,
      aux_sym_block_repeat1,
    STATE(916), 1,
      sym_trace32_hll_variable,
    STATE(1587), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(815), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(817), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(819), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(821), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(575), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(577), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(915), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1270), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [44650] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(579), 1,
      aux_sym_symbol_token1,
    ACTIONS(581), 1,
      aux_sym_symbol_token2,
    ACTIONS(583), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(811), 1,
      sym_identifier,
    ACTIONS(813), 1,
      anon_sym_LPAREN,
    ACTIONS(823), 1,
      anon_sym_BSLASH,
    ACTIONS(825), 1,
      anon_sym_sizeof,
    ACTIONS(1603), 1,
      sym__blank,
    STATE(800), 1,
      aux_sym_block_repeat1,
    STATE(916), 1,
      sym_trace32_hll_variable,
    STATE(1587), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(815), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(817), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(819), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(821), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(575), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(577), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(915), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1294), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [44737] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1804), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(1802), 24,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [44790] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2089), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(2087), 24,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [44843] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(579), 1,
      aux_sym_symbol_token1,
    ACTIONS(581), 1,
      aux_sym_symbol_token2,
    ACTIONS(583), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(811), 1,
      sym_identifier,
    ACTIONS(813), 1,
      anon_sym_LPAREN,
    ACTIONS(823), 1,
      anon_sym_BSLASH,
    ACTIONS(825), 1,
      anon_sym_sizeof,
    ACTIONS(1603), 1,
      sym__blank,
    STATE(800), 1,
      aux_sym_block_repeat1,
    STATE(916), 1,
      sym_trace32_hll_variable,
    STATE(1587), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(815), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(817), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(819), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(821), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(575), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(577), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(915), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1354), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [44930] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(394), 1,
      sym_identifier,
    ACTIONS(396), 1,
      anon_sym_LPAREN,
    ACTIONS(406), 1,
      anon_sym_BSLASH,
    ACTIONS(408), 1,
      anon_sym_sizeof,
    ACTIONS(414), 1,
      aux_sym_symbol_token1,
    ACTIONS(416), 1,
      aux_sym_symbol_token2,
    ACTIONS(418), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(2091), 1,
      sym__blank,
    STATE(477), 1,
      aux_sym_block_repeat1,
    STATE(893), 1,
      sym_trace32_hll_variable,
    STATE(1615), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(398), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(400), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(402), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(643), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(410), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(412), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(892), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(861), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [45017] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(394), 1,
      sym_identifier,
    ACTIONS(396), 1,
      anon_sym_LPAREN,
    ACTIONS(406), 1,
      anon_sym_BSLASH,
    ACTIONS(408), 1,
      anon_sym_sizeof,
    ACTIONS(414), 1,
      aux_sym_symbol_token1,
    ACTIONS(416), 1,
      aux_sym_symbol_token2,
    ACTIONS(418), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(1603), 1,
      sym__blank,
    STATE(800), 1,
      aux_sym_block_repeat1,
    STATE(893), 1,
      sym_trace32_hll_variable,
    STATE(1615), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(398), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(400), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(402), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(643), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(410), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(412), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(892), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(863), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [45104] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(559), 1,
      sym_identifier,
    ACTIONS(561), 1,
      anon_sym_LPAREN,
    ACTIONS(571), 1,
      anon_sym_BSLASH,
    ACTIONS(573), 1,
      anon_sym_sizeof,
    ACTIONS(579), 1,
      aux_sym_symbol_token1,
    ACTIONS(581), 1,
      aux_sym_symbol_token2,
    ACTIONS(583), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(2093), 1,
      sym__blank,
    STATE(437), 1,
      aux_sym_block_repeat1,
    STATE(812), 1,
      sym_trace32_hll_variable,
    STATE(1655), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(563), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(565), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(567), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(569), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(575), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(577), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(811), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(993), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [45191] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2097), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(2095), 24,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [45244] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2101), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(2099), 24,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [45297] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(579), 1,
      aux_sym_symbol_token1,
    ACTIONS(581), 1,
      aux_sym_symbol_token2,
    ACTIONS(583), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(811), 1,
      sym_identifier,
    ACTIONS(813), 1,
      anon_sym_LPAREN,
    ACTIONS(823), 1,
      anon_sym_BSLASH,
    ACTIONS(825), 1,
      anon_sym_sizeof,
    ACTIONS(1603), 1,
      sym__blank,
    STATE(800), 1,
      aux_sym_block_repeat1,
    STATE(916), 1,
      sym_trace32_hll_variable,
    STATE(1587), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(815), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(817), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(819), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(821), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(575), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(577), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(915), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1337), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [45384] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(579), 1,
      aux_sym_symbol_token1,
    ACTIONS(581), 1,
      aux_sym_symbol_token2,
    ACTIONS(583), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(811), 1,
      sym_identifier,
    ACTIONS(813), 1,
      anon_sym_LPAREN,
    ACTIONS(823), 1,
      anon_sym_BSLASH,
    ACTIONS(825), 1,
      anon_sym_sizeof,
    ACTIONS(1603), 1,
      sym__blank,
    STATE(800), 1,
      aux_sym_block_repeat1,
    STATE(916), 1,
      sym_trace32_hll_variable,
    STATE(1587), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(815), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(817), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(819), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(821), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(575), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(577), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(915), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1338), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [45471] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(394), 1,
      sym_identifier,
    ACTIONS(396), 1,
      anon_sym_LPAREN,
    ACTIONS(406), 1,
      anon_sym_BSLASH,
    ACTIONS(408), 1,
      anon_sym_sizeof,
    ACTIONS(414), 1,
      aux_sym_symbol_token1,
    ACTIONS(416), 1,
      aux_sym_symbol_token2,
    ACTIONS(418), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(2103), 1,
      sym__blank,
    STATE(489), 1,
      aux_sym_block_repeat1,
    STATE(893), 1,
      sym_trace32_hll_variable,
    STATE(1615), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(398), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(400), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(402), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(643), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(410), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(412), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(892), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(864), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [45558] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(579), 1,
      aux_sym_symbol_token1,
    ACTIONS(581), 1,
      aux_sym_symbol_token2,
    ACTIONS(583), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(811), 1,
      sym_identifier,
    ACTIONS(813), 1,
      anon_sym_LPAREN,
    ACTIONS(823), 1,
      anon_sym_BSLASH,
    ACTIONS(825), 1,
      anon_sym_sizeof,
    ACTIONS(1603), 1,
      sym__blank,
    STATE(800), 1,
      aux_sym_block_repeat1,
    STATE(916), 1,
      sym_trace32_hll_variable,
    STATE(1587), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(815), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(817), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(819), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(821), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(575), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(577), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(915), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1347), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [45645] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(579), 1,
      aux_sym_symbol_token1,
    ACTIONS(581), 1,
      aux_sym_symbol_token2,
    ACTIONS(583), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(811), 1,
      sym_identifier,
    ACTIONS(813), 1,
      anon_sym_LPAREN,
    ACTIONS(823), 1,
      anon_sym_BSLASH,
    ACTIONS(825), 1,
      anon_sym_sizeof,
    ACTIONS(1603), 1,
      sym__blank,
    STATE(800), 1,
      aux_sym_block_repeat1,
    STATE(916), 1,
      sym_trace32_hll_variable,
    STATE(1587), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(815), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(817), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(819), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(821), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(575), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(577), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(915), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1349), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [45732] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(368), 1,
      sym_identifier,
    ACTIONS(370), 1,
      anon_sym_LPAREN,
    ACTIONS(380), 1,
      anon_sym_BSLASH,
    ACTIONS(382), 1,
      anon_sym_sizeof,
    ACTIONS(388), 1,
      aux_sym_symbol_token1,
    ACTIONS(390), 1,
      aux_sym_symbol_token2,
    ACTIONS(392), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(2105), 1,
      sym__blank,
    STATE(487), 1,
      aux_sym_block_repeat1,
    STATE(900), 1,
      sym_trace32_hll_variable,
    STATE(1580), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(372), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(374), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(376), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(821), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(384), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(386), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(898), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(835), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [45819] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(368), 1,
      sym_identifier,
    ACTIONS(370), 1,
      anon_sym_LPAREN,
    ACTIONS(380), 1,
      anon_sym_BSLASH,
    ACTIONS(382), 1,
      anon_sym_sizeof,
    ACTIONS(388), 1,
      aux_sym_symbol_token1,
    ACTIONS(390), 1,
      aux_sym_symbol_token2,
    ACTIONS(392), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(1603), 1,
      sym__blank,
    STATE(800), 1,
      aux_sym_block_repeat1,
    STATE(900), 1,
      sym_trace32_hll_variable,
    STATE(1580), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(372), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(374), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(376), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(821), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(384), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(386), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(898), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(837), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [45906] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(368), 1,
      sym_identifier,
    ACTIONS(370), 1,
      anon_sym_LPAREN,
    ACTIONS(380), 1,
      anon_sym_BSLASH,
    ACTIONS(382), 1,
      anon_sym_sizeof,
    ACTIONS(388), 1,
      aux_sym_symbol_token1,
    ACTIONS(390), 1,
      aux_sym_symbol_token2,
    ACTIONS(392), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(2107), 1,
      sym__blank,
    STATE(490), 1,
      aux_sym_block_repeat1,
    STATE(900), 1,
      sym_trace32_hll_variable,
    STATE(1580), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(372), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(374), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(376), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(821), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(384), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(386), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(898), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(838), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [45993] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(394), 1,
      sym_identifier,
    ACTIONS(396), 1,
      anon_sym_LPAREN,
    ACTIONS(406), 1,
      anon_sym_BSLASH,
    ACTIONS(408), 1,
      anon_sym_sizeof,
    ACTIONS(414), 1,
      aux_sym_symbol_token1,
    ACTIONS(416), 1,
      aux_sym_symbol_token2,
    ACTIONS(418), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(1603), 1,
      sym__blank,
    STATE(800), 1,
      aux_sym_block_repeat1,
    STATE(893), 1,
      sym_trace32_hll_variable,
    STATE(1615), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(398), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(400), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(402), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(643), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(410), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(412), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(892), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(866), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [46080] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(368), 1,
      sym_identifier,
    ACTIONS(370), 1,
      anon_sym_LPAREN,
    ACTIONS(380), 1,
      anon_sym_BSLASH,
    ACTIONS(382), 1,
      anon_sym_sizeof,
    ACTIONS(388), 1,
      aux_sym_symbol_token1,
    ACTIONS(390), 1,
      aux_sym_symbol_token2,
    ACTIONS(392), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(1603), 1,
      sym__blank,
    STATE(800), 1,
      aux_sym_block_repeat1,
    STATE(900), 1,
      sym_trace32_hll_variable,
    STATE(1580), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(372), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(374), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(376), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(821), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(384), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(386), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(898), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(840), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [46167] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(342), 1,
      sym_identifier,
    ACTIONS(344), 1,
      anon_sym_LPAREN,
    ACTIONS(354), 1,
      anon_sym_BSLASH,
    ACTIONS(356), 1,
      anon_sym_sizeof,
    ACTIONS(362), 1,
      aux_sym_symbol_token1,
    ACTIONS(364), 1,
      aux_sym_symbol_token2,
    ACTIONS(366), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(1603), 1,
      sym__blank,
    STATE(800), 1,
      aux_sym_block_repeat1,
    STATE(807), 1,
      sym_trace32_hll_variable,
    STATE(1593), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(346), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(348), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(350), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(569), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(358), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(360), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(806), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(774), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [46254] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(579), 1,
      aux_sym_symbol_token1,
    ACTIONS(581), 1,
      aux_sym_symbol_token2,
    ACTIONS(583), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(811), 1,
      sym_identifier,
    ACTIONS(813), 1,
      anon_sym_LPAREN,
    ACTIONS(823), 1,
      anon_sym_BSLASH,
    ACTIONS(825), 1,
      anon_sym_sizeof,
    ACTIONS(1603), 1,
      sym__blank,
    STATE(800), 1,
      aux_sym_block_repeat1,
    STATE(916), 1,
      sym_trace32_hll_variable,
    STATE(1587), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(815), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(817), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(819), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(821), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(575), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(577), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(915), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1334), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [46341] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(342), 1,
      sym_identifier,
    ACTIONS(344), 1,
      anon_sym_LPAREN,
    ACTIONS(354), 1,
      anon_sym_BSLASH,
    ACTIONS(356), 1,
      anon_sym_sizeof,
    ACTIONS(362), 1,
      aux_sym_symbol_token1,
    ACTIONS(364), 1,
      aux_sym_symbol_token2,
    ACTIONS(366), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(2109), 1,
      sym__blank,
    STATE(469), 1,
      aux_sym_block_repeat1,
    STATE(807), 1,
      sym_trace32_hll_variable,
    STATE(1593), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(346), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(348), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(350), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(569), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(358), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(360), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(806), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(777), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [46428] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(579), 1,
      aux_sym_symbol_token1,
    ACTIONS(581), 1,
      aux_sym_symbol_token2,
    ACTIONS(583), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(619), 1,
      sym_identifier,
    ACTIONS(621), 1,
      anon_sym_LPAREN,
    ACTIONS(629), 1,
      anon_sym_BSLASH,
    ACTIONS(631), 1,
      anon_sym_sizeof,
    ACTIONS(2111), 1,
      sym__blank,
    STATE(430), 1,
      aux_sym_block_repeat1,
    STATE(842), 1,
      sym_trace32_hll_variable,
    STATE(1596), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(448), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(623), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(625), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(627), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(575), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(577), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(841), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1246), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [46515] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(579), 1,
      aux_sym_symbol_token1,
    ACTIONS(581), 1,
      aux_sym_symbol_token2,
    ACTIONS(583), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(619), 1,
      sym_identifier,
    ACTIONS(621), 1,
      anon_sym_LPAREN,
    ACTIONS(629), 1,
      anon_sym_BSLASH,
    ACTIONS(631), 1,
      anon_sym_sizeof,
    ACTIONS(2113), 1,
      anon_sym_COLON,
    STATE(842), 1,
      sym_trace32_hll_variable,
    STATE(1596), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(448), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(623), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(625), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(627), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(575), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(577), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(841), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1369), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [46599] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(440), 1,
      anon_sym_LPAREN,
    ACTIONS(450), 1,
      anon_sym_BSLASH,
    ACTIONS(452), 1,
      anon_sym_sizeof,
    ACTIONS(470), 1,
      aux_sym_symbol_token1,
    ACTIONS(472), 1,
      aux_sym_symbol_token2,
    ACTIONS(476), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(547), 1,
      sym_identifier,
    STATE(799), 1,
      sym_trace32_hll_variable,
    STATE(1652), 1,
      sym__hll_assignment_left_expression,
    STATE(2401), 1,
      sym_hll_range_expression,
    ACTIONS(442), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(444), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(446), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(448), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(454), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(456), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(798), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1105), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [46683] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(579), 1,
      aux_sym_symbol_token1,
    ACTIONS(581), 1,
      aux_sym_symbol_token2,
    ACTIONS(583), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(619), 1,
      sym_identifier,
    ACTIONS(621), 1,
      anon_sym_LPAREN,
    ACTIONS(629), 1,
      anon_sym_BSLASH,
    ACTIONS(631), 1,
      anon_sym_sizeof,
    ACTIONS(2115), 1,
      anon_sym_COLON,
    STATE(842), 1,
      sym_trace32_hll_variable,
    STATE(1596), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(448), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(623), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(625), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(627), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(575), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(577), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(841), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1418), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [46767] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(440), 1,
      anon_sym_LPAREN,
    ACTIONS(450), 1,
      anon_sym_BSLASH,
    ACTIONS(452), 1,
      anon_sym_sizeof,
    ACTIONS(470), 1,
      aux_sym_symbol_token1,
    ACTIONS(472), 1,
      aux_sym_symbol_token2,
    ACTIONS(476), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(547), 1,
      sym_identifier,
    STATE(799), 1,
      sym_trace32_hll_variable,
    STATE(1652), 1,
      sym__hll_assignment_left_expression,
    STATE(2446), 1,
      sym_hll_range_expression,
    ACTIONS(442), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(444), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(446), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(448), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(454), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(456), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(798), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1045), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [46851] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(440), 1,
      anon_sym_LPAREN,
    ACTIONS(450), 1,
      anon_sym_BSLASH,
    ACTIONS(452), 1,
      anon_sym_sizeof,
    ACTIONS(470), 1,
      aux_sym_symbol_token1,
    ACTIONS(472), 1,
      aux_sym_symbol_token2,
    ACTIONS(476), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(547), 1,
      sym_identifier,
    STATE(799), 1,
      sym_trace32_hll_variable,
    STATE(1652), 1,
      sym__hll_assignment_left_expression,
    STATE(2396), 1,
      sym_hll_range_expression,
    ACTIONS(442), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(444), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(446), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(448), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(454), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(456), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(798), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1088), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [46935] = 13,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2117), 1,
      sym_identifier,
    ACTIONS(2124), 1,
      anon_sym_struct,
    ACTIONS(2127), 1,
      anon_sym_union,
    ACTIONS(2130), 1,
      anon_sym_enum,
    ACTIONS(2136), 1,
      sym_hll_primitive_type,
    ACTIONS(2139), 1,
      sym__blank,
    STATE(800), 1,
      aux_sym_block_repeat1,
    STATE(1743), 1,
      aux_sym_hll_sized_type_specifier_repeat1,
    ACTIONS(2133), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(1530), 6,
      sym__hll_type_specifier,
      sym_hll_struct_specifier,
      sym_hll_union_specifier,
      sym_hll_enum_specifier,
      sym_hll_sized_type_specifier,
      sym__hll_type_identifier,
    ACTIONS(2122), 7,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BSLASH,
      anon_sym_sizeof,
      anon_sym_const,
      anon_sym_volatile,
      aux_sym_symbol_token2,
    ACTIONS(2120), 19,
      sym__hll_number_literal_pre_hook,
      anon_sym_LPAREN,
      anon_sym_TILDE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      aux_sym_symbol_token1,
  [47007] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(579), 1,
      aux_sym_symbol_token1,
    ACTIONS(581), 1,
      aux_sym_symbol_token2,
    ACTIONS(583), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(619), 1,
      sym_identifier,
    ACTIONS(621), 1,
      anon_sym_LPAREN,
    ACTIONS(629), 1,
      anon_sym_BSLASH,
    ACTIONS(631), 1,
      anon_sym_sizeof,
    ACTIONS(2142), 1,
      anon_sym_COLON,
    STATE(842), 1,
      sym_trace32_hll_variable,
    STATE(1596), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(448), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(623), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(625), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(627), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(575), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(577), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(841), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1380), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [47091] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(579), 1,
      aux_sym_symbol_token1,
    ACTIONS(581), 1,
      aux_sym_symbol_token2,
    ACTIONS(583), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(619), 1,
      sym_identifier,
    ACTIONS(621), 1,
      anon_sym_LPAREN,
    ACTIONS(629), 1,
      anon_sym_BSLASH,
    ACTIONS(631), 1,
      anon_sym_sizeof,
    ACTIONS(2144), 1,
      anon_sym_COLON,
    STATE(842), 1,
      sym_trace32_hll_variable,
    STATE(1596), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(448), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(623), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(625), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(627), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(575), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(577), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(841), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1367), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [47175] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(559), 1,
      sym_identifier,
    ACTIONS(561), 1,
      anon_sym_LPAREN,
    ACTIONS(571), 1,
      anon_sym_BSLASH,
    ACTIONS(573), 1,
      anon_sym_sizeof,
    ACTIONS(579), 1,
      aux_sym_symbol_token1,
    ACTIONS(581), 1,
      aux_sym_symbol_token2,
    ACTIONS(583), 1,
      sym__hll_number_literal_pre_hook,
    STATE(509), 1,
      aux_sym__hll_var_command_argument_list_default_format_repeat1,
    STATE(812), 1,
      sym_trace32_hll_variable,
    STATE(1655), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(563), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(565), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(567), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(569), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(575), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(577), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(811), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(957), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [47259] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(559), 1,
      sym_identifier,
    ACTIONS(561), 1,
      anon_sym_LPAREN,
    ACTIONS(571), 1,
      anon_sym_BSLASH,
    ACTIONS(573), 1,
      anon_sym_sizeof,
    ACTIONS(579), 1,
      aux_sym_symbol_token1,
    ACTIONS(581), 1,
      aux_sym_symbol_token2,
    ACTIONS(583), 1,
      sym__hll_number_literal_pre_hook,
    STATE(509), 1,
      aux_sym__hll_var_command_argument_list_default_format_repeat1,
    STATE(812), 1,
      sym_trace32_hll_variable,
    STATE(1655), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(563), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(565), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(567), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(569), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(575), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(577), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(811), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(954), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [47343] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(579), 1,
      aux_sym_symbol_token1,
    ACTIONS(581), 1,
      aux_sym_symbol_token2,
    ACTIONS(583), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(619), 1,
      sym_identifier,
    ACTIONS(621), 1,
      anon_sym_LPAREN,
    ACTIONS(629), 1,
      anon_sym_BSLASH,
    ACTIONS(631), 1,
      anon_sym_sizeof,
    ACTIONS(2146), 1,
      anon_sym_COLON,
    STATE(842), 1,
      sym_trace32_hll_variable,
    STATE(1596), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(448), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(623), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(625), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(627), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(575), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(577), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(841), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1381), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [47427] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(579), 1,
      aux_sym_symbol_token1,
    ACTIONS(581), 1,
      aux_sym_symbol_token2,
    ACTIONS(583), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(619), 1,
      sym_identifier,
    ACTIONS(621), 1,
      anon_sym_LPAREN,
    ACTIONS(629), 1,
      anon_sym_BSLASH,
    ACTIONS(631), 1,
      anon_sym_sizeof,
    ACTIONS(2148), 1,
      anon_sym_COLON,
    STATE(842), 1,
      sym_trace32_hll_variable,
    STATE(1596), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(448), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(623), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(625), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(627), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(575), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(577), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(841), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1382), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [47511] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(579), 1,
      aux_sym_symbol_token1,
    ACTIONS(581), 1,
      aux_sym_symbol_token2,
    ACTIONS(583), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(619), 1,
      sym_identifier,
    ACTIONS(621), 1,
      anon_sym_LPAREN,
    ACTIONS(629), 1,
      anon_sym_BSLASH,
    ACTIONS(631), 1,
      anon_sym_sizeof,
    ACTIONS(2150), 1,
      anon_sym_COLON,
    STATE(842), 1,
      sym_trace32_hll_variable,
    STATE(1596), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(448), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(623), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(625), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(627), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(575), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(577), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(841), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1385), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [47595] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(579), 1,
      aux_sym_symbol_token1,
    ACTIONS(581), 1,
      aux_sym_symbol_token2,
    ACTIONS(583), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(619), 1,
      sym_identifier,
    ACTIONS(621), 1,
      anon_sym_LPAREN,
    ACTIONS(629), 1,
      anon_sym_BSLASH,
    ACTIONS(631), 1,
      anon_sym_sizeof,
    ACTIONS(2152), 1,
      anon_sym_COLON,
    STATE(842), 1,
      sym_trace32_hll_variable,
    STATE(1596), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(448), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(623), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(625), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(627), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(575), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(577), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(841), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1387), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [47679] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2154), 1,
      sym_identifier,
    ACTIONS(2157), 1,
      anon_sym_LPAREN,
    ACTIONS(2172), 1,
      anon_sym_BSLASH,
    ACTIONS(2175), 1,
      anon_sym_sizeof,
    ACTIONS(2184), 1,
      aux_sym_symbol_token1,
    ACTIONS(2187), 1,
      aux_sym_symbol_token2,
    ACTIONS(2190), 1,
      sym__hll_number_literal_pre_hook,
    STATE(509), 1,
      aux_sym__hll_var_command_argument_list_default_format_repeat1,
    STATE(885), 1,
      sym_trace32_hll_variable,
    STATE(1605), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(2160), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2163), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(2166), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2169), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(2178), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(2181), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(884), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1311), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [47763] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(559), 1,
      sym_identifier,
    ACTIONS(561), 1,
      anon_sym_LPAREN,
    ACTIONS(571), 1,
      anon_sym_BSLASH,
    ACTIONS(573), 1,
      anon_sym_sizeof,
    ACTIONS(579), 1,
      aux_sym_symbol_token1,
    ACTIONS(581), 1,
      aux_sym_symbol_token2,
    ACTIONS(583), 1,
      sym__hll_number_literal_pre_hook,
    STATE(509), 1,
      aux_sym__hll_var_command_argument_list_default_format_repeat1,
    STATE(812), 1,
      sym_trace32_hll_variable,
    STATE(1655), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(563), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(565), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(567), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(569), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(575), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(577), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(811), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(955), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [47847] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(440), 1,
      anon_sym_LPAREN,
    ACTIONS(450), 1,
      anon_sym_BSLASH,
    ACTIONS(452), 1,
      anon_sym_sizeof,
    ACTIONS(470), 1,
      aux_sym_symbol_token1,
    ACTIONS(472), 1,
      aux_sym_symbol_token2,
    ACTIONS(476), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(547), 1,
      sym_identifier,
    STATE(799), 1,
      sym_trace32_hll_variable,
    STATE(1652), 1,
      sym__hll_assignment_left_expression,
    STATE(2432), 1,
      sym_hll_range_expression,
    ACTIONS(442), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(444), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(446), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(448), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(454), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(456), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(798), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1096), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [47931] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(579), 1,
      aux_sym_symbol_token1,
    ACTIONS(581), 1,
      aux_sym_symbol_token2,
    ACTIONS(583), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(619), 1,
      sym_identifier,
    ACTIONS(621), 1,
      anon_sym_LPAREN,
    ACTIONS(629), 1,
      anon_sym_BSLASH,
    ACTIONS(631), 1,
      anon_sym_sizeof,
    ACTIONS(2193), 1,
      anon_sym_COLON,
    STATE(842), 1,
      sym_trace32_hll_variable,
    STATE(1596), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(448), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(623), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(625), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(627), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(575), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(577), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(841), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1390), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [48015] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(579), 1,
      aux_sym_symbol_token1,
    ACTIONS(581), 1,
      aux_sym_symbol_token2,
    ACTIONS(583), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(619), 1,
      sym_identifier,
    ACTIONS(621), 1,
      anon_sym_LPAREN,
    ACTIONS(629), 1,
      anon_sym_BSLASH,
    ACTIONS(631), 1,
      anon_sym_sizeof,
    ACTIONS(2195), 1,
      anon_sym_COLON,
    STATE(842), 1,
      sym_trace32_hll_variable,
    STATE(1596), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(448), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(623), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(625), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(627), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(575), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(577), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(841), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1391), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [48099] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(633), 1,
      sym_identifier,
    ACTIONS(635), 1,
      anon_sym_LPAREN,
    ACTIONS(645), 1,
      anon_sym_BSLASH,
    ACTIONS(647), 1,
      anon_sym_sizeof,
    ACTIONS(653), 1,
      aux_sym_symbol_token1,
    ACTIONS(655), 1,
      aux_sym_symbol_token2,
    ACTIONS(657), 1,
      sym__hll_number_literal_pre_hook,
    STATE(509), 1,
      aux_sym__hll_var_command_argument_list_default_format_repeat1,
    STATE(890), 1,
      sym_trace32_hll_variable,
    STATE(1609), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(637), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(639), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(641), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(643), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(649), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(651), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(889), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1113), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [48183] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(440), 1,
      anon_sym_LPAREN,
    ACTIONS(450), 1,
      anon_sym_BSLASH,
    ACTIONS(452), 1,
      anon_sym_sizeof,
    ACTIONS(470), 1,
      aux_sym_symbol_token1,
    ACTIONS(472), 1,
      aux_sym_symbol_token2,
    ACTIONS(476), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(547), 1,
      sym_identifier,
    STATE(799), 1,
      sym_trace32_hll_variable,
    STATE(1652), 1,
      sym__hll_assignment_left_expression,
    STATE(2286), 1,
      sym_hll_comma_expression,
    ACTIONS(442), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(444), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(446), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(448), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(454), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(456), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(798), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1148), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [48267] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(559), 1,
      sym_identifier,
    ACTIONS(561), 1,
      anon_sym_LPAREN,
    ACTIONS(571), 1,
      anon_sym_BSLASH,
    ACTIONS(573), 1,
      anon_sym_sizeof,
    ACTIONS(579), 1,
      aux_sym_symbol_token1,
    ACTIONS(581), 1,
      aux_sym_symbol_token2,
    ACTIONS(583), 1,
      sym__hll_number_literal_pre_hook,
    STATE(509), 1,
      aux_sym__hll_var_command_argument_list_default_format_repeat1,
    STATE(812), 1,
      sym_trace32_hll_variable,
    STATE(1655), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(563), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(565), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(567), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(569), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(575), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(577), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(811), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(960), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [48351] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(368), 1,
      sym_identifier,
    ACTIONS(370), 1,
      anon_sym_LPAREN,
    ACTIONS(380), 1,
      anon_sym_BSLASH,
    ACTIONS(382), 1,
      anon_sym_sizeof,
    ACTIONS(388), 1,
      aux_sym_symbol_token1,
    ACTIONS(390), 1,
      aux_sym_symbol_token2,
    ACTIONS(392), 1,
      sym__hll_number_literal_pre_hook,
    STATE(900), 1,
      sym_trace32_hll_variable,
    STATE(1580), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(372), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(374), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(376), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(821), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(384), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(386), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(898), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(827), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [48432] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(645), 1,
      anon_sym_BSLASH,
    ACTIONS(653), 1,
      aux_sym_symbol_token1,
    ACTIONS(655), 1,
      aux_sym_symbol_token2,
    ACTIONS(657), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(717), 1,
      sym_identifier,
    ACTIONS(719), 1,
      anon_sym_LPAREN,
    ACTIONS(727), 1,
      anon_sym_sizeof,
    STATE(885), 1,
      sym_trace32_hll_variable,
    STATE(1605), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(643), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(721), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(723), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(725), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(649), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(651), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(884), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1280), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [48513] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(645), 1,
      anon_sym_BSLASH,
    ACTIONS(653), 1,
      aux_sym_symbol_token1,
    ACTIONS(655), 1,
      aux_sym_symbol_token2,
    ACTIONS(657), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(717), 1,
      sym_identifier,
    ACTIONS(719), 1,
      anon_sym_LPAREN,
    ACTIONS(727), 1,
      anon_sym_sizeof,
    STATE(885), 1,
      sym_trace32_hll_variable,
    STATE(1605), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(643), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(721), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(723), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(725), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(649), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(651), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(884), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1247), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [48594] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(645), 1,
      anon_sym_BSLASH,
    ACTIONS(653), 1,
      aux_sym_symbol_token1,
    ACTIONS(655), 1,
      aux_sym_symbol_token2,
    ACTIONS(657), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(717), 1,
      sym_identifier,
    ACTIONS(719), 1,
      anon_sym_LPAREN,
    ACTIONS(727), 1,
      anon_sym_sizeof,
    STATE(885), 1,
      sym_trace32_hll_variable,
    STATE(1605), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(643), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(721), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(723), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(725), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(649), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(651), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(884), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1282), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [48675] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(645), 1,
      anon_sym_BSLASH,
    ACTIONS(653), 1,
      aux_sym_symbol_token1,
    ACTIONS(655), 1,
      aux_sym_symbol_token2,
    ACTIONS(657), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(717), 1,
      sym_identifier,
    ACTIONS(719), 1,
      anon_sym_LPAREN,
    ACTIONS(727), 1,
      anon_sym_sizeof,
    STATE(885), 1,
      sym_trace32_hll_variable,
    STATE(1605), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(643), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(721), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(723), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(725), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(649), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(651), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(884), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1255), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [48756] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(645), 1,
      anon_sym_BSLASH,
    ACTIONS(653), 1,
      aux_sym_symbol_token1,
    ACTIONS(655), 1,
      aux_sym_symbol_token2,
    ACTIONS(657), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(717), 1,
      sym_identifier,
    ACTIONS(719), 1,
      anon_sym_LPAREN,
    ACTIONS(727), 1,
      anon_sym_sizeof,
    STATE(885), 1,
      sym_trace32_hll_variable,
    STATE(1605), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(643), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(721), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(723), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(725), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(649), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(651), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(884), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1256), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [48837] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(645), 1,
      anon_sym_BSLASH,
    ACTIONS(653), 1,
      aux_sym_symbol_token1,
    ACTIONS(655), 1,
      aux_sym_symbol_token2,
    ACTIONS(657), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(717), 1,
      sym_identifier,
    ACTIONS(719), 1,
      anon_sym_LPAREN,
    ACTIONS(727), 1,
      anon_sym_sizeof,
    STATE(885), 1,
      sym_trace32_hll_variable,
    STATE(1605), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(643), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(721), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(723), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(725), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(649), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(651), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(884), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1286), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [48918] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(645), 1,
      anon_sym_BSLASH,
    ACTIONS(653), 1,
      aux_sym_symbol_token1,
    ACTIONS(655), 1,
      aux_sym_symbol_token2,
    ACTIONS(657), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(717), 1,
      sym_identifier,
    ACTIONS(719), 1,
      anon_sym_LPAREN,
    ACTIONS(727), 1,
      anon_sym_sizeof,
    STATE(885), 1,
      sym_trace32_hll_variable,
    STATE(1605), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(643), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(721), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(723), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(725), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(649), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(651), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(884), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1259), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [48999] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2199), 1,
      anon_sym_LPAREN,
    ACTIONS(2205), 1,
      anon_sym_DOT,
    ACTIONS(2207), 1,
      anon_sym_DASH_GT,
    ACTIONS(2209), 1,
      anon_sym_LBRACK,
    STATE(752), 1,
      sym_hll_argument_list,
    ACTIONS(2203), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2201), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
    ACTIONS(2197), 23,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [49062] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(579), 1,
      aux_sym_symbol_token1,
    ACTIONS(581), 1,
      aux_sym_symbol_token2,
    ACTIONS(583), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(811), 1,
      sym_identifier,
    ACTIONS(813), 1,
      anon_sym_LPAREN,
    ACTIONS(823), 1,
      anon_sym_BSLASH,
    ACTIONS(825), 1,
      anon_sym_sizeof,
    STATE(916), 1,
      sym_trace32_hll_variable,
    STATE(1587), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(815), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(817), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(819), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(821), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(575), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(577), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(915), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1318), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [49143] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(633), 1,
      sym_identifier,
    ACTIONS(635), 1,
      anon_sym_LPAREN,
    ACTIONS(645), 1,
      anon_sym_BSLASH,
    ACTIONS(647), 1,
      anon_sym_sizeof,
    ACTIONS(653), 1,
      aux_sym_symbol_token1,
    ACTIONS(655), 1,
      aux_sym_symbol_token2,
    ACTIONS(657), 1,
      sym__hll_number_literal_pre_hook,
    STATE(890), 1,
      sym_trace32_hll_variable,
    STATE(1609), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(637), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(639), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(641), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(643), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(649), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(651), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(889), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1143), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [49224] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(633), 1,
      sym_identifier,
    ACTIONS(635), 1,
      anon_sym_LPAREN,
    ACTIONS(645), 1,
      anon_sym_BSLASH,
    ACTIONS(647), 1,
      anon_sym_sizeof,
    ACTIONS(653), 1,
      aux_sym_symbol_token1,
    ACTIONS(655), 1,
      aux_sym_symbol_token2,
    ACTIONS(657), 1,
      sym__hll_number_literal_pre_hook,
    STATE(890), 1,
      sym_trace32_hll_variable,
    STATE(1609), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(637), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(639), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(641), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(643), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(649), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(651), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(889), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1145), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [49305] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(633), 1,
      sym_identifier,
    ACTIONS(635), 1,
      anon_sym_LPAREN,
    ACTIONS(645), 1,
      anon_sym_BSLASH,
    ACTIONS(647), 1,
      anon_sym_sizeof,
    ACTIONS(653), 1,
      aux_sym_symbol_token1,
    ACTIONS(655), 1,
      aux_sym_symbol_token2,
    ACTIONS(657), 1,
      sym__hll_number_literal_pre_hook,
    STATE(890), 1,
      sym_trace32_hll_variable,
    STATE(1609), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(637), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(639), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(641), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(643), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(649), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(651), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(889), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1147), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [49386] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(633), 1,
      sym_identifier,
    ACTIONS(635), 1,
      anon_sym_LPAREN,
    ACTIONS(645), 1,
      anon_sym_BSLASH,
    ACTIONS(647), 1,
      anon_sym_sizeof,
    ACTIONS(653), 1,
      aux_sym_symbol_token1,
    ACTIONS(655), 1,
      aux_sym_symbol_token2,
    ACTIONS(657), 1,
      sym__hll_number_literal_pre_hook,
    STATE(890), 1,
      sym_trace32_hll_variable,
    STATE(1609), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(637), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(639), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(641), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(643), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(649), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(651), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(889), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1153), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [49467] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(633), 1,
      sym_identifier,
    ACTIONS(635), 1,
      anon_sym_LPAREN,
    ACTIONS(645), 1,
      anon_sym_BSLASH,
    ACTIONS(647), 1,
      anon_sym_sizeof,
    ACTIONS(653), 1,
      aux_sym_symbol_token1,
    ACTIONS(655), 1,
      aux_sym_symbol_token2,
    ACTIONS(657), 1,
      sym__hll_number_literal_pre_hook,
    STATE(890), 1,
      sym_trace32_hll_variable,
    STATE(1609), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(637), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(639), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(641), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(643), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(649), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(651), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(889), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1154), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [49548] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(633), 1,
      sym_identifier,
    ACTIONS(635), 1,
      anon_sym_LPAREN,
    ACTIONS(645), 1,
      anon_sym_BSLASH,
    ACTIONS(647), 1,
      anon_sym_sizeof,
    ACTIONS(653), 1,
      aux_sym_symbol_token1,
    ACTIONS(655), 1,
      aux_sym_symbol_token2,
    ACTIONS(657), 1,
      sym__hll_number_literal_pre_hook,
    STATE(890), 1,
      sym_trace32_hll_variable,
    STATE(1609), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(637), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(639), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(641), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(643), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(649), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(651), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(889), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1155), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [49629] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(633), 1,
      sym_identifier,
    ACTIONS(635), 1,
      anon_sym_LPAREN,
    ACTIONS(645), 1,
      anon_sym_BSLASH,
    ACTIONS(647), 1,
      anon_sym_sizeof,
    ACTIONS(653), 1,
      aux_sym_symbol_token1,
    ACTIONS(655), 1,
      aux_sym_symbol_token2,
    ACTIONS(657), 1,
      sym__hll_number_literal_pre_hook,
    STATE(890), 1,
      sym_trace32_hll_variable,
    STATE(1609), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(637), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(639), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(641), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(643), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(649), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(651), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(889), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1158), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [49710] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(633), 1,
      sym_identifier,
    ACTIONS(635), 1,
      anon_sym_LPAREN,
    ACTIONS(645), 1,
      anon_sym_BSLASH,
    ACTIONS(647), 1,
      anon_sym_sizeof,
    ACTIONS(653), 1,
      aux_sym_symbol_token1,
    ACTIONS(655), 1,
      aux_sym_symbol_token2,
    ACTIONS(657), 1,
      sym__hll_number_literal_pre_hook,
    STATE(890), 1,
      sym_trace32_hll_variable,
    STATE(1609), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(637), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(639), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(641), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(643), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(649), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(651), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(889), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1232), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [49791] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(633), 1,
      sym_identifier,
    ACTIONS(635), 1,
      anon_sym_LPAREN,
    ACTIONS(645), 1,
      anon_sym_BSLASH,
    ACTIONS(647), 1,
      anon_sym_sizeof,
    ACTIONS(653), 1,
      aux_sym_symbol_token1,
    ACTIONS(655), 1,
      aux_sym_symbol_token2,
    ACTIONS(657), 1,
      sym__hll_number_literal_pre_hook,
    STATE(890), 1,
      sym_trace32_hll_variable,
    STATE(1609), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(637), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(639), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(641), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(643), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(649), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(651), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(889), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1159), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [49872] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(633), 1,
      sym_identifier,
    ACTIONS(635), 1,
      anon_sym_LPAREN,
    ACTIONS(645), 1,
      anon_sym_BSLASH,
    ACTIONS(647), 1,
      anon_sym_sizeof,
    ACTIONS(653), 1,
      aux_sym_symbol_token1,
    ACTIONS(655), 1,
      aux_sym_symbol_token2,
    ACTIONS(657), 1,
      sym__hll_number_literal_pre_hook,
    STATE(890), 1,
      sym_trace32_hll_variable,
    STATE(1609), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(637), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(639), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(641), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(643), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(649), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(651), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(889), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1162), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [49953] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(633), 1,
      sym_identifier,
    ACTIONS(635), 1,
      anon_sym_LPAREN,
    ACTIONS(645), 1,
      anon_sym_BSLASH,
    ACTIONS(647), 1,
      anon_sym_sizeof,
    ACTIONS(653), 1,
      aux_sym_symbol_token1,
    ACTIONS(655), 1,
      aux_sym_symbol_token2,
    ACTIONS(657), 1,
      sym__hll_number_literal_pre_hook,
    STATE(890), 1,
      sym_trace32_hll_variable,
    STATE(1609), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(637), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(639), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(641), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(643), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(649), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(651), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(889), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1247), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [50034] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(633), 1,
      sym_identifier,
    ACTIONS(635), 1,
      anon_sym_LPAREN,
    ACTIONS(645), 1,
      anon_sym_BSLASH,
    ACTIONS(647), 1,
      anon_sym_sizeof,
    ACTIONS(653), 1,
      aux_sym_symbol_token1,
    ACTIONS(655), 1,
      aux_sym_symbol_token2,
    ACTIONS(657), 1,
      sym__hll_number_literal_pre_hook,
    STATE(890), 1,
      sym_trace32_hll_variable,
    STATE(1609), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(637), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(639), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(641), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(643), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(649), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(651), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(889), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1184), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [50115] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(342), 1,
      sym_identifier,
    ACTIONS(344), 1,
      anon_sym_LPAREN,
    ACTIONS(354), 1,
      anon_sym_BSLASH,
    ACTIONS(356), 1,
      anon_sym_sizeof,
    ACTIONS(362), 1,
      aux_sym_symbol_token1,
    ACTIONS(364), 1,
      aux_sym_symbol_token2,
    ACTIONS(366), 1,
      sym__hll_number_literal_pre_hook,
    STATE(807), 1,
      sym_trace32_hll_variable,
    STATE(1593), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(346), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(348), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(350), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(569), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(358), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(360), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(806), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(760), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [50196] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(633), 1,
      sym_identifier,
    ACTIONS(635), 1,
      anon_sym_LPAREN,
    ACTIONS(645), 1,
      anon_sym_BSLASH,
    ACTIONS(647), 1,
      anon_sym_sizeof,
    ACTIONS(653), 1,
      aux_sym_symbol_token1,
    ACTIONS(655), 1,
      aux_sym_symbol_token2,
    ACTIONS(657), 1,
      sym__hll_number_literal_pre_hook,
    STATE(890), 1,
      sym_trace32_hll_variable,
    STATE(1609), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(637), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(639), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(641), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(643), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(649), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(651), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(889), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1255), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [50277] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(633), 1,
      sym_identifier,
    ACTIONS(635), 1,
      anon_sym_LPAREN,
    ACTIONS(645), 1,
      anon_sym_BSLASH,
    ACTIONS(647), 1,
      anon_sym_sizeof,
    ACTIONS(653), 1,
      aux_sym_symbol_token1,
    ACTIONS(655), 1,
      aux_sym_symbol_token2,
    ACTIONS(657), 1,
      sym__hll_number_literal_pre_hook,
    STATE(890), 1,
      sym_trace32_hll_variable,
    STATE(1609), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(637), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(639), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(641), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(643), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(649), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(651), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(889), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1256), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [50358] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(342), 1,
      sym_identifier,
    ACTIONS(344), 1,
      anon_sym_LPAREN,
    ACTIONS(354), 1,
      anon_sym_BSLASH,
    ACTIONS(356), 1,
      anon_sym_sizeof,
    ACTIONS(362), 1,
      aux_sym_symbol_token1,
    ACTIONS(364), 1,
      aux_sym_symbol_token2,
    ACTIONS(366), 1,
      sym__hll_number_literal_pre_hook,
    STATE(807), 1,
      sym_trace32_hll_variable,
    STATE(1593), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(346), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(348), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(350), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(569), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(358), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(360), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(806), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(767), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [50439] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(633), 1,
      sym_identifier,
    ACTIONS(635), 1,
      anon_sym_LPAREN,
    ACTIONS(645), 1,
      anon_sym_BSLASH,
    ACTIONS(647), 1,
      anon_sym_sizeof,
    ACTIONS(653), 1,
      aux_sym_symbol_token1,
    ACTIONS(655), 1,
      aux_sym_symbol_token2,
    ACTIONS(657), 1,
      sym__hll_number_literal_pre_hook,
    STATE(890), 1,
      sym_trace32_hll_variable,
    STATE(1609), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(637), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(639), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(641), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(643), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(649), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(651), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(889), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1193), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [50520] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(633), 1,
      sym_identifier,
    ACTIONS(635), 1,
      anon_sym_LPAREN,
    ACTIONS(645), 1,
      anon_sym_BSLASH,
    ACTIONS(647), 1,
      anon_sym_sizeof,
    ACTIONS(653), 1,
      aux_sym_symbol_token1,
    ACTIONS(655), 1,
      aux_sym_symbol_token2,
    ACTIONS(657), 1,
      sym__hll_number_literal_pre_hook,
    STATE(890), 1,
      sym_trace32_hll_variable,
    STATE(1609), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(637), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(639), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(641), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(643), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(649), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(651), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(889), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1259), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [50601] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(579), 1,
      aux_sym_symbol_token1,
    ACTIONS(581), 1,
      aux_sym_symbol_token2,
    ACTIONS(583), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(811), 1,
      sym_identifier,
    ACTIONS(823), 1,
      anon_sym_BSLASH,
    ACTIONS(825), 1,
      anon_sym_sizeof,
    ACTIONS(2211), 1,
      anon_sym_LPAREN,
    STATE(916), 1,
      sym_trace32_hll_variable,
    STATE(1587), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(815), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(817), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(819), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(821), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(575), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(577), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(915), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1321), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [50682] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2199), 1,
      anon_sym_LPAREN,
    ACTIONS(2205), 1,
      anon_sym_DOT,
    ACTIONS(2207), 1,
      anon_sym_DASH_GT,
    ACTIONS(2209), 1,
      anon_sym_LBRACK,
    STATE(752), 1,
      sym_hll_argument_list,
    ACTIONS(2203), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2215), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
    ACTIONS(2213), 23,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [50745] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(579), 1,
      aux_sym_symbol_token1,
    ACTIONS(581), 1,
      aux_sym_symbol_token2,
    ACTIONS(583), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(811), 1,
      sym_identifier,
    ACTIONS(813), 1,
      anon_sym_LPAREN,
    ACTIONS(823), 1,
      anon_sym_BSLASH,
    ACTIONS(825), 1,
      anon_sym_sizeof,
    STATE(916), 1,
      sym_trace32_hll_variable,
    STATE(1587), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(815), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(817), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(819), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(821), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(575), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(577), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(915), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1351), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [50826] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1987), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_DOT,
    ACTIONS(1989), 29,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym_symbol_token3,
      sym__blank,
  [50877] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(394), 1,
      sym_identifier,
    ACTIONS(396), 1,
      anon_sym_LPAREN,
    ACTIONS(406), 1,
      anon_sym_BSLASH,
    ACTIONS(408), 1,
      anon_sym_sizeof,
    ACTIONS(414), 1,
      aux_sym_symbol_token1,
    ACTIONS(416), 1,
      aux_sym_symbol_token2,
    ACTIONS(418), 1,
      sym__hll_number_literal_pre_hook,
    STATE(893), 1,
      sym_trace32_hll_variable,
    STATE(1615), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(398), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(400), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(402), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(643), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(410), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(412), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(892), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(852), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [50958] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(394), 1,
      sym_identifier,
    ACTIONS(396), 1,
      anon_sym_LPAREN,
    ACTIONS(406), 1,
      anon_sym_BSLASH,
    ACTIONS(408), 1,
      anon_sym_sizeof,
    ACTIONS(414), 1,
      aux_sym_symbol_token1,
    ACTIONS(416), 1,
      aux_sym_symbol_token2,
    ACTIONS(418), 1,
      sym__hll_number_literal_pre_hook,
    STATE(893), 1,
      sym_trace32_hll_variable,
    STATE(1615), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(398), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(400), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(402), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(643), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(410), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(412), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(892), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(853), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [51039] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(394), 1,
      sym_identifier,
    ACTIONS(396), 1,
      anon_sym_LPAREN,
    ACTIONS(406), 1,
      anon_sym_BSLASH,
    ACTIONS(408), 1,
      anon_sym_sizeof,
    ACTIONS(414), 1,
      aux_sym_symbol_token1,
    ACTIONS(416), 1,
      aux_sym_symbol_token2,
    ACTIONS(418), 1,
      sym__hll_number_literal_pre_hook,
    STATE(893), 1,
      sym_trace32_hll_variable,
    STATE(1615), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(398), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(400), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(402), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(643), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(410), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(412), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(892), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(854), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [51120] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(394), 1,
      sym_identifier,
    ACTIONS(396), 1,
      anon_sym_LPAREN,
    ACTIONS(406), 1,
      anon_sym_BSLASH,
    ACTIONS(408), 1,
      anon_sym_sizeof,
    ACTIONS(414), 1,
      aux_sym_symbol_token1,
    ACTIONS(416), 1,
      aux_sym_symbol_token2,
    ACTIONS(418), 1,
      sym__hll_number_literal_pre_hook,
    STATE(893), 1,
      sym_trace32_hll_variable,
    STATE(1615), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(398), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(400), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(402), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(643), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(410), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(412), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(892), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(855), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [51201] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(394), 1,
      sym_identifier,
    ACTIONS(396), 1,
      anon_sym_LPAREN,
    ACTIONS(406), 1,
      anon_sym_BSLASH,
    ACTIONS(408), 1,
      anon_sym_sizeof,
    ACTIONS(414), 1,
      aux_sym_symbol_token1,
    ACTIONS(416), 1,
      aux_sym_symbol_token2,
    ACTIONS(418), 1,
      sym__hll_number_literal_pre_hook,
    STATE(893), 1,
      sym_trace32_hll_variable,
    STATE(1615), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(398), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(400), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(402), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(643), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(410), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(412), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(892), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(856), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [51282] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(394), 1,
      sym_identifier,
    ACTIONS(396), 1,
      anon_sym_LPAREN,
    ACTIONS(406), 1,
      anon_sym_BSLASH,
    ACTIONS(408), 1,
      anon_sym_sizeof,
    ACTIONS(414), 1,
      aux_sym_symbol_token1,
    ACTIONS(416), 1,
      aux_sym_symbol_token2,
    ACTIONS(418), 1,
      sym__hll_number_literal_pre_hook,
    STATE(893), 1,
      sym_trace32_hll_variable,
    STATE(1615), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(398), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(400), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(402), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(643), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(410), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(412), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(892), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(857), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [51363] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(394), 1,
      sym_identifier,
    ACTIONS(396), 1,
      anon_sym_LPAREN,
    ACTIONS(406), 1,
      anon_sym_BSLASH,
    ACTIONS(408), 1,
      anon_sym_sizeof,
    ACTIONS(414), 1,
      aux_sym_symbol_token1,
    ACTIONS(416), 1,
      aux_sym_symbol_token2,
    ACTIONS(418), 1,
      sym__hll_number_literal_pre_hook,
    STATE(893), 1,
      sym_trace32_hll_variable,
    STATE(1615), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(398), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(400), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(402), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(643), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(410), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(412), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(892), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(858), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [51444] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(394), 1,
      sym_identifier,
    ACTIONS(396), 1,
      anon_sym_LPAREN,
    ACTIONS(406), 1,
      anon_sym_BSLASH,
    ACTIONS(408), 1,
      anon_sym_sizeof,
    ACTIONS(414), 1,
      aux_sym_symbol_token1,
    ACTIONS(416), 1,
      aux_sym_symbol_token2,
    ACTIONS(418), 1,
      sym__hll_number_literal_pre_hook,
    STATE(893), 1,
      sym_trace32_hll_variable,
    STATE(1615), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(398), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(400), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(402), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(643), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(410), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(412), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(892), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(847), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [51525] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(394), 1,
      sym_identifier,
    ACTIONS(396), 1,
      anon_sym_LPAREN,
    ACTIONS(406), 1,
      anon_sym_BSLASH,
    ACTIONS(408), 1,
      anon_sym_sizeof,
    ACTIONS(414), 1,
      aux_sym_symbol_token1,
    ACTIONS(416), 1,
      aux_sym_symbol_token2,
    ACTIONS(418), 1,
      sym__hll_number_literal_pre_hook,
    STATE(893), 1,
      sym_trace32_hll_variable,
    STATE(1615), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(398), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(400), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(402), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(643), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(410), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(412), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(892), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(859), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [51606] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(394), 1,
      sym_identifier,
    ACTIONS(396), 1,
      anon_sym_LPAREN,
    ACTIONS(406), 1,
      anon_sym_BSLASH,
    ACTIONS(408), 1,
      anon_sym_sizeof,
    ACTIONS(414), 1,
      aux_sym_symbol_token1,
    ACTIONS(416), 1,
      aux_sym_symbol_token2,
    ACTIONS(418), 1,
      sym__hll_number_literal_pre_hook,
    STATE(893), 1,
      sym_trace32_hll_variable,
    STATE(1615), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(398), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(400), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(402), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(643), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(410), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(412), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(892), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(860), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [51687] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(342), 1,
      sym_identifier,
    ACTIONS(344), 1,
      anon_sym_LPAREN,
    ACTIONS(354), 1,
      anon_sym_BSLASH,
    ACTIONS(356), 1,
      anon_sym_sizeof,
    ACTIONS(362), 1,
      aux_sym_symbol_token1,
    ACTIONS(364), 1,
      aux_sym_symbol_token2,
    ACTIONS(366), 1,
      sym__hll_number_literal_pre_hook,
    STATE(807), 1,
      sym_trace32_hll_variable,
    STATE(1593), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(346), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(348), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(350), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(569), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(358), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(360), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(806), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(775), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [51768] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2011), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_DOT,
    ACTIONS(2013), 29,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym_symbol_token3,
      sym__blank,
  [51819] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(394), 1,
      sym_identifier,
    ACTIONS(396), 1,
      anon_sym_LPAREN,
    ACTIONS(406), 1,
      anon_sym_BSLASH,
    ACTIONS(408), 1,
      anon_sym_sizeof,
    ACTIONS(414), 1,
      aux_sym_symbol_token1,
    ACTIONS(416), 1,
      aux_sym_symbol_token2,
    ACTIONS(418), 1,
      sym__hll_number_literal_pre_hook,
    STATE(893), 1,
      sym_trace32_hll_variable,
    STATE(1615), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(398), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(400), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(402), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(643), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(410), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(412), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(892), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(848), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [51900] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(394), 1,
      sym_identifier,
    ACTIONS(396), 1,
      anon_sym_LPAREN,
    ACTIONS(406), 1,
      anon_sym_BSLASH,
    ACTIONS(408), 1,
      anon_sym_sizeof,
    ACTIONS(414), 1,
      aux_sym_symbol_token1,
    ACTIONS(416), 1,
      aux_sym_symbol_token2,
    ACTIONS(418), 1,
      sym__hll_number_literal_pre_hook,
    STATE(893), 1,
      sym_trace32_hll_variable,
    STATE(1615), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(398), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(400), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(402), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(643), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(410), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(412), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(892), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(862), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [51981] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(342), 1,
      sym_identifier,
    ACTIONS(344), 1,
      anon_sym_LPAREN,
    ACTIONS(354), 1,
      anon_sym_BSLASH,
    ACTIONS(356), 1,
      anon_sym_sizeof,
    ACTIONS(362), 1,
      aux_sym_symbol_token1,
    ACTIONS(364), 1,
      aux_sym_symbol_token2,
    ACTIONS(366), 1,
      sym__hll_number_literal_pre_hook,
    STATE(807), 1,
      sym_trace32_hll_variable,
    STATE(1593), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(346), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(348), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(350), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(569), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(358), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(360), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(806), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(776), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [52062] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(342), 1,
      sym_identifier,
    ACTIONS(344), 1,
      anon_sym_LPAREN,
    ACTIONS(354), 1,
      anon_sym_BSLASH,
    ACTIONS(356), 1,
      anon_sym_sizeof,
    ACTIONS(362), 1,
      aux_sym_symbol_token1,
    ACTIONS(364), 1,
      aux_sym_symbol_token2,
    ACTIONS(366), 1,
      sym__hll_number_literal_pre_hook,
    STATE(807), 1,
      sym_trace32_hll_variable,
    STATE(1593), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(346), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(348), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(350), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(569), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(358), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(360), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(806), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(748), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [52143] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(394), 1,
      sym_identifier,
    ACTIONS(396), 1,
      anon_sym_LPAREN,
    ACTIONS(406), 1,
      anon_sym_BSLASH,
    ACTIONS(408), 1,
      anon_sym_sizeof,
    ACTIONS(414), 1,
      aux_sym_symbol_token1,
    ACTIONS(416), 1,
      aux_sym_symbol_token2,
    ACTIONS(418), 1,
      sym__hll_number_literal_pre_hook,
    STATE(893), 1,
      sym_trace32_hll_variable,
    STATE(1615), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(398), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(400), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(402), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(643), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(410), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(412), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(892), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(849), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [52224] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(394), 1,
      sym_identifier,
    ACTIONS(396), 1,
      anon_sym_LPAREN,
    ACTIONS(406), 1,
      anon_sym_BSLASH,
    ACTIONS(408), 1,
      anon_sym_sizeof,
    ACTIONS(414), 1,
      aux_sym_symbol_token1,
    ACTIONS(416), 1,
      aux_sym_symbol_token2,
    ACTIONS(418), 1,
      sym__hll_number_literal_pre_hook,
    STATE(893), 1,
      sym_trace32_hll_variable,
    STATE(1615), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(398), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(400), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(402), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(643), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(410), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(412), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(892), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(850), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [52305] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(579), 1,
      aux_sym_symbol_token1,
    ACTIONS(581), 1,
      aux_sym_symbol_token2,
    ACTIONS(583), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(811), 1,
      sym_identifier,
    ACTIONS(813), 1,
      anon_sym_LPAREN,
    ACTIONS(823), 1,
      anon_sym_BSLASH,
    ACTIONS(825), 1,
      anon_sym_sizeof,
    STATE(916), 1,
      sym_trace32_hll_variable,
    STATE(1587), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(815), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(817), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(819), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(821), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(575), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(577), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(915), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1319), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [52386] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(394), 1,
      sym_identifier,
    ACTIONS(396), 1,
      anon_sym_LPAREN,
    ACTIONS(406), 1,
      anon_sym_BSLASH,
    ACTIONS(408), 1,
      anon_sym_sizeof,
    ACTIONS(414), 1,
      aux_sym_symbol_token1,
    ACTIONS(416), 1,
      aux_sym_symbol_token2,
    ACTIONS(418), 1,
      sym__hll_number_literal_pre_hook,
    STATE(893), 1,
      sym_trace32_hll_variable,
    STATE(1615), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(398), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(400), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(402), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(643), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(410), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(412), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(892), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(865), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [52467] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(394), 1,
      sym_identifier,
    ACTIONS(396), 1,
      anon_sym_LPAREN,
    ACTIONS(406), 1,
      anon_sym_BSLASH,
    ACTIONS(408), 1,
      anon_sym_sizeof,
    ACTIONS(414), 1,
      aux_sym_symbol_token1,
    ACTIONS(416), 1,
      aux_sym_symbol_token2,
    ACTIONS(418), 1,
      sym__hll_number_literal_pre_hook,
    STATE(893), 1,
      sym_trace32_hll_variable,
    STATE(1615), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(398), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(400), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(402), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(643), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(410), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(412), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(892), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(851), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [52548] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(342), 1,
      sym_identifier,
    ACTIONS(344), 1,
      anon_sym_LPAREN,
    ACTIONS(354), 1,
      anon_sym_BSLASH,
    ACTIONS(356), 1,
      anon_sym_sizeof,
    ACTIONS(362), 1,
      aux_sym_symbol_token1,
    ACTIONS(364), 1,
      aux_sym_symbol_token2,
    ACTIONS(366), 1,
      sym__hll_number_literal_pre_hook,
    STATE(807), 1,
      sym_trace32_hll_variable,
    STATE(1593), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(346), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(348), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(350), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(569), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(358), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(360), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(806), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(744), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [52629] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(342), 1,
      sym_identifier,
    ACTIONS(344), 1,
      anon_sym_LPAREN,
    ACTIONS(354), 1,
      anon_sym_BSLASH,
    ACTIONS(356), 1,
      anon_sym_sizeof,
    ACTIONS(362), 1,
      aux_sym_symbol_token1,
    ACTIONS(364), 1,
      aux_sym_symbol_token2,
    ACTIONS(366), 1,
      sym__hll_number_literal_pre_hook,
    STATE(807), 1,
      sym_trace32_hll_variable,
    STATE(1593), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(346), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(348), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(350), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(569), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(358), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(360), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(806), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(764), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [52710] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2199), 1,
      anon_sym_LPAREN,
    ACTIONS(2205), 1,
      anon_sym_DOT,
    ACTIONS(2207), 1,
      anon_sym_DASH_GT,
    ACTIONS(2209), 1,
      anon_sym_LBRACK,
    STATE(752), 1,
      sym_hll_argument_list,
    ACTIONS(2203), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2219), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
    ACTIONS(2217), 23,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [52773] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(440), 1,
      anon_sym_LPAREN,
    ACTIONS(450), 1,
      anon_sym_BSLASH,
    ACTIONS(452), 1,
      anon_sym_sizeof,
    ACTIONS(470), 1,
      aux_sym_symbol_token1,
    ACTIONS(472), 1,
      aux_sym_symbol_token2,
    ACTIONS(476), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(547), 1,
      sym_identifier,
    STATE(799), 1,
      sym_trace32_hll_variable,
    STATE(1652), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(442), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(444), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(446), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(448), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(454), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(456), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(798), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1031), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [52854] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(440), 1,
      anon_sym_LPAREN,
    ACTIONS(450), 1,
      anon_sym_BSLASH,
    ACTIONS(452), 1,
      anon_sym_sizeof,
    ACTIONS(470), 1,
      aux_sym_symbol_token1,
    ACTIONS(472), 1,
      aux_sym_symbol_token2,
    ACTIONS(476), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(547), 1,
      sym_identifier,
    STATE(799), 1,
      sym_trace32_hll_variable,
    STATE(1652), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(442), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(444), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(446), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(448), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(454), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(456), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(798), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(974), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [52935] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(559), 1,
      sym_identifier,
    ACTIONS(561), 1,
      anon_sym_LPAREN,
    ACTIONS(571), 1,
      anon_sym_BSLASH,
    ACTIONS(573), 1,
      anon_sym_sizeof,
    ACTIONS(579), 1,
      aux_sym_symbol_token1,
    ACTIONS(581), 1,
      aux_sym_symbol_token2,
    ACTIONS(583), 1,
      sym__hll_number_literal_pre_hook,
    STATE(812), 1,
      sym_trace32_hll_variable,
    STATE(1655), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(563), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(565), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(567), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(569), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(575), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(577), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(811), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(976), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [53016] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(559), 1,
      sym_identifier,
    ACTIONS(561), 1,
      anon_sym_LPAREN,
    ACTIONS(571), 1,
      anon_sym_BSLASH,
    ACTIONS(573), 1,
      anon_sym_sizeof,
    ACTIONS(579), 1,
      aux_sym_symbol_token1,
    ACTIONS(581), 1,
      aux_sym_symbol_token2,
    ACTIONS(583), 1,
      sym__hll_number_literal_pre_hook,
    STATE(812), 1,
      sym_trace32_hll_variable,
    STATE(1655), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(563), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(565), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(567), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(569), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(575), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(577), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(811), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(977), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [53097] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(342), 1,
      sym_identifier,
    ACTIONS(344), 1,
      anon_sym_LPAREN,
    ACTIONS(354), 1,
      anon_sym_BSLASH,
    ACTIONS(356), 1,
      anon_sym_sizeof,
    ACTIONS(362), 1,
      aux_sym_symbol_token1,
    ACTIONS(364), 1,
      aux_sym_symbol_token2,
    ACTIONS(366), 1,
      sym__hll_number_literal_pre_hook,
    STATE(807), 1,
      sym_trace32_hll_variable,
    STATE(1593), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(346), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(348), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(350), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(569), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(358), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(360), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(806), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(784), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [53178] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(559), 1,
      sym_identifier,
    ACTIONS(571), 1,
      anon_sym_BSLASH,
    ACTIONS(573), 1,
      anon_sym_sizeof,
    ACTIONS(579), 1,
      aux_sym_symbol_token1,
    ACTIONS(581), 1,
      aux_sym_symbol_token2,
    ACTIONS(583), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(2221), 1,
      anon_sym_LPAREN,
    STATE(812), 1,
      sym_trace32_hll_variable,
    STATE(1655), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(563), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(565), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(567), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(569), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(575), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(577), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(811), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(978), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [53259] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(440), 1,
      anon_sym_LPAREN,
    ACTIONS(450), 1,
      anon_sym_BSLASH,
    ACTIONS(452), 1,
      anon_sym_sizeof,
    ACTIONS(470), 1,
      aux_sym_symbol_token1,
    ACTIONS(472), 1,
      aux_sym_symbol_token2,
    ACTIONS(476), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(547), 1,
      sym_identifier,
    STATE(799), 1,
      sym_trace32_hll_variable,
    STATE(1652), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(442), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(444), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(446), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(448), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(454), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(456), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(798), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(992), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [53340] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2199), 1,
      anon_sym_LPAREN,
    ACTIONS(2205), 1,
      anon_sym_DOT,
    ACTIONS(2207), 1,
      anon_sym_DASH_GT,
    ACTIONS(2209), 1,
      anon_sym_LBRACK,
    STATE(752), 1,
      sym_hll_argument_list,
    ACTIONS(2203), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2225), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
    ACTIONS(2223), 23,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [53403] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(440), 1,
      anon_sym_LPAREN,
    ACTIONS(450), 1,
      anon_sym_BSLASH,
    ACTIONS(452), 1,
      anon_sym_sizeof,
    ACTIONS(470), 1,
      aux_sym_symbol_token1,
    ACTIONS(472), 1,
      aux_sym_symbol_token2,
    ACTIONS(476), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(547), 1,
      sym_identifier,
    STATE(799), 1,
      sym_trace32_hll_variable,
    STATE(1652), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(442), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(444), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(446), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(448), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(454), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(456), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(798), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(995), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [53484] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(440), 1,
      anon_sym_LPAREN,
    ACTIONS(450), 1,
      anon_sym_BSLASH,
    ACTIONS(452), 1,
      anon_sym_sizeof,
    ACTIONS(470), 1,
      aux_sym_symbol_token1,
    ACTIONS(472), 1,
      aux_sym_symbol_token2,
    ACTIONS(476), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(547), 1,
      sym_identifier,
    STATE(799), 1,
      sym_trace32_hll_variable,
    STATE(1652), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(442), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(444), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(446), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(448), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(454), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(456), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(798), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(996), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [53565] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2199), 1,
      anon_sym_LPAREN,
    ACTIONS(2205), 1,
      anon_sym_DOT,
    ACTIONS(2207), 1,
      anon_sym_DASH_GT,
    ACTIONS(2209), 1,
      anon_sym_LBRACK,
    STATE(752), 1,
      sym_hll_argument_list,
    ACTIONS(2203), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2229), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
    ACTIONS(2227), 23,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [53628] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(440), 1,
      anon_sym_LPAREN,
    ACTIONS(450), 1,
      anon_sym_BSLASH,
    ACTIONS(452), 1,
      anon_sym_sizeof,
    ACTIONS(470), 1,
      aux_sym_symbol_token1,
    ACTIONS(472), 1,
      aux_sym_symbol_token2,
    ACTIONS(476), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(547), 1,
      sym_identifier,
    STATE(799), 1,
      sym_trace32_hll_variable,
    STATE(1652), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(442), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(444), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(446), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(448), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(454), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(456), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(798), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1003), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [53709] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(440), 1,
      anon_sym_LPAREN,
    ACTIONS(450), 1,
      anon_sym_BSLASH,
    ACTIONS(452), 1,
      anon_sym_sizeof,
    ACTIONS(470), 1,
      aux_sym_symbol_token1,
    ACTIONS(472), 1,
      aux_sym_symbol_token2,
    ACTIONS(476), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(547), 1,
      sym_identifier,
    STATE(799), 1,
      sym_trace32_hll_variable,
    STATE(1652), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(442), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(444), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(446), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(448), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(454), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(456), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(798), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1005), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [53790] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(579), 1,
      aux_sym_symbol_token1,
    ACTIONS(581), 1,
      aux_sym_symbol_token2,
    ACTIONS(583), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(811), 1,
      sym_identifier,
    ACTIONS(813), 1,
      anon_sym_LPAREN,
    ACTIONS(823), 1,
      anon_sym_BSLASH,
    ACTIONS(825), 1,
      anon_sym_sizeof,
    STATE(916), 1,
      sym_trace32_hll_variable,
    STATE(1587), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(815), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(817), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(819), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(821), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(575), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(577), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(915), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1322), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [53871] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(342), 1,
      sym_identifier,
    ACTIONS(344), 1,
      anon_sym_LPAREN,
    ACTIONS(354), 1,
      anon_sym_BSLASH,
    ACTIONS(356), 1,
      anon_sym_sizeof,
    ACTIONS(362), 1,
      aux_sym_symbol_token1,
    ACTIONS(364), 1,
      aux_sym_symbol_token2,
    ACTIONS(366), 1,
      sym__hll_number_literal_pre_hook,
    STATE(807), 1,
      sym_trace32_hll_variable,
    STATE(1593), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(346), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(348), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(350), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(569), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(358), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(360), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(806), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(780), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [53952] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(440), 1,
      anon_sym_LPAREN,
    ACTIONS(450), 1,
      anon_sym_BSLASH,
    ACTIONS(452), 1,
      anon_sym_sizeof,
    ACTIONS(470), 1,
      aux_sym_symbol_token1,
    ACTIONS(472), 1,
      aux_sym_symbol_token2,
    ACTIONS(476), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(547), 1,
      sym_identifier,
    STATE(799), 1,
      sym_trace32_hll_variable,
    STATE(1652), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(442), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(444), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(446), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(448), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(454), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(456), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(798), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1027), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [54033] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(559), 1,
      sym_identifier,
    ACTIONS(561), 1,
      anon_sym_LPAREN,
    ACTIONS(571), 1,
      anon_sym_BSLASH,
    ACTIONS(573), 1,
      anon_sym_sizeof,
    ACTIONS(579), 1,
      aux_sym_symbol_token1,
    ACTIONS(581), 1,
      aux_sym_symbol_token2,
    ACTIONS(583), 1,
      sym__hll_number_literal_pre_hook,
    STATE(812), 1,
      sym_trace32_hll_variable,
    STATE(1655), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(563), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(565), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(567), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(569), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(575), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(577), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(811), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1000), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [54114] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(342), 1,
      sym_identifier,
    ACTIONS(344), 1,
      anon_sym_LPAREN,
    ACTIONS(354), 1,
      anon_sym_BSLASH,
    ACTIONS(356), 1,
      anon_sym_sizeof,
    ACTIONS(362), 1,
      aux_sym_symbol_token1,
    ACTIONS(364), 1,
      aux_sym_symbol_token2,
    ACTIONS(366), 1,
      sym__hll_number_literal_pre_hook,
    STATE(807), 1,
      sym_trace32_hll_variable,
    STATE(1593), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(346), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(348), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(350), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(569), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(358), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(360), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(806), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(758), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [54195] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(440), 1,
      anon_sym_LPAREN,
    ACTIONS(450), 1,
      anon_sym_BSLASH,
    ACTIONS(452), 1,
      anon_sym_sizeof,
    ACTIONS(470), 1,
      aux_sym_symbol_token1,
    ACTIONS(472), 1,
      aux_sym_symbol_token2,
    ACTIONS(476), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(547), 1,
      sym_identifier,
    STATE(799), 1,
      sym_trace32_hll_variable,
    STATE(1652), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(442), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(444), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(446), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(448), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(454), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(456), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(798), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(968), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [54276] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(440), 1,
      anon_sym_LPAREN,
    ACTIONS(450), 1,
      anon_sym_BSLASH,
    ACTIONS(452), 1,
      anon_sym_sizeof,
    ACTIONS(470), 1,
      aux_sym_symbol_token1,
    ACTIONS(472), 1,
      aux_sym_symbol_token2,
    ACTIONS(476), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(547), 1,
      sym_identifier,
    STATE(799), 1,
      sym_trace32_hll_variable,
    STATE(1652), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(442), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(444), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(446), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(448), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(454), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(456), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(798), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(973), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [54357] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2199), 1,
      anon_sym_LPAREN,
    ACTIONS(2205), 1,
      anon_sym_DOT,
    ACTIONS(2207), 1,
      anon_sym_DASH_GT,
    ACTIONS(2209), 1,
      anon_sym_LBRACK,
    STATE(752), 1,
      sym_hll_argument_list,
    ACTIONS(2203), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2233), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
    ACTIONS(2231), 23,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [54420] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(342), 1,
      sym_identifier,
    ACTIONS(344), 1,
      anon_sym_LPAREN,
    ACTIONS(354), 1,
      anon_sym_BSLASH,
    ACTIONS(356), 1,
      anon_sym_sizeof,
    ACTIONS(362), 1,
      aux_sym_symbol_token1,
    ACTIONS(364), 1,
      aux_sym_symbol_token2,
    ACTIONS(366), 1,
      sym__hll_number_literal_pre_hook,
    STATE(807), 1,
      sym_trace32_hll_variable,
    STATE(1593), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(346), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(348), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(350), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(569), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(358), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(360), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(806), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(785), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [54501] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(559), 1,
      sym_identifier,
    ACTIONS(561), 1,
      anon_sym_LPAREN,
    ACTIONS(571), 1,
      anon_sym_BSLASH,
    ACTIONS(573), 1,
      anon_sym_sizeof,
    ACTIONS(579), 1,
      aux_sym_symbol_token1,
    ACTIONS(581), 1,
      aux_sym_symbol_token2,
    ACTIONS(583), 1,
      sym__hll_number_literal_pre_hook,
    STATE(812), 1,
      sym_trace32_hll_variable,
    STATE(1655), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(563), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(565), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(567), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(569), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(575), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(577), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(811), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(987), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [54582] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(579), 1,
      aux_sym_symbol_token1,
    ACTIONS(581), 1,
      aux_sym_symbol_token2,
    ACTIONS(583), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(619), 1,
      sym_identifier,
    ACTIONS(621), 1,
      anon_sym_LPAREN,
    ACTIONS(629), 1,
      anon_sym_BSLASH,
    ACTIONS(631), 1,
      anon_sym_sizeof,
    STATE(842), 1,
      sym_trace32_hll_variable,
    STATE(1596), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(448), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(623), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(625), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(627), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(575), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(577), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(841), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1222), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [54663] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(579), 1,
      aux_sym_symbol_token1,
    ACTIONS(581), 1,
      aux_sym_symbol_token2,
    ACTIONS(583), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(811), 1,
      sym_identifier,
    ACTIONS(813), 1,
      anon_sym_LPAREN,
    ACTIONS(823), 1,
      anon_sym_BSLASH,
    ACTIONS(825), 1,
      anon_sym_sizeof,
    STATE(916), 1,
      sym_trace32_hll_variable,
    STATE(1587), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(815), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(817), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(819), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(821), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(575), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(577), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(915), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1300), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [54744] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(579), 1,
      aux_sym_symbol_token1,
    ACTIONS(581), 1,
      aux_sym_symbol_token2,
    ACTIONS(583), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(619), 1,
      sym_identifier,
    ACTIONS(621), 1,
      anon_sym_LPAREN,
    ACTIONS(629), 1,
      anon_sym_BSLASH,
    ACTIONS(631), 1,
      anon_sym_sizeof,
    STATE(842), 1,
      sym_trace32_hll_variable,
    STATE(1596), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(448), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(623), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(625), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(627), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(575), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(577), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(841), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1224), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [54825] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(579), 1,
      aux_sym_symbol_token1,
    ACTIONS(581), 1,
      aux_sym_symbol_token2,
    ACTIONS(583), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(811), 1,
      sym_identifier,
    ACTIONS(813), 1,
      anon_sym_LPAREN,
    ACTIONS(823), 1,
      anon_sym_BSLASH,
    ACTIONS(825), 1,
      anon_sym_sizeof,
    STATE(916), 1,
      sym_trace32_hll_variable,
    STATE(1587), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(815), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(817), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(819), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(821), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(575), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(577), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(915), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1356), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [54906] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(579), 1,
      aux_sym_symbol_token1,
    ACTIONS(581), 1,
      aux_sym_symbol_token2,
    ACTIONS(583), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(811), 1,
      sym_identifier,
    ACTIONS(813), 1,
      anon_sym_LPAREN,
    ACTIONS(823), 1,
      anon_sym_BSLASH,
    ACTIONS(825), 1,
      anon_sym_sizeof,
    STATE(916), 1,
      sym_trace32_hll_variable,
    STATE(1587), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(815), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(817), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(819), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(821), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(575), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(577), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(915), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1291), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [54987] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(579), 1,
      aux_sym_symbol_token1,
    ACTIONS(581), 1,
      aux_sym_symbol_token2,
    ACTIONS(583), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(811), 1,
      sym_identifier,
    ACTIONS(813), 1,
      anon_sym_LPAREN,
    ACTIONS(823), 1,
      anon_sym_BSLASH,
    ACTIONS(825), 1,
      anon_sym_sizeof,
    STATE(916), 1,
      sym_trace32_hll_variable,
    STATE(1587), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(815), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(817), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(819), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(821), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(575), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(577), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(915), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1323), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [55068] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(579), 1,
      aux_sym_symbol_token1,
    ACTIONS(581), 1,
      aux_sym_symbol_token2,
    ACTIONS(583), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(619), 1,
      sym_identifier,
    ACTIONS(621), 1,
      anon_sym_LPAREN,
    ACTIONS(629), 1,
      anon_sym_BSLASH,
    ACTIONS(631), 1,
      anon_sym_sizeof,
    STATE(842), 1,
      sym_trace32_hll_variable,
    STATE(1596), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(448), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(623), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(625), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(627), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(575), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(577), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(841), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1225), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [55149] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(579), 1,
      aux_sym_symbol_token1,
    ACTIONS(581), 1,
      aux_sym_symbol_token2,
    ACTIONS(583), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(619), 1,
      sym_identifier,
    ACTIONS(621), 1,
      anon_sym_LPAREN,
    ACTIONS(629), 1,
      anon_sym_BSLASH,
    ACTIONS(631), 1,
      anon_sym_sizeof,
    STATE(842), 1,
      sym_trace32_hll_variable,
    STATE(1596), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(448), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(623), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(625), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(627), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(575), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(577), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(841), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1226), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [55230] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(579), 1,
      aux_sym_symbol_token1,
    ACTIONS(581), 1,
      aux_sym_symbol_token2,
    ACTIONS(583), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(619), 1,
      sym_identifier,
    ACTIONS(621), 1,
      anon_sym_LPAREN,
    ACTIONS(629), 1,
      anon_sym_BSLASH,
    ACTIONS(631), 1,
      anon_sym_sizeof,
    STATE(842), 1,
      sym_trace32_hll_variable,
    STATE(1596), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(448), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(623), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(625), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(627), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(575), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(577), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(841), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1227), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [55311] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(579), 1,
      aux_sym_symbol_token1,
    ACTIONS(581), 1,
      aux_sym_symbol_token2,
    ACTIONS(583), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(619), 1,
      sym_identifier,
    ACTIONS(621), 1,
      anon_sym_LPAREN,
    ACTIONS(629), 1,
      anon_sym_BSLASH,
    ACTIONS(631), 1,
      anon_sym_sizeof,
    STATE(842), 1,
      sym_trace32_hll_variable,
    STATE(1596), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(448), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(623), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(625), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(627), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(575), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(577), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(841), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1230), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [55392] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(579), 1,
      aux_sym_symbol_token1,
    ACTIONS(581), 1,
      aux_sym_symbol_token2,
    ACTIONS(583), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(619), 1,
      sym_identifier,
    ACTIONS(621), 1,
      anon_sym_LPAREN,
    ACTIONS(629), 1,
      anon_sym_BSLASH,
    ACTIONS(631), 1,
      anon_sym_sizeof,
    STATE(842), 1,
      sym_trace32_hll_variable,
    STATE(1596), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(448), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(623), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(625), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(627), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(575), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(577), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(841), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1231), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [55473] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(579), 1,
      aux_sym_symbol_token1,
    ACTIONS(581), 1,
      aux_sym_symbol_token2,
    ACTIONS(583), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(619), 1,
      sym_identifier,
    ACTIONS(621), 1,
      anon_sym_LPAREN,
    ACTIONS(629), 1,
      anon_sym_BSLASH,
    ACTIONS(631), 1,
      anon_sym_sizeof,
    STATE(842), 1,
      sym_trace32_hll_variable,
    STATE(1596), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(448), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(623), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(625), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(627), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(575), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(577), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(841), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1181), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [55554] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(579), 1,
      aux_sym_symbol_token1,
    ACTIONS(581), 1,
      aux_sym_symbol_token2,
    ACTIONS(583), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(619), 1,
      sym_identifier,
    ACTIONS(621), 1,
      anon_sym_LPAREN,
    ACTIONS(629), 1,
      anon_sym_BSLASH,
    ACTIONS(631), 1,
      anon_sym_sizeof,
    STATE(842), 1,
      sym_trace32_hll_variable,
    STATE(1596), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(448), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(623), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(625), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(627), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(575), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(577), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(841), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1234), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [55635] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(579), 1,
      aux_sym_symbol_token1,
    ACTIONS(581), 1,
      aux_sym_symbol_token2,
    ACTIONS(583), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(619), 1,
      sym_identifier,
    ACTIONS(621), 1,
      anon_sym_LPAREN,
    ACTIONS(629), 1,
      anon_sym_BSLASH,
    ACTIONS(631), 1,
      anon_sym_sizeof,
    STATE(842), 1,
      sym_trace32_hll_variable,
    STATE(1596), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(448), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(623), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(625), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(627), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(575), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(577), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(841), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1242), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [55716] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(342), 1,
      sym_identifier,
    ACTIONS(344), 1,
      anon_sym_LPAREN,
    ACTIONS(354), 1,
      anon_sym_BSLASH,
    ACTIONS(356), 1,
      anon_sym_sizeof,
    ACTIONS(362), 1,
      aux_sym_symbol_token1,
    ACTIONS(364), 1,
      aux_sym_symbol_token2,
    ACTIONS(366), 1,
      sym__hll_number_literal_pre_hook,
    STATE(807), 1,
      sym_trace32_hll_variable,
    STATE(1593), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(346), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(348), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(350), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(569), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(358), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(360), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(806), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(755), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [55797] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(559), 1,
      sym_identifier,
    ACTIONS(561), 1,
      anon_sym_LPAREN,
    ACTIONS(571), 1,
      anon_sym_BSLASH,
    ACTIONS(573), 1,
      anon_sym_sizeof,
    ACTIONS(579), 1,
      aux_sym_symbol_token1,
    ACTIONS(581), 1,
      aux_sym_symbol_token2,
    ACTIONS(583), 1,
      sym__hll_number_literal_pre_hook,
    STATE(812), 1,
      sym_trace32_hll_variable,
    STATE(1655), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(563), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(565), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(567), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(569), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(575), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(577), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(811), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(983), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [55878] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(579), 1,
      aux_sym_symbol_token1,
    ACTIONS(581), 1,
      aux_sym_symbol_token2,
    ACTIONS(583), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(619), 1,
      sym_identifier,
    ACTIONS(621), 1,
      anon_sym_LPAREN,
    ACTIONS(629), 1,
      anon_sym_BSLASH,
    ACTIONS(631), 1,
      anon_sym_sizeof,
    STATE(842), 1,
      sym_trace32_hll_variable,
    STATE(1596), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(448), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(623), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(625), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(627), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(575), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(577), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(841), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1183), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [55959] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(579), 1,
      aux_sym_symbol_token1,
    ACTIONS(581), 1,
      aux_sym_symbol_token2,
    ACTIONS(583), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(811), 1,
      sym_identifier,
    ACTIONS(813), 1,
      anon_sym_LPAREN,
    ACTIONS(823), 1,
      anon_sym_BSLASH,
    ACTIONS(825), 1,
      anon_sym_sizeof,
    STATE(916), 1,
      sym_trace32_hll_variable,
    STATE(1587), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(815), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(817), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(819), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(821), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(575), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(577), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(915), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1324), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [56040] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(579), 1,
      aux_sym_symbol_token1,
    ACTIONS(581), 1,
      aux_sym_symbol_token2,
    ACTIONS(583), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(811), 1,
      sym_identifier,
    ACTIONS(813), 1,
      anon_sym_LPAREN,
    ACTIONS(823), 1,
      anon_sym_BSLASH,
    ACTIONS(825), 1,
      anon_sym_sizeof,
    STATE(916), 1,
      sym_trace32_hll_variable,
    STATE(1587), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(815), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(817), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(819), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(821), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(575), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(577), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(915), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1327), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [56121] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(579), 1,
      aux_sym_symbol_token1,
    ACTIONS(581), 1,
      aux_sym_symbol_token2,
    ACTIONS(583), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(811), 1,
      sym_identifier,
    ACTIONS(813), 1,
      anon_sym_LPAREN,
    ACTIONS(823), 1,
      anon_sym_BSLASH,
    ACTIONS(825), 1,
      anon_sym_sizeof,
    STATE(916), 1,
      sym_trace32_hll_variable,
    STATE(1587), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(815), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(817), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(819), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(821), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(575), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(577), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(915), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1330), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [56202] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(559), 1,
      sym_identifier,
    ACTIONS(561), 1,
      anon_sym_LPAREN,
    ACTIONS(571), 1,
      anon_sym_BSLASH,
    ACTIONS(573), 1,
      anon_sym_sizeof,
    ACTIONS(579), 1,
      aux_sym_symbol_token1,
    ACTIONS(581), 1,
      aux_sym_symbol_token2,
    ACTIONS(583), 1,
      sym__hll_number_literal_pre_hook,
    STATE(812), 1,
      sym_trace32_hll_variable,
    STATE(1655), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(563), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(565), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(567), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(569), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(575), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(577), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(811), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(985), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [56283] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(579), 1,
      aux_sym_symbol_token1,
    ACTIONS(581), 1,
      aux_sym_symbol_token2,
    ACTIONS(583), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(619), 1,
      sym_identifier,
    ACTIONS(621), 1,
      anon_sym_LPAREN,
    ACTIONS(629), 1,
      anon_sym_BSLASH,
    ACTIONS(631), 1,
      anon_sym_sizeof,
    STATE(842), 1,
      sym_trace32_hll_variable,
    STATE(1596), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(448), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(623), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(625), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(627), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(575), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(577), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(841), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1250), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [56364] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(440), 1,
      anon_sym_LPAREN,
    ACTIONS(450), 1,
      anon_sym_BSLASH,
    ACTIONS(452), 1,
      anon_sym_sizeof,
    ACTIONS(470), 1,
      aux_sym_symbol_token1,
    ACTIONS(472), 1,
      aux_sym_symbol_token2,
    ACTIONS(476), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(547), 1,
      sym_identifier,
    STATE(799), 1,
      sym_trace32_hll_variable,
    STATE(1652), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(442), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(444), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(446), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(448), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(454), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(456), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(798), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1010), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [56445] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(440), 1,
      anon_sym_LPAREN,
    ACTIONS(450), 1,
      anon_sym_BSLASH,
    ACTIONS(452), 1,
      anon_sym_sizeof,
    ACTIONS(470), 1,
      aux_sym_symbol_token1,
    ACTIONS(472), 1,
      aux_sym_symbol_token2,
    ACTIONS(476), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(547), 1,
      sym_identifier,
    STATE(799), 1,
      sym_trace32_hll_variable,
    STATE(1652), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(442), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(444), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(446), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(448), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(454), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(456), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(798), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1011), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [56526] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(300), 1,
      sym_identifier,
    ACTIONS(304), 1,
      anon_sym_LPAREN,
    ACTIONS(316), 1,
      anon_sym_BSLASH,
    ACTIONS(318), 1,
      anon_sym_sizeof,
    ACTIONS(324), 1,
      aux_sym_symbol_token1,
    ACTIONS(326), 1,
      aux_sym_symbol_token2,
    ACTIONS(328), 1,
      sym__hll_number_literal_pre_hook,
    STATE(781), 1,
      sym_trace32_hll_variable,
    STATE(1601), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(308), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(310), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(312), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(448), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(320), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(322), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(778), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(572), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [56607] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(450), 1,
      anon_sym_BSLASH,
    ACTIONS(452), 1,
      anon_sym_sizeof,
    ACTIONS(470), 1,
      aux_sym_symbol_token1,
    ACTIONS(472), 1,
      aux_sym_symbol_token2,
    ACTIONS(476), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(547), 1,
      sym_identifier,
    ACTIONS(2235), 1,
      anon_sym_LPAREN,
    STATE(799), 1,
      sym_trace32_hll_variable,
    STATE(1652), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(442), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(444), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(446), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(448), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(454), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(456), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(798), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1013), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [56688] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(440), 1,
      anon_sym_LPAREN,
    ACTIONS(450), 1,
      anon_sym_BSLASH,
    ACTIONS(452), 1,
      anon_sym_sizeof,
    ACTIONS(470), 1,
      aux_sym_symbol_token1,
    ACTIONS(472), 1,
      aux_sym_symbol_token2,
    ACTIONS(476), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(547), 1,
      sym_identifier,
    STATE(799), 1,
      sym_trace32_hll_variable,
    STATE(1652), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(442), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(444), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(446), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(448), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(454), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(456), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(798), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(971), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [56769] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(342), 1,
      sym_identifier,
    ACTIONS(344), 1,
      anon_sym_LPAREN,
    ACTIONS(354), 1,
      anon_sym_BSLASH,
    ACTIONS(356), 1,
      anon_sym_sizeof,
    ACTIONS(362), 1,
      aux_sym_symbol_token1,
    ACTIONS(364), 1,
      aux_sym_symbol_token2,
    ACTIONS(366), 1,
      sym__hll_number_literal_pre_hook,
    STATE(807), 1,
      sym_trace32_hll_variable,
    STATE(1593), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(346), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(348), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(350), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(569), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(358), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(360), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(806), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(783), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [56850] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(342), 1,
      sym_identifier,
    ACTIONS(344), 1,
      anon_sym_LPAREN,
    ACTIONS(354), 1,
      anon_sym_BSLASH,
    ACTIONS(356), 1,
      anon_sym_sizeof,
    ACTIONS(362), 1,
      aux_sym_symbol_token1,
    ACTIONS(364), 1,
      aux_sym_symbol_token2,
    ACTIONS(366), 1,
      sym__hll_number_literal_pre_hook,
    STATE(807), 1,
      sym_trace32_hll_variable,
    STATE(1593), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(346), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(348), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(350), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(569), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(358), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(360), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(806), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(789), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [56931] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(579), 1,
      aux_sym_symbol_token1,
    ACTIONS(581), 1,
      aux_sym_symbol_token2,
    ACTIONS(583), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(619), 1,
      sym_identifier,
    ACTIONS(621), 1,
      anon_sym_LPAREN,
    ACTIONS(629), 1,
      anon_sym_BSLASH,
    ACTIONS(631), 1,
      anon_sym_sizeof,
    STATE(842), 1,
      sym_trace32_hll_variable,
    STATE(1596), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(448), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(623), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(625), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(627), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(575), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(577), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(841), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1185), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [57012] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(579), 1,
      aux_sym_symbol_token1,
    ACTIONS(581), 1,
      aux_sym_symbol_token2,
    ACTIONS(583), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(619), 1,
      sym_identifier,
    ACTIONS(621), 1,
      anon_sym_LPAREN,
    ACTIONS(629), 1,
      anon_sym_BSLASH,
    ACTIONS(631), 1,
      anon_sym_sizeof,
    STATE(842), 1,
      sym_trace32_hll_variable,
    STATE(1596), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(448), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(623), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(625), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(627), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(575), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(577), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(841), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1186), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [57093] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(342), 1,
      sym_identifier,
    ACTIONS(344), 1,
      anon_sym_LPAREN,
    ACTIONS(354), 1,
      anon_sym_BSLASH,
    ACTIONS(356), 1,
      anon_sym_sizeof,
    ACTIONS(362), 1,
      aux_sym_symbol_token1,
    ACTIONS(364), 1,
      aux_sym_symbol_token2,
    ACTIONS(366), 1,
      sym__hll_number_literal_pre_hook,
    STATE(807), 1,
      sym_trace32_hll_variable,
    STATE(1593), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(346), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(348), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(350), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(569), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(358), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(360), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(806), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(743), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [57174] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(579), 1,
      aux_sym_symbol_token1,
    ACTIONS(581), 1,
      aux_sym_symbol_token2,
    ACTIONS(583), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(619), 1,
      sym_identifier,
    ACTIONS(621), 1,
      anon_sym_LPAREN,
    ACTIONS(629), 1,
      anon_sym_BSLASH,
    ACTIONS(631), 1,
      anon_sym_sizeof,
    STATE(842), 1,
      sym_trace32_hll_variable,
    STATE(1596), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(448), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(623), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(625), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(627), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(575), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(577), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(841), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1257), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [57255] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(440), 1,
      anon_sym_LPAREN,
    ACTIONS(450), 1,
      anon_sym_BSLASH,
    ACTIONS(452), 1,
      anon_sym_sizeof,
    ACTIONS(470), 1,
      aux_sym_symbol_token1,
    ACTIONS(472), 1,
      aux_sym_symbol_token2,
    ACTIONS(476), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(547), 1,
      sym_identifier,
    STATE(799), 1,
      sym_trace32_hll_variable,
    STATE(1652), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(442), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(444), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(446), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(448), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(454), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(456), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(798), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1008), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [57336] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(342), 1,
      sym_identifier,
    ACTIONS(344), 1,
      anon_sym_LPAREN,
    ACTIONS(354), 1,
      anon_sym_BSLASH,
    ACTIONS(356), 1,
      anon_sym_sizeof,
    ACTIONS(362), 1,
      aux_sym_symbol_token1,
    ACTIONS(364), 1,
      aux_sym_symbol_token2,
    ACTIONS(366), 1,
      sym__hll_number_literal_pre_hook,
    STATE(807), 1,
      sym_trace32_hll_variable,
    STATE(1593), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(346), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(348), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(350), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(569), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(358), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(360), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(806), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(762), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [57417] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(368), 1,
      sym_identifier,
    ACTIONS(370), 1,
      anon_sym_LPAREN,
    ACTIONS(380), 1,
      anon_sym_BSLASH,
    ACTIONS(382), 1,
      anon_sym_sizeof,
    ACTIONS(388), 1,
      aux_sym_symbol_token1,
    ACTIONS(390), 1,
      aux_sym_symbol_token2,
    ACTIONS(392), 1,
      sym__hll_number_literal_pre_hook,
    STATE(900), 1,
      sym_trace32_hll_variable,
    STATE(1580), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(372), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(374), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(376), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(821), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(384), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(386), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(898), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(871), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [57498] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(368), 1,
      sym_identifier,
    ACTIONS(370), 1,
      anon_sym_LPAREN,
    ACTIONS(380), 1,
      anon_sym_BSLASH,
    ACTIONS(382), 1,
      anon_sym_sizeof,
    ACTIONS(388), 1,
      aux_sym_symbol_token1,
    ACTIONS(390), 1,
      aux_sym_symbol_token2,
    ACTIONS(392), 1,
      sym__hll_number_literal_pre_hook,
    STATE(900), 1,
      sym_trace32_hll_variable,
    STATE(1580), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(372), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(374), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(376), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(821), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(384), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(386), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(898), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(872), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [57579] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(394), 1,
      sym_identifier,
    ACTIONS(396), 1,
      anon_sym_LPAREN,
    ACTIONS(406), 1,
      anon_sym_BSLASH,
    ACTIONS(408), 1,
      anon_sym_sizeof,
    ACTIONS(414), 1,
      aux_sym_symbol_token1,
    ACTIONS(416), 1,
      aux_sym_symbol_token2,
    ACTIONS(418), 1,
      sym__hll_number_literal_pre_hook,
    STATE(893), 1,
      sym_trace32_hll_variable,
    STATE(1615), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(398), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(400), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(402), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(643), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(410), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(412), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(892), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(825), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [57660] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(368), 1,
      sym_identifier,
    ACTIONS(380), 1,
      anon_sym_BSLASH,
    ACTIONS(382), 1,
      anon_sym_sizeof,
    ACTIONS(388), 1,
      aux_sym_symbol_token1,
    ACTIONS(390), 1,
      aux_sym_symbol_token2,
    ACTIONS(392), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(2237), 1,
      anon_sym_LPAREN,
    STATE(900), 1,
      sym_trace32_hll_variable,
    STATE(1580), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(372), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(374), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(376), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(821), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(384), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(386), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(898), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(819), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [57741] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(579), 1,
      aux_sym_symbol_token1,
    ACTIONS(581), 1,
      aux_sym_symbol_token2,
    ACTIONS(583), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(619), 1,
      sym_identifier,
    ACTIONS(621), 1,
      anon_sym_LPAREN,
    ACTIONS(629), 1,
      anon_sym_BSLASH,
    ACTIONS(631), 1,
      anon_sym_sizeof,
    STATE(842), 1,
      sym_trace32_hll_variable,
    STATE(1596), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(448), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(623), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(625), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(627), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(575), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(577), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(841), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1187), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [57822] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(579), 1,
      aux_sym_symbol_token1,
    ACTIONS(581), 1,
      aux_sym_symbol_token2,
    ACTIONS(583), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(811), 1,
      sym_identifier,
    ACTIONS(813), 1,
      anon_sym_LPAREN,
    ACTIONS(823), 1,
      anon_sym_BSLASH,
    ACTIONS(825), 1,
      anon_sym_sizeof,
    STATE(916), 1,
      sym_trace32_hll_variable,
    STATE(1587), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(815), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(817), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(819), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(821), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(575), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(577), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(915), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1331), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [57903] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(342), 1,
      sym_identifier,
    ACTIONS(344), 1,
      anon_sym_LPAREN,
    ACTIONS(354), 1,
      anon_sym_BSLASH,
    ACTIONS(356), 1,
      anon_sym_sizeof,
    ACTIONS(362), 1,
      aux_sym_symbol_token1,
    ACTIONS(364), 1,
      aux_sym_symbol_token2,
    ACTIONS(366), 1,
      sym__hll_number_literal_pre_hook,
    STATE(807), 1,
      sym_trace32_hll_variable,
    STATE(1593), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(346), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(348), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(350), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(569), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(358), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(360), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(806), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(769), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [57984] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(579), 1,
      aux_sym_symbol_token1,
    ACTIONS(581), 1,
      aux_sym_symbol_token2,
    ACTIONS(583), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(811), 1,
      sym_identifier,
    ACTIONS(813), 1,
      anon_sym_LPAREN,
    ACTIONS(823), 1,
      anon_sym_BSLASH,
    ACTIONS(825), 1,
      anon_sym_sizeof,
    STATE(916), 1,
      sym_trace32_hll_variable,
    STATE(1587), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(815), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(817), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(819), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(821), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(575), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(577), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(915), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1314), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [58065] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(440), 1,
      anon_sym_LPAREN,
    ACTIONS(450), 1,
      anon_sym_BSLASH,
    ACTIONS(452), 1,
      anon_sym_sizeof,
    ACTIONS(470), 1,
      aux_sym_symbol_token1,
    ACTIONS(472), 1,
      aux_sym_symbol_token2,
    ACTIONS(476), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(547), 1,
      sym_identifier,
    STATE(799), 1,
      sym_trace32_hll_variable,
    STATE(1652), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(442), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(444), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(446), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(448), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(454), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(456), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(798), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1002), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [58146] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(300), 1,
      sym_identifier,
    ACTIONS(304), 1,
      anon_sym_LPAREN,
    ACTIONS(316), 1,
      anon_sym_BSLASH,
    ACTIONS(318), 1,
      anon_sym_sizeof,
    ACTIONS(324), 1,
      aux_sym_symbol_token1,
    ACTIONS(326), 1,
      aux_sym_symbol_token2,
    ACTIONS(328), 1,
      sym__hll_number_literal_pre_hook,
    STATE(781), 1,
      sym_trace32_hll_variable,
    STATE(1601), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(308), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(310), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(312), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(448), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(320), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(322), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(778), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(673), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [58227] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2199), 1,
      anon_sym_LPAREN,
    ACTIONS(2205), 1,
      anon_sym_DOT,
    ACTIONS(2207), 1,
      anon_sym_DASH_GT,
    ACTIONS(2209), 1,
      anon_sym_LBRACK,
    STATE(752), 1,
      sym_hll_argument_list,
    ACTIONS(2203), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2243), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2241), 11,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
    ACTIONS(2239), 23,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [58292] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(342), 1,
      sym_identifier,
    ACTIONS(344), 1,
      anon_sym_LPAREN,
    ACTIONS(354), 1,
      anon_sym_BSLASH,
    ACTIONS(356), 1,
      anon_sym_sizeof,
    ACTIONS(362), 1,
      aux_sym_symbol_token1,
    ACTIONS(364), 1,
      aux_sym_symbol_token2,
    ACTIONS(366), 1,
      sym__hll_number_literal_pre_hook,
    STATE(807), 1,
      sym_trace32_hll_variable,
    STATE(1593), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(346), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(348), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(350), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(569), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(358), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(360), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(806), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(771), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [58373] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(342), 1,
      sym_identifier,
    ACTIONS(344), 1,
      anon_sym_LPAREN,
    ACTIONS(354), 1,
      anon_sym_BSLASH,
    ACTIONS(356), 1,
      anon_sym_sizeof,
    ACTIONS(362), 1,
      aux_sym_symbol_token1,
    ACTIONS(364), 1,
      aux_sym_symbol_token2,
    ACTIONS(366), 1,
      sym__hll_number_literal_pre_hook,
    STATE(807), 1,
      sym_trace32_hll_variable,
    STATE(1593), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(346), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(348), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(350), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(569), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(358), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(360), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(806), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(772), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [58454] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(342), 1,
      sym_identifier,
    ACTIONS(354), 1,
      anon_sym_BSLASH,
    ACTIONS(356), 1,
      anon_sym_sizeof,
    ACTIONS(362), 1,
      aux_sym_symbol_token1,
    ACTIONS(364), 1,
      aux_sym_symbol_token2,
    ACTIONS(366), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(2245), 1,
      anon_sym_LPAREN,
    STATE(807), 1,
      sym_trace32_hll_variable,
    STATE(1593), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(346), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(348), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(350), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(569), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(358), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(360), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(806), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(773), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [58535] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(300), 1,
      sym_identifier,
    ACTIONS(304), 1,
      anon_sym_LPAREN,
    ACTIONS(316), 1,
      anon_sym_BSLASH,
    ACTIONS(318), 1,
      anon_sym_sizeof,
    ACTIONS(324), 1,
      aux_sym_symbol_token1,
    ACTIONS(326), 1,
      aux_sym_symbol_token2,
    ACTIONS(328), 1,
      sym__hll_number_literal_pre_hook,
    STATE(781), 1,
      sym_trace32_hll_variable,
    STATE(1601), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(308), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(310), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(312), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(448), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(320), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(322), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(778), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(675), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [58616] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(579), 1,
      aux_sym_symbol_token1,
    ACTIONS(581), 1,
      aux_sym_symbol_token2,
    ACTIONS(583), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(619), 1,
      sym_identifier,
    ACTIONS(621), 1,
      anon_sym_LPAREN,
    ACTIONS(629), 1,
      anon_sym_BSLASH,
    ACTIONS(631), 1,
      anon_sym_sizeof,
    STATE(842), 1,
      sym_trace32_hll_variable,
    STATE(1596), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(448), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(623), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(625), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(627), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(575), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(577), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(841), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1174), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [58697] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(579), 1,
      aux_sym_symbol_token1,
    ACTIONS(581), 1,
      aux_sym_symbol_token2,
    ACTIONS(583), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(619), 1,
      sym_identifier,
    ACTIONS(621), 1,
      anon_sym_LPAREN,
    ACTIONS(629), 1,
      anon_sym_BSLASH,
    ACTIONS(631), 1,
      anon_sym_sizeof,
    STATE(842), 1,
      sym_trace32_hll_variable,
    STATE(1596), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(448), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(623), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(625), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(627), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(575), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(577), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(841), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1175), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [58778] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(579), 1,
      aux_sym_symbol_token1,
    ACTIONS(581), 1,
      aux_sym_symbol_token2,
    ACTIONS(583), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(619), 1,
      sym_identifier,
    ACTIONS(629), 1,
      anon_sym_BSLASH,
    ACTIONS(631), 1,
      anon_sym_sizeof,
    ACTIONS(2247), 1,
      anon_sym_LPAREN,
    STATE(842), 1,
      sym_trace32_hll_variable,
    STATE(1596), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(448), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(623), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(625), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(627), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(575), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(577), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(841), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1176), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [58859] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(300), 1,
      sym_identifier,
    ACTIONS(304), 1,
      anon_sym_LPAREN,
    ACTIONS(316), 1,
      anon_sym_BSLASH,
    ACTIONS(318), 1,
      anon_sym_sizeof,
    ACTIONS(324), 1,
      aux_sym_symbol_token1,
    ACTIONS(326), 1,
      aux_sym_symbol_token2,
    ACTIONS(328), 1,
      sym__hll_number_literal_pre_hook,
    STATE(781), 1,
      sym_trace32_hll_variable,
    STATE(1601), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(308), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(310), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(312), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(448), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(320), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(322), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(778), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(676), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [58940] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(300), 1,
      sym_identifier,
    ACTIONS(304), 1,
      anon_sym_LPAREN,
    ACTIONS(316), 1,
      anon_sym_BSLASH,
    ACTIONS(318), 1,
      anon_sym_sizeof,
    ACTIONS(324), 1,
      aux_sym_symbol_token1,
    ACTIONS(326), 1,
      aux_sym_symbol_token2,
    ACTIONS(328), 1,
      sym__hll_number_literal_pre_hook,
    STATE(781), 1,
      sym_trace32_hll_variable,
    STATE(1601), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(308), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(310), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(312), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(448), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(320), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(322), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(778), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(739), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [59021] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(300), 1,
      sym_identifier,
    ACTIONS(304), 1,
      anon_sym_LPAREN,
    ACTIONS(316), 1,
      anon_sym_BSLASH,
    ACTIONS(318), 1,
      anon_sym_sizeof,
    ACTIONS(324), 1,
      aux_sym_symbol_token1,
    ACTIONS(326), 1,
      aux_sym_symbol_token2,
    ACTIONS(328), 1,
      sym__hll_number_literal_pre_hook,
    STATE(781), 1,
      sym_trace32_hll_variable,
    STATE(1601), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(308), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(310), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(312), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(448), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(320), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(322), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(778), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(693), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [59102] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(300), 1,
      sym_identifier,
    ACTIONS(316), 1,
      anon_sym_BSLASH,
    ACTIONS(318), 1,
      anon_sym_sizeof,
    ACTIONS(324), 1,
      aux_sym_symbol_token1,
    ACTIONS(326), 1,
      aux_sym_symbol_token2,
    ACTIONS(328), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(2249), 1,
      anon_sym_LPAREN,
    STATE(781), 1,
      sym_trace32_hll_variable,
    STATE(1601), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(308), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(310), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(312), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(448), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(320), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(322), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(778), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(641), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [59183] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(300), 1,
      sym_identifier,
    ACTIONS(304), 1,
      anon_sym_LPAREN,
    ACTIONS(316), 1,
      anon_sym_BSLASH,
    ACTIONS(318), 1,
      anon_sym_sizeof,
    ACTIONS(324), 1,
      aux_sym_symbol_token1,
    ACTIONS(326), 1,
      aux_sym_symbol_token2,
    ACTIONS(328), 1,
      sym__hll_number_literal_pre_hook,
    STATE(781), 1,
      sym_trace32_hll_variable,
    STATE(1601), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(308), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(310), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(312), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(448), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(320), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(322), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(778), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(677), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [59264] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(645), 1,
      anon_sym_BSLASH,
    ACTIONS(653), 1,
      aux_sym_symbol_token1,
    ACTIONS(655), 1,
      aux_sym_symbol_token2,
    ACTIONS(657), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(717), 1,
      sym_identifier,
    ACTIONS(719), 1,
      anon_sym_LPAREN,
    ACTIONS(727), 1,
      anon_sym_sizeof,
    STATE(885), 1,
      sym_trace32_hll_variable,
    STATE(1605), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(643), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(721), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(723), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(725), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(649), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(651), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(884), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1195), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [59345] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(645), 1,
      anon_sym_BSLASH,
    ACTIONS(653), 1,
      aux_sym_symbol_token1,
    ACTIONS(655), 1,
      aux_sym_symbol_token2,
    ACTIONS(657), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(717), 1,
      sym_identifier,
    ACTIONS(719), 1,
      anon_sym_LPAREN,
    ACTIONS(727), 1,
      anon_sym_sizeof,
    STATE(885), 1,
      sym_trace32_hll_variable,
    STATE(1605), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(643), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(721), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(723), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(725), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(649), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(651), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(884), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1197), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [59426] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(645), 1,
      anon_sym_BSLASH,
    ACTIONS(653), 1,
      aux_sym_symbol_token1,
    ACTIONS(655), 1,
      aux_sym_symbol_token2,
    ACTIONS(657), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(717), 1,
      sym_identifier,
    ACTIONS(727), 1,
      anon_sym_sizeof,
    ACTIONS(2251), 1,
      anon_sym_LPAREN,
    STATE(885), 1,
      sym_trace32_hll_variable,
    STATE(1605), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(643), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(721), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(723), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(725), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(649), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(651), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(884), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1309), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [59507] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(300), 1,
      sym_identifier,
    ACTIONS(304), 1,
      anon_sym_LPAREN,
    ACTIONS(316), 1,
      anon_sym_BSLASH,
    ACTIONS(318), 1,
      anon_sym_sizeof,
    ACTIONS(324), 1,
      aux_sym_symbol_token1,
    ACTIONS(326), 1,
      aux_sym_symbol_token2,
    ACTIONS(328), 1,
      sym__hll_number_literal_pre_hook,
    STATE(781), 1,
      sym_trace32_hll_variable,
    STATE(1601), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(308), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(310), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(312), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(448), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(320), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(322), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(778), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(678), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [59588] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(633), 1,
      sym_identifier,
    ACTIONS(635), 1,
      anon_sym_LPAREN,
    ACTIONS(645), 1,
      anon_sym_BSLASH,
    ACTIONS(647), 1,
      anon_sym_sizeof,
    ACTIONS(653), 1,
      aux_sym_symbol_token1,
    ACTIONS(655), 1,
      aux_sym_symbol_token2,
    ACTIONS(657), 1,
      sym__hll_number_literal_pre_hook,
    STATE(890), 1,
      sym_trace32_hll_variable,
    STATE(1609), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(637), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(639), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(641), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(643), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(649), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(651), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(889), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1195), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [59669] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(633), 1,
      sym_identifier,
    ACTIONS(635), 1,
      anon_sym_LPAREN,
    ACTIONS(645), 1,
      anon_sym_BSLASH,
    ACTIONS(647), 1,
      anon_sym_sizeof,
    ACTIONS(653), 1,
      aux_sym_symbol_token1,
    ACTIONS(655), 1,
      aux_sym_symbol_token2,
    ACTIONS(657), 1,
      sym__hll_number_literal_pre_hook,
    STATE(890), 1,
      sym_trace32_hll_variable,
    STATE(1609), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(637), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(639), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(641), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(643), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(649), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(651), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(889), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1197), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [59750] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(633), 1,
      sym_identifier,
    ACTIONS(645), 1,
      anon_sym_BSLASH,
    ACTIONS(647), 1,
      anon_sym_sizeof,
    ACTIONS(653), 1,
      aux_sym_symbol_token1,
    ACTIONS(655), 1,
      aux_sym_symbol_token2,
    ACTIONS(657), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(2253), 1,
      anon_sym_LPAREN,
    STATE(890), 1,
      sym_trace32_hll_variable,
    STATE(1609), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(637), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(639), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(641), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(643), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(649), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(651), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(889), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1169), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [59831] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(300), 1,
      sym_identifier,
    ACTIONS(304), 1,
      anon_sym_LPAREN,
    ACTIONS(316), 1,
      anon_sym_BSLASH,
    ACTIONS(318), 1,
      anon_sym_sizeof,
    ACTIONS(324), 1,
      aux_sym_symbol_token1,
    ACTIONS(326), 1,
      aux_sym_symbol_token2,
    ACTIONS(328), 1,
      sym__hll_number_literal_pre_hook,
    STATE(781), 1,
      sym_trace32_hll_variable,
    STATE(1601), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(308), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(310), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(312), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(448), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(320), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(322), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(778), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(680), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [59912] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(394), 1,
      sym_identifier,
    ACTIONS(396), 1,
      anon_sym_LPAREN,
    ACTIONS(406), 1,
      anon_sym_BSLASH,
    ACTIONS(408), 1,
      anon_sym_sizeof,
    ACTIONS(414), 1,
      aux_sym_symbol_token1,
    ACTIONS(416), 1,
      aux_sym_symbol_token2,
    ACTIONS(418), 1,
      sym__hll_number_literal_pre_hook,
    STATE(893), 1,
      sym_trace32_hll_variable,
    STATE(1615), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(398), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(400), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(402), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(643), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(410), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(412), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(892), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(843), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [59993] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(394), 1,
      sym_identifier,
    ACTIONS(396), 1,
      anon_sym_LPAREN,
    ACTIONS(406), 1,
      anon_sym_BSLASH,
    ACTIONS(408), 1,
      anon_sym_sizeof,
    ACTIONS(414), 1,
      aux_sym_symbol_token1,
    ACTIONS(416), 1,
      aux_sym_symbol_token2,
    ACTIONS(418), 1,
      sym__hll_number_literal_pre_hook,
    STATE(893), 1,
      sym_trace32_hll_variable,
    STATE(1615), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(398), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(400), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(402), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(643), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(410), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(412), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(892), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(844), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [60074] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(394), 1,
      sym_identifier,
    ACTIONS(406), 1,
      anon_sym_BSLASH,
    ACTIONS(408), 1,
      anon_sym_sizeof,
    ACTIONS(414), 1,
      aux_sym_symbol_token1,
    ACTIONS(416), 1,
      aux_sym_symbol_token2,
    ACTIONS(418), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(2255), 1,
      anon_sym_LPAREN,
    STATE(893), 1,
      sym_trace32_hll_variable,
    STATE(1615), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(398), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(400), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(402), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(643), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(410), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(412), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(892), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(845), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [60155] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(300), 1,
      sym_identifier,
    ACTIONS(304), 1,
      anon_sym_LPAREN,
    ACTIONS(316), 1,
      anon_sym_BSLASH,
    ACTIONS(318), 1,
      anon_sym_sizeof,
    ACTIONS(324), 1,
      aux_sym_symbol_token1,
    ACTIONS(326), 1,
      aux_sym_symbol_token2,
    ACTIONS(328), 1,
      sym__hll_number_literal_pre_hook,
    STATE(781), 1,
      sym_trace32_hll_variable,
    STATE(1601), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(308), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(310), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(312), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(448), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(320), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(322), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(778), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(525), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [60236] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(440), 1,
      anon_sym_LPAREN,
    ACTIONS(450), 1,
      anon_sym_BSLASH,
    ACTIONS(452), 1,
      anon_sym_sizeof,
    ACTIONS(470), 1,
      aux_sym_symbol_token1,
    ACTIONS(472), 1,
      aux_sym_symbol_token2,
    ACTIONS(476), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(547), 1,
      sym_identifier,
    STATE(799), 1,
      sym_trace32_hll_variable,
    STATE(1652), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(442), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(444), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(446), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(448), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(454), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(456), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(798), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(988), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [60317] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(579), 1,
      aux_sym_symbol_token1,
    ACTIONS(581), 1,
      aux_sym_symbol_token2,
    ACTIONS(583), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(811), 1,
      sym_identifier,
    ACTIONS(813), 1,
      anon_sym_LPAREN,
    ACTIONS(823), 1,
      anon_sym_BSLASH,
    ACTIONS(825), 1,
      anon_sym_sizeof,
    STATE(916), 1,
      sym_trace32_hll_variable,
    STATE(1587), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(815), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(817), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(819), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(821), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(575), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(577), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(915), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1267), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [60398] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(300), 1,
      sym_identifier,
    ACTIONS(304), 1,
      anon_sym_LPAREN,
    ACTIONS(316), 1,
      anon_sym_BSLASH,
    ACTIONS(318), 1,
      anon_sym_sizeof,
    ACTIONS(324), 1,
      aux_sym_symbol_token1,
    ACTIONS(326), 1,
      aux_sym_symbol_token2,
    ACTIONS(328), 1,
      sym__hll_number_literal_pre_hook,
    STATE(781), 1,
      sym_trace32_hll_variable,
    STATE(1601), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(308), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(310), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(312), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(448), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(320), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(322), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(778), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(681), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [60479] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(579), 1,
      aux_sym_symbol_token1,
    ACTIONS(581), 1,
      aux_sym_symbol_token2,
    ACTIONS(583), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(619), 1,
      sym_identifier,
    ACTIONS(621), 1,
      anon_sym_LPAREN,
    ACTIONS(629), 1,
      anon_sym_BSLASH,
    ACTIONS(631), 1,
      anon_sym_sizeof,
    STATE(842), 1,
      sym_trace32_hll_variable,
    STATE(1596), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(448), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(623), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(625), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(627), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(575), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(577), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(841), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1365), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [60560] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(300), 1,
      sym_identifier,
    ACTIONS(304), 1,
      anon_sym_LPAREN,
    ACTIONS(316), 1,
      anon_sym_BSLASH,
    ACTIONS(318), 1,
      anon_sym_sizeof,
    ACTIONS(324), 1,
      aux_sym_symbol_token1,
    ACTIONS(326), 1,
      aux_sym_symbol_token2,
    ACTIONS(328), 1,
      sym__hll_number_literal_pre_hook,
    STATE(781), 1,
      sym_trace32_hll_variable,
    STATE(1601), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(308), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(310), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(312), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(448), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(320), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(322), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(778), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(682), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [60641] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(300), 1,
      sym_identifier,
    ACTIONS(304), 1,
      anon_sym_LPAREN,
    ACTIONS(316), 1,
      anon_sym_BSLASH,
    ACTIONS(318), 1,
      anon_sym_sizeof,
    ACTIONS(324), 1,
      aux_sym_symbol_token1,
    ACTIONS(326), 1,
      aux_sym_symbol_token2,
    ACTIONS(328), 1,
      sym__hll_number_literal_pre_hook,
    STATE(781), 1,
      sym_trace32_hll_variable,
    STATE(1601), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(308), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(310), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(312), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(448), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(320), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(322), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(778), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(546), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [60722] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(440), 1,
      anon_sym_LPAREN,
    ACTIONS(450), 1,
      anon_sym_BSLASH,
    ACTIONS(452), 1,
      anon_sym_sizeof,
    ACTIONS(470), 1,
      aux_sym_symbol_token1,
    ACTIONS(472), 1,
      aux_sym_symbol_token2,
    ACTIONS(476), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(547), 1,
      sym_identifier,
    STATE(799), 1,
      sym_trace32_hll_variable,
    STATE(1652), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(442), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(444), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(446), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(448), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(454), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(456), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(798), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(965), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [60803] = 11,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2199), 1,
      anon_sym_LPAREN,
    ACTIONS(2205), 1,
      anon_sym_DOT,
    ACTIONS(2207), 1,
      anon_sym_DASH_GT,
    ACTIONS(2209), 1,
      anon_sym_LBRACK,
    STATE(752), 1,
      sym_hll_argument_list,
    ACTIONS(2203), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2243), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2257), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2201), 8,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
    ACTIONS(2197), 23,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [60870] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2199), 1,
      anon_sym_LPAREN,
    ACTIONS(2201), 1,
      anon_sym_EQ,
    ACTIONS(2205), 1,
      anon_sym_DOT,
    ACTIONS(2207), 1,
      anon_sym_DASH_GT,
    ACTIONS(2209), 1,
      anon_sym_LBRACK,
    ACTIONS(2261), 1,
      anon_sym_PIPE,
    ACTIONS(2263), 1,
      anon_sym_CARET,
    ACTIONS(2271), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2273), 1,
      anon_sym_AMP,
    STATE(752), 1,
      sym_hll_argument_list,
    ACTIONS(2203), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2243), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2259), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2265), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2267), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2269), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2257), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2197), 18,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_DOT,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [60953] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2199), 1,
      anon_sym_LPAREN,
    ACTIONS(2205), 1,
      anon_sym_DOT,
    ACTIONS(2207), 1,
      anon_sym_DASH_GT,
    ACTIONS(2209), 1,
      anon_sym_LBRACK,
    STATE(752), 1,
      sym_hll_argument_list,
    ACTIONS(2203), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2243), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2201), 11,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
    ACTIONS(2197), 23,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [61018] = 17,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2199), 1,
      anon_sym_LPAREN,
    ACTIONS(2205), 1,
      anon_sym_DOT,
    ACTIONS(2207), 1,
      anon_sym_DASH_GT,
    ACTIONS(2209), 1,
      anon_sym_LBRACK,
    ACTIONS(2263), 1,
      anon_sym_CARET,
    ACTIONS(2273), 1,
      anon_sym_AMP,
    STATE(752), 1,
      sym_hll_argument_list,
    ACTIONS(2201), 2,
      anon_sym_EQ,
      anon_sym_PIPE,
    ACTIONS(2203), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2243), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2259), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2265), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2267), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2269), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2257), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2197), 19,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [61097] = 16,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2199), 1,
      anon_sym_LPAREN,
    ACTIONS(2205), 1,
      anon_sym_DOT,
    ACTIONS(2207), 1,
      anon_sym_DASH_GT,
    ACTIONS(2209), 1,
      anon_sym_LBRACK,
    ACTIONS(2273), 1,
      anon_sym_AMP,
    STATE(752), 1,
      sym_hll_argument_list,
    ACTIONS(2203), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2243), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2259), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2265), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2267), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2269), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2201), 3,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
    ACTIONS(2257), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2197), 19,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [61174] = 14,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2199), 1,
      anon_sym_LPAREN,
    ACTIONS(2205), 1,
      anon_sym_DOT,
    ACTIONS(2207), 1,
      anon_sym_DASH_GT,
    ACTIONS(2209), 1,
      anon_sym_LBRACK,
    STATE(752), 1,
      sym_hll_argument_list,
    ACTIONS(2203), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2243), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2259), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2267), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2269), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2257), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2201), 4,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
    ACTIONS(2197), 21,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [61247] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(440), 1,
      anon_sym_LPAREN,
    ACTIONS(450), 1,
      anon_sym_BSLASH,
    ACTIONS(452), 1,
      anon_sym_sizeof,
    ACTIONS(470), 1,
      aux_sym_symbol_token1,
    ACTIONS(472), 1,
      aux_sym_symbol_token2,
    ACTIONS(476), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(547), 1,
      sym_identifier,
    STATE(799), 1,
      sym_trace32_hll_variable,
    STATE(1652), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(442), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(444), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(446), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(448), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(454), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(456), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(798), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1030), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [61328] = 12,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2199), 1,
      anon_sym_LPAREN,
    ACTIONS(2205), 1,
      anon_sym_DOT,
    ACTIONS(2207), 1,
      anon_sym_DASH_GT,
    ACTIONS(2209), 1,
      anon_sym_LBRACK,
    STATE(752), 1,
      sym_hll_argument_list,
    ACTIONS(2203), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2243), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2259), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2257), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2201), 6,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
    ACTIONS(2197), 23,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [61397] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2199), 1,
      anon_sym_LPAREN,
    ACTIONS(2201), 1,
      anon_sym_EQ,
    ACTIONS(2205), 1,
      anon_sym_DOT,
    ACTIONS(2207), 1,
      anon_sym_DASH_GT,
    ACTIONS(2209), 1,
      anon_sym_LBRACK,
    ACTIONS(2261), 1,
      anon_sym_PIPE,
    ACTIONS(2263), 1,
      anon_sym_CARET,
    ACTIONS(2273), 1,
      anon_sym_AMP,
    STATE(752), 1,
      sym_hll_argument_list,
    ACTIONS(2203), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2243), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2259), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2265), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2267), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2269), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2257), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2197), 19,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [61478] = 15,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2199), 1,
      anon_sym_LPAREN,
    ACTIONS(2205), 1,
      anon_sym_DOT,
    ACTIONS(2207), 1,
      anon_sym_DASH_GT,
    ACTIONS(2209), 1,
      anon_sym_LBRACK,
    STATE(752), 1,
      sym_hll_argument_list,
    ACTIONS(2203), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2243), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2259), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2265), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2267), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2269), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2257), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2201), 4,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
    ACTIONS(2197), 19,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [61553] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(300), 1,
      sym_identifier,
    ACTIONS(304), 1,
      anon_sym_LPAREN,
    ACTIONS(316), 1,
      anon_sym_BSLASH,
    ACTIONS(318), 1,
      anon_sym_sizeof,
    ACTIONS(324), 1,
      aux_sym_symbol_token1,
    ACTIONS(326), 1,
      aux_sym_symbol_token2,
    ACTIONS(328), 1,
      sym__hll_number_literal_pre_hook,
    STATE(781), 1,
      sym_trace32_hll_variable,
    STATE(1601), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(308), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(310), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(312), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(448), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(320), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(322), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(778), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(691), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [61634] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2199), 1,
      anon_sym_LPAREN,
    ACTIONS(2205), 1,
      anon_sym_DOT,
    ACTIONS(2207), 1,
      anon_sym_DASH_GT,
    ACTIONS(2209), 1,
      anon_sym_LBRACK,
    ACTIONS(2261), 1,
      anon_sym_PIPE,
    ACTIONS(2263), 1,
      anon_sym_CARET,
    ACTIONS(2271), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2273), 1,
      anon_sym_AMP,
    ACTIONS(2277), 1,
      anon_sym_EQ,
    ACTIONS(2279), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2281), 1,
      anon_sym_QMARK,
    STATE(752), 1,
      sym_hll_argument_list,
    ACTIONS(2203), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2243), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2259), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2265), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2267), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2269), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2257), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2275), 16,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [61721] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(559), 1,
      sym_identifier,
    ACTIONS(561), 1,
      anon_sym_LPAREN,
    ACTIONS(571), 1,
      anon_sym_BSLASH,
    ACTIONS(573), 1,
      anon_sym_sizeof,
    ACTIONS(579), 1,
      aux_sym_symbol_token1,
    ACTIONS(581), 1,
      aux_sym_symbol_token2,
    ACTIONS(583), 1,
      sym__hll_number_literal_pre_hook,
    STATE(812), 1,
      sym_trace32_hll_variable,
    STATE(1655), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(563), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(565), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(567), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(569), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(575), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(577), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(811), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(986), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [61802] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(579), 1,
      aux_sym_symbol_token1,
    ACTIONS(581), 1,
      aux_sym_symbol_token2,
    ACTIONS(583), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(619), 1,
      sym_identifier,
    ACTIONS(621), 1,
      anon_sym_LPAREN,
    ACTIONS(629), 1,
      anon_sym_BSLASH,
    ACTIONS(631), 1,
      anon_sym_sizeof,
    STATE(842), 1,
      sym_trace32_hll_variable,
    STATE(1596), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(448), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(623), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(625), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(627), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(575), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(577), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(841), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1363), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [61883] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(300), 1,
      sym_identifier,
    ACTIONS(304), 1,
      anon_sym_LPAREN,
    ACTIONS(316), 1,
      anon_sym_BSLASH,
    ACTIONS(318), 1,
      anon_sym_sizeof,
    ACTIONS(324), 1,
      aux_sym_symbol_token1,
    ACTIONS(326), 1,
      aux_sym_symbol_token2,
    ACTIONS(328), 1,
      sym__hll_number_literal_pre_hook,
    STATE(781), 1,
      sym_trace32_hll_variable,
    STATE(1601), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(308), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(310), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(312), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(448), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(320), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(322), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(778), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(580), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [61964] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(300), 1,
      sym_identifier,
    ACTIONS(304), 1,
      anon_sym_LPAREN,
    ACTIONS(316), 1,
      anon_sym_BSLASH,
    ACTIONS(318), 1,
      anon_sym_sizeof,
    ACTIONS(324), 1,
      aux_sym_symbol_token1,
    ACTIONS(326), 1,
      aux_sym_symbol_token2,
    ACTIONS(328), 1,
      sym__hll_number_literal_pre_hook,
    STATE(781), 1,
      sym_trace32_hll_variable,
    STATE(1601), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(308), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(310), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(312), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(448), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(320), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(322), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(778), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(583), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [62045] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(368), 1,
      sym_identifier,
    ACTIONS(370), 1,
      anon_sym_LPAREN,
    ACTIONS(380), 1,
      anon_sym_BSLASH,
    ACTIONS(382), 1,
      anon_sym_sizeof,
    ACTIONS(388), 1,
      aux_sym_symbol_token1,
    ACTIONS(390), 1,
      aux_sym_symbol_token2,
    ACTIONS(392), 1,
      sym__hll_number_literal_pre_hook,
    STATE(900), 1,
      sym_trace32_hll_variable,
    STATE(1580), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(372), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(374), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(376), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(821), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(384), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(386), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(898), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(870), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [62126] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(368), 1,
      sym_identifier,
    ACTIONS(370), 1,
      anon_sym_LPAREN,
    ACTIONS(380), 1,
      anon_sym_BSLASH,
    ACTIONS(382), 1,
      anon_sym_sizeof,
    ACTIONS(388), 1,
      aux_sym_symbol_token1,
    ACTIONS(390), 1,
      aux_sym_symbol_token2,
    ACTIONS(392), 1,
      sym__hll_number_literal_pre_hook,
    STATE(900), 1,
      sym_trace32_hll_variable,
    STATE(1580), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(372), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(374), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(376), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(821), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(384), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(386), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(898), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(826), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [62207] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2199), 1,
      anon_sym_LPAREN,
    ACTIONS(2205), 1,
      anon_sym_DOT,
    ACTIONS(2207), 1,
      anon_sym_DASH_GT,
    ACTIONS(2209), 1,
      anon_sym_LBRACK,
    ACTIONS(2261), 1,
      anon_sym_PIPE,
    ACTIONS(2263), 1,
      anon_sym_CARET,
    ACTIONS(2271), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2273), 1,
      anon_sym_AMP,
    ACTIONS(2279), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2281), 1,
      anon_sym_QMARK,
    ACTIONS(2285), 1,
      anon_sym_EQ,
    STATE(752), 1,
      sym_hll_argument_list,
    ACTIONS(2203), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2243), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2259), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2265), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2267), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2269), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2257), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2283), 16,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [62294] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(300), 1,
      sym_identifier,
    ACTIONS(304), 1,
      anon_sym_LPAREN,
    ACTIONS(316), 1,
      anon_sym_BSLASH,
    ACTIONS(318), 1,
      anon_sym_sizeof,
    ACTIONS(324), 1,
      aux_sym_symbol_token1,
    ACTIONS(326), 1,
      aux_sym_symbol_token2,
    ACTIONS(328), 1,
      sym__hll_number_literal_pre_hook,
    STATE(781), 1,
      sym_trace32_hll_variable,
    STATE(1601), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(308), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(310), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(312), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(448), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(320), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(322), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(778), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(710), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [62375] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2199), 1,
      anon_sym_LPAREN,
    ACTIONS(2205), 1,
      anon_sym_DOT,
    ACTIONS(2207), 1,
      anon_sym_DASH_GT,
    ACTIONS(2209), 1,
      anon_sym_LBRACK,
    STATE(752), 1,
      sym_hll_argument_list,
    ACTIONS(2203), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2289), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
    ACTIONS(2287), 23,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [62438] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2199), 1,
      anon_sym_LPAREN,
    ACTIONS(2205), 1,
      anon_sym_DOT,
    ACTIONS(2207), 1,
      anon_sym_DASH_GT,
    ACTIONS(2209), 1,
      anon_sym_LBRACK,
    ACTIONS(2261), 1,
      anon_sym_PIPE,
    ACTIONS(2263), 1,
      anon_sym_CARET,
    ACTIONS(2271), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2273), 1,
      anon_sym_AMP,
    ACTIONS(2279), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2281), 1,
      anon_sym_QMARK,
    ACTIONS(2293), 1,
      anon_sym_EQ,
    STATE(752), 1,
      sym_hll_argument_list,
    ACTIONS(2203), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2243), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2259), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2265), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2267), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2269), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2257), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2291), 16,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [62525] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(368), 1,
      sym_identifier,
    ACTIONS(370), 1,
      anon_sym_LPAREN,
    ACTIONS(380), 1,
      anon_sym_BSLASH,
    ACTIONS(382), 1,
      anon_sym_sizeof,
    ACTIONS(388), 1,
      aux_sym_symbol_token1,
    ACTIONS(390), 1,
      aux_sym_symbol_token2,
    ACTIONS(392), 1,
      sym__hll_number_literal_pre_hook,
    STATE(900), 1,
      sym_trace32_hll_variable,
    STATE(1580), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(372), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(374), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(376), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(821), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(384), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(386), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(898), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(828), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [62606] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(559), 1,
      sym_identifier,
    ACTIONS(561), 1,
      anon_sym_LPAREN,
    ACTIONS(571), 1,
      anon_sym_BSLASH,
    ACTIONS(573), 1,
      anon_sym_sizeof,
    ACTIONS(579), 1,
      aux_sym_symbol_token1,
    ACTIONS(581), 1,
      aux_sym_symbol_token2,
    ACTIONS(583), 1,
      sym__hll_number_literal_pre_hook,
    STATE(812), 1,
      sym_trace32_hll_variable,
    STATE(1655), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(563), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(565), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(567), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(569), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(575), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(577), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(811), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1020), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [62687] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(559), 1,
      sym_identifier,
    ACTIONS(561), 1,
      anon_sym_LPAREN,
    ACTIONS(571), 1,
      anon_sym_BSLASH,
    ACTIONS(573), 1,
      anon_sym_sizeof,
    ACTIONS(579), 1,
      aux_sym_symbol_token1,
    ACTIONS(581), 1,
      aux_sym_symbol_token2,
    ACTIONS(583), 1,
      sym__hll_number_literal_pre_hook,
    STATE(812), 1,
      sym_trace32_hll_variable,
    STATE(1655), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(563), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(565), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(567), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(569), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(575), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(577), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(811), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1021), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [62768] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(559), 1,
      sym_identifier,
    ACTIONS(561), 1,
      anon_sym_LPAREN,
    ACTIONS(571), 1,
      anon_sym_BSLASH,
    ACTIONS(573), 1,
      anon_sym_sizeof,
    ACTIONS(579), 1,
      aux_sym_symbol_token1,
    ACTIONS(581), 1,
      aux_sym_symbol_token2,
    ACTIONS(583), 1,
      sym__hll_number_literal_pre_hook,
    STATE(812), 1,
      sym_trace32_hll_variable,
    STATE(1655), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(563), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(565), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(567), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(569), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(575), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(577), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(811), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1022), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [62849] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(559), 1,
      sym_identifier,
    ACTIONS(561), 1,
      anon_sym_LPAREN,
    ACTIONS(571), 1,
      anon_sym_BSLASH,
    ACTIONS(573), 1,
      anon_sym_sizeof,
    ACTIONS(579), 1,
      aux_sym_symbol_token1,
    ACTIONS(581), 1,
      aux_sym_symbol_token2,
    ACTIONS(583), 1,
      sym__hll_number_literal_pre_hook,
    STATE(812), 1,
      sym_trace32_hll_variable,
    STATE(1655), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(563), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(565), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(567), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(569), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(575), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(577), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(811), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1023), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [62930] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(559), 1,
      sym_identifier,
    ACTIONS(561), 1,
      anon_sym_LPAREN,
    ACTIONS(571), 1,
      anon_sym_BSLASH,
    ACTIONS(573), 1,
      anon_sym_sizeof,
    ACTIONS(579), 1,
      aux_sym_symbol_token1,
    ACTIONS(581), 1,
      aux_sym_symbol_token2,
    ACTIONS(583), 1,
      sym__hll_number_literal_pre_hook,
    STATE(812), 1,
      sym_trace32_hll_variable,
    STATE(1655), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(563), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(565), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(567), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(569), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(575), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(577), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(811), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1024), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [63011] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(559), 1,
      sym_identifier,
    ACTIONS(561), 1,
      anon_sym_LPAREN,
    ACTIONS(571), 1,
      anon_sym_BSLASH,
    ACTIONS(573), 1,
      anon_sym_sizeof,
    ACTIONS(579), 1,
      aux_sym_symbol_token1,
    ACTIONS(581), 1,
      aux_sym_symbol_token2,
    ACTIONS(583), 1,
      sym__hll_number_literal_pre_hook,
    STATE(812), 1,
      sym_trace32_hll_variable,
    STATE(1655), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(563), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(565), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(567), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(569), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(575), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(577), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(811), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1025), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [63092] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(559), 1,
      sym_identifier,
    ACTIONS(561), 1,
      anon_sym_LPAREN,
    ACTIONS(571), 1,
      anon_sym_BSLASH,
    ACTIONS(573), 1,
      anon_sym_sizeof,
    ACTIONS(579), 1,
      aux_sym_symbol_token1,
    ACTIONS(581), 1,
      aux_sym_symbol_token2,
    ACTIONS(583), 1,
      sym__hll_number_literal_pre_hook,
    STATE(812), 1,
      sym_trace32_hll_variable,
    STATE(1655), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(563), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(565), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(567), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(569), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(575), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(577), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(811), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1026), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [63173] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(559), 1,
      sym_identifier,
    ACTIONS(561), 1,
      anon_sym_LPAREN,
    ACTIONS(571), 1,
      anon_sym_BSLASH,
    ACTIONS(573), 1,
      anon_sym_sizeof,
    ACTIONS(579), 1,
      aux_sym_symbol_token1,
    ACTIONS(581), 1,
      aux_sym_symbol_token2,
    ACTIONS(583), 1,
      sym__hll_number_literal_pre_hook,
    STATE(812), 1,
      sym_trace32_hll_variable,
    STATE(1655), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(563), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(565), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(567), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(569), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(575), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(577), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(811), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(982), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [63254] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(559), 1,
      sym_identifier,
    ACTIONS(561), 1,
      anon_sym_LPAREN,
    ACTIONS(571), 1,
      anon_sym_BSLASH,
    ACTIONS(573), 1,
      anon_sym_sizeof,
    ACTIONS(579), 1,
      aux_sym_symbol_token1,
    ACTIONS(581), 1,
      aux_sym_symbol_token2,
    ACTIONS(583), 1,
      sym__hll_number_literal_pre_hook,
    STATE(812), 1,
      sym_trace32_hll_variable,
    STATE(1655), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(563), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(565), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(567), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(569), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(575), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(577), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(811), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1028), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [63335] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(559), 1,
      sym_identifier,
    ACTIONS(561), 1,
      anon_sym_LPAREN,
    ACTIONS(571), 1,
      anon_sym_BSLASH,
    ACTIONS(573), 1,
      anon_sym_sizeof,
    ACTIONS(579), 1,
      aux_sym_symbol_token1,
    ACTIONS(581), 1,
      aux_sym_symbol_token2,
    ACTIONS(583), 1,
      sym__hll_number_literal_pre_hook,
    STATE(812), 1,
      sym_trace32_hll_variable,
    STATE(1655), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(563), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(565), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(567), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(569), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(575), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(577), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(811), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1029), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [63416] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2199), 1,
      anon_sym_LPAREN,
    ACTIONS(2205), 1,
      anon_sym_DOT,
    ACTIONS(2207), 1,
      anon_sym_DASH_GT,
    ACTIONS(2209), 1,
      anon_sym_LBRACK,
    ACTIONS(2261), 1,
      anon_sym_PIPE,
    ACTIONS(2263), 1,
      anon_sym_CARET,
    ACTIONS(2271), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2273), 1,
      anon_sym_AMP,
    ACTIONS(2279), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2281), 1,
      anon_sym_QMARK,
    ACTIONS(2297), 1,
      anon_sym_EQ,
    STATE(752), 1,
      sym_hll_argument_list,
    ACTIONS(2203), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2243), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2259), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2265), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2267), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2269), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2257), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2295), 16,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [63503] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(300), 1,
      sym_identifier,
    ACTIONS(304), 1,
      anon_sym_LPAREN,
    ACTIONS(316), 1,
      anon_sym_BSLASH,
    ACTIONS(318), 1,
      anon_sym_sizeof,
    ACTIONS(324), 1,
      aux_sym_symbol_token1,
    ACTIONS(326), 1,
      aux_sym_symbol_token2,
    ACTIONS(328), 1,
      sym__hll_number_literal_pre_hook,
    STATE(781), 1,
      sym_trace32_hll_variable,
    STATE(1601), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(308), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(310), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(312), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(448), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(320), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(322), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(778), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(593), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [63584] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(579), 1,
      aux_sym_symbol_token1,
    ACTIONS(581), 1,
      aux_sym_symbol_token2,
    ACTIONS(583), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(811), 1,
      sym_identifier,
    ACTIONS(813), 1,
      anon_sym_LPAREN,
    ACTIONS(823), 1,
      anon_sym_BSLASH,
    ACTIONS(825), 1,
      anon_sym_sizeof,
    STATE(916), 1,
      sym_trace32_hll_variable,
    STATE(1587), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(815), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(817), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(819), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(821), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(575), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(577), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(915), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1292), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [63665] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(579), 1,
      aux_sym_symbol_token1,
    ACTIONS(581), 1,
      aux_sym_symbol_token2,
    ACTIONS(583), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(811), 1,
      sym_identifier,
    ACTIONS(813), 1,
      anon_sym_LPAREN,
    ACTIONS(823), 1,
      anon_sym_BSLASH,
    ACTIONS(825), 1,
      anon_sym_sizeof,
    STATE(916), 1,
      sym_trace32_hll_variable,
    STATE(1587), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(815), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(817), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(819), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(821), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(575), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(577), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(915), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1316), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [63746] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2199), 1,
      anon_sym_LPAREN,
    ACTIONS(2205), 1,
      anon_sym_DOT,
    ACTIONS(2207), 1,
      anon_sym_DASH_GT,
    ACTIONS(2209), 1,
      anon_sym_LBRACK,
    ACTIONS(2261), 1,
      anon_sym_PIPE,
    ACTIONS(2263), 1,
      anon_sym_CARET,
    ACTIONS(2271), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2273), 1,
      anon_sym_AMP,
    ACTIONS(2279), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2281), 1,
      anon_sym_QMARK,
    ACTIONS(2301), 1,
      anon_sym_EQ,
    STATE(752), 1,
      sym_hll_argument_list,
    ACTIONS(2203), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2243), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2259), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2265), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2267), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2269), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2257), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2299), 16,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [63833] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(368), 1,
      sym_identifier,
    ACTIONS(370), 1,
      anon_sym_LPAREN,
    ACTIONS(380), 1,
      anon_sym_BSLASH,
    ACTIONS(382), 1,
      anon_sym_sizeof,
    ACTIONS(388), 1,
      aux_sym_symbol_token1,
    ACTIONS(390), 1,
      aux_sym_symbol_token2,
    ACTIONS(392), 1,
      sym__hll_number_literal_pre_hook,
    STATE(900), 1,
      sym_trace32_hll_variable,
    STATE(1580), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(372), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(374), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(376), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(821), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(384), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(386), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(898), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(829), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [63914] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2199), 1,
      anon_sym_LPAREN,
    ACTIONS(2205), 1,
      anon_sym_DOT,
    ACTIONS(2207), 1,
      anon_sym_DASH_GT,
    ACTIONS(2209), 1,
      anon_sym_LBRACK,
    ACTIONS(2261), 1,
      anon_sym_PIPE,
    ACTIONS(2263), 1,
      anon_sym_CARET,
    ACTIONS(2271), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2273), 1,
      anon_sym_AMP,
    ACTIONS(2279), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2281), 1,
      anon_sym_QMARK,
    ACTIONS(2305), 1,
      anon_sym_EQ,
    STATE(752), 1,
      sym_hll_argument_list,
    ACTIONS(2203), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2243), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2259), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2265), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2267), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2269), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2257), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2303), 16,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [64001] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(579), 1,
      aux_sym_symbol_token1,
    ACTIONS(581), 1,
      aux_sym_symbol_token2,
    ACTIONS(583), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(619), 1,
      sym_identifier,
    ACTIONS(621), 1,
      anon_sym_LPAREN,
    ACTIONS(629), 1,
      anon_sym_BSLASH,
    ACTIONS(631), 1,
      anon_sym_sizeof,
    STATE(842), 1,
      sym_trace32_hll_variable,
    STATE(1596), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(448), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(623), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(625), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(627), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(575), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(577), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(841), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1366), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [64082] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(579), 1,
      aux_sym_symbol_token1,
    ACTIONS(581), 1,
      aux_sym_symbol_token2,
    ACTIONS(583), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(811), 1,
      sym_identifier,
    ACTIONS(813), 1,
      anon_sym_LPAREN,
    ACTIONS(823), 1,
      anon_sym_BSLASH,
    ACTIONS(825), 1,
      anon_sym_sizeof,
    STATE(916), 1,
      sym_trace32_hll_variable,
    STATE(1587), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(815), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(817), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(819), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(821), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(575), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(577), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(915), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1317), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [64163] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(368), 1,
      sym_identifier,
    ACTIONS(370), 1,
      anon_sym_LPAREN,
    ACTIONS(380), 1,
      anon_sym_BSLASH,
    ACTIONS(382), 1,
      anon_sym_sizeof,
    ACTIONS(388), 1,
      aux_sym_symbol_token1,
    ACTIONS(390), 1,
      aux_sym_symbol_token2,
    ACTIONS(392), 1,
      sym__hll_number_literal_pre_hook,
    STATE(900), 1,
      sym_trace32_hll_variable,
    STATE(1580), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(372), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(374), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(376), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(821), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(384), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(386), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(898), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(830), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [64244] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(368), 1,
      sym_identifier,
    ACTIONS(370), 1,
      anon_sym_LPAREN,
    ACTIONS(380), 1,
      anon_sym_BSLASH,
    ACTIONS(382), 1,
      anon_sym_sizeof,
    ACTIONS(388), 1,
      aux_sym_symbol_token1,
    ACTIONS(390), 1,
      aux_sym_symbol_token2,
    ACTIONS(392), 1,
      sym__hll_number_literal_pre_hook,
    STATE(900), 1,
      sym_trace32_hll_variable,
    STATE(1580), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(372), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(374), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(376), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(821), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(384), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(386), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(898), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(831), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [64325] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(368), 1,
      sym_identifier,
    ACTIONS(370), 1,
      anon_sym_LPAREN,
    ACTIONS(380), 1,
      anon_sym_BSLASH,
    ACTIONS(382), 1,
      anon_sym_sizeof,
    ACTIONS(388), 1,
      aux_sym_symbol_token1,
    ACTIONS(390), 1,
      aux_sym_symbol_token2,
    ACTIONS(392), 1,
      sym__hll_number_literal_pre_hook,
    STATE(900), 1,
      sym_trace32_hll_variable,
    STATE(1580), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(372), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(374), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(376), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(821), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(384), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(386), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(898), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(832), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [64406] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(368), 1,
      sym_identifier,
    ACTIONS(370), 1,
      anon_sym_LPAREN,
    ACTIONS(380), 1,
      anon_sym_BSLASH,
    ACTIONS(382), 1,
      anon_sym_sizeof,
    ACTIONS(388), 1,
      aux_sym_symbol_token1,
    ACTIONS(390), 1,
      aux_sym_symbol_token2,
    ACTIONS(392), 1,
      sym__hll_number_literal_pre_hook,
    STATE(900), 1,
      sym_trace32_hll_variable,
    STATE(1580), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(372), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(374), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(376), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(821), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(384), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(386), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(898), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(820), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [64487] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(368), 1,
      sym_identifier,
    ACTIONS(370), 1,
      anon_sym_LPAREN,
    ACTIONS(380), 1,
      anon_sym_BSLASH,
    ACTIONS(382), 1,
      anon_sym_sizeof,
    ACTIONS(388), 1,
      aux_sym_symbol_token1,
    ACTIONS(390), 1,
      aux_sym_symbol_token2,
    ACTIONS(392), 1,
      sym__hll_number_literal_pre_hook,
    STATE(900), 1,
      sym_trace32_hll_variable,
    STATE(1580), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(372), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(374), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(376), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(821), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(384), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(386), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(898), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(833), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [64568] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(368), 1,
      sym_identifier,
    ACTIONS(370), 1,
      anon_sym_LPAREN,
    ACTIONS(380), 1,
      anon_sym_BSLASH,
    ACTIONS(382), 1,
      anon_sym_sizeof,
    ACTIONS(388), 1,
      aux_sym_symbol_token1,
    ACTIONS(390), 1,
      aux_sym_symbol_token2,
    ACTIONS(392), 1,
      sym__hll_number_literal_pre_hook,
    STATE(900), 1,
      sym_trace32_hll_variable,
    STATE(1580), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(372), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(374), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(376), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(821), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(384), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(386), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(898), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(834), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [64649] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(368), 1,
      sym_identifier,
    ACTIONS(370), 1,
      anon_sym_LPAREN,
    ACTIONS(380), 1,
      anon_sym_BSLASH,
    ACTIONS(382), 1,
      anon_sym_sizeof,
    ACTIONS(388), 1,
      aux_sym_symbol_token1,
    ACTIONS(390), 1,
      aux_sym_symbol_token2,
    ACTIONS(392), 1,
      sym__hll_number_literal_pre_hook,
    STATE(900), 1,
      sym_trace32_hll_variable,
    STATE(1580), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(372), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(374), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(376), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(821), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(384), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(386), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(898), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(821), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [64730] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(368), 1,
      sym_identifier,
    ACTIONS(370), 1,
      anon_sym_LPAREN,
    ACTIONS(380), 1,
      anon_sym_BSLASH,
    ACTIONS(382), 1,
      anon_sym_sizeof,
    ACTIONS(388), 1,
      aux_sym_symbol_token1,
    ACTIONS(390), 1,
      aux_sym_symbol_token2,
    ACTIONS(392), 1,
      sym__hll_number_literal_pre_hook,
    STATE(900), 1,
      sym_trace32_hll_variable,
    STATE(1580), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(372), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(374), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(376), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(821), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(384), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(386), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(898), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(836), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [64811] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2307), 1,
      aux_sym_symbol_token3,
    ACTIONS(1889), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_DOT,
    ACTIONS(1891), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [64864] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(645), 1,
      anon_sym_BSLASH,
    ACTIONS(653), 1,
      aux_sym_symbol_token1,
    ACTIONS(655), 1,
      aux_sym_symbol_token2,
    ACTIONS(657), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(717), 1,
      sym_identifier,
    ACTIONS(719), 1,
      anon_sym_LPAREN,
    ACTIONS(727), 1,
      anon_sym_sizeof,
    STATE(885), 1,
      sym_trace32_hll_variable,
    STATE(1605), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(643), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(721), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(723), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(725), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(649), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(651), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(884), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1273), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [64945] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(368), 1,
      sym_identifier,
    ACTIONS(370), 1,
      anon_sym_LPAREN,
    ACTIONS(380), 1,
      anon_sym_BSLASH,
    ACTIONS(382), 1,
      anon_sym_sizeof,
    ACTIONS(388), 1,
      aux_sym_symbol_token1,
    ACTIONS(390), 1,
      aux_sym_symbol_token2,
    ACTIONS(392), 1,
      sym__hll_number_literal_pre_hook,
    STATE(900), 1,
      sym_trace32_hll_variable,
    STATE(1580), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(372), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(374), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(376), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(821), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(384), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(386), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(898), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(822), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [65026] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(368), 1,
      sym_identifier,
    ACTIONS(370), 1,
      anon_sym_LPAREN,
    ACTIONS(380), 1,
      anon_sym_BSLASH,
    ACTIONS(382), 1,
      anon_sym_sizeof,
    ACTIONS(388), 1,
      aux_sym_symbol_token1,
    ACTIONS(390), 1,
      aux_sym_symbol_token2,
    ACTIONS(392), 1,
      sym__hll_number_literal_pre_hook,
    STATE(900), 1,
      sym_trace32_hll_variable,
    STATE(1580), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(372), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(374), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(376), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(821), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(384), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(386), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(898), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(823), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [65107] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(645), 1,
      anon_sym_BSLASH,
    ACTIONS(653), 1,
      aux_sym_symbol_token1,
    ACTIONS(655), 1,
      aux_sym_symbol_token2,
    ACTIONS(657), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(717), 1,
      sym_identifier,
    ACTIONS(719), 1,
      anon_sym_LPAREN,
    ACTIONS(727), 1,
      anon_sym_sizeof,
    STATE(885), 1,
      sym_trace32_hll_variable,
    STATE(1605), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(643), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(721), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(723), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(725), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(649), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(651), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(884), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1274), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [65188] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(368), 1,
      sym_identifier,
    ACTIONS(370), 1,
      anon_sym_LPAREN,
    ACTIONS(380), 1,
      anon_sym_BSLASH,
    ACTIONS(382), 1,
      anon_sym_sizeof,
    ACTIONS(388), 1,
      aux_sym_symbol_token1,
    ACTIONS(390), 1,
      aux_sym_symbol_token2,
    ACTIONS(392), 1,
      sym__hll_number_literal_pre_hook,
    STATE(900), 1,
      sym_trace32_hll_variable,
    STATE(1580), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(372), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(374), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(376), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(821), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(384), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(386), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(898), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(839), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [65269] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(645), 1,
      anon_sym_BSLASH,
    ACTIONS(653), 1,
      aux_sym_symbol_token1,
    ACTIONS(655), 1,
      aux_sym_symbol_token2,
    ACTIONS(657), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(717), 1,
      sym_identifier,
    ACTIONS(719), 1,
      anon_sym_LPAREN,
    ACTIONS(727), 1,
      anon_sym_sizeof,
    STATE(885), 1,
      sym_trace32_hll_variable,
    STATE(1605), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(643), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(721), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(723), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(725), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(649), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(651), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(884), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1275), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [65350] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(368), 1,
      sym_identifier,
    ACTIONS(370), 1,
      anon_sym_LPAREN,
    ACTIONS(380), 1,
      anon_sym_BSLASH,
    ACTIONS(382), 1,
      anon_sym_sizeof,
    ACTIONS(388), 1,
      aux_sym_symbol_token1,
    ACTIONS(390), 1,
      aux_sym_symbol_token2,
    ACTIONS(392), 1,
      sym__hll_number_literal_pre_hook,
    STATE(900), 1,
      sym_trace32_hll_variable,
    STATE(1580), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(372), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(374), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(376), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(821), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(384), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(386), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(898), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(824), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [65431] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(645), 1,
      anon_sym_BSLASH,
    ACTIONS(653), 1,
      aux_sym_symbol_token1,
    ACTIONS(655), 1,
      aux_sym_symbol_token2,
    ACTIONS(657), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(717), 1,
      sym_identifier,
    ACTIONS(719), 1,
      anon_sym_LPAREN,
    ACTIONS(727), 1,
      anon_sym_sizeof,
    STATE(885), 1,
      sym_trace32_hll_variable,
    STATE(1605), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(643), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(721), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(723), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(725), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(649), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(651), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(884), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1276), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [65512] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(559), 1,
      sym_identifier,
    ACTIONS(561), 1,
      anon_sym_LPAREN,
    ACTIONS(571), 1,
      anon_sym_BSLASH,
    ACTIONS(573), 1,
      anon_sym_sizeof,
    ACTIONS(579), 1,
      aux_sym_symbol_token1,
    ACTIONS(581), 1,
      aux_sym_symbol_token2,
    ACTIONS(583), 1,
      sym__hll_number_literal_pre_hook,
    STATE(812), 1,
      sym_trace32_hll_variable,
    STATE(1655), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(563), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(565), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(567), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(569), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(575), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(577), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(811), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(997), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [65593] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(645), 1,
      anon_sym_BSLASH,
    ACTIONS(653), 1,
      aux_sym_symbol_token1,
    ACTIONS(655), 1,
      aux_sym_symbol_token2,
    ACTIONS(657), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(717), 1,
      sym_identifier,
    ACTIONS(719), 1,
      anon_sym_LPAREN,
    ACTIONS(727), 1,
      anon_sym_sizeof,
    STATE(885), 1,
      sym_trace32_hll_variable,
    STATE(1605), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(643), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(721), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(723), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(725), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(649), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(651), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(884), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1277), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [65674] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(579), 1,
      aux_sym_symbol_token1,
    ACTIONS(581), 1,
      aux_sym_symbol_token2,
    ACTIONS(583), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(811), 1,
      sym_identifier,
    ACTIONS(813), 1,
      anon_sym_LPAREN,
    ACTIONS(823), 1,
      anon_sym_BSLASH,
    ACTIONS(825), 1,
      anon_sym_sizeof,
    STATE(916), 1,
      sym_trace32_hll_variable,
    STATE(1587), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(815), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(817), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(819), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(821), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(575), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(577), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(915), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1312), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [65755] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(645), 1,
      anon_sym_BSLASH,
    ACTIONS(653), 1,
      aux_sym_symbol_token1,
    ACTIONS(655), 1,
      aux_sym_symbol_token2,
    ACTIONS(657), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(717), 1,
      sym_identifier,
    ACTIONS(719), 1,
      anon_sym_LPAREN,
    ACTIONS(727), 1,
      anon_sym_sizeof,
    STATE(885), 1,
      sym_trace32_hll_variable,
    STATE(1605), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(643), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(721), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(723), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(725), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(649), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(651), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(884), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1265), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [65836] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(645), 1,
      anon_sym_BSLASH,
    ACTIONS(653), 1,
      aux_sym_symbol_token1,
    ACTIONS(655), 1,
      aux_sym_symbol_token2,
    ACTIONS(657), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(717), 1,
      sym_identifier,
    ACTIONS(719), 1,
      anon_sym_LPAREN,
    ACTIONS(727), 1,
      anon_sym_sizeof,
    STATE(885), 1,
      sym_trace32_hll_variable,
    STATE(1605), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(643), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(721), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(723), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(725), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(649), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(651), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(884), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1278), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [65917] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(645), 1,
      anon_sym_BSLASH,
    ACTIONS(653), 1,
      aux_sym_symbol_token1,
    ACTIONS(655), 1,
      aux_sym_symbol_token2,
    ACTIONS(657), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(717), 1,
      sym_identifier,
    ACTIONS(719), 1,
      anon_sym_LPAREN,
    ACTIONS(727), 1,
      anon_sym_sizeof,
    STATE(885), 1,
      sym_trace32_hll_variable,
    STATE(1605), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(643), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(721), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(723), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(725), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(649), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(651), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(884), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1232), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [65998] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(645), 1,
      anon_sym_BSLASH,
    ACTIONS(653), 1,
      aux_sym_symbol_token1,
    ACTIONS(655), 1,
      aux_sym_symbol_token2,
    ACTIONS(657), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(717), 1,
      sym_identifier,
    ACTIONS(719), 1,
      anon_sym_LPAREN,
    ACTIONS(727), 1,
      anon_sym_sizeof,
    STATE(885), 1,
      sym_trace32_hll_variable,
    STATE(1605), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(643), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(721), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(723), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(725), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(649), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(651), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(884), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(1279), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [66079] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2199), 1,
      anon_sym_LPAREN,
    ACTIONS(2205), 1,
      anon_sym_DOT,
    ACTIONS(2207), 1,
      anon_sym_DASH_GT,
    ACTIONS(2209), 1,
      anon_sym_LBRACK,
    STATE(752), 1,
      sym_hll_argument_list,
    ACTIONS(2311), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
    ACTIONS(2309), 25,
      anon_sym_RPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [66140] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(300), 1,
      sym_identifier,
    ACTIONS(304), 1,
      anon_sym_LPAREN,
    ACTIONS(316), 1,
      anon_sym_BSLASH,
    ACTIONS(318), 1,
      anon_sym_sizeof,
    ACTIONS(324), 1,
      aux_sym_symbol_token1,
    ACTIONS(326), 1,
      aux_sym_symbol_token2,
    ACTIONS(328), 1,
      sym__hll_number_literal_pre_hook,
    STATE(781), 1,
      sym_trace32_hll_variable,
    STATE(1601), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(308), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(310), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(312), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(448), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(320), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(322), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(778), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
    STATE(674), 11,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_symbol,
  [66221] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2315), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_DOT,
    ACTIONS(2313), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [66271] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2317), 1,
      anon_sym_LPAREN,
    ACTIONS(2323), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2327), 1,
      anon_sym_PIPE,
    ACTIONS(2329), 1,
      anon_sym_CARET,
    ACTIONS(2339), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2341), 1,
      anon_sym_AMP,
    ACTIONS(2345), 1,
      anon_sym_QMARK,
    ACTIONS(2347), 1,
      anon_sym_LBRACK,
    STATE(813), 1,
      sym_hll_argument_list,
    ACTIONS(2319), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2321), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2331), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2333), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2335), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2337), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2343), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2277), 3,
      anon_sym_EQ,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(2325), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2275), 13,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [66355] = 17,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2317), 1,
      anon_sym_LPAREN,
    ACTIONS(2327), 1,
      anon_sym_PIPE,
    ACTIONS(2329), 1,
      anon_sym_CARET,
    ACTIONS(2341), 1,
      anon_sym_AMP,
    ACTIONS(2347), 1,
      anon_sym_LBRACK,
    STATE(813), 1,
      sym_hll_argument_list,
    ACTIONS(2319), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2321), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2331), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2333), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2335), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2337), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2343), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2201), 3,
      anon_sym_EQ,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(2325), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2197), 16,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [66433] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2317), 1,
      anon_sym_LPAREN,
    ACTIONS(2323), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2327), 1,
      anon_sym_PIPE,
    ACTIONS(2329), 1,
      anon_sym_CARET,
    ACTIONS(2339), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2341), 1,
      anon_sym_AMP,
    ACTIONS(2345), 1,
      anon_sym_QMARK,
    ACTIONS(2347), 1,
      anon_sym_LBRACK,
    STATE(813), 1,
      sym_hll_argument_list,
    ACTIONS(2319), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2321), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2331), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2333), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2335), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2337), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2343), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2301), 3,
      anon_sym_EQ,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(2325), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2299), 13,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [66517] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2035), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_DOT,
    ACTIONS(2037), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [66567] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2351), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_DOT,
    ACTIONS(2349), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [66617] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2355), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_DOT,
    ACTIONS(2353), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [66667] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2317), 1,
      anon_sym_LPAREN,
    ACTIONS(2327), 1,
      anon_sym_PIPE,
    ACTIONS(2329), 1,
      anon_sym_CARET,
    ACTIONS(2339), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2341), 1,
      anon_sym_AMP,
    ACTIONS(2347), 1,
      anon_sym_LBRACK,
    STATE(813), 1,
      sym_hll_argument_list,
    ACTIONS(2319), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2321), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2331), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2333), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2335), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2337), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2343), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2201), 3,
      anon_sym_EQ,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(2325), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2197), 15,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [66747] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2359), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_DOT,
    ACTIONS(2357), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [66797] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1987), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(1989), 27,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym_symbol_token3,
      sym_comment,
      sym__blank_line,
  [66847] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2363), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_DOT,
    ACTIONS(2361), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [66897] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2367), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_DOT,
    ACTIONS(2365), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [66947] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2371), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_DOT,
    ACTIONS(2369), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [66997] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2317), 1,
      anon_sym_LPAREN,
    ACTIONS(2323), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2327), 1,
      anon_sym_PIPE,
    ACTIONS(2329), 1,
      anon_sym_CARET,
    ACTIONS(2339), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2341), 1,
      anon_sym_AMP,
    ACTIONS(2345), 1,
      anon_sym_QMARK,
    ACTIONS(2347), 1,
      anon_sym_LBRACK,
    STATE(813), 1,
      sym_hll_argument_list,
    ACTIONS(2319), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2321), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2331), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2333), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2335), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2337), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2343), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2305), 3,
      anon_sym_EQ,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(2325), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2303), 13,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [67081] = 13,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2317), 1,
      anon_sym_LPAREN,
    ACTIONS(2347), 1,
      anon_sym_LBRACK,
    STATE(813), 1,
      sym_hll_argument_list,
    ACTIONS(2319), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2321), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2333), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2335), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2337), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2343), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2325), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2201), 6,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(2197), 18,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [67151] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2375), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_DOT,
    ACTIONS(2373), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [67201] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2379), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_DOT,
    ACTIONS(2377), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [67251] = 16,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2317), 1,
      anon_sym_LPAREN,
    ACTIONS(2329), 1,
      anon_sym_CARET,
    ACTIONS(2341), 1,
      anon_sym_AMP,
    ACTIONS(2347), 1,
      anon_sym_LBRACK,
    STATE(813), 1,
      sym_hll_argument_list,
    ACTIONS(2319), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2321), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2331), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2333), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2335), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2337), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2343), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2325), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2201), 4,
      anon_sym_EQ,
      anon_sym_PIPE,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(2197), 16,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [67327] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2087), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_DOT,
    ACTIONS(2089), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [67377] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2317), 1,
      anon_sym_LPAREN,
    ACTIONS(2323), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2327), 1,
      anon_sym_PIPE,
    ACTIONS(2329), 1,
      anon_sym_CARET,
    ACTIONS(2339), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2341), 1,
      anon_sym_AMP,
    ACTIONS(2345), 1,
      anon_sym_QMARK,
    ACTIONS(2347), 1,
      anon_sym_LBRACK,
    STATE(813), 1,
      sym_hll_argument_list,
    ACTIONS(2319), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2321), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2331), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2333), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2335), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2337), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2343), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2285), 3,
      anon_sym_EQ,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(2325), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2283), 13,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [67461] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2383), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_DOT,
    ACTIONS(2381), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [67511] = 14,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2317), 1,
      anon_sym_LPAREN,
    ACTIONS(2347), 1,
      anon_sym_LBRACK,
    STATE(813), 1,
      sym_hll_argument_list,
    ACTIONS(2319), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2321), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2331), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2333), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2335), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2337), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2343), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2325), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2201), 6,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(2197), 16,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [67583] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2049), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_DOT,
    ACTIONS(2051), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [67633] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2317), 1,
      anon_sym_LPAREN,
    ACTIONS(2347), 1,
      anon_sym_LBRACK,
    STATE(813), 1,
      sym_hll_argument_list,
    ACTIONS(2321), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2337), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2343), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2201), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(2197), 20,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [67695] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2387), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_DOT,
    ACTIONS(2385), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [67745] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2391), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_DOT,
    ACTIONS(2389), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [67795] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2317), 1,
      anon_sym_LPAREN,
    ACTIONS(2347), 1,
      anon_sym_LBRACK,
    STATE(813), 1,
      sym_hll_argument_list,
    ACTIONS(2321), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2337), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2343), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2325), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2201), 10,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(2197), 20,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [67859] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2395), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_DOT,
    ACTIONS(2393), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [67909] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2317), 1,
      anon_sym_LPAREN,
    ACTIONS(2347), 1,
      anon_sym_LBRACK,
    STATE(813), 1,
      sym_hll_argument_list,
    ACTIONS(2321), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2343), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2215), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(2213), 20,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [67969] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2011), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(2013), 27,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym_symbol_token3,
      sym_comment,
      sym__blank_line,
  [68019] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2317), 1,
      anon_sym_LPAREN,
    ACTIONS(2347), 1,
      anon_sym_LBRACK,
    STATE(813), 1,
      sym_hll_argument_list,
    ACTIONS(2343), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2311), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(2309), 22,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [68077] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2317), 1,
      anon_sym_LPAREN,
    ACTIONS(2347), 1,
      anon_sym_LBRACK,
    STATE(813), 1,
      sym_hll_argument_list,
    ACTIONS(2321), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2343), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2289), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(2287), 20,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [68137] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2317), 1,
      anon_sym_LPAREN,
    ACTIONS(2347), 1,
      anon_sym_LBRACK,
    STATE(813), 1,
      sym_hll_argument_list,
    ACTIONS(2321), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2337), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2343), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2241), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(2239), 20,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [68199] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2317), 1,
      anon_sym_LPAREN,
    ACTIONS(2323), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2327), 1,
      anon_sym_PIPE,
    ACTIONS(2329), 1,
      anon_sym_CARET,
    ACTIONS(2339), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2341), 1,
      anon_sym_AMP,
    ACTIONS(2345), 1,
      anon_sym_QMARK,
    ACTIONS(2347), 1,
      anon_sym_LBRACK,
    STATE(813), 1,
      sym_hll_argument_list,
    ACTIONS(2319), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2321), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2331), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2333), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2335), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2337), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2343), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2293), 3,
      anon_sym_EQ,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(2325), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2291), 13,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [68283] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2317), 1,
      anon_sym_LPAREN,
    ACTIONS(2347), 1,
      anon_sym_LBRACK,
    STATE(813), 1,
      sym_hll_argument_list,
    ACTIONS(2321), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2343), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2225), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(2223), 20,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [68343] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2317), 1,
      anon_sym_LPAREN,
    ACTIONS(2347), 1,
      anon_sym_LBRACK,
    STATE(813), 1,
      sym_hll_argument_list,
    ACTIONS(2321), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2343), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2229), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(2227), 20,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [68403] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2317), 1,
      anon_sym_LPAREN,
    ACTIONS(2323), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2327), 1,
      anon_sym_PIPE,
    ACTIONS(2329), 1,
      anon_sym_CARET,
    ACTIONS(2339), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2341), 1,
      anon_sym_AMP,
    ACTIONS(2345), 1,
      anon_sym_QMARK,
    ACTIONS(2347), 1,
      anon_sym_LBRACK,
    STATE(813), 1,
      sym_hll_argument_list,
    ACTIONS(2319), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2321), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2331), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2333), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2335), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2337), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2343), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2297), 3,
      anon_sym_EQ,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(2325), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2295), 13,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [68487] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2399), 1,
      anon_sym_EQ,
    ACTIONS(2404), 11,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
    ACTIONS(2402), 13,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_DOT,
    ACTIONS(2397), 17,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
  [68541] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2409), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_DOT,
    ACTIONS(2407), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [68591] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2317), 1,
      anon_sym_LPAREN,
    ACTIONS(2347), 1,
      anon_sym_LBRACK,
    STATE(813), 1,
      sym_hll_argument_list,
    ACTIONS(2321), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2343), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2233), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(2231), 20,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [68651] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2399), 1,
      anon_sym_EQ,
    ACTIONS(2404), 11,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
    ACTIONS(2402), 13,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_DOT,
    ACTIONS(2397), 17,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
  [68705] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2411), 1,
      aux_sym_symbol_token3,
    ACTIONS(1889), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(1891), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [68757] = 11,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2317), 1,
      anon_sym_LPAREN,
    ACTIONS(2347), 1,
      anon_sym_LBRACK,
    STATE(813), 1,
      sym_hll_argument_list,
    ACTIONS(2319), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2321), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2337), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2343), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2325), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2201), 8,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(2197), 20,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [68823] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2317), 1,
      anon_sym_LPAREN,
    ACTIONS(2347), 1,
      anon_sym_LBRACK,
    STATE(813), 1,
      sym_hll_argument_list,
    ACTIONS(2321), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2343), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2219), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(2217), 20,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [68883] = 15,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2317), 1,
      anon_sym_LPAREN,
    ACTIONS(2341), 1,
      anon_sym_AMP,
    ACTIONS(2347), 1,
      anon_sym_LBRACK,
    STATE(813), 1,
      sym_hll_argument_list,
    ACTIONS(2319), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2321), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2331), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2333), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2335), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2337), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2343), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2325), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2201), 5,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(2197), 16,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [68957] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2415), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_DOT,
    ACTIONS(2413), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [69007] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2419), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_DOT,
    ACTIONS(2417), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [69057] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2423), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_DOT,
    ACTIONS(2421), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [69107] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2317), 1,
      anon_sym_LPAREN,
    ACTIONS(2347), 1,
      anon_sym_LBRACK,
    STATE(813), 1,
      sym_hll_argument_list,
    ACTIONS(2321), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2343), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2201), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(2197), 20,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [69167] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2415), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(2413), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [69216] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2409), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(2407), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [69265] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2419), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(2417), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [69314] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2351), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(2349), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [69363] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2363), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(2361), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [69412] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2375), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(2373), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [69461] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2383), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(2381), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [69510] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2315), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(2313), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [69559] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2404), 1,
      sym__blank,
    ACTIONS(2425), 1,
      anon_sym_EQ,
    ACTIONS(2427), 10,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
    ACTIONS(2402), 13,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_DOT,
    ACTIONS(2397), 16,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
  [69614] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2404), 1,
      sym__blank,
    ACTIONS(2425), 1,
      anon_sym_EQ,
    ACTIONS(2427), 10,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
    ACTIONS(2402), 13,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_DOT,
    ACTIONS(2397), 16,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
  [69669] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2139), 1,
      sym__blank,
    STATE(800), 1,
      aux_sym_block_repeat1,
    ACTIONS(2122), 16,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BSLASH,
      anon_sym_sizeof,
      anon_sym_const,
      anon_sym_volatile,
      anon_sym_struct,
      anon_sym_union,
      anon_sym_enum,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
      sym_hll_primitive_type,
      aux_sym_symbol_token2,
      sym_identifier,
    ACTIONS(2120), 23,
      sym__hll_number_literal_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_TILDE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_RBRACK,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      aux_sym_symbol_token1,
  [69722] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2087), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(2089), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [69771] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2395), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(2393), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [69820] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2379), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(2377), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [69869] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2387), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(2385), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [69918] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2391), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(2389), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [69967] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2399), 2,
      anon_sym_EQ,
      sym__blank,
    ACTIONS(2404), 10,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
    ACTIONS(2402), 13,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
    ACTIONS(2397), 16,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [70020] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2399), 2,
      anon_sym_EQ,
      sym__blank,
    ACTIONS(2404), 10,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
    ACTIONS(2402), 13,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
    ACTIONS(2397), 16,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [70073] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2049), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(2051), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [70122] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2035), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(2037), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [70171] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2425), 1,
      anon_sym_EQ,
    ACTIONS(2432), 1,
      anon_sym_STAR,
    ACTIONS(2437), 1,
      sym__blank,
    ACTIONS(2435), 2,
      anon_sym_const,
      anon_sym_volatile,
    ACTIONS(2429), 3,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
    ACTIONS(2427), 10,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
    ACTIONS(2402), 11,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
    ACTIONS(2397), 12,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
  [70232] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2399), 1,
      sym__blank,
    ACTIONS(2425), 1,
      anon_sym_EQ,
    ACTIONS(2427), 10,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
    ACTIONS(2402), 13,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
    ACTIONS(2397), 16,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [70287] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2399), 1,
      sym__blank,
    ACTIONS(2425), 1,
      anon_sym_EQ,
    ACTIONS(2427), 10,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
    ACTIONS(2402), 13,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
    ACTIONS(2397), 16,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [70342] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2367), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(2365), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [70391] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2423), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(2421), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [70440] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2355), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(2353), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [70489] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2359), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(2357), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [70538] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2371), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(2369), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [70587] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2441), 1,
      aux_sym_symbol_token3,
    ACTIONS(1889), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(1891), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [70637] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2443), 1,
      anon_sym_LPAREN,
    ACTIONS(2451), 1,
      anon_sym_LBRACK,
    STATE(917), 1,
      sym_hll_argument_list,
    ACTIONS(2445), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2447), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2449), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2241), 12,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2239), 19,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [70697] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2443), 1,
      anon_sym_LPAREN,
    ACTIONS(2451), 1,
      anon_sym_LBRACK,
    STATE(917), 1,
      sym_hll_argument_list,
    ACTIONS(2445), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2449), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2201), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2197), 19,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [70755] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2443), 1,
      anon_sym_LPAREN,
    ACTIONS(2451), 1,
      anon_sym_LBRACK,
    STATE(917), 1,
      sym_hll_argument_list,
    ACTIONS(2445), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2449), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2215), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2213), 19,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [70813] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2443), 1,
      anon_sym_LPAREN,
    ACTIONS(2451), 1,
      anon_sym_LBRACK,
    STATE(917), 1,
      sym_hll_argument_list,
    ACTIONS(2445), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2449), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2225), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2223), 19,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [70871] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2443), 1,
      anon_sym_LPAREN,
    ACTIONS(2451), 1,
      anon_sym_LBRACK,
    STATE(917), 1,
      sym_hll_argument_list,
    ACTIONS(2445), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2449), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2229), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2227), 19,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [70929] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2443), 1,
      anon_sym_LPAREN,
    ACTIONS(2451), 1,
      anon_sym_LBRACK,
    STATE(917), 1,
      sym_hll_argument_list,
    ACTIONS(2445), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2449), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2233), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2231), 19,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [70987] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2453), 1,
      anon_sym_LPAREN,
    ACTIONS(2459), 1,
      anon_sym_LBRACK,
    STATE(904), 1,
      sym_hll_argument_list,
    ACTIONS(2455), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2457), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2219), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2217), 19,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [71045] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2443), 1,
      anon_sym_LPAREN,
    ACTIONS(2451), 1,
      anon_sym_LBRACK,
    STATE(917), 1,
      sym_hll_argument_list,
    ACTIONS(2445), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2447), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2449), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2461), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2201), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2197), 19,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [71107] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2443), 1,
      anon_sym_LPAREN,
    ACTIONS(2451), 1,
      anon_sym_LBRACK,
    ACTIONS(2465), 1,
      anon_sym_PIPE,
    ACTIONS(2467), 1,
      anon_sym_CARET,
    ACTIONS(2475), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2477), 1,
      anon_sym_AMP,
    STATE(917), 1,
      sym_hll_argument_list,
    ACTIONS(2201), 2,
      anon_sym_EQ,
      sym__blank,
    ACTIONS(2445), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2447), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2449), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2463), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2469), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2471), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2473), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2461), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2197), 14,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [71185] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2443), 1,
      anon_sym_LPAREN,
    ACTIONS(2451), 1,
      anon_sym_LBRACK,
    STATE(917), 1,
      sym_hll_argument_list,
    ACTIONS(2445), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2447), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2449), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2201), 12,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2197), 19,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [71245] = 16,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2443), 1,
      anon_sym_LPAREN,
    ACTIONS(2451), 1,
      anon_sym_LBRACK,
    ACTIONS(2467), 1,
      anon_sym_CARET,
    ACTIONS(2477), 1,
      anon_sym_AMP,
    STATE(917), 1,
      sym_hll_argument_list,
    ACTIONS(2445), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2447), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2449), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2463), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2469), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2471), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2473), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2201), 3,
      anon_sym_EQ,
      anon_sym_PIPE,
      sym__blank,
    ACTIONS(2461), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2197), 15,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [71319] = 15,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2443), 1,
      anon_sym_LPAREN,
    ACTIONS(2451), 1,
      anon_sym_LBRACK,
    ACTIONS(2477), 1,
      anon_sym_AMP,
    STATE(917), 1,
      sym_hll_argument_list,
    ACTIONS(2445), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2447), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2449), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2463), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2469), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2471), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2473), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2461), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2201), 4,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      sym__blank,
    ACTIONS(2197), 15,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [71391] = 13,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2443), 1,
      anon_sym_LPAREN,
    ACTIONS(2451), 1,
      anon_sym_LBRACK,
    STATE(917), 1,
      sym_hll_argument_list,
    ACTIONS(2445), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2447), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2449), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2463), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2471), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2473), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2461), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2201), 5,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2197), 17,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [71459] = 11,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2443), 1,
      anon_sym_LPAREN,
    ACTIONS(2451), 1,
      anon_sym_LBRACK,
    STATE(917), 1,
      sym_hll_argument_list,
    ACTIONS(2445), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2447), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2449), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2463), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2461), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2201), 7,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2197), 19,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [71523] = 17,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2443), 1,
      anon_sym_LPAREN,
    ACTIONS(2451), 1,
      anon_sym_LBRACK,
    ACTIONS(2465), 1,
      anon_sym_PIPE,
    ACTIONS(2467), 1,
      anon_sym_CARET,
    ACTIONS(2477), 1,
      anon_sym_AMP,
    STATE(917), 1,
      sym_hll_argument_list,
    ACTIONS(2201), 2,
      anon_sym_EQ,
      sym__blank,
    ACTIONS(2445), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2447), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2449), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2463), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2469), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2471), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2473), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2461), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2197), 15,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [71599] = 14,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2443), 1,
      anon_sym_LPAREN,
    ACTIONS(2451), 1,
      anon_sym_LBRACK,
    STATE(917), 1,
      sym_hll_argument_list,
    ACTIONS(2445), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2447), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2449), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2463), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2469), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2471), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2473), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2461), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2201), 5,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2197), 15,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [71669] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2443), 1,
      anon_sym_LPAREN,
    ACTIONS(2451), 1,
      anon_sym_LBRACK,
    ACTIONS(2465), 1,
      anon_sym_PIPE,
    ACTIONS(2467), 1,
      anon_sym_CARET,
    ACTIONS(2475), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2477), 1,
      anon_sym_AMP,
    ACTIONS(2479), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2481), 1,
      anon_sym_QMARK,
    STATE(917), 1,
      sym_hll_argument_list,
    ACTIONS(2277), 2,
      anon_sym_EQ,
      sym__blank,
    ACTIONS(2445), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2447), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2449), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2463), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2469), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2471), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2473), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2461), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2275), 12,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [71751] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2443), 1,
      anon_sym_LPAREN,
    ACTIONS(2451), 1,
      anon_sym_LBRACK,
    ACTIONS(2465), 1,
      anon_sym_PIPE,
    ACTIONS(2467), 1,
      anon_sym_CARET,
    ACTIONS(2475), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2477), 1,
      anon_sym_AMP,
    ACTIONS(2479), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2481), 1,
      anon_sym_QMARK,
    STATE(917), 1,
      sym_hll_argument_list,
    ACTIONS(2285), 2,
      anon_sym_EQ,
      sym__blank,
    ACTIONS(2445), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2447), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2449), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2463), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2469), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2471), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2473), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2461), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2283), 12,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [71833] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2443), 1,
      anon_sym_LPAREN,
    ACTIONS(2451), 1,
      anon_sym_LBRACK,
    ACTIONS(2465), 1,
      anon_sym_PIPE,
    ACTIONS(2467), 1,
      anon_sym_CARET,
    ACTIONS(2475), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2477), 1,
      anon_sym_AMP,
    ACTIONS(2479), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2481), 1,
      anon_sym_QMARK,
    STATE(917), 1,
      sym_hll_argument_list,
    ACTIONS(2293), 2,
      anon_sym_EQ,
      sym__blank,
    ACTIONS(2445), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2447), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2449), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2463), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2469), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2471), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2473), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2461), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2291), 12,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [71915] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2443), 1,
      anon_sym_LPAREN,
    ACTIONS(2451), 1,
      anon_sym_LBRACK,
    ACTIONS(2465), 1,
      anon_sym_PIPE,
    ACTIONS(2467), 1,
      anon_sym_CARET,
    ACTIONS(2475), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2477), 1,
      anon_sym_AMP,
    ACTIONS(2479), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2481), 1,
      anon_sym_QMARK,
    STATE(917), 1,
      sym_hll_argument_list,
    ACTIONS(2297), 2,
      anon_sym_EQ,
      sym__blank,
    ACTIONS(2445), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2447), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2449), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2463), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2469), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2471), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2473), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2461), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2295), 12,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [71997] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2443), 1,
      anon_sym_LPAREN,
    ACTIONS(2451), 1,
      anon_sym_LBRACK,
    ACTIONS(2465), 1,
      anon_sym_PIPE,
    ACTIONS(2467), 1,
      anon_sym_CARET,
    ACTIONS(2475), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2477), 1,
      anon_sym_AMP,
    ACTIONS(2479), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2481), 1,
      anon_sym_QMARK,
    STATE(917), 1,
      sym_hll_argument_list,
    ACTIONS(2301), 2,
      anon_sym_EQ,
      sym__blank,
    ACTIONS(2445), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2447), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2449), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2463), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2469), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2471), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2473), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2461), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2299), 12,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [72079] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2443), 1,
      anon_sym_LPAREN,
    ACTIONS(2451), 1,
      anon_sym_LBRACK,
    ACTIONS(2465), 1,
      anon_sym_PIPE,
    ACTIONS(2467), 1,
      anon_sym_CARET,
    ACTIONS(2475), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2477), 1,
      anon_sym_AMP,
    ACTIONS(2479), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2481), 1,
      anon_sym_QMARK,
    STATE(917), 1,
      sym_hll_argument_list,
    ACTIONS(2305), 2,
      anon_sym_EQ,
      sym__blank,
    ACTIONS(2445), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2447), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2449), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2463), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2469), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2471), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2473), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2461), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2303), 12,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [72161] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2425), 1,
      anon_sym_EQ,
    ACTIONS(2427), 11,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
    ACTIONS(2402), 12,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
    ACTIONS(2397), 16,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
  [72213] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2425), 1,
      anon_sym_EQ,
    ACTIONS(2427), 11,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
    ACTIONS(2402), 12,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
    ACTIONS(2397), 16,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
  [72265] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2453), 1,
      anon_sym_LPAREN,
    ACTIONS(2459), 1,
      anon_sym_LBRACK,
    STATE(904), 1,
      sym_hll_argument_list,
    ACTIONS(2457), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2311), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2309), 21,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [72321] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2453), 1,
      anon_sym_LPAREN,
    ACTIONS(2459), 1,
      anon_sym_LBRACK,
    STATE(904), 1,
      sym_hll_argument_list,
    ACTIONS(2455), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2457), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2289), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2287), 19,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [72379] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2453), 1,
      anon_sym_LPAREN,
    ACTIONS(2459), 1,
      anon_sym_LBRACK,
    STATE(904), 1,
      sym_hll_argument_list,
    ACTIONS(2455), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2457), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2483), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2241), 12,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2239), 19,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [72439] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2011), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2013), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym_symbol_token3,
      sym_comment,
      sym__blank_line,
  [72487] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2453), 1,
      anon_sym_LPAREN,
    ACTIONS(2459), 1,
      anon_sym_LBRACK,
    STATE(904), 1,
      sym_hll_argument_list,
    ACTIONS(2455), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2457), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2201), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2197), 19,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [72545] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2453), 1,
      anon_sym_LPAREN,
    ACTIONS(2459), 1,
      anon_sym_LBRACK,
    STATE(904), 1,
      sym_hll_argument_list,
    ACTIONS(2455), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2457), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2215), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2213), 19,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [72603] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2453), 1,
      anon_sym_LPAREN,
    ACTIONS(2459), 1,
      anon_sym_LBRACK,
    STATE(904), 1,
      sym_hll_argument_list,
    ACTIONS(2455), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2457), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2225), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2223), 19,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [72661] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2453), 1,
      anon_sym_LPAREN,
    ACTIONS(2459), 1,
      anon_sym_LBRACK,
    STATE(904), 1,
      sym_hll_argument_list,
    ACTIONS(2455), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2457), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2229), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2227), 19,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [72719] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2453), 1,
      anon_sym_LPAREN,
    ACTIONS(2459), 1,
      anon_sym_LBRACK,
    STATE(904), 1,
      sym_hll_argument_list,
    ACTIONS(2455), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2457), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2233), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2231), 19,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [72777] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2453), 1,
      anon_sym_LPAREN,
    ACTIONS(2459), 1,
      anon_sym_LBRACK,
    STATE(904), 1,
      sym_hll_argument_list,
    ACTIONS(2455), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2457), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2483), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2485), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2201), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2197), 19,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [72839] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2453), 1,
      anon_sym_LPAREN,
    ACTIONS(2459), 1,
      anon_sym_LBRACK,
    ACTIONS(2489), 1,
      anon_sym_PIPE,
    ACTIONS(2491), 1,
      anon_sym_CARET,
    ACTIONS(2499), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2501), 1,
      anon_sym_AMP,
    STATE(904), 1,
      sym_hll_argument_list,
    ACTIONS(2201), 2,
      anon_sym_EQ,
      sym__blank,
    ACTIONS(2455), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2457), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2483), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2487), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2493), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2495), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2497), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2485), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2197), 14,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [72917] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2453), 1,
      anon_sym_LPAREN,
    ACTIONS(2459), 1,
      anon_sym_LBRACK,
    STATE(904), 1,
      sym_hll_argument_list,
    ACTIONS(2455), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2457), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2483), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2201), 12,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2197), 19,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [72977] = 16,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2453), 1,
      anon_sym_LPAREN,
    ACTIONS(2459), 1,
      anon_sym_LBRACK,
    ACTIONS(2491), 1,
      anon_sym_CARET,
    ACTIONS(2501), 1,
      anon_sym_AMP,
    STATE(904), 1,
      sym_hll_argument_list,
    ACTIONS(2455), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2457), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2483), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2487), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2493), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2495), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2497), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2201), 3,
      anon_sym_EQ,
      anon_sym_PIPE,
      sym__blank,
    ACTIONS(2485), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2197), 15,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [73051] = 15,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2453), 1,
      anon_sym_LPAREN,
    ACTIONS(2459), 1,
      anon_sym_LBRACK,
    ACTIONS(2501), 1,
      anon_sym_AMP,
    STATE(904), 1,
      sym_hll_argument_list,
    ACTIONS(2455), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2457), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2483), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2487), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2493), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2495), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2497), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2485), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2201), 4,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      sym__blank,
    ACTIONS(2197), 15,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [73123] = 13,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2453), 1,
      anon_sym_LPAREN,
    ACTIONS(2459), 1,
      anon_sym_LBRACK,
    STATE(904), 1,
      sym_hll_argument_list,
    ACTIONS(2455), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2457), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2483), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2487), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2495), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2497), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2485), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2201), 5,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2197), 17,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [73191] = 11,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2453), 1,
      anon_sym_LPAREN,
    ACTIONS(2459), 1,
      anon_sym_LBRACK,
    STATE(904), 1,
      sym_hll_argument_list,
    ACTIONS(2455), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2457), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2483), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2487), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2485), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2201), 7,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2197), 19,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [73255] = 17,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2453), 1,
      anon_sym_LPAREN,
    ACTIONS(2459), 1,
      anon_sym_LBRACK,
    ACTIONS(2489), 1,
      anon_sym_PIPE,
    ACTIONS(2491), 1,
      anon_sym_CARET,
    ACTIONS(2501), 1,
      anon_sym_AMP,
    STATE(904), 1,
      sym_hll_argument_list,
    ACTIONS(2201), 2,
      anon_sym_EQ,
      sym__blank,
    ACTIONS(2455), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2457), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2483), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2487), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2493), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2495), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2497), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2485), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2197), 15,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [73331] = 14,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2453), 1,
      anon_sym_LPAREN,
    ACTIONS(2459), 1,
      anon_sym_LBRACK,
    STATE(904), 1,
      sym_hll_argument_list,
    ACTIONS(2455), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2457), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2483), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2487), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2493), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2495), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2497), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2485), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2201), 5,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2197), 15,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [73401] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2453), 1,
      anon_sym_LPAREN,
    ACTIONS(2459), 1,
      anon_sym_LBRACK,
    ACTIONS(2489), 1,
      anon_sym_PIPE,
    ACTIONS(2491), 1,
      anon_sym_CARET,
    ACTIONS(2499), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2501), 1,
      anon_sym_AMP,
    ACTIONS(2503), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2505), 1,
      anon_sym_QMARK,
    STATE(904), 1,
      sym_hll_argument_list,
    ACTIONS(2277), 2,
      anon_sym_EQ,
      sym__blank,
    ACTIONS(2455), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2457), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2483), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2487), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2493), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2495), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2497), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2485), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2275), 12,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [73483] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2453), 1,
      anon_sym_LPAREN,
    ACTIONS(2459), 1,
      anon_sym_LBRACK,
    ACTIONS(2489), 1,
      anon_sym_PIPE,
    ACTIONS(2491), 1,
      anon_sym_CARET,
    ACTIONS(2499), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2501), 1,
      anon_sym_AMP,
    ACTIONS(2503), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2505), 1,
      anon_sym_QMARK,
    STATE(904), 1,
      sym_hll_argument_list,
    ACTIONS(2285), 2,
      anon_sym_EQ,
      sym__blank,
    ACTIONS(2455), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2457), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2483), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2487), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2493), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2495), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2497), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2485), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2283), 12,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [73565] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2453), 1,
      anon_sym_LPAREN,
    ACTIONS(2459), 1,
      anon_sym_LBRACK,
    ACTIONS(2489), 1,
      anon_sym_PIPE,
    ACTIONS(2491), 1,
      anon_sym_CARET,
    ACTIONS(2499), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2501), 1,
      anon_sym_AMP,
    ACTIONS(2503), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2505), 1,
      anon_sym_QMARK,
    STATE(904), 1,
      sym_hll_argument_list,
    ACTIONS(2293), 2,
      anon_sym_EQ,
      sym__blank,
    ACTIONS(2455), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2457), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2483), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2487), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2493), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2495), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2497), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2485), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2291), 12,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [73647] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2453), 1,
      anon_sym_LPAREN,
    ACTIONS(2459), 1,
      anon_sym_LBRACK,
    ACTIONS(2489), 1,
      anon_sym_PIPE,
    ACTIONS(2491), 1,
      anon_sym_CARET,
    ACTIONS(2499), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2501), 1,
      anon_sym_AMP,
    ACTIONS(2503), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2505), 1,
      anon_sym_QMARK,
    STATE(904), 1,
      sym_hll_argument_list,
    ACTIONS(2297), 2,
      anon_sym_EQ,
      sym__blank,
    ACTIONS(2455), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2457), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2483), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2487), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2493), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2495), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2497), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2485), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2295), 12,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [73729] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2453), 1,
      anon_sym_LPAREN,
    ACTIONS(2459), 1,
      anon_sym_LBRACK,
    ACTIONS(2489), 1,
      anon_sym_PIPE,
    ACTIONS(2491), 1,
      anon_sym_CARET,
    ACTIONS(2499), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2501), 1,
      anon_sym_AMP,
    ACTIONS(2503), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2505), 1,
      anon_sym_QMARK,
    STATE(904), 1,
      sym_hll_argument_list,
    ACTIONS(2301), 2,
      anon_sym_EQ,
      sym__blank,
    ACTIONS(2455), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2457), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2483), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2487), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2493), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2495), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2497), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2485), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2299), 12,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [73811] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2453), 1,
      anon_sym_LPAREN,
    ACTIONS(2459), 1,
      anon_sym_LBRACK,
    ACTIONS(2489), 1,
      anon_sym_PIPE,
    ACTIONS(2491), 1,
      anon_sym_CARET,
    ACTIONS(2499), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2501), 1,
      anon_sym_AMP,
    ACTIONS(2503), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2505), 1,
      anon_sym_QMARK,
    STATE(904), 1,
      sym_hll_argument_list,
    ACTIONS(2305), 2,
      anon_sym_EQ,
      sym__blank,
    ACTIONS(2455), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2457), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2483), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2487), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2493), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2495), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2497), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2485), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2303), 12,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [73893] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2507), 1,
      aux_sym_symbol_token3,
    ACTIONS(1889), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(1891), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [73943] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1987), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(1989), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
      aux_sym_symbol_token3,
  [73991] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2011), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2013), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
      aux_sym_symbol_token3,
  [74039] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2443), 1,
      anon_sym_LPAREN,
    ACTIONS(2451), 1,
      anon_sym_LBRACK,
    STATE(917), 1,
      sym_hll_argument_list,
    ACTIONS(2445), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2449), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2219), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2217), 19,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [74097] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2443), 1,
      anon_sym_LPAREN,
    ACTIONS(2451), 1,
      anon_sym_LBRACK,
    STATE(917), 1,
      sym_hll_argument_list,
    ACTIONS(2449), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2311), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2309), 21,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [74153] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2443), 1,
      anon_sym_LPAREN,
    ACTIONS(2451), 1,
      anon_sym_LBRACK,
    STATE(917), 1,
      sym_hll_argument_list,
    ACTIONS(2445), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2449), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2289), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2287), 19,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [74211] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1987), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(1989), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym_symbol_token3,
      sym_comment,
      sym__blank_line,
  [74259] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2351), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2349), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [74306] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2395), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2393), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [74353] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2035), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2037), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [74400] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2379), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2377), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [74447] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2415), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2413), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [74494] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2379), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2377), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [74541] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2387), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2385), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [74588] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2363), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2361), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [74635] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2375), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2373), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [74682] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2359), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2357), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [74729] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2425), 2,
      anon_sym_EQ,
      sym__blank,
    ACTIONS(2427), 10,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
    ACTIONS(2402), 12,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
    ACTIONS(2397), 15,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [74780] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2425), 2,
      anon_sym_EQ,
      sym__blank,
    ACTIONS(2427), 10,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
    ACTIONS(2402), 12,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
    ACTIONS(2397), 15,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [74831] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2395), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2393), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [74878] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2387), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2385), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [74925] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2391), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2389), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [74972] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2399), 1,
      sym__blank,
    ACTIONS(2425), 1,
      anon_sym_EQ,
    ACTIONS(2427), 10,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
    ACTIONS(2402), 12,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
    ACTIONS(2397), 15,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [75025] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2399), 1,
      sym__blank,
    ACTIONS(2425), 1,
      anon_sym_EQ,
    ACTIONS(2427), 10,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
    ACTIONS(2402), 12,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
    ACTIONS(2397), 15,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [75078] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2087), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2089), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [75125] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2399), 2,
      anon_sym_EQ,
      sym__blank,
    ACTIONS(2404), 10,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
    ACTIONS(2402), 12,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
    ACTIONS(2397), 15,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [75176] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2399), 2,
      anon_sym_EQ,
      sym__blank,
    ACTIONS(2404), 10,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
    ACTIONS(2402), 12,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
    ACTIONS(2397), 15,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [75227] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2383), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2381), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [75274] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2371), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2369), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [75321] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2391), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2389), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [75368] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2419), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2417), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [75415] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2399), 2,
      anon_sym_EQ,
      sym__blank,
    ACTIONS(2404), 10,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
    ACTIONS(2402), 12,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
    ACTIONS(2397), 15,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      sym_comment,
      sym__blank_line,
  [75466] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2355), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2353), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [75513] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2399), 2,
      anon_sym_EQ,
      sym__blank,
    ACTIONS(2404), 10,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
    ACTIONS(2402), 12,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
    ACTIONS(2397), 15,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      sym_comment,
      sym__blank_line,
  [75564] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2359), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2357), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [75611] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2363), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2361), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [75658] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2375), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2373), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [75705] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2367), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2365), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [75752] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2423), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2421), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [75799] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2383), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2381), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [75846] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2315), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2313), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [75893] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2049), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2051), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [75940] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2409), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2407), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [75987] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2035), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2037), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [76034] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2419), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2417), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [76081] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2423), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2421), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [76128] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2315), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2313), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [76175] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2351), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2349), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [76222] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2425), 2,
      anon_sym_EQ,
      sym__blank,
    ACTIONS(2427), 10,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
    ACTIONS(2402), 12,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
    ACTIONS(2397), 15,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      sym_comment,
      sym__blank_line,
  [76273] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2425), 2,
      anon_sym_EQ,
      sym__blank,
    ACTIONS(2427), 10,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
    ACTIONS(2402), 12,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
    ACTIONS(2397), 15,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      sym_comment,
      sym__blank_line,
  [76324] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2367), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2365), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [76371] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2087), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2089), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [76418] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2415), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2413), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [76465] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2049), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2051), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [76512] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2355), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2353), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [76559] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2371), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2369), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [76606] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2409), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2407), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [76653] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(434), 1,
      anon_sym_SLASH,
    ACTIONS(436), 1,
      sym__blank,
    STATE(935), 1,
      aux_sym_block_repeat1,
    STATE(1816), 1,
      sym_option_expression,
    STATE(2182), 1,
      aux_sym__command_arguments_repeat2,
    ACTIONS(2509), 14,
      anon_sym_PLUS,
      anon_sym_DASH,
      aux_sym__hll_non_default_format_var_command_token1,
      anon_sym_BSLASH,
      sym_access_class,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
      sym_float,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
      aux_sym_symbol_token2,
      sym_time,
      sym_frequency,
      sym_identifier,
    ACTIONS(2511), 18,
      sym__decimal_number_pre_hook,
      sym_path,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_TILDE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_COMMA,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      aux_sym_symbol_token1,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
  [76708] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(434), 1,
      anon_sym_SLASH,
    ACTIONS(436), 1,
      sym__blank,
    STATE(935), 1,
      aux_sym_block_repeat1,
    STATE(1904), 1,
      sym_option_expression,
    STATE(2172), 1,
      aux_sym__command_arguments_repeat2,
    ACTIONS(2509), 14,
      anon_sym_PLUS,
      anon_sym_DASH,
      aux_sym__hll_non_default_format_var_command_token1,
      anon_sym_BSLASH,
      sym_access_class,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
      sym_float,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
      aux_sym_symbol_token2,
      sym_time,
      sym_frequency,
      sym_identifier,
    ACTIONS(2511), 18,
      sym__decimal_number_pre_hook,
      sym_path,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_TILDE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_COMMA,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      aux_sym_symbol_token1,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
  [76763] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(434), 1,
      anon_sym_SLASH,
    ACTIONS(436), 1,
      sym__blank,
    STATE(935), 1,
      aux_sym_block_repeat1,
    STATE(1904), 1,
      sym_option_expression,
    STATE(2172), 1,
      aux_sym__command_arguments_repeat2,
    ACTIONS(2513), 14,
      anon_sym_PLUS,
      anon_sym_DASH,
      aux_sym__hll_non_default_format_var_command_token1,
      anon_sym_BSLASH,
      sym_access_class,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
      sym_float,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
      aux_sym_symbol_token2,
      sym_time,
      sym_frequency,
      sym_identifier,
    ACTIONS(2515), 18,
      sym__decimal_number_pre_hook,
      sym_path,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_TILDE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_COMMA,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      aux_sym_symbol_token1,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
  [76818] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2517), 1,
      sym__blank,
    STATE(927), 1,
      aux_sym_block_repeat1,
    ACTIONS(2122), 15,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      aux_sym__hll_non_default_format_var_command_token1,
      anon_sym_BSLASH,
      sym_access_class,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
      sym_float,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
      aux_sym_symbol_token2,
      sym_time,
      sym_frequency,
      sym_identifier,
    ACTIONS(2120), 20,
      sym__decimal_number_pre_hook,
      sym_path,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_TILDE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_COMMA,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      aux_sym_symbol_token1,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
      sym_comment,
      sym__blank_line,
  [76867] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(434), 1,
      anon_sym_SLASH,
    ACTIONS(436), 1,
      sym__blank,
    STATE(935), 1,
      aux_sym_block_repeat1,
    STATE(1939), 1,
      sym_option_expression,
    STATE(2231), 1,
      aux_sym__command_arguments_repeat2,
    ACTIONS(2513), 14,
      anon_sym_PLUS,
      anon_sym_DASH,
      aux_sym__hll_non_default_format_var_command_token1,
      anon_sym_BSLASH,
      sym_access_class,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
      sym_float,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
      aux_sym_symbol_token2,
      sym_time,
      sym_frequency,
      sym_identifier,
    ACTIONS(2515), 18,
      sym__decimal_number_pre_hook,
      sym_path,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_TILDE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_COMMA,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      aux_sym_symbol_token1,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
  [76922] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(434), 1,
      anon_sym_SLASH,
    ACTIONS(436), 1,
      sym__blank,
    ACTIONS(2520), 1,
      anon_sym_COMMA,
    STATE(935), 1,
      aux_sym_block_repeat1,
    STATE(1939), 1,
      sym_option_expression,
    STATE(2231), 1,
      aux_sym__command_arguments_repeat2,
    ACTIONS(2513), 14,
      anon_sym_PLUS,
      anon_sym_DASH,
      aux_sym__hll_non_default_format_var_command_token1,
      anon_sym_BSLASH,
      sym_access_class,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
      sym_float,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
      aux_sym_symbol_token2,
      sym_time,
      sym_frequency,
      sym_identifier,
    ACTIONS(2515), 17,
      sym__decimal_number_pre_hook,
      sym_path,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_TILDE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      aux_sym_symbol_token1,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
  [76979] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(434), 1,
      anon_sym_SLASH,
    ACTIONS(436), 1,
      sym__blank,
    ACTIONS(2520), 1,
      anon_sym_COMMA,
    STATE(935), 1,
      aux_sym_block_repeat1,
    STATE(1904), 1,
      sym_option_expression,
    STATE(2172), 1,
      aux_sym__command_arguments_repeat2,
    ACTIONS(2513), 14,
      anon_sym_PLUS,
      anon_sym_DASH,
      aux_sym__hll_non_default_format_var_command_token1,
      anon_sym_BSLASH,
      sym_access_class,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
      sym_float,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
      aux_sym_symbol_token2,
      sym_time,
      sym_frequency,
      sym_identifier,
    ACTIONS(2515), 17,
      sym__decimal_number_pre_hook,
      sym_path,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_TILDE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      aux_sym_symbol_token1,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
  [77036] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2529), 1,
      sym__blank,
    STATE(928), 1,
      aux_sym_block_repeat1,
    ACTIONS(2527), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(2523), 14,
      anon_sym_PLUS,
      anon_sym_DASH,
      aux_sym__hll_non_default_format_var_command_token1,
      anon_sym_BSLASH,
      sym_access_class,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
      sym_float,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
      aux_sym_symbol_token2,
      sym_time,
      sym_frequency,
      sym_identifier,
    ACTIONS(2525), 18,
      sym__decimal_number_pre_hook,
      sym_path,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_TILDE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_COMMA,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      aux_sym_symbol_token1,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
  [77086] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2533), 1,
      sym__blank,
    STATE(924), 1,
      aux_sym_block_repeat1,
    ACTIONS(2531), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(2513), 14,
      anon_sym_PLUS,
      anon_sym_DASH,
      aux_sym__hll_non_default_format_var_command_token1,
      anon_sym_BSLASH,
      sym_access_class,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
      sym_float,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
      aux_sym_symbol_token2,
      sym_time,
      sym_frequency,
      sym_identifier,
    ACTIONS(2515), 18,
      sym__decimal_number_pre_hook,
      sym_path,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_TILDE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_COMMA,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      aux_sym_symbol_token1,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
  [77136] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2537), 1,
      sym__blank,
    STATE(925), 1,
      aux_sym_block_repeat1,
    ACTIONS(2535), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(2513), 14,
      anon_sym_PLUS,
      anon_sym_DASH,
      aux_sym__hll_non_default_format_var_command_token1,
      anon_sym_BSLASH,
      sym_access_class,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
      sym_float,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
      aux_sym_symbol_token2,
      sym_time,
      sym_frequency,
      sym_identifier,
    ACTIONS(2515), 18,
      sym__decimal_number_pre_hook,
      sym_path,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_TILDE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_COMMA,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      aux_sym_symbol_token1,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
  [77186] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2539), 1,
      sym__blank,
    STATE(926), 1,
      aux_sym_block_repeat1,
    ACTIONS(2535), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(2523), 14,
      anon_sym_PLUS,
      anon_sym_DASH,
      aux_sym__hll_non_default_format_var_command_token1,
      anon_sym_BSLASH,
      sym_access_class,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
      sym_float,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
      aux_sym_symbol_token2,
      sym_time,
      sym_frequency,
      sym_identifier,
    ACTIONS(2525), 18,
      sym__decimal_number_pre_hook,
      sym_path,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_TILDE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_COMMA,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      aux_sym_symbol_token1,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
  [77236] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2541), 1,
      sym__blank,
    STATE(935), 1,
      aux_sym_block_repeat1,
    ACTIONS(2122), 14,
      anon_sym_PLUS,
      anon_sym_DASH,
      aux_sym__hll_non_default_format_var_command_token1,
      anon_sym_BSLASH,
      sym_access_class,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
      sym_float,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
      aux_sym_symbol_token2,
      sym_time,
      sym_frequency,
      sym_identifier,
    ACTIONS(2120), 19,
      sym__decimal_number_pre_hook,
      sym_path,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_TILDE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_COMMA,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      aux_sym_symbol_token1,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
  [77283] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2011), 9,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(2013), 25,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      aux_sym__hll_expression_separator_token1,
      aux_sym_symbol_token3,
      sym_comment,
      sym__blank_line,
  [77325] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(436), 1,
      sym__blank,
    STATE(935), 1,
      aux_sym_block_repeat1,
    ACTIONS(2544), 14,
      anon_sym_PLUS,
      anon_sym_DASH,
      aux_sym__hll_non_default_format_var_command_token1,
      anon_sym_BSLASH,
      sym_access_class,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
      sym_float,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
      aux_sym_symbol_token2,
      sym_time,
      sym_frequency,
      sym_identifier,
    ACTIONS(2546), 18,
      sym__decimal_number_pre_hook,
      sym_path,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_TILDE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_COMMA,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      aux_sym_symbol_token1,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
  [77371] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(436), 1,
      sym__blank,
    STATE(935), 1,
      aux_sym_block_repeat1,
    ACTIONS(2509), 14,
      anon_sym_PLUS,
      anon_sym_DASH,
      aux_sym__hll_non_default_format_var_command_token1,
      anon_sym_BSLASH,
      sym_access_class,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
      sym_float,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
      aux_sym_symbol_token2,
      sym_time,
      sym_frequency,
      sym_identifier,
    ACTIONS(2511), 18,
      sym__decimal_number_pre_hook,
      sym_path,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_TILDE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_COMMA,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      aux_sym_symbol_token1,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
  [77417] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(436), 1,
      sym__blank,
    STATE(935), 1,
      aux_sym_block_repeat1,
    ACTIONS(2513), 14,
      anon_sym_PLUS,
      anon_sym_DASH,
      aux_sym__hll_non_default_format_var_command_token1,
      anon_sym_BSLASH,
      sym_access_class,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
      sym_float,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
      aux_sym_symbol_token2,
      sym_time,
      sym_frequency,
      sym_identifier,
    ACTIONS(2515), 18,
      sym__decimal_number_pre_hook,
      sym_path,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_TILDE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_COMMA,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      aux_sym_symbol_token1,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
  [77463] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2548), 1,
      sym__blank,
    STATE(937), 1,
      aux_sym_block_repeat1,
    ACTIONS(2509), 14,
      anon_sym_PLUS,
      anon_sym_DASH,
      aux_sym__hll_non_default_format_var_command_token1,
      anon_sym_BSLASH,
      sym_access_class,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
      sym_float,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
      aux_sym_symbol_token2,
      sym_time,
      sym_frequency,
      sym_identifier,
    ACTIONS(2511), 18,
      sym__decimal_number_pre_hook,
      sym_path,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_TILDE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_COMMA,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      aux_sym_symbol_token1,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
  [77509] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2550), 1,
      aux_sym_symbol_token3,
    ACTIONS(1889), 9,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(1891), 24,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [77553] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2552), 1,
      sym__blank,
    STATE(939), 1,
      aux_sym_block_repeat1,
    ACTIONS(2523), 14,
      anon_sym_PLUS,
      anon_sym_DASH,
      aux_sym__hll_non_default_format_var_command_token1,
      anon_sym_BSLASH,
      sym_access_class,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
      sym_float,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
      aux_sym_symbol_token2,
      sym_time,
      sym_frequency,
      sym_identifier,
    ACTIONS(2525), 18,
      sym__decimal_number_pre_hook,
      sym_path,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_TILDE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_COMMA,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      aux_sym_symbol_token1,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
  [77599] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2554), 1,
      sym__blank,
    STATE(938), 1,
      aux_sym_block_repeat1,
    ACTIONS(2513), 14,
      anon_sym_PLUS,
      anon_sym_DASH,
      aux_sym__hll_non_default_format_var_command_token1,
      anon_sym_BSLASH,
      sym_access_class,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
      sym_float,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
      aux_sym_symbol_token2,
      sym_time,
      sym_frequency,
      sym_identifier,
    ACTIONS(2515), 18,
      sym__decimal_number_pre_hook,
      sym_path,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_TILDE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_COMMA,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      aux_sym_symbol_token1,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
  [77645] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1987), 9,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(1989), 25,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      aux_sym__hll_expression_separator_token1,
      aux_sym_symbol_token3,
      sym_comment,
      sym__blank_line,
  [77687] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(436), 1,
      sym__blank,
    ACTIONS(2520), 1,
      anon_sym_COMMA,
    STATE(935), 1,
      aux_sym_block_repeat1,
    ACTIONS(2513), 14,
      anon_sym_PLUS,
      anon_sym_DASH,
      aux_sym__hll_non_default_format_var_command_token1,
      anon_sym_BSLASH,
      sym_access_class,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
      sym_float,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
      aux_sym_symbol_token2,
      sym_time,
      sym_frequency,
      sym_identifier,
    ACTIONS(2515), 17,
      sym__decimal_number_pre_hook,
      sym_path,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_TILDE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      aux_sym_symbol_token1,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
  [77735] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2387), 9,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(2385), 24,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [77776] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2035), 9,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(2037), 24,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [77817] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2391), 9,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(2389), 24,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [77858] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2049), 9,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(2051), 24,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [77899] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2395), 9,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(2393), 24,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [77940] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2415), 9,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(2413), 24,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [77981] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2556), 1,
      sym__blank,
    STATE(952), 1,
      aux_sym_block_repeat1,
    ACTIONS(2122), 15,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_const,
      anon_sym_volatile,
      anon_sym_struct,
      anon_sym_union,
      anon_sym_enum,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
      sym_hll_primitive_type,
      sym_identifier,
    ACTIONS(2120), 16,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      anon_sym_EQ,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [78026] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2379), 9,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(2377), 24,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [78067] = 24,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2317), 1,
      anon_sym_LPAREN,
    ACTIONS(2347), 1,
      anon_sym_LBRACK,
    ACTIONS(2563), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2567), 1,
      anon_sym_SLASH,
    ACTIONS(2569), 1,
      anon_sym_PIPE,
    ACTIONS(2571), 1,
      anon_sym_CARET,
    ACTIONS(2581), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2583), 1,
      anon_sym_AMP,
    ACTIONS(2585), 1,
      anon_sym_QMARK,
    ACTIONS(2587), 1,
      aux_sym__hll_expression_separator_token1,
    ACTIONS(2589), 1,
      aux_sym__hll_expression_separator_token2,
    ACTIONS(2593), 1,
      sym__blank,
    STATE(813), 1,
      sym_hll_argument_list,
    STATE(1092), 1,
      aux_sym_block_repeat1,
    ACTIONS(2343), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2559), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2561), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2565), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(2573), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2575), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2577), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2579), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2591), 2,
      sym_comment,
      sym__blank_line,
  [78149] = 24,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2317), 1,
      anon_sym_LPAREN,
    ACTIONS(2347), 1,
      anon_sym_LBRACK,
    ACTIONS(2563), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2567), 1,
      anon_sym_SLASH,
    ACTIONS(2569), 1,
      anon_sym_PIPE,
    ACTIONS(2571), 1,
      anon_sym_CARET,
    ACTIONS(2581), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2583), 1,
      anon_sym_AMP,
    ACTIONS(2585), 1,
      anon_sym_QMARK,
    ACTIONS(2587), 1,
      aux_sym__hll_expression_separator_token1,
    ACTIONS(2589), 1,
      aux_sym__hll_expression_separator_token2,
    ACTIONS(2597), 1,
      sym__blank,
    STATE(813), 1,
      sym_hll_argument_list,
    STATE(1014), 1,
      aux_sym_block_repeat1,
    ACTIONS(2343), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2559), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2561), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2565), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(2573), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2575), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2577), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2579), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2595), 2,
      sym_comment,
      sym__blank_line,
  [78231] = 24,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2317), 1,
      anon_sym_LPAREN,
    ACTIONS(2347), 1,
      anon_sym_LBRACK,
    ACTIONS(2563), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2567), 1,
      anon_sym_SLASH,
    ACTIONS(2569), 1,
      anon_sym_PIPE,
    ACTIONS(2571), 1,
      anon_sym_CARET,
    ACTIONS(2581), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2583), 1,
      anon_sym_AMP,
    ACTIONS(2585), 1,
      anon_sym_QMARK,
    ACTIONS(2587), 1,
      aux_sym__hll_expression_separator_token1,
    ACTIONS(2589), 1,
      aux_sym__hll_expression_separator_token2,
    ACTIONS(2601), 1,
      sym__blank,
    STATE(813), 1,
      sym_hll_argument_list,
    STATE(1134), 1,
      aux_sym_block_repeat1,
    ACTIONS(2343), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2559), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2561), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2565), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(2573), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2575), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2577), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2579), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2599), 2,
      sym_comment,
      sym__blank_line,
  [78313] = 24,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2317), 1,
      anon_sym_LPAREN,
    ACTIONS(2347), 1,
      anon_sym_LBRACK,
    ACTIONS(2563), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2567), 1,
      anon_sym_SLASH,
    ACTIONS(2569), 1,
      anon_sym_PIPE,
    ACTIONS(2571), 1,
      anon_sym_CARET,
    ACTIONS(2581), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2583), 1,
      anon_sym_AMP,
    ACTIONS(2585), 1,
      anon_sym_QMARK,
    ACTIONS(2587), 1,
      aux_sym__hll_expression_separator_token1,
    ACTIONS(2589), 1,
      aux_sym__hll_expression_separator_token2,
    ACTIONS(2603), 1,
      sym__blank,
    STATE(813), 1,
      sym_hll_argument_list,
    STATE(1084), 1,
      aux_sym_block_repeat1,
    ACTIONS(2343), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2559), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2561), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2565), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(2573), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2575), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2577), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2579), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2599), 2,
      sym_comment,
      sym__blank_line,
  [78395] = 24,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2317), 1,
      anon_sym_LPAREN,
    ACTIONS(2347), 1,
      anon_sym_LBRACK,
    ACTIONS(2563), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2567), 1,
      anon_sym_SLASH,
    ACTIONS(2569), 1,
      anon_sym_PIPE,
    ACTIONS(2571), 1,
      anon_sym_CARET,
    ACTIONS(2581), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2583), 1,
      anon_sym_AMP,
    ACTIONS(2585), 1,
      anon_sym_QMARK,
    ACTIONS(2587), 1,
      aux_sym__hll_expression_separator_token1,
    ACTIONS(2589), 1,
      aux_sym__hll_expression_separator_token2,
    ACTIONS(2607), 1,
      sym__blank,
    STATE(813), 1,
      sym_hll_argument_list,
    STATE(1009), 1,
      aux_sym_block_repeat1,
    ACTIONS(2343), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2559), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2561), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2565), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(2573), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2575), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2577), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2579), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2605), 2,
      sym_comment,
      sym__blank_line,
  [78477] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2616), 1,
      sym__blank,
    STATE(1844), 1,
      aux_sym_block_repeat1,
    ACTIONS(2613), 2,
      anon_sym_const,
      anon_sym_volatile,
    STATE(959), 2,
      sym_hll_type_qualifier,
      aux_sym_hll_type_descriptor_repeat2,
    ACTIONS(2609), 6,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BSLASH,
      anon_sym_sizeof,
      aux_sym_symbol_token2,
      sym_identifier,
    ACTIONS(2611), 20,
      sym__hll_number_literal_pre_hook,
      anon_sym_LPAREN,
      anon_sym_TILDE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_RBRACK,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      aux_sym_symbol_token1,
  [78525] = 24,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2317), 1,
      anon_sym_LPAREN,
    ACTIONS(2347), 1,
      anon_sym_LBRACK,
    ACTIONS(2563), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2567), 1,
      anon_sym_SLASH,
    ACTIONS(2569), 1,
      anon_sym_PIPE,
    ACTIONS(2571), 1,
      anon_sym_CARET,
    ACTIONS(2581), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2583), 1,
      anon_sym_AMP,
    ACTIONS(2585), 1,
      anon_sym_QMARK,
    ACTIONS(2587), 1,
      aux_sym__hll_expression_separator_token1,
    ACTIONS(2589), 1,
      aux_sym__hll_expression_separator_token2,
    ACTIONS(2621), 1,
      sym__blank,
    STATE(813), 1,
      sym_hll_argument_list,
    STATE(1017), 1,
      aux_sym_block_repeat1,
    ACTIONS(2343), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2559), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2561), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2565), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(2573), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2575), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2577), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2579), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2619), 2,
      sym_comment,
      sym__blank_line,
  [78607] = 24,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2317), 1,
      anon_sym_LPAREN,
    ACTIONS(2347), 1,
      anon_sym_LBRACK,
    ACTIONS(2563), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2567), 1,
      anon_sym_SLASH,
    ACTIONS(2569), 1,
      anon_sym_PIPE,
    ACTIONS(2571), 1,
      anon_sym_CARET,
    ACTIONS(2581), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2583), 1,
      anon_sym_AMP,
    ACTIONS(2585), 1,
      anon_sym_QMARK,
    ACTIONS(2587), 1,
      aux_sym__hll_expression_separator_token1,
    ACTIONS(2589), 1,
      aux_sym__hll_expression_separator_token2,
    ACTIONS(2623), 1,
      sym__blank,
    STATE(813), 1,
      sym_hll_argument_list,
    STATE(969), 1,
      aux_sym_block_repeat1,
    ACTIONS(2343), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2559), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2561), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2565), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(2573), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2575), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2577), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2579), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2619), 2,
      sym_comment,
      sym__blank_line,
  [78689] = 24,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2317), 1,
      anon_sym_LPAREN,
    ACTIONS(2347), 1,
      anon_sym_LBRACK,
    ACTIONS(2563), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2567), 1,
      anon_sym_SLASH,
    ACTIONS(2569), 1,
      anon_sym_PIPE,
    ACTIONS(2571), 1,
      anon_sym_CARET,
    ACTIONS(2581), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2583), 1,
      anon_sym_AMP,
    ACTIONS(2585), 1,
      anon_sym_QMARK,
    ACTIONS(2587), 1,
      aux_sym__hll_expression_separator_token1,
    ACTIONS(2589), 1,
      aux_sym__hll_expression_separator_token2,
    ACTIONS(2627), 1,
      sym__blank,
    STATE(813), 1,
      sym_hll_argument_list,
    STATE(1065), 1,
      aux_sym_block_repeat1,
    ACTIONS(2343), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2559), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2561), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2565), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(2573), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2575), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2577), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2579), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2625), 2,
      sym_comment,
      sym__blank_line,
  [78771] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1665), 11,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
      sym__blank,
    ACTIONS(1667), 20,
      sym__and_operator_pre_hook,
      sym_path,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_COLON_COLON_COLON,
      sym_comment,
      sym__blank_line,
  [78810] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2011), 7,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      anon_sym_DOT,
    ACTIONS(2013), 24,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      aux_sym_symbol_token3,
      sym__blank,
  [78849] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2199), 1,
      anon_sym_LPAREN,
    ACTIONS(2205), 1,
      anon_sym_DOT,
    ACTIONS(2207), 1,
      anon_sym_DASH_GT,
    ACTIONS(2209), 1,
      anon_sym_LBRACK,
    ACTIONS(2633), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2637), 1,
      anon_sym_PIPE,
    ACTIONS(2639), 1,
      anon_sym_CARET,
    ACTIONS(2649), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2651), 1,
      anon_sym_AMP,
    ACTIONS(2653), 1,
      anon_sym_QMARK,
    STATE(752), 1,
      sym_hll_argument_list,
    ACTIONS(2629), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2631), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2641), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2643), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2645), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2647), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2635), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2299), 5,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      sym__blank,
  [78922] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2199), 1,
      anon_sym_LPAREN,
    ACTIONS(2205), 1,
      anon_sym_DOT,
    ACTIONS(2207), 1,
      anon_sym_DASH_GT,
    ACTIONS(2209), 1,
      anon_sym_LBRACK,
    ACTIONS(2633), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2637), 1,
      anon_sym_PIPE,
    ACTIONS(2639), 1,
      anon_sym_CARET,
    ACTIONS(2649), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2651), 1,
      anon_sym_AMP,
    ACTIONS(2653), 1,
      anon_sym_QMARK,
    STATE(752), 1,
      sym_hll_argument_list,
    ACTIONS(2629), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2631), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2641), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2643), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2645), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2647), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2635), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2303), 5,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      sym__blank,
  [78995] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1687), 1,
      sym_path,
    ACTIONS(1645), 2,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
    ACTIONS(1647), 4,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON_COLON,
    ACTIONS(1639), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1642), 17,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      sym__blank,
  [79040] = 17,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2199), 1,
      anon_sym_LPAREN,
    ACTIONS(2205), 1,
      anon_sym_DOT,
    ACTIONS(2207), 1,
      anon_sym_DASH_GT,
    ACTIONS(2209), 1,
      anon_sym_LBRACK,
    ACTIONS(2637), 1,
      anon_sym_PIPE,
    ACTIONS(2639), 1,
      anon_sym_CARET,
    ACTIONS(2651), 1,
      anon_sym_AMP,
    STATE(752), 1,
      sym_hll_argument_list,
    ACTIONS(2629), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2631), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2641), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2643), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2645), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2647), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2635), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2197), 8,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_RBRACK,
      sym__blank,
  [79107] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(434), 1,
      anon_sym_SLASH,
    ACTIONS(1603), 1,
      sym__blank,
    STATE(800), 1,
      aux_sym_block_repeat1,
    STATE(1968), 1,
      sym_option_expression,
    STATE(2178), 1,
      aux_sym__command_arguments_repeat2,
    ACTIONS(2655), 6,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BSLASH,
      anon_sym_sizeof,
      aux_sym_symbol_token2,
      sym_identifier,
    ACTIONS(2657), 20,
      sym__hll_number_literal_pre_hook,
      anon_sym_LPAREN,
      anon_sym_TILDE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      aux_sym_symbol_token1,
  [79156] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1647), 1,
      anon_sym_COLON_COLON_COLON,
    ACTIONS(1687), 1,
      sym_path,
    ACTIONS(1645), 2,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
    ACTIONS(1635), 3,
      anon_sym_EQ,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1639), 4,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
    ACTIONS(1642), 6,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT_DOT,
    ACTIONS(1637), 14,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COMMA,
      sym__blank,
  [79205] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2199), 1,
      anon_sym_LPAREN,
    ACTIONS(2205), 1,
      anon_sym_DOT,
    ACTIONS(2207), 1,
      anon_sym_DASH_GT,
    ACTIONS(2209), 1,
      anon_sym_LBRACK,
    STATE(752), 1,
      sym_hll_argument_list,
    ACTIONS(2631), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2215), 6,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
    ACTIONS(2213), 18,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_RBRACK,
      sym__blank,
  [79256] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1687), 1,
      sym_path,
    ACTIONS(1645), 2,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
    ACTIONS(1647), 4,
      anon_sym_COMMA,
      anon_sym_COLON_COLON_COLON,
      sym_comment,
      sym__blank_line,
    ACTIONS(1639), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(1642), 15,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
  [79301] = 15,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2199), 1,
      anon_sym_LPAREN,
    ACTIONS(2205), 1,
      anon_sym_DOT,
    ACTIONS(2207), 1,
      anon_sym_DASH_GT,
    ACTIONS(2209), 1,
      anon_sym_LBRACK,
    STATE(752), 1,
      sym_hll_argument_list,
    ACTIONS(2201), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(2629), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2631), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2641), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2643), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2645), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2647), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2635), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2197), 9,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_CARET,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_RBRACK,
      sym__blank,
  [79364] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2199), 1,
      anon_sym_LPAREN,
    ACTIONS(2205), 1,
      anon_sym_DOT,
    ACTIONS(2207), 1,
      anon_sym_DASH_GT,
    ACTIONS(2209), 1,
      anon_sym_LBRACK,
    ACTIONS(2637), 1,
      anon_sym_PIPE,
    ACTIONS(2639), 1,
      anon_sym_CARET,
    ACTIONS(2649), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2651), 1,
      anon_sym_AMP,
    STATE(752), 1,
      sym_hll_argument_list,
    ACTIONS(2629), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2631), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2641), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2643), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2645), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2647), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2635), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2197), 7,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_RBRACK,
      sym__blank,
  [79433] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1647), 1,
      anon_sym_COLON_COLON_COLON,
    ACTIONS(1687), 1,
      sym_path,
    ACTIONS(1645), 2,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
    ACTIONS(1635), 3,
      anon_sym_EQ,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1639), 4,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
    ACTIONS(1642), 8,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT_DOT,
    ACTIONS(1637), 12,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COMMA,
      sym__blank,
  [79482] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2317), 1,
      anon_sym_LPAREN,
    ACTIONS(2347), 1,
      anon_sym_LBRACK,
    STATE(813), 1,
      sym_hll_argument_list,
    ACTIONS(2343), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2311), 9,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(2309), 17,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [79529] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2317), 1,
      anon_sym_LPAREN,
    ACTIONS(2347), 1,
      anon_sym_LBRACK,
    STATE(813), 1,
      sym_hll_argument_list,
    ACTIONS(2343), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2561), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2289), 9,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(2287), 15,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [79578] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2317), 1,
      anon_sym_LPAREN,
    ACTIONS(2347), 1,
      anon_sym_LBRACK,
    STATE(813), 1,
      sym_hll_argument_list,
    ACTIONS(2343), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2561), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2579), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2241), 9,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(2239), 13,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [79629] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2199), 1,
      anon_sym_LPAREN,
    ACTIONS(2205), 1,
      anon_sym_DOT,
    ACTIONS(2207), 1,
      anon_sym_DASH_GT,
    ACTIONS(2209), 1,
      anon_sym_LBRACK,
    ACTIONS(2633), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2637), 1,
      anon_sym_PIPE,
    ACTIONS(2639), 1,
      anon_sym_CARET,
    ACTIONS(2649), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2651), 1,
      anon_sym_AMP,
    ACTIONS(2653), 1,
      anon_sym_QMARK,
    STATE(752), 1,
      sym_hll_argument_list,
    ACTIONS(2629), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2631), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2641), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2643), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2645), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2647), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2635), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2275), 5,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      sym__blank,
  [79702] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1647), 1,
      anon_sym_COLON_COLON_COLON,
    ACTIONS(2659), 1,
      sym_path,
    ACTIONS(1645), 2,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
    ACTIONS(1635), 4,
      anon_sym_EQ,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(1639), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
    ACTIONS(1642), 5,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_DOT_DOT,
    ACTIONS(1637), 13,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [79751] = 23,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1943), 1,
      anon_sym_RPAREN,
    ACTIONS(2199), 1,
      anon_sym_LPAREN,
    ACTIONS(2209), 1,
      anon_sym_LBRACK,
    ACTIONS(2633), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2637), 1,
      anon_sym_PIPE,
    ACTIONS(2639), 1,
      anon_sym_CARET,
    ACTIONS(2649), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2651), 1,
      anon_sym_AMP,
    ACTIONS(2653), 1,
      anon_sym_QMARK,
    ACTIONS(2661), 1,
      anon_sym_COMMA,
    ACTIONS(2663), 1,
      sym__blank,
    STATE(752), 1,
      sym_hll_argument_list,
    STATE(1832), 1,
      aux_sym_block_repeat1,
    STATE(2181), 1,
      aux_sym_hll_argument_list_repeat1,
    ACTIONS(2207), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2629), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2631), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2641), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2643), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2645), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2647), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2635), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [79830] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2317), 1,
      anon_sym_LPAREN,
    ACTIONS(2347), 1,
      anon_sym_LBRACK,
    STATE(813), 1,
      sym_hll_argument_list,
    ACTIONS(2343), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2561), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2201), 9,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(2197), 15,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [79879] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2317), 1,
      anon_sym_LPAREN,
    ACTIONS(2347), 1,
      anon_sym_LBRACK,
    STATE(813), 1,
      sym_hll_argument_list,
    ACTIONS(2343), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2561), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2215), 9,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(2213), 15,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [79928] = 23,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2199), 1,
      anon_sym_LPAREN,
    ACTIONS(2209), 1,
      anon_sym_LBRACK,
    ACTIONS(2633), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2637), 1,
      anon_sym_PIPE,
    ACTIONS(2639), 1,
      anon_sym_CARET,
    ACTIONS(2649), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2651), 1,
      anon_sym_AMP,
    ACTIONS(2653), 1,
      anon_sym_QMARK,
    ACTIONS(2661), 1,
      anon_sym_COMMA,
    ACTIONS(2665), 1,
      anon_sym_RPAREN,
    ACTIONS(2667), 1,
      sym__blank,
    STATE(752), 1,
      sym_hll_argument_list,
    STATE(1837), 1,
      aux_sym_block_repeat1,
    STATE(2226), 1,
      aux_sym_hll_argument_list_repeat1,
    ACTIONS(2207), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2629), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2631), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2641), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2643), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2645), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2647), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2635), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [80007] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2317), 1,
      anon_sym_LPAREN,
    ACTIONS(2347), 1,
      anon_sym_LBRACK,
    STATE(813), 1,
      sym_hll_argument_list,
    ACTIONS(2343), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2561), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2225), 9,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(2223), 15,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [80056] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2317), 1,
      anon_sym_LPAREN,
    ACTIONS(2347), 1,
      anon_sym_LBRACK,
    STATE(813), 1,
      sym_hll_argument_list,
    ACTIONS(2343), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2561), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2229), 9,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(2227), 15,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [80105] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2317), 1,
      anon_sym_LPAREN,
    ACTIONS(2347), 1,
      anon_sym_LBRACK,
    STATE(813), 1,
      sym_hll_argument_list,
    ACTIONS(2343), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2561), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2233), 9,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(2231), 15,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [80154] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2199), 1,
      anon_sym_LPAREN,
    ACTIONS(2205), 1,
      anon_sym_DOT,
    ACTIONS(2207), 1,
      anon_sym_DASH_GT,
    ACTIONS(2209), 1,
      anon_sym_LBRACK,
    STATE(752), 1,
      sym_hll_argument_list,
    ACTIONS(2631), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2229), 6,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
    ACTIONS(2227), 18,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_RBRACK,
      sym__blank,
  [80205] = 23,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1979), 1,
      anon_sym_RPAREN,
    ACTIONS(2199), 1,
      anon_sym_LPAREN,
    ACTIONS(2209), 1,
      anon_sym_LBRACK,
    ACTIONS(2633), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2637), 1,
      anon_sym_PIPE,
    ACTIONS(2639), 1,
      anon_sym_CARET,
    ACTIONS(2649), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2651), 1,
      anon_sym_AMP,
    ACTIONS(2653), 1,
      anon_sym_QMARK,
    ACTIONS(2661), 1,
      anon_sym_COMMA,
    ACTIONS(2669), 1,
      sym__blank,
    STATE(752), 1,
      sym_hll_argument_list,
    STATE(1871), 1,
      aux_sym_block_repeat1,
    STATE(2034), 1,
      aux_sym_hll_argument_list_repeat1,
    ACTIONS(2207), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2629), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2631), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2641), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2643), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2645), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2647), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2635), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [80284] = 23,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2199), 1,
      anon_sym_LPAREN,
    ACTIONS(2209), 1,
      anon_sym_LBRACK,
    ACTIONS(2633), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2637), 1,
      anon_sym_PIPE,
    ACTIONS(2639), 1,
      anon_sym_CARET,
    ACTIONS(2649), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2651), 1,
      anon_sym_AMP,
    ACTIONS(2653), 1,
      anon_sym_QMARK,
    ACTIONS(2661), 1,
      anon_sym_COMMA,
    ACTIONS(2671), 1,
      anon_sym_RPAREN,
    ACTIONS(2673), 1,
      sym__blank,
    STATE(752), 1,
      sym_hll_argument_list,
    STATE(1936), 1,
      aux_sym_block_repeat1,
    STATE(2222), 1,
      aux_sym_hll_argument_list_repeat1,
    ACTIONS(2207), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2629), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2631), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2641), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2643), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2645), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2647), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2635), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [80363] = 23,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2199), 1,
      anon_sym_LPAREN,
    ACTIONS(2209), 1,
      anon_sym_LBRACK,
    ACTIONS(2633), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2637), 1,
      anon_sym_PIPE,
    ACTIONS(2639), 1,
      anon_sym_CARET,
    ACTIONS(2649), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2651), 1,
      anon_sym_AMP,
    ACTIONS(2653), 1,
      anon_sym_QMARK,
    ACTIONS(2661), 1,
      anon_sym_COMMA,
    ACTIONS(2675), 1,
      anon_sym_RPAREN,
    ACTIONS(2677), 1,
      sym__blank,
    STATE(752), 1,
      sym_hll_argument_list,
    STATE(1872), 1,
      aux_sym_block_repeat1,
    STATE(2037), 1,
      aux_sym_hll_argument_list_repeat1,
    ACTIONS(2207), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2629), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2631), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2641), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2643), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2645), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2647), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2635), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [80442] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2199), 1,
      anon_sym_LPAREN,
    ACTIONS(2205), 1,
      anon_sym_DOT,
    ACTIONS(2207), 1,
      anon_sym_DASH_GT,
    ACTIONS(2209), 1,
      anon_sym_LBRACK,
    STATE(752), 1,
      sym_hll_argument_list,
    ACTIONS(2631), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2647), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2201), 6,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
    ACTIONS(2197), 16,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_RBRACK,
      sym__blank,
  [80495] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2317), 1,
      anon_sym_LPAREN,
    ACTIONS(2347), 1,
      anon_sym_LBRACK,
    ACTIONS(2563), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2567), 1,
      anon_sym_SLASH,
    ACTIONS(2569), 1,
      anon_sym_PIPE,
    ACTIONS(2571), 1,
      anon_sym_CARET,
    ACTIONS(2581), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2583), 1,
      anon_sym_AMP,
    ACTIONS(2585), 1,
      anon_sym_QMARK,
    STATE(813), 1,
      sym_hll_argument_list,
    ACTIONS(2277), 2,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(2343), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2559), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2561), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2565), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(2573), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2575), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2577), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2579), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2275), 3,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [80570] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1987), 7,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      anon_sym_DOT,
    ACTIONS(1989), 24,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      aux_sym_symbol_token3,
      sym__blank,
  [80609] = 17,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2199), 1,
      anon_sym_LPAREN,
    ACTIONS(2201), 1,
      anon_sym_PIPE,
    ACTIONS(2205), 1,
      anon_sym_DOT,
    ACTIONS(2207), 1,
      anon_sym_DASH_GT,
    ACTIONS(2209), 1,
      anon_sym_LBRACK,
    ACTIONS(2639), 1,
      anon_sym_CARET,
    ACTIONS(2651), 1,
      anon_sym_AMP,
    STATE(752), 1,
      sym_hll_argument_list,
    ACTIONS(2629), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2631), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2641), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2643), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2645), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2647), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2635), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2197), 8,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_RBRACK,
      sym__blank,
  [80676] = 16,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2199), 1,
      anon_sym_LPAREN,
    ACTIONS(2201), 1,
      anon_sym_PIPE,
    ACTIONS(2205), 1,
      anon_sym_DOT,
    ACTIONS(2207), 1,
      anon_sym_DASH_GT,
    ACTIONS(2209), 1,
      anon_sym_LBRACK,
    ACTIONS(2651), 1,
      anon_sym_AMP,
    STATE(752), 1,
      sym_hll_argument_list,
    ACTIONS(2629), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2631), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2641), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2643), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2645), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2647), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2635), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2197), 9,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_CARET,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_RBRACK,
      sym__blank,
  [80741] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2317), 1,
      anon_sym_LPAREN,
    ACTIONS(2347), 1,
      anon_sym_LBRACK,
    ACTIONS(2563), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2567), 1,
      anon_sym_SLASH,
    ACTIONS(2569), 1,
      anon_sym_PIPE,
    ACTIONS(2571), 1,
      anon_sym_CARET,
    ACTIONS(2581), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2583), 1,
      anon_sym_AMP,
    ACTIONS(2585), 1,
      anon_sym_QMARK,
    STATE(813), 1,
      sym_hll_argument_list,
    ACTIONS(2285), 2,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(2343), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2559), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2561), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2565), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(2573), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2575), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2577), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2579), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2283), 3,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [80816] = 23,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1985), 1,
      anon_sym_RPAREN,
    ACTIONS(2199), 1,
      anon_sym_LPAREN,
    ACTIONS(2209), 1,
      anon_sym_LBRACK,
    ACTIONS(2633), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2637), 1,
      anon_sym_PIPE,
    ACTIONS(2639), 1,
      anon_sym_CARET,
    ACTIONS(2649), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2651), 1,
      anon_sym_AMP,
    ACTIONS(2653), 1,
      anon_sym_QMARK,
    ACTIONS(2661), 1,
      anon_sym_COMMA,
    ACTIONS(2679), 1,
      sym__blank,
    STATE(752), 1,
      sym_hll_argument_list,
    STATE(1881), 1,
      aux_sym_block_repeat1,
    STATE(2068), 1,
      aux_sym_hll_argument_list_repeat1,
    ACTIONS(2207), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2629), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2631), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2641), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2643), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2645), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2647), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2635), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [80895] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2199), 1,
      anon_sym_LPAREN,
    ACTIONS(2205), 1,
      anon_sym_DOT,
    ACTIONS(2207), 1,
      anon_sym_DASH_GT,
    ACTIONS(2209), 1,
      anon_sym_LBRACK,
    ACTIONS(2633), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2637), 1,
      anon_sym_PIPE,
    ACTIONS(2639), 1,
      anon_sym_CARET,
    ACTIONS(2649), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2651), 1,
      anon_sym_AMP,
    ACTIONS(2653), 1,
      anon_sym_QMARK,
    STATE(752), 1,
      sym_hll_argument_list,
    ACTIONS(2629), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2631), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2641), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2643), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2645), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2647), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2635), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2291), 5,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      sym__blank,
  [80968] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2317), 1,
      anon_sym_LPAREN,
    ACTIONS(2347), 1,
      anon_sym_LBRACK,
    ACTIONS(2563), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2567), 1,
      anon_sym_SLASH,
    ACTIONS(2569), 1,
      anon_sym_PIPE,
    ACTIONS(2571), 1,
      anon_sym_CARET,
    ACTIONS(2581), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2583), 1,
      anon_sym_AMP,
    ACTIONS(2585), 1,
      anon_sym_QMARK,
    STATE(813), 1,
      sym_hll_argument_list,
    ACTIONS(2301), 2,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(2343), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2559), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2561), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2565), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(2573), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2575), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2577), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2579), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2299), 3,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [81043] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2317), 1,
      anon_sym_LPAREN,
    ACTIONS(2347), 1,
      anon_sym_LBRACK,
    ACTIONS(2563), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2567), 1,
      anon_sym_SLASH,
    ACTIONS(2569), 1,
      anon_sym_PIPE,
    ACTIONS(2571), 1,
      anon_sym_CARET,
    ACTIONS(2581), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2583), 1,
      anon_sym_AMP,
    ACTIONS(2585), 1,
      anon_sym_QMARK,
    STATE(813), 1,
      sym_hll_argument_list,
    ACTIONS(2297), 2,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(2343), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2559), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2561), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2565), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(2573), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2575), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2577), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2579), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2295), 3,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [81118] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2199), 1,
      anon_sym_LPAREN,
    ACTIONS(2205), 1,
      anon_sym_DOT,
    ACTIONS(2207), 1,
      anon_sym_DASH_GT,
    ACTIONS(2209), 1,
      anon_sym_LBRACK,
    STATE(752), 1,
      sym_hll_argument_list,
    ACTIONS(2631), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2225), 6,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
    ACTIONS(2223), 18,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_RBRACK,
      sym__blank,
  [81169] = 14,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2199), 1,
      anon_sym_LPAREN,
    ACTIONS(2205), 1,
      anon_sym_DOT,
    ACTIONS(2207), 1,
      anon_sym_DASH_GT,
    ACTIONS(2209), 1,
      anon_sym_LBRACK,
    STATE(752), 1,
      sym_hll_argument_list,
    ACTIONS(2201), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(2629), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2631), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2643), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2645), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2647), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2635), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2197), 11,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_RBRACK,
      sym__blank,
  [81230] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1665), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
    ACTIONS(1667), 22,
      sym__and_operator_pre_hook,
      sym_path,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_COLON_COLON_COLON,
      sym__blank,
  [81269] = 12,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2199), 1,
      anon_sym_LPAREN,
    ACTIONS(2205), 1,
      anon_sym_DOT,
    ACTIONS(2207), 1,
      anon_sym_DASH_GT,
    ACTIONS(2209), 1,
      anon_sym_LBRACK,
    STATE(752), 1,
      sym_hll_argument_list,
    ACTIONS(2629), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2631), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2647), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2635), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2201), 4,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
    ACTIONS(2197), 13,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_RBRACK,
      sym__blank,
  [81326] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2317), 1,
      anon_sym_LPAREN,
    ACTIONS(2347), 1,
      anon_sym_LBRACK,
    ACTIONS(2563), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2567), 1,
      anon_sym_SLASH,
    ACTIONS(2569), 1,
      anon_sym_PIPE,
    ACTIONS(2571), 1,
      anon_sym_CARET,
    ACTIONS(2581), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2583), 1,
      anon_sym_AMP,
    ACTIONS(2585), 1,
      anon_sym_QMARK,
    STATE(813), 1,
      sym_hll_argument_list,
    ACTIONS(2293), 2,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(2343), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2559), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2561), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2565), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(2573), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2575), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2577), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2579), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2291), 3,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [81401] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2681), 1,
      aux_sym_symbol_token3,
    ACTIONS(1889), 7,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      anon_sym_DOT,
    ACTIONS(1891), 23,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      sym__blank,
  [81442] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2199), 1,
      anon_sym_LPAREN,
    ACTIONS(2205), 1,
      anon_sym_DOT,
    ACTIONS(2207), 1,
      anon_sym_DASH_GT,
    ACTIONS(2209), 1,
      anon_sym_LBRACK,
    ACTIONS(2633), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2637), 1,
      anon_sym_PIPE,
    ACTIONS(2639), 1,
      anon_sym_CARET,
    ACTIONS(2649), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2651), 1,
      anon_sym_AMP,
    ACTIONS(2653), 1,
      anon_sym_QMARK,
    STATE(752), 1,
      sym_hll_argument_list,
    ACTIONS(2629), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2631), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2641), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2643), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2645), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2647), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2635), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2283), 5,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      sym__blank,
  [81515] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(434), 1,
      anon_sym_SLASH,
    ACTIONS(1603), 1,
      sym__blank,
    STATE(800), 1,
      aux_sym_block_repeat1,
    STATE(2017), 1,
      sym_option_expression,
    STATE(2208), 1,
      aux_sym__command_arguments_repeat2,
    ACTIONS(2655), 6,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BSLASH,
      anon_sym_sizeof,
      aux_sym_symbol_token2,
      sym_identifier,
    ACTIONS(2657), 20,
      sym__hll_number_literal_pre_hook,
      anon_sym_LPAREN,
      anon_sym_TILDE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      aux_sym_symbol_token1,
  [81564] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2199), 1,
      anon_sym_LPAREN,
    ACTIONS(2205), 1,
      anon_sym_DOT,
    ACTIONS(2207), 1,
      anon_sym_DASH_GT,
    ACTIONS(2209), 1,
      anon_sym_LBRACK,
    STATE(752), 1,
      sym_hll_argument_list,
    ACTIONS(2311), 6,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
    ACTIONS(2309), 20,
      anon_sym_RPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_RBRACK,
      sym__blank,
  [81613] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2199), 1,
      anon_sym_LPAREN,
    ACTIONS(2205), 1,
      anon_sym_DOT,
    ACTIONS(2207), 1,
      anon_sym_DASH_GT,
    ACTIONS(2209), 1,
      anon_sym_LBRACK,
    STATE(752), 1,
      sym_hll_argument_list,
    ACTIONS(2631), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2289), 6,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
    ACTIONS(2287), 18,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_RBRACK,
      sym__blank,
  [81664] = 23,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1945), 1,
      anon_sym_RPAREN,
    ACTIONS(2199), 1,
      anon_sym_LPAREN,
    ACTIONS(2209), 1,
      anon_sym_LBRACK,
    ACTIONS(2633), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2637), 1,
      anon_sym_PIPE,
    ACTIONS(2639), 1,
      anon_sym_CARET,
    ACTIONS(2649), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2651), 1,
      anon_sym_AMP,
    ACTIONS(2653), 1,
      anon_sym_QMARK,
    ACTIONS(2661), 1,
      anon_sym_COMMA,
    ACTIONS(2683), 1,
      sym__blank,
    STATE(752), 1,
      sym_hll_argument_list,
    STATE(1887), 1,
      aux_sym_block_repeat1,
    STATE(2094), 1,
      aux_sym_hll_argument_list_repeat1,
    ACTIONS(2207), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2629), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2631), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2641), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2643), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2645), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2647), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2635), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [81743] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2199), 1,
      anon_sym_LPAREN,
    ACTIONS(2205), 1,
      anon_sym_DOT,
    ACTIONS(2207), 1,
      anon_sym_DASH_GT,
    ACTIONS(2209), 1,
      anon_sym_LBRACK,
    STATE(752), 1,
      sym_hll_argument_list,
    ACTIONS(2631), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2647), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2241), 6,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
    ACTIONS(2239), 16,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_RBRACK,
      sym__blank,
  [81796] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(434), 1,
      anon_sym_SLASH,
    ACTIONS(1603), 1,
      sym__blank,
    STATE(800), 1,
      aux_sym_block_repeat1,
    STATE(2029), 1,
      sym_option_expression,
    STATE(2049), 1,
      aux_sym__command_arguments_repeat2,
    ACTIONS(2685), 6,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BSLASH,
      anon_sym_sizeof,
      aux_sym_symbol_token2,
      sym_identifier,
    ACTIONS(2687), 20,
      sym__hll_number_literal_pre_hook,
      anon_sym_LPAREN,
      anon_sym_TILDE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      aux_sym_symbol_token1,
  [81845] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2199), 1,
      anon_sym_LPAREN,
    ACTIONS(2205), 1,
      anon_sym_DOT,
    ACTIONS(2207), 1,
      anon_sym_DASH_GT,
    ACTIONS(2209), 1,
      anon_sym_LBRACK,
    ACTIONS(2633), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2637), 1,
      anon_sym_PIPE,
    ACTIONS(2639), 1,
      anon_sym_CARET,
    ACTIONS(2649), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2651), 1,
      anon_sym_AMP,
    ACTIONS(2653), 1,
      anon_sym_QMARK,
    STATE(752), 1,
      sym_hll_argument_list,
    ACTIONS(2629), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2631), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2641), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2643), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2645), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2647), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2635), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2295), 5,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      sym__blank,
  [81918] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1661), 11,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
      sym__blank,
    ACTIONS(1663), 20,
      sym__and_operator_pre_hook,
      sym_path,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_COLON_COLON_COLON,
      sym_comment,
      sym__blank_line,
  [81957] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(434), 1,
      anon_sym_SLASH,
    ACTIONS(1603), 1,
      sym__blank,
    STATE(800), 1,
      aux_sym_block_repeat1,
    STATE(1968), 1,
      sym_option_expression,
    STATE(2178), 1,
      aux_sym__command_arguments_repeat2,
    ACTIONS(2685), 6,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BSLASH,
      anon_sym_sizeof,
      aux_sym_symbol_token2,
      sym_identifier,
    ACTIONS(2687), 20,
      sym__hll_number_literal_pre_hook,
      anon_sym_LPAREN,
      anon_sym_TILDE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      aux_sym_symbol_token1,
  [82006] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2317), 1,
      anon_sym_LPAREN,
    ACTIONS(2347), 1,
      anon_sym_LBRACK,
    ACTIONS(2563), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2567), 1,
      anon_sym_SLASH,
    ACTIONS(2569), 1,
      anon_sym_PIPE,
    ACTIONS(2571), 1,
      anon_sym_CARET,
    ACTIONS(2581), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2583), 1,
      anon_sym_AMP,
    ACTIONS(2585), 1,
      anon_sym_QMARK,
    STATE(813), 1,
      sym_hll_argument_list,
    ACTIONS(2305), 2,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(2343), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2559), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2561), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2565), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(2573), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2575), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2577), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2579), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2303), 3,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [82081] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1661), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
    ACTIONS(1663), 22,
      sym__and_operator_pre_hook,
      sym_path,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_COLON_COLON_COLON,
      sym__blank,
  [82120] = 11,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2317), 1,
      anon_sym_LPAREN,
    ACTIONS(2347), 1,
      anon_sym_LBRACK,
    ACTIONS(2567), 1,
      anon_sym_SLASH,
    STATE(813), 1,
      sym_hll_argument_list,
    ACTIONS(2343), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2561), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2565), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(2579), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2201), 8,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(2197), 11,
      anon_sym_PIPE_PIPE,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [82175] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2317), 1,
      anon_sym_LPAREN,
    ACTIONS(2347), 1,
      anon_sym_LBRACK,
    ACTIONS(2567), 1,
      anon_sym_SLASH,
    ACTIONS(2569), 1,
      anon_sym_PIPE,
    ACTIONS(2571), 1,
      anon_sym_CARET,
    ACTIONS(2581), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2583), 1,
      anon_sym_AMP,
    STATE(813), 1,
      sym_hll_argument_list,
    ACTIONS(2201), 2,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(2343), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2559), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2561), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2565), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(2573), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2575), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2577), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2579), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2197), 5,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [82246] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2317), 1,
      anon_sym_LPAREN,
    ACTIONS(2347), 1,
      anon_sym_LBRACK,
    STATE(813), 1,
      sym_hll_argument_list,
    ACTIONS(2343), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2561), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2579), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2201), 9,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(2197), 13,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [82297] = 17,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2317), 1,
      anon_sym_LPAREN,
    ACTIONS(2347), 1,
      anon_sym_LBRACK,
    ACTIONS(2567), 1,
      anon_sym_SLASH,
    ACTIONS(2571), 1,
      anon_sym_CARET,
    ACTIONS(2583), 1,
      anon_sym_AMP,
    STATE(813), 1,
      sym_hll_argument_list,
    ACTIONS(2343), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2559), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2561), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2565), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(2573), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2575), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2577), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2579), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2201), 3,
      anon_sym_PIPE,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(2197), 6,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [82364] = 16,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2317), 1,
      anon_sym_LPAREN,
    ACTIONS(2347), 1,
      anon_sym_LBRACK,
    ACTIONS(2567), 1,
      anon_sym_SLASH,
    ACTIONS(2583), 1,
      anon_sym_AMP,
    STATE(813), 1,
      sym_hll_argument_list,
    ACTIONS(2343), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2559), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2561), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2565), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(2573), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2575), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2577), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2579), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2201), 3,
      anon_sym_PIPE,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(2197), 7,
      anon_sym_PIPE_PIPE,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [82429] = 14,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2317), 1,
      anon_sym_LPAREN,
    ACTIONS(2347), 1,
      anon_sym_LBRACK,
    ACTIONS(2567), 1,
      anon_sym_SLASH,
    STATE(813), 1,
      sym_hll_argument_list,
    ACTIONS(2343), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2559), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2561), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2565), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(2575), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2577), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2579), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2201), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(2197), 9,
      anon_sym_PIPE_PIPE,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [82490] = 12,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2317), 1,
      anon_sym_LPAREN,
    ACTIONS(2347), 1,
      anon_sym_LBRACK,
    ACTIONS(2567), 1,
      anon_sym_SLASH,
    STATE(813), 1,
      sym_hll_argument_list,
    ACTIONS(2343), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2559), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2561), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2565), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(2579), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2201), 6,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(2197), 11,
      anon_sym_PIPE_PIPE,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [82547] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2199), 1,
      anon_sym_LPAREN,
    ACTIONS(2205), 1,
      anon_sym_DOT,
    ACTIONS(2207), 1,
      anon_sym_DASH_GT,
    ACTIONS(2209), 1,
      anon_sym_LBRACK,
    STATE(752), 1,
      sym_hll_argument_list,
    ACTIONS(2631), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2201), 6,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
    ACTIONS(2197), 18,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_RBRACK,
      sym__blank,
  [82598] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2317), 1,
      anon_sym_LPAREN,
    ACTIONS(2347), 1,
      anon_sym_LBRACK,
    ACTIONS(2567), 1,
      anon_sym_SLASH,
    ACTIONS(2569), 1,
      anon_sym_PIPE,
    ACTIONS(2571), 1,
      anon_sym_CARET,
    ACTIONS(2583), 1,
      anon_sym_AMP,
    STATE(813), 1,
      sym_hll_argument_list,
    ACTIONS(2201), 2,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(2343), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2559), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2561), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2565), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(2573), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2575), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2577), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2579), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2197), 6,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [82667] = 15,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2317), 1,
      anon_sym_LPAREN,
    ACTIONS(2347), 1,
      anon_sym_LBRACK,
    ACTIONS(2567), 1,
      anon_sym_SLASH,
    STATE(813), 1,
      sym_hll_argument_list,
    ACTIONS(2343), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2559), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2561), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2565), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(2573), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2575), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2577), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2579), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2201), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(2197), 7,
      anon_sym_PIPE_PIPE,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [82730] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2199), 1,
      anon_sym_LPAREN,
    ACTIONS(2205), 1,
      anon_sym_DOT,
    ACTIONS(2207), 1,
      anon_sym_DASH_GT,
    ACTIONS(2209), 1,
      anon_sym_LBRACK,
    STATE(752), 1,
      sym_hll_argument_list,
    ACTIONS(2631), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2233), 6,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
    ACTIONS(2231), 18,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_RBRACK,
      sym__blank,
  [82781] = 11,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2199), 1,
      anon_sym_LPAREN,
    ACTIONS(2205), 1,
      anon_sym_DOT,
    ACTIONS(2207), 1,
      anon_sym_DASH_GT,
    ACTIONS(2209), 1,
      anon_sym_LBRACK,
    STATE(752), 1,
      sym_hll_argument_list,
    ACTIONS(2631), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2647), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2635), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2201), 6,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
    ACTIONS(2197), 13,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_RBRACK,
      sym__blank,
  [82836] = 23,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2199), 1,
      anon_sym_LPAREN,
    ACTIONS(2209), 1,
      anon_sym_LBRACK,
    ACTIONS(2633), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2637), 1,
      anon_sym_PIPE,
    ACTIONS(2639), 1,
      anon_sym_CARET,
    ACTIONS(2649), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2651), 1,
      anon_sym_AMP,
    ACTIONS(2653), 1,
      anon_sym_QMARK,
    ACTIONS(2661), 1,
      anon_sym_COMMA,
    ACTIONS(2689), 1,
      anon_sym_RPAREN,
    ACTIONS(2691), 1,
      sym__blank,
    STATE(752), 1,
      sym_hll_argument_list,
    STATE(1883), 1,
      aux_sym_block_repeat1,
    STATE(2071), 1,
      aux_sym_hll_argument_list_repeat1,
    ACTIONS(2207), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2629), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2631), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2641), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2643), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2645), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2647), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2635), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [82915] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1707), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
    ACTIONS(1709), 21,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_COLON_COLON_COLON,
      sym__blank,
  [82953] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1645), 2,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
    ACTIONS(1647), 4,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON_COLON,
    ACTIONS(1639), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1642), 17,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      sym__blank,
  [82995] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1645), 2,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
    ACTIONS(1647), 4,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON_COLON,
    ACTIONS(1719), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1722), 17,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      sym__blank,
  [83037] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1703), 11,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
      sym__blank,
    ACTIONS(1705), 19,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_COLON_COLON_COLON,
      sym_comment,
      sym__blank_line,
  [83075] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1757), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
    ACTIONS(1759), 21,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_COLON_COLON_COLON,
      sym__blank,
  [83113] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2693), 3,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOT_DOT,
    ACTIONS(2695), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1769), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
    ACTIONS(1771), 15,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COMMA,
      anon_sym_COLON_COLON_COLON,
      sym__blank,
  [83155] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1769), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
    ACTIONS(1771), 21,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_COLON_COLON_COLON,
      sym__blank,
  [83193] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2701), 1,
      aux_sym_elif_block_token1,
    ACTIONS(2706), 1,
      sym__blank,
    STATE(1452), 1,
      sym_else_block,
    STATE(1695), 1,
      aux_sym_subroutine_block_repeat1,
    STATE(1835), 1,
      aux_sym_block_repeat1,
    ACTIONS(2703), 2,
      sym_comment,
      sym__blank_line,
    STATE(1207), 2,
      sym_elif_block,
      aux_sym_if_block_repeat1,
    ACTIONS(2697), 6,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
    ACTIONS(2699), 15,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
  [83245] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2693), 3,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOT_DOT,
    ACTIONS(1769), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
    ACTIONS(1771), 18,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COMMA,
      anon_sym_COLON_COLON_COLON,
      sym__blank,
  [83285] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2711), 1,
      anon_sym_CARET,
    ACTIONS(2709), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2693), 3,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOT_DOT,
    ACTIONS(2695), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1769), 6,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
    ACTIONS(1771), 15,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COMMA,
      anon_sym_COLON_COLON_COLON,
      sym__blank,
  [83331] = 12,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1741), 1,
      anon_sym_COLON,
    ACTIONS(1743), 1,
      anon_sym_COLON_COLON_COLON,
    ACTIONS(1745), 1,
      anon_sym_COLON_COLON,
    ACTIONS(2719), 1,
      anon_sym_SLASH,
    ACTIONS(2721), 1,
      anon_sym_PIPE,
    ACTIONS(2723), 1,
      anon_sym_CARET,
    ACTIONS(2713), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2717), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(2715), 3,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOT_DOT,
    ACTIONS(1781), 4,
      anon_sym_EQ,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(1783), 13,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [83387] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2709), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2693), 3,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOT_DOT,
    ACTIONS(2695), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1769), 7,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
    ACTIONS(1771), 15,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COMMA,
      anon_sym_COLON_COLON_COLON,
      sym__blank,
  [83431] = 23,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2199), 1,
      anon_sym_LPAREN,
    ACTIONS(2205), 1,
      anon_sym_DOT,
    ACTIONS(2207), 1,
      anon_sym_DASH_GT,
    ACTIONS(2209), 1,
      anon_sym_LBRACK,
    ACTIONS(2633), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2637), 1,
      anon_sym_PIPE,
    ACTIONS(2639), 1,
      anon_sym_CARET,
    ACTIONS(2649), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2651), 1,
      anon_sym_AMP,
    ACTIONS(2653), 1,
      anon_sym_QMARK,
    ACTIONS(2725), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2727), 1,
      anon_sym_RBRACK,
    ACTIONS(2729), 1,
      sym__blank,
    STATE(752), 1,
      sym_hll_argument_list,
    STATE(2102), 1,
      aux_sym_block_repeat1,
    ACTIONS(2629), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2631), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2641), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2643), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2645), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2647), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2635), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [83509] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1647), 1,
      anon_sym_COLON_COLON_COLON,
    ACTIONS(1645), 2,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
    ACTIONS(1635), 3,
      anon_sym_EQ,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1639), 4,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
    ACTIONS(1642), 8,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT_DOT,
    ACTIONS(1637), 12,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COMMA,
      sym__blank,
  [83555] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1777), 11,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
      sym__blank,
    ACTIONS(1779), 19,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_COLON_COLON_COLON,
      sym_comment,
      sym__blank_line,
  [83593] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2199), 1,
      anon_sym_LPAREN,
    ACTIONS(2209), 1,
      anon_sym_LBRACK,
    ACTIONS(2633), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2637), 1,
      anon_sym_PIPE,
    ACTIONS(2639), 1,
      anon_sym_CARET,
    ACTIONS(2649), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2651), 1,
      anon_sym_AMP,
    ACTIONS(2653), 1,
      anon_sym_QMARK,
    ACTIONS(2733), 1,
      sym__blank,
    STATE(752), 1,
      sym_hll_argument_list,
    STATE(2032), 1,
      aux_sym_block_repeat1,
    ACTIONS(2207), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2629), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2631), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2641), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2643), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2645), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2647), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2731), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
    ACTIONS(2635), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [83667] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1699), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
    ACTIONS(1701), 21,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_COLON_COLON_COLON,
      sym__blank,
  [83705] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2735), 1,
      aux_sym_elif_block_token1,
    ACTIONS(2741), 1,
      sym__blank,
    STATE(1452), 1,
      sym_else_block,
    STATE(1694), 1,
      aux_sym_subroutine_block_repeat1,
    STATE(1934), 1,
      aux_sym_block_repeat1,
    ACTIONS(2738), 2,
      sym_comment,
      sym__blank_line,
    STATE(1207), 2,
      sym_elif_block,
      aux_sym_if_block_repeat1,
    ACTIONS(2697), 6,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
    ACTIONS(2699), 15,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
  [83757] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1687), 1,
      sym_path,
    ACTIONS(1645), 2,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
    ACTIONS(1635), 3,
      anon_sym_EQ,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1647), 3,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON_COLON,
    ACTIONS(1639), 4,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
    ACTIONS(1642), 6,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT_DOT,
    ACTIONS(1637), 11,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      sym__blank,
  [83805] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1647), 1,
      anon_sym_COLON_COLON_COLON,
    ACTIONS(1645), 2,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
    ACTIONS(1715), 3,
      anon_sym_EQ,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1719), 4,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
    ACTIONS(1722), 8,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT_DOT,
    ACTIONS(1717), 12,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COMMA,
      sym__blank,
  [83851] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(169), 1,
      anon_sym_AMP,
    STATE(1073), 1,
      aux_sym__path_expression_repeat2,
    STATE(1299), 1,
      sym_macro,
    ACTIONS(1809), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1811), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [83895] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1691), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
    ACTIONS(1693), 21,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_COLON_COLON_COLON,
      sym__blank,
  [83933] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1707), 11,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
      sym__blank,
    ACTIONS(1709), 19,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_COLON_COLON_COLON,
      sym_comment,
      sym__blank_line,
  [83971] = 11,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1741), 1,
      anon_sym_COLON,
    ACTIONS(1743), 1,
      anon_sym_COLON_COLON_COLON,
    ACTIONS(1745), 1,
      anon_sym_COLON_COLON,
    ACTIONS(2711), 1,
      anon_sym_CARET,
    ACTIONS(2744), 1,
      anon_sym_PIPE,
    ACTIONS(2709), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1781), 3,
      anon_sym_EQ,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2693), 3,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOT_DOT,
    ACTIONS(2695), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1783), 14,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COMMA,
      sym__blank,
  [84025] = 22,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2199), 1,
      anon_sym_LPAREN,
    ACTIONS(2209), 1,
      anon_sym_LBRACK,
    ACTIONS(2633), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2637), 1,
      anon_sym_PIPE,
    ACTIONS(2639), 1,
      anon_sym_CARET,
    ACTIONS(2649), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2651), 1,
      anon_sym_AMP,
    ACTIONS(2653), 1,
      anon_sym_QMARK,
    ACTIONS(2746), 1,
      anon_sym_RPAREN,
    ACTIONS(2748), 1,
      anon_sym_COMMA,
    ACTIONS(2750), 1,
      sym__blank,
    STATE(752), 1,
      sym_hll_argument_list,
    STATE(2055), 1,
      aux_sym_block_repeat1,
    ACTIONS(2207), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2629), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2631), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2641), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2643), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2645), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2647), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2635), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [84101] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1711), 11,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
      sym__blank,
    ACTIONS(1713), 19,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_COLON_COLON_COLON,
      sym_comment,
      sym__blank_line,
  [84139] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2752), 14,
      anon_sym_PLUS,
      anon_sym_DASH,
      aux_sym__hll_non_default_format_var_command_token1,
      anon_sym_BSLASH,
      sym_access_class,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
      sym_float,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
      aux_sym_symbol_token2,
      sym_time,
      sym_frequency,
      sym_identifier,
    ACTIONS(2756), 16,
      sym__decimal_number_pre_hook,
      sym_path,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_TILDE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      aux_sym_symbol_token1,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
  [84177] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1647), 1,
      anon_sym_COLON_COLON_COLON,
    ACTIONS(1645), 2,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
    ACTIONS(1635), 4,
      anon_sym_EQ,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(1639), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
    ACTIONS(1642), 5,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_DOT_DOT,
    ACTIONS(1637), 13,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [84223] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1699), 11,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
      sym__blank,
    ACTIONS(1701), 19,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_COLON_COLON_COLON,
      sym_comment,
      sym__blank_line,
  [84261] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2760), 14,
      anon_sym_PLUS,
      anon_sym_DASH,
      aux_sym__hll_non_default_format_var_command_token1,
      anon_sym_BSLASH,
      sym_access_class,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
      sym_float,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
      aux_sym_symbol_token2,
      sym_time,
      sym_frequency,
      sym_identifier,
    ACTIONS(2762), 16,
      sym__decimal_number_pre_hook,
      sym_path,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_TILDE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      aux_sym_symbol_token1,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
  [84299] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2199), 1,
      anon_sym_LPAREN,
    ACTIONS(2209), 1,
      anon_sym_LBRACK,
    ACTIONS(2633), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2637), 1,
      anon_sym_PIPE,
    ACTIONS(2639), 1,
      anon_sym_CARET,
    ACTIONS(2649), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2651), 1,
      anon_sym_AMP,
    ACTIONS(2653), 1,
      anon_sym_QMARK,
    ACTIONS(2766), 1,
      sym__blank,
    STATE(752), 1,
      sym_hll_argument_list,
    STATE(1999), 1,
      aux_sym_block_repeat1,
    ACTIONS(2207), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2629), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2631), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2641), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2643), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2645), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2647), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2764), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
    ACTIONS(2635), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [84373] = 12,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1741), 1,
      anon_sym_COLON,
    ACTIONS(1743), 1,
      anon_sym_COLON_COLON_COLON,
    ACTIONS(1745), 1,
      anon_sym_COLON_COLON,
    ACTIONS(2719), 1,
      anon_sym_SLASH,
    ACTIONS(2721), 1,
      anon_sym_PIPE,
    ACTIONS(2723), 1,
      anon_sym_CARET,
    ACTIONS(2713), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2717), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(2715), 3,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOT_DOT,
    ACTIONS(1725), 4,
      anon_sym_EQ,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(1727), 13,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [84429] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1603), 1,
      sym__blank,
    ACTIONS(2768), 1,
      anon_sym_SLASH,
    STATE(800), 1,
      aux_sym_block_repeat1,
    STATE(2270), 1,
      sym_option_expression,
    ACTIONS(2655), 6,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BSLASH,
      anon_sym_sizeof,
      aux_sym_symbol_token2,
      sym_identifier,
    ACTIONS(2657), 20,
      sym__hll_number_literal_pre_hook,
      anon_sym_LPAREN,
      anon_sym_TILDE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      aux_sym_symbol_token1,
  [84475] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1765), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
    ACTIONS(1767), 21,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_COLON_COLON_COLON,
      sym__blank,
  [84513] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1765), 11,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
      sym__blank,
    ACTIONS(1767), 19,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_COLON_COLON_COLON,
      sym_comment,
      sym__blank_line,
  [84551] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1695), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
    ACTIONS(1697), 21,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_COLON_COLON_COLON,
      sym__blank,
  [84589] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2701), 1,
      aux_sym_elif_block_token1,
    ACTIONS(2777), 1,
      sym__blank,
    STATE(1494), 1,
      sym_else_block,
    STATE(1687), 1,
      aux_sym_subroutine_block_repeat1,
    STATE(1920), 1,
      aux_sym_block_repeat1,
    ACTIONS(2774), 2,
      sym_comment,
      sym__blank_line,
    STATE(1207), 2,
      sym_elif_block,
      aux_sym_if_block_repeat1,
    ACTIONS(2770), 6,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
    ACTIONS(2772), 15,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
  [84641] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1711), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
    ACTIONS(1713), 21,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_COLON_COLON_COLON,
      sym__blank,
  [84679] = 11,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1741), 1,
      anon_sym_COLON,
    ACTIONS(1743), 1,
      anon_sym_COLON_COLON_COLON,
    ACTIONS(1745), 1,
      anon_sym_COLON_COLON,
    ACTIONS(2711), 1,
      anon_sym_CARET,
    ACTIONS(2744), 1,
      anon_sym_PIPE,
    ACTIONS(2709), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1725), 3,
      anon_sym_EQ,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2693), 3,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOT_DOT,
    ACTIONS(2695), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1727), 14,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COMMA,
      sym__blank,
  [84733] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2701), 1,
      aux_sym_elif_block_token1,
    ACTIONS(2777), 1,
      sym__blank,
    STATE(1494), 1,
      sym_else_block,
    STATE(1687), 1,
      aux_sym_subroutine_block_repeat1,
    STATE(1920), 1,
      aux_sym_block_repeat1,
    ACTIONS(2774), 2,
      sym_comment,
      sym__blank_line,
    STATE(1040), 2,
      sym_elif_block,
      aux_sym_if_block_repeat1,
    ACTIONS(2770), 6,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
    ACTIONS(2772), 15,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
  [84785] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2780), 1,
      anon_sym_AMP,
    STATE(1073), 1,
      aux_sym__path_expression_repeat2,
    STATE(2367), 1,
      sym_macro,
    ACTIONS(1802), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1804), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [84829] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2049), 7,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      anon_sym_DOT,
    ACTIONS(2051), 23,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      sym__blank,
  [84867] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1695), 11,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
      sym__blank,
    ACTIONS(1697), 19,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_COLON_COLON_COLON,
      sym_comment,
      sym__blank_line,
  [84905] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2783), 14,
      anon_sym_PLUS,
      anon_sym_DASH,
      aux_sym__hll_non_default_format_var_command_token1,
      anon_sym_BSLASH,
      sym_access_class,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
      sym_float,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
      aux_sym_symbol_token2,
      sym_time,
      sym_frequency,
      sym_identifier,
    ACTIONS(2786), 16,
      sym__decimal_number_pre_hook,
      sym_path,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_TILDE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      aux_sym_symbol_token1,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
  [84943] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1647), 1,
      anon_sym_COLON_COLON_COLON,
    ACTIONS(1687), 1,
      sym_path,
    ACTIONS(1645), 2,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
    ACTIONS(2789), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(1635), 4,
      anon_sym_EQ,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(1639), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
    ACTIONS(1642), 5,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_DOT_DOT,
    ACTIONS(1637), 10,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
  [84993] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1703), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
    ACTIONS(1705), 21,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_COLON_COLON_COLON,
      sym__blank,
  [85031] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2780), 1,
      anon_sym_AMP,
    STATE(1079), 1,
      aux_sym__path_expression_repeat2,
    STATE(2417), 1,
      sym_macro,
    ACTIONS(1802), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(1804), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [85075] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1647), 1,
      anon_sym_COLON_COLON_COLON,
    ACTIONS(1645), 2,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
    ACTIONS(1715), 4,
      anon_sym_EQ,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(1719), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
    ACTIONS(1722), 5,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_DOT_DOT,
    ACTIONS(1717), 13,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [85121] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2791), 14,
      anon_sym_PLUS,
      anon_sym_DASH,
      aux_sym__hll_non_default_format_var_command_token1,
      anon_sym_BSLASH,
      sym_access_class,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
      sym_float,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
      aux_sym_symbol_token2,
      sym_time,
      sym_frequency,
      sym_identifier,
    ACTIONS(2794), 16,
      sym__decimal_number_pre_hook,
      sym_path,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_TILDE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      aux_sym_symbol_token1,
      sym__composed_name,
      sym_percentage,
      sym_file_handle,
  [85159] = 22,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2199), 1,
      anon_sym_LPAREN,
    ACTIONS(2209), 1,
      anon_sym_LBRACK,
    ACTIONS(2633), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2637), 1,
      anon_sym_PIPE,
    ACTIONS(2639), 1,
      anon_sym_CARET,
    ACTIONS(2649), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2651), 1,
      anon_sym_AMP,
    ACTIONS(2653), 1,
      anon_sym_QMARK,
    ACTIONS(2748), 1,
      anon_sym_COMMA,
    ACTIONS(2797), 1,
      anon_sym_RPAREN,
    ACTIONS(2799), 1,
      sym__blank,
    STATE(752), 1,
      sym_hll_argument_list,
    STATE(2166), 1,
      aux_sym_block_repeat1,
    ACTIONS(2207), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2629), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2631), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2641), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2643), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2645), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2647), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2635), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [85235] = 22,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2199), 1,
      anon_sym_LPAREN,
    ACTIONS(2209), 1,
      anon_sym_LBRACK,
    ACTIONS(2633), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2637), 1,
      anon_sym_PIPE,
    ACTIONS(2639), 1,
      anon_sym_CARET,
    ACTIONS(2649), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2651), 1,
      anon_sym_AMP,
    ACTIONS(2653), 1,
      anon_sym_QMARK,
    ACTIONS(2748), 1,
      anon_sym_COMMA,
    ACTIONS(2801), 1,
      anon_sym_RPAREN,
    ACTIONS(2803), 1,
      sym__blank,
    STATE(752), 1,
      sym_hll_argument_list,
    STATE(2075), 1,
      aux_sym_block_repeat1,
    ACTIONS(2207), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2629), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2631), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2641), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2643), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2645), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2647), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2635), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [85311] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1603), 1,
      sym__blank,
    ACTIONS(2768), 1,
      anon_sym_SLASH,
    STATE(800), 1,
      aux_sym_block_repeat1,
    STATE(2306), 1,
      sym_option_expression,
    ACTIONS(2685), 6,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BSLASH,
      anon_sym_sizeof,
      aux_sym_symbol_token2,
      sym_identifier,
    ACTIONS(2687), 20,
      sym__hll_number_literal_pre_hook,
      anon_sym_LPAREN,
      anon_sym_TILDE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      aux_sym_symbol_token1,
  [85357] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2453), 1,
      anon_sym_LPAREN,
    ACTIONS(2459), 1,
      anon_sym_LBRACK,
    ACTIONS(2809), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2813), 1,
      anon_sym_PIPE,
    ACTIONS(2815), 1,
      anon_sym_CARET,
    ACTIONS(2825), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2827), 1,
      anon_sym_AMP,
    ACTIONS(2829), 1,
      anon_sym_QMARK,
    ACTIONS(2831), 1,
      sym__blank,
    STATE(904), 1,
      sym_hll_argument_list,
    STATE(1320), 1,
      aux_sym_block_repeat1,
    ACTIONS(2457), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2587), 2,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
    ACTIONS(2805), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2807), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2817), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2819), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2821), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2823), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2811), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [85431] = 22,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2199), 1,
      anon_sym_LPAREN,
    ACTIONS(2209), 1,
      anon_sym_LBRACK,
    ACTIONS(2633), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2637), 1,
      anon_sym_PIPE,
    ACTIONS(2639), 1,
      anon_sym_CARET,
    ACTIONS(2649), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2651), 1,
      anon_sym_AMP,
    ACTIONS(2653), 1,
      anon_sym_QMARK,
    ACTIONS(2748), 1,
      anon_sym_COMMA,
    ACTIONS(2833), 1,
      anon_sym_RPAREN,
    ACTIONS(2835), 1,
      sym__blank,
    STATE(752), 1,
      sym_hll_argument_list,
    STATE(2163), 1,
      aux_sym_block_repeat1,
    ACTIONS(2207), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2629), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2631), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2641), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2643), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2645), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2647), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2635), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [85507] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2035), 7,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      anon_sym_DOT,
    ACTIONS(2037), 23,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      sym__blank,
  [85545] = 23,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2199), 1,
      anon_sym_LPAREN,
    ACTIONS(2205), 1,
      anon_sym_DOT,
    ACTIONS(2207), 1,
      anon_sym_DASH_GT,
    ACTIONS(2209), 1,
      anon_sym_LBRACK,
    ACTIONS(2633), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2637), 1,
      anon_sym_PIPE,
    ACTIONS(2639), 1,
      anon_sym_CARET,
    ACTIONS(2649), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2651), 1,
      anon_sym_AMP,
    ACTIONS(2653), 1,
      anon_sym_QMARK,
    ACTIONS(2725), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2729), 1,
      sym__blank,
    ACTIONS(2837), 1,
      anon_sym_RBRACK,
    STATE(752), 1,
      sym_hll_argument_list,
    STATE(2102), 1,
      aux_sym_block_repeat1,
    ACTIONS(2629), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2631), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2641), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2643), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2645), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2647), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2635), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [85623] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2839), 1,
      aux_sym_elif_block_token1,
    ACTIONS(2845), 1,
      sym__blank,
    STATE(1494), 1,
      sym_else_block,
    STATE(1693), 1,
      aux_sym_subroutine_block_repeat1,
    STATE(1932), 1,
      aux_sym_block_repeat1,
    ACTIONS(2842), 2,
      sym_comment,
      sym__blank_line,
    STATE(1207), 2,
      sym_elif_block,
      aux_sym_if_block_repeat1,
    ACTIONS(2770), 6,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
    ACTIONS(2772), 15,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
  [85675] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1691), 11,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
      sym__blank,
    ACTIONS(1693), 19,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_COLON_COLON_COLON,
      sym_comment,
      sym__blank_line,
  [85713] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2839), 1,
      aux_sym_elif_block_token1,
    ACTIONS(2845), 1,
      sym__blank,
    STATE(1494), 1,
      sym_else_block,
    STATE(1693), 1,
      aux_sym_subroutine_block_repeat1,
    STATE(1932), 1,
      aux_sym_block_repeat1,
    ACTIONS(2842), 2,
      sym_comment,
      sym__blank_line,
    STATE(1050), 2,
      sym_elif_block,
      aux_sym_if_block_repeat1,
    ACTIONS(2770), 6,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
    ACTIONS(2772), 15,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
  [85765] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1603), 1,
      sym__blank,
    ACTIONS(2768), 1,
      anon_sym_SLASH,
    STATE(800), 1,
      aux_sym_block_repeat1,
    STATE(2245), 1,
      sym_option_expression,
    ACTIONS(2685), 6,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BSLASH,
      anon_sym_sizeof,
      aux_sym_symbol_token2,
      sym_identifier,
    ACTIONS(2687), 20,
      sym__hll_number_literal_pre_hook,
      anon_sym_LPAREN,
      anon_sym_TILDE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      aux_sym_symbol_token1,
  [85811] = 22,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2199), 1,
      anon_sym_LPAREN,
    ACTIONS(2209), 1,
      anon_sym_LBRACK,
    ACTIONS(2633), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2637), 1,
      anon_sym_PIPE,
    ACTIONS(2639), 1,
      anon_sym_CARET,
    ACTIONS(2649), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2651), 1,
      anon_sym_AMP,
    ACTIONS(2653), 1,
      anon_sym_QMARK,
    ACTIONS(2748), 1,
      anon_sym_COMMA,
    ACTIONS(2848), 1,
      anon_sym_RPAREN,
    ACTIONS(2850), 1,
      sym__blank,
    STATE(752), 1,
      sym_hll_argument_list,
    STATE(2216), 1,
      aux_sym_block_repeat1,
    ACTIONS(2207), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2629), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2631), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2641), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2643), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2645), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2647), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2635), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [85887] = 22,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2199), 1,
      anon_sym_LPAREN,
    ACTIONS(2209), 1,
      anon_sym_LBRACK,
    ACTIONS(2633), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2637), 1,
      anon_sym_PIPE,
    ACTIONS(2639), 1,
      anon_sym_CARET,
    ACTIONS(2649), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2651), 1,
      anon_sym_AMP,
    ACTIONS(2653), 1,
      anon_sym_QMARK,
    ACTIONS(2748), 1,
      anon_sym_COMMA,
    ACTIONS(2852), 1,
      anon_sym_RPAREN,
    ACTIONS(2854), 1,
      sym__blank,
    STATE(752), 1,
      sym_hll_argument_list,
    STATE(2234), 1,
      aux_sym_block_repeat1,
    ACTIONS(2207), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2629), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2631), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2641), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2643), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2645), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2647), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2635), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [85963] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1777), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
    ACTIONS(1779), 21,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_COLON_COLON_COLON,
      sym__blank,
  [86001] = 23,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2199), 1,
      anon_sym_LPAREN,
    ACTIONS(2205), 1,
      anon_sym_DOT,
    ACTIONS(2207), 1,
      anon_sym_DASH_GT,
    ACTIONS(2209), 1,
      anon_sym_LBRACK,
    ACTIONS(2633), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2637), 1,
      anon_sym_PIPE,
    ACTIONS(2639), 1,
      anon_sym_CARET,
    ACTIONS(2649), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2651), 1,
      anon_sym_AMP,
    ACTIONS(2653), 1,
      anon_sym_QMARK,
    ACTIONS(2725), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2729), 1,
      sym__blank,
    ACTIONS(2856), 1,
      anon_sym_RBRACK,
    STATE(752), 1,
      sym_hll_argument_list,
    STATE(2102), 1,
      aux_sym_block_repeat1,
    ACTIONS(2629), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2631), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2641), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2643), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2645), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2647), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2635), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [86079] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1647), 1,
      anon_sym_COLON_COLON_COLON,
    ACTIONS(1645), 2,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
    ACTIONS(1635), 3,
      anon_sym_EQ,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1639), 4,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
    ACTIONS(1642), 6,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT_DOT,
    ACTIONS(1637), 14,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COMMA,
      sym__blank,
  [86125] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1647), 1,
      anon_sym_COLON_COLON_COLON,
    ACTIONS(1645), 2,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
    ACTIONS(1715), 3,
      anon_sym_EQ,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1719), 4,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
    ACTIONS(1722), 6,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT_DOT,
    ACTIONS(1717), 14,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COMMA,
      sym__blank,
  [86171] = 12,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1741), 1,
      anon_sym_COLON,
    ACTIONS(1743), 1,
      anon_sym_COLON_COLON_COLON,
    ACTIONS(1745), 1,
      anon_sym_COLON_COLON,
    ACTIONS(2711), 1,
      anon_sym_CARET,
    ACTIONS(2744), 1,
      anon_sym_PIPE,
    ACTIONS(2709), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1752), 3,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_COMMA,
    ACTIONS(1754), 3,
      anon_sym_EQ,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2693), 3,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOT_DOT,
    ACTIONS(2695), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1749), 11,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      sym__blank,
  [86227] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(147), 1,
      anon_sym_AMP,
    STATE(1079), 1,
      aux_sym__path_expression_repeat2,
    STATE(1304), 1,
      sym_macro,
    ACTIONS(1809), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(1811), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [86271] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2701), 1,
      aux_sym_elif_block_token1,
    ACTIONS(2865), 1,
      sym__blank,
    STATE(1445), 1,
      sym_else_block,
    STATE(1690), 1,
      aux_sym_subroutine_block_repeat1,
    STATE(1855), 1,
      aux_sym_block_repeat1,
    ACTIONS(2862), 2,
      sym_comment,
      sym__blank_line,
    STATE(1069), 2,
      sym_elif_block,
      aux_sym_if_block_repeat1,
    ACTIONS(2858), 6,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
    ACTIONS(2860), 15,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
  [86323] = 22,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2199), 1,
      anon_sym_LPAREN,
    ACTIONS(2209), 1,
      anon_sym_LBRACK,
    ACTIONS(2633), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2637), 1,
      anon_sym_PIPE,
    ACTIONS(2639), 1,
      anon_sym_CARET,
    ACTIONS(2649), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2651), 1,
      anon_sym_AMP,
    ACTIONS(2653), 1,
      anon_sym_QMARK,
    ACTIONS(2748), 1,
      anon_sym_COMMA,
    ACTIONS(2868), 1,
      anon_sym_RPAREN,
    ACTIONS(2870), 1,
      sym__blank,
    STATE(752), 1,
      sym_hll_argument_list,
    STATE(2057), 1,
      aux_sym_block_repeat1,
    ACTIONS(2207), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2629), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2631), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2641), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2643), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2645), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2647), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2635), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [86399] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1773), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
    ACTIONS(1775), 21,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_COLON_COLON_COLON,
      sym__blank,
  [86437] = 22,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2199), 1,
      anon_sym_LPAREN,
    ACTIONS(2209), 1,
      anon_sym_LBRACK,
    ACTIONS(2633), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2637), 1,
      anon_sym_PIPE,
    ACTIONS(2639), 1,
      anon_sym_CARET,
    ACTIONS(2649), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2651), 1,
      anon_sym_AMP,
    ACTIONS(2653), 1,
      anon_sym_QMARK,
    ACTIONS(2748), 1,
      anon_sym_COMMA,
    ACTIONS(2872), 1,
      anon_sym_RPAREN,
    ACTIONS(2874), 1,
      sym__blank,
    STATE(752), 1,
      sym_hll_argument_list,
    STATE(2064), 1,
      aux_sym_block_repeat1,
    ACTIONS(2207), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2629), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2631), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2641), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2643), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2645), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2647), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2635), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [86513] = 23,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2199), 1,
      anon_sym_LPAREN,
    ACTIONS(2205), 1,
      anon_sym_DOT,
    ACTIONS(2207), 1,
      anon_sym_DASH_GT,
    ACTIONS(2209), 1,
      anon_sym_LBRACK,
    ACTIONS(2633), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2637), 1,
      anon_sym_PIPE,
    ACTIONS(2639), 1,
      anon_sym_CARET,
    ACTIONS(2649), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2651), 1,
      anon_sym_AMP,
    ACTIONS(2653), 1,
      anon_sym_QMARK,
    ACTIONS(2725), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2729), 1,
      sym__blank,
    ACTIONS(2876), 1,
      anon_sym_RBRACK,
    STATE(752), 1,
      sym_hll_argument_list,
    STATE(2102), 1,
      aux_sym_block_repeat1,
    ACTIONS(2629), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2631), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2641), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2643), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2645), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2647), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2635), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [86591] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1647), 1,
      anon_sym_COLON_COLON_COLON,
    ACTIONS(1687), 1,
      sym_path,
    ACTIONS(2878), 1,
      sym__blank,
    ACTIONS(1645), 2,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
    ACTIONS(2789), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(1635), 3,
      anon_sym_EQ,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1639), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
    ACTIONS(1642), 5,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_DOT_DOT,
    ACTIONS(1637), 10,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
  [86643] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1761), 11,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
      sym__blank,
    ACTIONS(1763), 19,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_COLON_COLON_COLON,
      sym_comment,
      sym__blank_line,
  [86681] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1645), 2,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
    ACTIONS(1647), 4,
      anon_sym_COMMA,
      anon_sym_COLON_COLON_COLON,
      sym_comment,
      sym__blank_line,
    ACTIONS(1639), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(1642), 15,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
  [86723] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1761), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
    ACTIONS(1763), 21,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_COLON_COLON_COLON,
      sym__blank,
  [86761] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1645), 2,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
    ACTIONS(1647), 4,
      anon_sym_COMMA,
      anon_sym_COLON_COLON_COLON,
      sym_comment,
      sym__blank_line,
    ACTIONS(1719), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(1722), 15,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
  [86803] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2880), 1,
      aux_sym_elif_block_token1,
    ACTIONS(2885), 1,
      sym__blank,
    STATE(1494), 1,
      sym_else_block,
    STATE(1689), 1,
      aux_sym_subroutine_block_repeat1,
    STATE(1909), 1,
      aux_sym_block_repeat1,
    ACTIONS(2882), 2,
      sym_comment,
      sym__blank_line,
    STATE(1263), 2,
      sym_elif_block,
      aux_sym_if_block_repeat1,
    ACTIONS(2770), 6,
      sym_label_identifier,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
    ACTIONS(2772), 15,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
  [86855] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2880), 1,
      aux_sym_elif_block_token1,
    ACTIONS(2885), 1,
      sym__blank,
    STATE(1494), 1,
      sym_else_block,
    STATE(1689), 1,
      aux_sym_subroutine_block_repeat1,
    STATE(1909), 1,
      aux_sym_block_repeat1,
    ACTIONS(2882), 2,
      sym_comment,
      sym__blank_line,
    STATE(1114), 2,
      sym_elif_block,
      aux_sym_if_block_repeat1,
    ACTIONS(2770), 6,
      sym_label_identifier,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
    ACTIONS(2772), 15,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
  [86907] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2453), 1,
      anon_sym_LPAREN,
    ACTIONS(2459), 1,
      anon_sym_LBRACK,
    ACTIONS(2809), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2813), 1,
      anon_sym_PIPE,
    ACTIONS(2815), 1,
      anon_sym_CARET,
    ACTIONS(2825), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2827), 1,
      anon_sym_AMP,
    ACTIONS(2829), 1,
      anon_sym_QMARK,
    ACTIONS(2888), 1,
      sym__blank,
    STATE(904), 1,
      sym_hll_argument_list,
    STATE(1272), 1,
      aux_sym_block_repeat1,
    ACTIONS(2457), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2587), 2,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
    ACTIONS(2805), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2807), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2817), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2819), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2821), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2823), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2811), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [86981] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2880), 1,
      aux_sym_elif_block_token1,
    ACTIONS(2893), 1,
      sym__blank,
    STATE(1452), 1,
      sym_else_block,
    STATE(1692), 1,
      aux_sym_subroutine_block_repeat1,
    STATE(1913), 1,
      aux_sym_block_repeat1,
    ACTIONS(2890), 2,
      sym_comment,
      sym__blank_line,
    STATE(1263), 2,
      sym_elif_block,
      aux_sym_if_block_repeat1,
    ACTIONS(2697), 6,
      sym_label_identifier,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
    ACTIONS(2699), 15,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
  [87033] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2896), 1,
      aux_sym_elif_block_token1,
    ACTIONS(2902), 1,
      sym__blank,
    STATE(1445), 1,
      sym_else_block,
    STATE(1697), 1,
      aux_sym_subroutine_block_repeat1,
    STATE(1940), 1,
      aux_sym_block_repeat1,
    ACTIONS(2899), 2,
      sym_comment,
      sym__blank_line,
    STATE(1116), 2,
      sym_elif_block,
      aux_sym_if_block_repeat1,
    ACTIONS(2858), 6,
      sym_label_identifier,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
    ACTIONS(2860), 15,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
  [87085] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2905), 1,
      aux_sym_elif_block_token1,
    ACTIONS(2911), 1,
      sym__blank,
    STATE(1494), 1,
      sym_else_block,
    STATE(1698), 1,
      aux_sym_subroutine_block_repeat1,
    STATE(1813), 1,
      aux_sym_block_repeat1,
    ACTIONS(2908), 2,
      sym_comment,
      sym__blank_line,
    STATE(1263), 2,
      sym_elif_block,
      aux_sym_if_block_repeat1,
    ACTIONS(2770), 6,
      sym_label_identifier,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
    ACTIONS(2772), 15,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
  [87137] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2905), 1,
      aux_sym_elif_block_token1,
    ACTIONS(2911), 1,
      sym__blank,
    STATE(1494), 1,
      sym_else_block,
    STATE(1698), 1,
      aux_sym_subroutine_block_repeat1,
    STATE(1813), 1,
      aux_sym_block_repeat1,
    ACTIONS(2908), 2,
      sym_comment,
      sym__blank_line,
    STATE(1118), 2,
      sym_elif_block,
      aux_sym_if_block_repeat1,
    ACTIONS(2770), 6,
      sym_label_identifier,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
    ACTIONS(2772), 15,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
  [87189] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2914), 1,
      aux_sym_elif_block_token1,
    ACTIONS(2920), 1,
      sym__blank,
    STATE(1452), 1,
      sym_else_block,
    STATE(1699), 1,
      aux_sym_subroutine_block_repeat1,
    STATE(1943), 1,
      aux_sym_block_repeat1,
    ACTIONS(2917), 2,
      sym_comment,
      sym__blank_line,
    STATE(1263), 2,
      sym_elif_block,
      aux_sym_if_block_repeat1,
    ACTIONS(2697), 6,
      sym_label_identifier,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
    ACTIONS(2699), 15,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
  [87241] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2415), 7,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      anon_sym_DOT,
    ACTIONS(2413), 23,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      sym__blank,
  [87279] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2395), 7,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      anon_sym_DOT,
    ACTIONS(2393), 23,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      sym__blank,
  [87317] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2379), 7,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      anon_sym_DOT,
    ACTIONS(2377), 23,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      sym__blank,
  [87355] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1757), 11,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
      sym__blank,
    ACTIONS(1759), 19,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_COLON_COLON_COLON,
      sym_comment,
      sym__blank_line,
  [87393] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2880), 1,
      aux_sym_elif_block_token1,
    ACTIONS(2926), 1,
      sym__blank,
    STATE(1445), 1,
      sym_else_block,
    STATE(1688), 1,
      aux_sym_subroutine_block_repeat1,
    STATE(1906), 1,
      aux_sym_block_repeat1,
    ACTIONS(2923), 2,
      sym_comment,
      sym__blank_line,
    STATE(1111), 2,
      sym_elif_block,
      aux_sym_if_block_repeat1,
    ACTIONS(2858), 6,
      sym_label_identifier,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
    ACTIONS(2860), 15,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
  [87445] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2929), 1,
      aux_sym_elif_block_token1,
    ACTIONS(2935), 1,
      sym__blank,
    STATE(1445), 1,
      sym_else_block,
    STATE(1691), 1,
      aux_sym_subroutine_block_repeat1,
    STATE(1930), 1,
      aux_sym_block_repeat1,
    ACTIONS(2932), 2,
      sym_comment,
      sym__blank_line,
    STATE(1089), 2,
      sym_elif_block,
      aux_sym_if_block_repeat1,
    ACTIONS(2858), 6,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
    ACTIONS(2860), 15,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
  [87497] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2719), 1,
      anon_sym_SLASH,
    ACTIONS(2717), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(2715), 3,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOT_DOT,
    ACTIONS(1769), 10,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
      sym__blank,
    ACTIONS(1771), 14,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COMMA,
      anon_sym_COLON_COLON_COLON,
      sym_comment,
      sym__blank_line,
  [87541] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1769), 11,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
      sym__blank,
    ACTIONS(1771), 19,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_COLON_COLON_COLON,
      sym_comment,
      sym__blank_line,
  [87579] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2715), 3,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOT_DOT,
    ACTIONS(1769), 11,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
      sym__blank,
    ACTIONS(1771), 16,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COMMA,
      anon_sym_COLON_COLON_COLON,
      sym_comment,
      sym__blank_line,
  [87619] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2719), 1,
      anon_sym_SLASH,
    ACTIONS(2723), 1,
      anon_sym_CARET,
    ACTIONS(2713), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2717), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(2715), 3,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOT_DOT,
    ACTIONS(1769), 7,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
      sym__blank,
    ACTIONS(1771), 14,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COMMA,
      anon_sym_COLON_COLON_COLON,
      sym_comment,
      sym__blank_line,
  [87667] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2719), 1,
      anon_sym_SLASH,
    ACTIONS(2713), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2717), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(2715), 3,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOT_DOT,
    ACTIONS(1769), 8,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
      sym__blank,
    ACTIONS(1771), 14,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COMMA,
      anon_sym_COLON_COLON_COLON,
      sym_comment,
      sym__blank_line,
  [87713] = 13,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1741), 1,
      anon_sym_COLON,
    ACTIONS(1743), 1,
      anon_sym_COLON_COLON_COLON,
    ACTIONS(1745), 1,
      anon_sym_COLON_COLON,
    ACTIONS(2719), 1,
      anon_sym_SLASH,
    ACTIONS(2721), 1,
      anon_sym_PIPE,
    ACTIONS(2723), 1,
      anon_sym_CARET,
    ACTIONS(2713), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2717), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(1752), 3,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
    ACTIONS(2715), 3,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOT_DOT,
    ACTIONS(1754), 4,
      anon_sym_EQ,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(1749), 10,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
  [87771] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2387), 7,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      anon_sym_DOT,
    ACTIONS(2385), 23,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      sym__blank,
  [87809] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2391), 7,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      anon_sym_DOT,
    ACTIONS(2389), 23,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      sym__blank,
  [87847] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1773), 11,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
      sym__blank,
    ACTIONS(1775), 19,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_COLON_COLON_COLON,
      sym_comment,
      sym__blank_line,
  [87885] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1603), 1,
      sym__blank,
    ACTIONS(2768), 1,
      anon_sym_SLASH,
    STATE(800), 1,
      aux_sym_block_repeat1,
    STATE(2306), 1,
      sym_option_expression,
    ACTIONS(2655), 6,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BSLASH,
      anon_sym_sizeof,
      aux_sym_symbol_token2,
      sym_identifier,
    ACTIONS(2657), 20,
      sym__hll_number_literal_pre_hook,
      anon_sym_LPAREN,
      anon_sym_TILDE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      aux_sym_symbol_token1,
  [87931] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1963), 1,
      anon_sym_RBRACK,
    ACTIONS(1965), 1,
      sym__blank,
    ACTIONS(2199), 1,
      anon_sym_LPAREN,
    ACTIONS(2209), 1,
      anon_sym_LBRACK,
    ACTIONS(2633), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2637), 1,
      anon_sym_PIPE,
    ACTIONS(2639), 1,
      anon_sym_CARET,
    ACTIONS(2649), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2651), 1,
      anon_sym_AMP,
    ACTIONS(2653), 1,
      anon_sym_QMARK,
    STATE(752), 1,
      sym_hll_argument_list,
    STATE(2146), 1,
      aux_sym_block_repeat1,
    ACTIONS(2207), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2629), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2631), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2641), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2643), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2645), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2647), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2635), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [88004] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1895), 1,
      anon_sym_RBRACK,
    ACTIONS(1897), 1,
      sym__blank,
    ACTIONS(2199), 1,
      anon_sym_LPAREN,
    ACTIONS(2209), 1,
      anon_sym_LBRACK,
    ACTIONS(2633), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2637), 1,
      anon_sym_PIPE,
    ACTIONS(2639), 1,
      anon_sym_CARET,
    ACTIONS(2649), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2651), 1,
      anon_sym_AMP,
    ACTIONS(2653), 1,
      anon_sym_QMARK,
    STATE(752), 1,
      sym_hll_argument_list,
    STATE(2188), 1,
      aux_sym_block_repeat1,
    ACTIONS(2207), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2629), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2631), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2641), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2643), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2645), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2647), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2635), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [88077] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2938), 1,
      sym_path,
    STATE(1137), 1,
      aux_sym__path_expression_repeat1,
    ACTIONS(1791), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(1793), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [88118] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1939), 1,
      anon_sym_RBRACK,
    ACTIONS(1941), 1,
      sym__blank,
    ACTIONS(2199), 1,
      anon_sym_LPAREN,
    ACTIONS(2209), 1,
      anon_sym_LBRACK,
    ACTIONS(2633), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2637), 1,
      anon_sym_PIPE,
    ACTIONS(2639), 1,
      anon_sym_CARET,
    ACTIONS(2649), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2651), 1,
      anon_sym_AMP,
    ACTIONS(2653), 1,
      anon_sym_QMARK,
    STATE(752), 1,
      sym_hll_argument_list,
    STATE(2095), 1,
      aux_sym_block_repeat1,
    ACTIONS(2207), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2629), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2631), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2641), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2643), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2645), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2647), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2635), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [88191] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2941), 1,
      anon_sym_LPAREN,
    ACTIONS(2943), 1,
      anon_sym_EQ,
    ACTIONS(2949), 1,
      anon_sym_CARET_CARET,
    ACTIONS(2951), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2955), 1,
      anon_sym_SLASH,
    ACTIONS(2957), 1,
      anon_sym_PIPE,
    ACTIONS(2959), 1,
      anon_sym_CARET,
    ACTIONS(2967), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2971), 1,
      sym__blank,
    ACTIONS(2974), 1,
      sym__and_operator_pre_hook,
    STATE(1055), 1,
      sym_argument_list,
    STATE(2063), 1,
      aux_sym_block_repeat1,
    ACTIONS(2945), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2947), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2953), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(2963), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2965), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2969), 3,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
    ACTIONS(2961), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
  [88262] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2941), 1,
      anon_sym_LPAREN,
    ACTIONS(2943), 1,
      anon_sym_EQ,
    ACTIONS(2949), 1,
      anon_sym_CARET_CARET,
    ACTIONS(2951), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2955), 1,
      anon_sym_SLASH,
    ACTIONS(2957), 1,
      anon_sym_PIPE,
    ACTIONS(2959), 1,
      anon_sym_CARET,
    ACTIONS(2967), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2974), 1,
      sym__and_operator_pre_hook,
    ACTIONS(2976), 1,
      sym__blank,
    STATE(1055), 1,
      sym_argument_list,
    STATE(2063), 1,
      aux_sym_block_repeat1,
    ACTIONS(2945), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2947), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2953), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(2963), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2965), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(1821), 3,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
    ACTIONS(2961), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
  [88333] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2978), 1,
      anon_sym_LPAREN,
    ACTIONS(2980), 1,
      anon_sym_EQ,
    ACTIONS(2986), 1,
      anon_sym_CARET_CARET,
    ACTIONS(2988), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2992), 1,
      anon_sym_PIPE,
    ACTIONS(2994), 1,
      anon_sym_CARET,
    ACTIONS(3002), 1,
      anon_sym_DOT_DOT,
    ACTIONS(3004), 1,
      sym__blank,
    ACTIONS(3006), 1,
      sym__and_operator_pre_hook,
    STATE(1033), 1,
      sym_argument_list,
    STATE(2054), 1,
      aux_sym_block_repeat1,
    ACTIONS(2982), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2984), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2998), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3000), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(1821), 3,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_COMMA,
    ACTIONS(2990), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2996), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
  [88402] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1947), 1,
      anon_sym_RBRACK,
    ACTIONS(1949), 1,
      sym__blank,
    ACTIONS(2199), 1,
      anon_sym_LPAREN,
    ACTIONS(2209), 1,
      anon_sym_LBRACK,
    ACTIONS(2633), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2637), 1,
      anon_sym_PIPE,
    ACTIONS(2639), 1,
      anon_sym_CARET,
    ACTIONS(2649), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2651), 1,
      anon_sym_AMP,
    ACTIONS(2653), 1,
      anon_sym_QMARK,
    STATE(752), 1,
      sym_hll_argument_list,
    STATE(2115), 1,
      aux_sym_block_repeat1,
    ACTIONS(2207), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2629), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2631), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2641), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2643), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2645), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2647), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2635), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [88475] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2453), 1,
      anon_sym_LPAREN,
    ACTIONS(2459), 1,
      anon_sym_LBRACK,
    STATE(904), 1,
      sym_hll_argument_list,
    ACTIONS(2457), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2807), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2823), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2811), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2201), 7,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2197), 10,
      anon_sym_PIPE_PIPE,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [88526] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1951), 1,
      anon_sym_RBRACK,
    ACTIONS(1953), 1,
      sym__blank,
    ACTIONS(2199), 1,
      anon_sym_LPAREN,
    ACTIONS(2209), 1,
      anon_sym_LBRACK,
    ACTIONS(2633), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2637), 1,
      anon_sym_PIPE,
    ACTIONS(2639), 1,
      anon_sym_CARET,
    ACTIONS(2649), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2651), 1,
      anon_sym_AMP,
    ACTIONS(2653), 1,
      anon_sym_QMARK,
    STATE(752), 1,
      sym_hll_argument_list,
    STATE(2122), 1,
      aux_sym_block_repeat1,
    ACTIONS(2207), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2629), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2631), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2641), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2643), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2645), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2647), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2635), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [88599] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2201), 1,
      sym__blank,
    ACTIONS(2453), 1,
      anon_sym_LPAREN,
    ACTIONS(2459), 1,
      anon_sym_LBRACK,
    ACTIONS(2813), 1,
      anon_sym_PIPE,
    ACTIONS(2815), 1,
      anon_sym_CARET,
    ACTIONS(2825), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2827), 1,
      anon_sym_AMP,
    STATE(904), 1,
      sym_hll_argument_list,
    ACTIONS(2457), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2805), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2807), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2817), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2819), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2821), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2823), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2811), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2197), 4,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [88666] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1955), 1,
      anon_sym_RBRACK,
    ACTIONS(1957), 1,
      sym__blank,
    ACTIONS(2199), 1,
      anon_sym_LPAREN,
    ACTIONS(2209), 1,
      anon_sym_LBRACK,
    ACTIONS(2633), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2637), 1,
      anon_sym_PIPE,
    ACTIONS(2639), 1,
      anon_sym_CARET,
    ACTIONS(2649), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2651), 1,
      anon_sym_AMP,
    ACTIONS(2653), 1,
      anon_sym_QMARK,
    STATE(752), 1,
      sym_hll_argument_list,
    STATE(2124), 1,
      aux_sym_block_repeat1,
    ACTIONS(2207), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2629), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2631), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2641), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2643), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2645), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2647), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2635), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [88739] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2453), 1,
      anon_sym_LPAREN,
    ACTIONS(2459), 1,
      anon_sym_LBRACK,
    STATE(904), 1,
      sym_hll_argument_list,
    ACTIONS(2457), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2807), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2823), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2201), 7,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2197), 13,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [88788] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2199), 1,
      anon_sym_LPAREN,
    ACTIONS(2209), 1,
      anon_sym_LBRACK,
    ACTIONS(2633), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2637), 1,
      anon_sym_PIPE,
    ACTIONS(2639), 1,
      anon_sym_CARET,
    ACTIONS(2649), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2651), 1,
      anon_sym_AMP,
    ACTIONS(2653), 1,
      anon_sym_QMARK,
    ACTIONS(2748), 1,
      anon_sym_COMMA,
    STATE(752), 1,
      sym_hll_argument_list,
    ACTIONS(2207), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2629), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2631), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2641), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2643), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2645), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2647), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3008), 2,
      anon_sym_RPAREN,
      sym__blank,
    ACTIONS(2635), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [88859] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2941), 1,
      anon_sym_LPAREN,
    ACTIONS(2949), 1,
      anon_sym_CARET_CARET,
    ACTIONS(2955), 1,
      anon_sym_SLASH,
    ACTIONS(2957), 1,
      anon_sym_PIPE,
    ACTIONS(2959), 1,
      anon_sym_CARET,
    ACTIONS(2967), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2974), 1,
      sym__and_operator_pre_hook,
    STATE(1055), 1,
      sym_argument_list,
    STATE(2063), 1,
      aux_sym_block_repeat1,
    ACTIONS(1815), 2,
      anon_sym_EQ,
      sym__blank,
    ACTIONS(2945), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2947), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2953), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(2963), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2965), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(1817), 4,
      anon_sym_PIPE_PIPE,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
    ACTIONS(2961), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
  [88926] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1915), 1,
      anon_sym_RBRACK,
    ACTIONS(1917), 1,
      sym__blank,
    ACTIONS(2199), 1,
      anon_sym_LPAREN,
    ACTIONS(2209), 1,
      anon_sym_LBRACK,
    ACTIONS(2633), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2637), 1,
      anon_sym_PIPE,
    ACTIONS(2639), 1,
      anon_sym_CARET,
    ACTIONS(2649), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2651), 1,
      anon_sym_AMP,
    ACTIONS(2653), 1,
      anon_sym_QMARK,
    STATE(752), 1,
      sym_hll_argument_list,
    STATE(2202), 1,
      aux_sym_block_repeat1,
    ACTIONS(2207), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2629), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2631), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2641), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2643), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2645), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2647), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2635), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [88999] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(9), 1,
      aux_sym_block_token1,
    ACTIONS(3014), 1,
      sym_comment,
    ACTIONS(3016), 1,
      sym__blank,
    STATE(1424), 1,
      aux_sym_block_repeat1,
    STATE(1488), 1,
      sym_block,
    STATE(1779), 1,
      aux_sym_labeled_expression_repeat1,
    ACTIONS(3010), 7,
      sym_label_identifier,
      ts_builtin_sym_end,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym__blank_line,
    ACTIONS(3012), 16,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
  [89048] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2978), 1,
      anon_sym_LPAREN,
    ACTIONS(2980), 1,
      anon_sym_EQ,
    ACTIONS(2986), 1,
      anon_sym_CARET_CARET,
    ACTIONS(2988), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2992), 1,
      anon_sym_PIPE,
    ACTIONS(2994), 1,
      anon_sym_CARET,
    ACTIONS(3002), 1,
      anon_sym_DOT_DOT,
    ACTIONS(3006), 1,
      sym__and_operator_pre_hook,
    ACTIONS(3018), 1,
      anon_sym_RPAREN,
    ACTIONS(3020), 1,
      anon_sym_COMMA,
    ACTIONS(3022), 1,
      sym__blank,
    STATE(1033), 1,
      sym_argument_list,
    STATE(1830), 1,
      aux_sym_argument_list_repeat1,
    STATE(2000), 1,
      aux_sym_block_repeat1,
    ACTIONS(2982), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2984), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2998), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3000), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2990), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2996), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
  [89121] = 16,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2453), 1,
      anon_sym_LPAREN,
    ACTIONS(2459), 1,
      anon_sym_LBRACK,
    ACTIONS(2815), 1,
      anon_sym_CARET,
    ACTIONS(2827), 1,
      anon_sym_AMP,
    STATE(904), 1,
      sym_hll_argument_list,
    ACTIONS(2201), 2,
      anon_sym_PIPE,
      sym__blank,
    ACTIONS(2457), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2805), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2807), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2817), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2819), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2821), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2823), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2811), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2197), 5,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [89184] = 15,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2453), 1,
      anon_sym_LPAREN,
    ACTIONS(2459), 1,
      anon_sym_LBRACK,
    ACTIONS(2827), 1,
      anon_sym_AMP,
    STATE(904), 1,
      sym_hll_argument_list,
    ACTIONS(2201), 2,
      anon_sym_PIPE,
      sym__blank,
    ACTIONS(2457), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2805), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2807), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2817), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2819), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2821), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2823), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2811), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2197), 6,
      anon_sym_PIPE_PIPE,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [89245] = 13,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2453), 1,
      anon_sym_LPAREN,
    ACTIONS(2459), 1,
      anon_sym_LBRACK,
    STATE(904), 1,
      sym_hll_argument_list,
    ACTIONS(2457), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2805), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2807), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2819), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2821), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2823), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2201), 3,
      anon_sym_PIPE,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2811), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2197), 8,
      anon_sym_PIPE_PIPE,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [89302] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(9), 1,
      aux_sym_block_token1,
    ACTIONS(3024), 1,
      sym_comment,
    ACTIONS(3026), 1,
      sym__blank,
    STATE(1428), 1,
      aux_sym_block_repeat1,
    STATE(1461), 1,
      sym_block,
    STATE(1801), 1,
      aux_sym_labeled_expression_repeat1,
    ACTIONS(3010), 7,
      sym_label_identifier,
      ts_builtin_sym_end,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym__blank_line,
    ACTIONS(3012), 16,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
  [89351] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2941), 1,
      anon_sym_LPAREN,
    ACTIONS(2967), 1,
      anon_sym_DOT_DOT,
    STATE(1055), 1,
      sym_argument_list,
    STATE(2063), 1,
      aux_sym_block_repeat1,
    ACTIONS(2947), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2965), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(1815), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(1817), 12,
      sym__and_operator_pre_hook,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [89400] = 11,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2453), 1,
      anon_sym_LPAREN,
    ACTIONS(2459), 1,
      anon_sym_LBRACK,
    STATE(904), 1,
      sym_hll_argument_list,
    ACTIONS(2457), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2805), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2807), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2823), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2811), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2201), 5,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2197), 10,
      anon_sym_PIPE_PIPE,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [89453] = 17,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2201), 1,
      sym__blank,
    ACTIONS(2453), 1,
      anon_sym_LPAREN,
    ACTIONS(2459), 1,
      anon_sym_LBRACK,
    ACTIONS(2813), 1,
      anon_sym_PIPE,
    ACTIONS(2815), 1,
      anon_sym_CARET,
    ACTIONS(2827), 1,
      anon_sym_AMP,
    STATE(904), 1,
      sym_hll_argument_list,
    ACTIONS(2457), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2805), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2807), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2817), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2819), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2821), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2823), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2811), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2197), 5,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [89518] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2941), 1,
      anon_sym_LPAREN,
    ACTIONS(2967), 1,
      anon_sym_DOT_DOT,
    STATE(1055), 1,
      sym_argument_list,
    STATE(2063), 1,
      aux_sym_block_repeat1,
    ACTIONS(2947), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1815), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(1817), 14,
      sym__and_operator_pre_hook,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [89565] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(147), 1,
      anon_sym_AMP,
    STATE(1301), 1,
      sym_macro,
    ACTIONS(1809), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(1811), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [89606] = 14,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2453), 1,
      anon_sym_LPAREN,
    ACTIONS(2459), 1,
      anon_sym_LBRACK,
    STATE(904), 1,
      sym_hll_argument_list,
    ACTIONS(2457), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2805), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2807), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2817), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2819), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2821), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2823), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2201), 3,
      anon_sym_PIPE,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2811), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2197), 6,
      anon_sym_PIPE_PIPE,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [89665] = 11,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2941), 1,
      anon_sym_LPAREN,
    ACTIONS(2955), 1,
      anon_sym_SLASH,
    ACTIONS(2967), 1,
      anon_sym_DOT_DOT,
    STATE(1055), 1,
      sym_argument_list,
    STATE(2063), 1,
      aux_sym_block_repeat1,
    ACTIONS(2947), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2953), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(2965), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(1815), 8,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(1817), 10,
      sym__and_operator_pre_hook,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [89718] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2277), 1,
      sym__blank,
    ACTIONS(2453), 1,
      anon_sym_LPAREN,
    ACTIONS(2459), 1,
      anon_sym_LBRACK,
    ACTIONS(2809), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2813), 1,
      anon_sym_PIPE,
    ACTIONS(2815), 1,
      anon_sym_CARET,
    ACTIONS(2825), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2827), 1,
      anon_sym_AMP,
    ACTIONS(2829), 1,
      anon_sym_QMARK,
    STATE(904), 1,
      sym_hll_argument_list,
    ACTIONS(2275), 2,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
    ACTIONS(2457), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2805), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2807), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2817), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2819), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2821), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2823), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2811), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [89789] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1959), 1,
      anon_sym_RBRACK,
    ACTIONS(1961), 1,
      sym__blank,
    ACTIONS(2199), 1,
      anon_sym_LPAREN,
    ACTIONS(2209), 1,
      anon_sym_LBRACK,
    ACTIONS(2633), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2637), 1,
      anon_sym_PIPE,
    ACTIONS(2639), 1,
      anon_sym_CARET,
    ACTIONS(2649), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2651), 1,
      anon_sym_AMP,
    ACTIONS(2653), 1,
      anon_sym_QMARK,
    STATE(752), 1,
      sym_hll_argument_list,
    STATE(2144), 1,
      aux_sym_block_repeat1,
    ACTIONS(2207), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2629), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2631), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2641), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2643), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2645), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2647), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2635), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [89862] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    STATE(1055), 1,
      sym_argument_list,
    STATE(2063), 1,
      aux_sym_block_repeat1,
    ACTIONS(1815), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(1817), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [89903] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1967), 1,
      anon_sym_RBRACK,
    ACTIONS(1969), 1,
      sym__blank,
    ACTIONS(2199), 1,
      anon_sym_LPAREN,
    ACTIONS(2209), 1,
      anon_sym_LBRACK,
    ACTIONS(2633), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2637), 1,
      anon_sym_PIPE,
    ACTIONS(2639), 1,
      anon_sym_CARET,
    ACTIONS(2649), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2651), 1,
      anon_sym_AMP,
    ACTIONS(2653), 1,
      anon_sym_QMARK,
    STATE(752), 1,
      sym_hll_argument_list,
    STATE(2165), 1,
      aux_sym_block_repeat1,
    ACTIONS(2207), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2629), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2631), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2641), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2643), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2645), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2647), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2635), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [89976] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1919), 1,
      anon_sym_RBRACK,
    ACTIONS(1921), 1,
      sym__blank,
    ACTIONS(2199), 1,
      anon_sym_LPAREN,
    ACTIONS(2209), 1,
      anon_sym_LBRACK,
    ACTIONS(2633), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2637), 1,
      anon_sym_PIPE,
    ACTIONS(2639), 1,
      anon_sym_CARET,
    ACTIONS(2649), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2651), 1,
      anon_sym_AMP,
    ACTIONS(2653), 1,
      anon_sym_QMARK,
    STATE(752), 1,
      sym_hll_argument_list,
    STATE(2039), 1,
      aux_sym_block_repeat1,
    ACTIONS(2207), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2629), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2631), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2641), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2643), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2645), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2647), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2635), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [90049] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2453), 1,
      anon_sym_LPAREN,
    ACTIONS(2459), 1,
      anon_sym_LBRACK,
    STATE(904), 1,
      sym_hll_argument_list,
    ACTIONS(2457), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2807), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2823), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2241), 7,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2239), 13,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [90098] = 16,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2941), 1,
      anon_sym_LPAREN,
    ACTIONS(2955), 1,
      anon_sym_SLASH,
    ACTIONS(2959), 1,
      anon_sym_CARET,
    ACTIONS(2967), 1,
      anon_sym_DOT_DOT,
    ACTIONS(3028), 1,
      sym__and_operator_pre_hook,
    STATE(1055), 1,
      sym_argument_list,
    STATE(2063), 1,
      aux_sym_block_repeat1,
    ACTIONS(2945), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2947), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2953), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(2963), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2965), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(1815), 3,
      anon_sym_EQ,
      anon_sym_PIPE,
      sym__blank,
    ACTIONS(2961), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1817), 5,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [90161] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1971), 1,
      anon_sym_RBRACK,
    ACTIONS(1973), 1,
      sym__blank,
    ACTIONS(2199), 1,
      anon_sym_LPAREN,
    ACTIONS(2209), 1,
      anon_sym_LBRACK,
    ACTIONS(2633), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2637), 1,
      anon_sym_PIPE,
    ACTIONS(2639), 1,
      anon_sym_CARET,
    ACTIONS(2649), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2651), 1,
      anon_sym_AMP,
    ACTIONS(2653), 1,
      anon_sym_QMARK,
    STATE(752), 1,
      sym_hll_argument_list,
    STATE(2168), 1,
      aux_sym_block_repeat1,
    ACTIONS(2207), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2629), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2631), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2641), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2643), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2645), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2647), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2635), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [90234] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3031), 1,
      sym_path,
    STATE(1137), 1,
      aux_sym__path_expression_repeat1,
    ACTIONS(1809), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(1811), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [90275] = 11,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2978), 1,
      anon_sym_LPAREN,
    ACTIONS(3002), 1,
      anon_sym_DOT_DOT,
    STATE(1033), 1,
      sym_argument_list,
    STATE(2054), 1,
      aux_sym_block_repeat1,
    ACTIONS(2982), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2984), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3000), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2990), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1815), 5,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1817), 11,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_COMMA,
      sym__blank,
  [90328] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2199), 1,
      anon_sym_LPAREN,
    ACTIONS(2209), 1,
      anon_sym_LBRACK,
    STATE(752), 1,
      sym_hll_argument_list,
    ACTIONS(2207), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2311), 6,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
    ACTIONS(2309), 18,
      anon_sym_RPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_RBRACK,
  [90373] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2199), 1,
      anon_sym_LPAREN,
    ACTIONS(2209), 1,
      anon_sym_LBRACK,
    STATE(752), 1,
      sym_hll_argument_list,
    ACTIONS(2207), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2561), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2289), 6,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
    ACTIONS(2287), 16,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_RBRACK,
  [90420] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2199), 1,
      anon_sym_LPAREN,
    ACTIONS(2209), 1,
      anon_sym_LBRACK,
    STATE(752), 1,
      sym_hll_argument_list,
    ACTIONS(2207), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2561), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3033), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2241), 6,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
    ACTIONS(2239), 14,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_RBRACK,
  [90469] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2978), 1,
      anon_sym_LPAREN,
    ACTIONS(2980), 1,
      anon_sym_EQ,
    ACTIONS(2986), 1,
      anon_sym_CARET_CARET,
    ACTIONS(2988), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2992), 1,
      anon_sym_PIPE,
    ACTIONS(2994), 1,
      anon_sym_CARET,
    ACTIONS(3002), 1,
      anon_sym_DOT_DOT,
    ACTIONS(3006), 1,
      sym__and_operator_pre_hook,
    ACTIONS(3020), 1,
      anon_sym_COMMA,
    ACTIONS(3022), 1,
      sym__blank,
    ACTIONS(3035), 1,
      anon_sym_RPAREN,
    STATE(1033), 1,
      sym_argument_list,
    STATE(1870), 1,
      aux_sym_argument_list_repeat1,
    STATE(2000), 1,
      aux_sym_block_repeat1,
    ACTIONS(2982), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2984), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2998), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3000), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2990), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2996), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
  [90542] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1923), 1,
      anon_sym_RBRACK,
    ACTIONS(1925), 1,
      sym__blank,
    ACTIONS(2199), 1,
      anon_sym_LPAREN,
    ACTIONS(2209), 1,
      anon_sym_LBRACK,
    ACTIONS(2633), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2637), 1,
      anon_sym_PIPE,
    ACTIONS(2639), 1,
      anon_sym_CARET,
    ACTIONS(2649), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2651), 1,
      anon_sym_AMP,
    ACTIONS(2653), 1,
      anon_sym_QMARK,
    STATE(752), 1,
      sym_hll_argument_list,
    STATE(2045), 1,
      aux_sym_block_repeat1,
    ACTIONS(2207), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2629), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2631), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2641), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2643), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2645), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2647), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2635), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [90615] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(169), 1,
      anon_sym_AMP,
    STATE(1268), 1,
      sym_macro,
    ACTIONS(1809), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1811), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [90656] = 15,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2978), 1,
      anon_sym_LPAREN,
    ACTIONS(2994), 1,
      anon_sym_CARET,
    ACTIONS(3002), 1,
      anon_sym_DOT_DOT,
    ACTIONS(3037), 1,
      sym__and_operator_pre_hook,
    STATE(1033), 1,
      sym_argument_list,
    STATE(2054), 1,
      aux_sym_block_repeat1,
    ACTIONS(1815), 2,
      anon_sym_EQ,
      anon_sym_PIPE,
    ACTIONS(2982), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2984), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2998), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3000), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2990), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2996), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1817), 6,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_COMMA,
      sym__blank,
  [90717] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2199), 1,
      anon_sym_LPAREN,
    ACTIONS(2209), 1,
      anon_sym_LBRACK,
    STATE(752), 1,
      sym_hll_argument_list,
    ACTIONS(2207), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2561), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2201), 6,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
    ACTIONS(2197), 16,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_RBRACK,
  [90764] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1927), 1,
      anon_sym_RBRACK,
    ACTIONS(1929), 1,
      sym__blank,
    ACTIONS(2199), 1,
      anon_sym_LPAREN,
    ACTIONS(2209), 1,
      anon_sym_LBRACK,
    ACTIONS(2633), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2637), 1,
      anon_sym_PIPE,
    ACTIONS(2639), 1,
      anon_sym_CARET,
    ACTIONS(2649), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2651), 1,
      anon_sym_AMP,
    ACTIONS(2653), 1,
      anon_sym_QMARK,
    STATE(752), 1,
      sym_hll_argument_list,
    STATE(2046), 1,
      aux_sym_block_repeat1,
    ACTIONS(2207), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2629), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2631), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2641), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2643), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2645), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2647), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2635), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [90837] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2199), 1,
      anon_sym_LPAREN,
    ACTIONS(2209), 1,
      anon_sym_LBRACK,
    STATE(752), 1,
      sym_hll_argument_list,
    ACTIONS(2207), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2561), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2215), 6,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
    ACTIONS(2213), 16,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_RBRACK,
  [90884] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2285), 1,
      sym__blank,
    ACTIONS(2453), 1,
      anon_sym_LPAREN,
    ACTIONS(2459), 1,
      anon_sym_LBRACK,
    ACTIONS(2809), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2813), 1,
      anon_sym_PIPE,
    ACTIONS(2815), 1,
      anon_sym_CARET,
    ACTIONS(2825), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2827), 1,
      anon_sym_AMP,
    ACTIONS(2829), 1,
      anon_sym_QMARK,
    STATE(904), 1,
      sym_hll_argument_list,
    ACTIONS(2283), 2,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
    ACTIONS(2457), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2805), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2807), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2817), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2819), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2821), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2823), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2811), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [90955] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2199), 1,
      anon_sym_LPAREN,
    ACTIONS(2209), 1,
      anon_sym_LBRACK,
    STATE(752), 1,
      sym_hll_argument_list,
    ACTIONS(2207), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2561), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2225), 6,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
    ACTIONS(2223), 16,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_RBRACK,
  [91002] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2199), 1,
      anon_sym_LPAREN,
    ACTIONS(2209), 1,
      anon_sym_LBRACK,
    STATE(752), 1,
      sym_hll_argument_list,
    ACTIONS(2207), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2561), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2229), 6,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
    ACTIONS(2227), 16,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_RBRACK,
  [91049] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2199), 1,
      anon_sym_LPAREN,
    ACTIONS(2209), 1,
      anon_sym_LBRACK,
    STATE(752), 1,
      sym_hll_argument_list,
    ACTIONS(2207), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2561), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2233), 6,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
    ACTIONS(2231), 16,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_RBRACK,
  [91096] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2293), 1,
      sym__blank,
    ACTIONS(2453), 1,
      anon_sym_LPAREN,
    ACTIONS(2459), 1,
      anon_sym_LBRACK,
    ACTIONS(2809), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2813), 1,
      anon_sym_PIPE,
    ACTIONS(2815), 1,
      anon_sym_CARET,
    ACTIONS(2825), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2827), 1,
      anon_sym_AMP,
    ACTIONS(2829), 1,
      anon_sym_QMARK,
    STATE(904), 1,
      sym_hll_argument_list,
    ACTIONS(2291), 2,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
    ACTIONS(2457), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2805), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2807), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2817), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2819), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2821), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2823), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2811), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [91167] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2297), 1,
      sym__blank,
    ACTIONS(2453), 1,
      anon_sym_LPAREN,
    ACTIONS(2459), 1,
      anon_sym_LBRACK,
    ACTIONS(2809), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2813), 1,
      anon_sym_PIPE,
    ACTIONS(2815), 1,
      anon_sym_CARET,
    ACTIONS(2825), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2827), 1,
      anon_sym_AMP,
    ACTIONS(2829), 1,
      anon_sym_QMARK,
    STATE(904), 1,
      sym_hll_argument_list,
    ACTIONS(2295), 2,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
    ACTIONS(2457), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2805), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2807), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2817), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2819), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2821), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2823), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2811), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [91238] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1931), 1,
      anon_sym_RBRACK,
    ACTIONS(1933), 1,
      sym__blank,
    ACTIONS(2199), 1,
      anon_sym_LPAREN,
    ACTIONS(2209), 1,
      anon_sym_LBRACK,
    ACTIONS(2633), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2637), 1,
      anon_sym_PIPE,
    ACTIONS(2639), 1,
      anon_sym_CARET,
    ACTIONS(2649), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2651), 1,
      anon_sym_AMP,
    ACTIONS(2653), 1,
      anon_sym_QMARK,
    STATE(752), 1,
      sym_hll_argument_list,
    STATE(2047), 1,
      aux_sym_block_repeat1,
    ACTIONS(2207), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2629), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2631), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2641), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2643), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2645), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2647), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2635), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [91311] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1880), 1,
      anon_sym_LPAREN,
    ACTIONS(1883), 1,
      anon_sym_DOT,
    STATE(2196), 1,
      aux_sym__function_identifier_repeat1,
    ACTIONS(1635), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1637), 19,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [91354] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1899), 1,
      anon_sym_RBRACK,
    ACTIONS(1901), 1,
      sym__blank,
    ACTIONS(2199), 1,
      anon_sym_LPAREN,
    ACTIONS(2209), 1,
      anon_sym_LBRACK,
    ACTIONS(2633), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2637), 1,
      anon_sym_PIPE,
    ACTIONS(2639), 1,
      anon_sym_CARET,
    ACTIONS(2649), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2651), 1,
      anon_sym_AMP,
    ACTIONS(2653), 1,
      anon_sym_QMARK,
    STATE(752), 1,
      sym_hll_argument_list,
    STATE(2160), 1,
      aux_sym_block_repeat1,
    ACTIONS(2207), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2629), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2631), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2641), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2643), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2645), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2647), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2635), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [91427] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2301), 1,
      sym__blank,
    ACTIONS(2453), 1,
      anon_sym_LPAREN,
    ACTIONS(2459), 1,
      anon_sym_LBRACK,
    ACTIONS(2809), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2813), 1,
      anon_sym_PIPE,
    ACTIONS(2815), 1,
      anon_sym_CARET,
    ACTIONS(2825), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2827), 1,
      anon_sym_AMP,
    ACTIONS(2829), 1,
      anon_sym_QMARK,
    STATE(904), 1,
      sym_hll_argument_list,
    ACTIONS(2299), 2,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
    ACTIONS(2457), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2805), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2807), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2817), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2819), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2821), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2823), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2811), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [91498] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2305), 1,
      sym__blank,
    ACTIONS(2453), 1,
      anon_sym_LPAREN,
    ACTIONS(2459), 1,
      anon_sym_LBRACK,
    ACTIONS(2809), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2813), 1,
      anon_sym_PIPE,
    ACTIONS(2815), 1,
      anon_sym_CARET,
    ACTIONS(2825), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2827), 1,
      anon_sym_AMP,
    ACTIONS(2829), 1,
      anon_sym_QMARK,
    STATE(904), 1,
      sym_hll_argument_list,
    ACTIONS(2303), 2,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
    ACTIONS(2457), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2805), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2807), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2817), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2819), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2821), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2823), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2811), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [91569] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2453), 1,
      anon_sym_LPAREN,
    ACTIONS(2459), 1,
      anon_sym_LBRACK,
    STATE(904), 1,
      sym_hll_argument_list,
    ACTIONS(2457), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2311), 7,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2309), 17,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [91614] = 17,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2941), 1,
      anon_sym_LPAREN,
    ACTIONS(2955), 1,
      anon_sym_SLASH,
    ACTIONS(2957), 1,
      anon_sym_PIPE,
    ACTIONS(2959), 1,
      anon_sym_CARET,
    ACTIONS(2967), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2974), 1,
      sym__and_operator_pre_hook,
    STATE(1055), 1,
      sym_argument_list,
    STATE(2063), 1,
      aux_sym_block_repeat1,
    ACTIONS(1872), 2,
      anon_sym_EQ,
      sym__blank,
    ACTIONS(2945), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2947), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2953), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(2963), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2965), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2961), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1874), 5,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [91679] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2453), 1,
      anon_sym_LPAREN,
    ACTIONS(2459), 1,
      anon_sym_LBRACK,
    STATE(904), 1,
      sym_hll_argument_list,
    ACTIONS(2457), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2807), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2289), 7,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2287), 15,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [91726] = 16,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1872), 1,
      anon_sym_EQ,
    ACTIONS(2978), 1,
      anon_sym_LPAREN,
    ACTIONS(2992), 1,
      anon_sym_PIPE,
    ACTIONS(2994), 1,
      anon_sym_CARET,
    ACTIONS(3002), 1,
      anon_sym_DOT_DOT,
    ACTIONS(3006), 1,
      sym__and_operator_pre_hook,
    STATE(1033), 1,
      sym_argument_list,
    STATE(2054), 1,
      aux_sym_block_repeat1,
    ACTIONS(2982), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2984), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2998), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3000), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2990), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2996), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1874), 6,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_COMMA,
      sym__blank,
  [91789] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3040), 1,
      aux_sym_symbol_token3,
    ACTIONS(1889), 7,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(1891), 21,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [91828] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2978), 1,
      anon_sym_LPAREN,
    ACTIONS(3002), 1,
      anon_sym_DOT_DOT,
    STATE(1033), 1,
      sym_argument_list,
    STATE(2054), 1,
      aux_sym_block_repeat1,
    ACTIONS(2984), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3000), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(1815), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1817), 14,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_COMMA,
      sym__blank,
  [91877] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2978), 1,
      anon_sym_LPAREN,
    ACTIONS(2980), 1,
      anon_sym_EQ,
    ACTIONS(2986), 1,
      anon_sym_CARET_CARET,
    ACTIONS(2988), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2992), 1,
      anon_sym_PIPE,
    ACTIONS(2994), 1,
      anon_sym_CARET,
    ACTIONS(3002), 1,
      anon_sym_DOT_DOT,
    ACTIONS(3004), 1,
      sym__blank,
    ACTIONS(3006), 1,
      sym__and_operator_pre_hook,
    STATE(1033), 1,
      sym_argument_list,
    STATE(2054), 1,
      aux_sym_block_repeat1,
    ACTIONS(2982), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2984), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2998), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3000), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(1787), 3,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_COMMA,
    ACTIONS(2990), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2996), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
  [91946] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2978), 1,
      anon_sym_LPAREN,
    ACTIONS(3002), 1,
      anon_sym_DOT_DOT,
    STATE(1033), 1,
      sym_argument_list,
    STATE(2054), 1,
      aux_sym_block_repeat1,
    ACTIONS(2984), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3000), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2990), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1815), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1817), 11,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_COMMA,
      sym__blank,
  [91997] = 13,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2978), 1,
      anon_sym_LPAREN,
    ACTIONS(3002), 1,
      anon_sym_DOT_DOT,
    STATE(1033), 1,
      sym_argument_list,
    STATE(2054), 1,
      aux_sym_block_repeat1,
    ACTIONS(2982), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2984), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2998), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3000), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(1872), 3,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
    ACTIONS(2990), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2996), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1874), 7,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_COMMA,
      sym__blank,
  [92054] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3042), 8,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BSLASH,
      anon_sym_sizeof,
      anon_sym_const,
      anon_sym_volatile,
      aux_sym_symbol_token2,
      sym_identifier,
    ACTIONS(3044), 21,
      sym__hll_number_literal_pre_hook,
      anon_sym_LPAREN,
      anon_sym_TILDE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_RBRACK,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      aux_sym_symbol_token1,
      sym__blank,
  [92091] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1645), 2,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
    ACTIONS(1635), 3,
      anon_sym_EQ,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1647), 3,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON_COLON,
    ACTIONS(1639), 4,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
    ACTIONS(1642), 6,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT_DOT,
    ACTIONS(1637), 11,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      sym__blank,
  [92136] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1645), 2,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
    ACTIONS(1647), 3,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON_COLON,
    ACTIONS(1715), 3,
      anon_sym_EQ,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1719), 4,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
    ACTIONS(1722), 6,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT_DOT,
    ACTIONS(1717), 11,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      sym__blank,
  [92181] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3050), 1,
      aux_sym_elif_block_token1,
    ACTIONS(3056), 1,
      sym__blank,
    STATE(1757), 1,
      aux_sym_subroutine_block_repeat1,
    STATE(1955), 1,
      aux_sym_block_repeat1,
    ACTIONS(3053), 2,
      sym_comment,
      sym__blank_line,
    STATE(1207), 2,
      sym_elif_block,
      aux_sym_if_block_repeat1,
    ACTIONS(3046), 6,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
    ACTIONS(3048), 15,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
  [92230] = 14,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2941), 1,
      anon_sym_LPAREN,
    ACTIONS(2955), 1,
      anon_sym_SLASH,
    ACTIONS(2967), 1,
      anon_sym_DOT_DOT,
    STATE(1055), 1,
      sym_argument_list,
    STATE(2063), 1,
      aux_sym_block_repeat1,
    ACTIONS(2945), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2947), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2953), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(2963), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2965), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(1872), 4,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      sym__blank,
    ACTIONS(2961), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1874), 6,
      sym__and_operator_pre_hook,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [92289] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1903), 1,
      anon_sym_RBRACK,
    ACTIONS(1905), 1,
      sym__blank,
    ACTIONS(2199), 1,
      anon_sym_LPAREN,
    ACTIONS(2209), 1,
      anon_sym_LBRACK,
    ACTIONS(2633), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2637), 1,
      anon_sym_PIPE,
    ACTIONS(2639), 1,
      anon_sym_CARET,
    ACTIONS(2649), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2651), 1,
      anon_sym_AMP,
    ACTIONS(2653), 1,
      anon_sym_QMARK,
    STATE(752), 1,
      sym_hll_argument_list,
    STATE(2038), 1,
      aux_sym_block_repeat1,
    ACTIONS(2207), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2629), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2631), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2641), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2643), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2645), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2647), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2635), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [92362] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    STATE(1033), 1,
      sym_argument_list,
    STATE(2054), 1,
      aux_sym_block_repeat1,
    ACTIONS(1815), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1817), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [92403] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1995), 1,
      anon_sym_RBRACK,
    ACTIONS(1997), 1,
      sym__blank,
    ACTIONS(2199), 1,
      anon_sym_LPAREN,
    ACTIONS(2209), 1,
      anon_sym_LBRACK,
    ACTIONS(2633), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2637), 1,
      anon_sym_PIPE,
    ACTIONS(2639), 1,
      anon_sym_CARET,
    ACTIONS(2649), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2651), 1,
      anon_sym_AMP,
    ACTIONS(2653), 1,
      anon_sym_QMARK,
    STATE(752), 1,
      sym_hll_argument_list,
    STATE(2183), 1,
      aux_sym_block_repeat1,
    ACTIONS(2207), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2629), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2631), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2641), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2643), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2645), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2647), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2635), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [92476] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2978), 1,
      anon_sym_LPAREN,
    ACTIONS(2980), 1,
      anon_sym_EQ,
    ACTIONS(2986), 1,
      anon_sym_CARET_CARET,
    ACTIONS(2988), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2992), 1,
      anon_sym_PIPE,
    ACTIONS(2994), 1,
      anon_sym_CARET,
    ACTIONS(3002), 1,
      anon_sym_DOT_DOT,
    ACTIONS(3004), 1,
      sym__blank,
    ACTIONS(3006), 1,
      sym__and_operator_pre_hook,
    STATE(1033), 1,
      sym_argument_list,
    STATE(2054), 1,
      aux_sym_block_repeat1,
    ACTIONS(2982), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2984), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2998), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3000), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(1887), 3,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_COMMA,
    ACTIONS(2990), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2996), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
  [92545] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1999), 1,
      anon_sym_RBRACK,
    ACTIONS(2001), 1,
      sym__blank,
    ACTIONS(2199), 1,
      anon_sym_LPAREN,
    ACTIONS(2209), 1,
      anon_sym_LBRACK,
    ACTIONS(2633), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2637), 1,
      anon_sym_PIPE,
    ACTIONS(2639), 1,
      anon_sym_CARET,
    ACTIONS(2649), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2651), 1,
      anon_sym_AMP,
    ACTIONS(2653), 1,
      anon_sym_QMARK,
    STATE(752), 1,
      sym_hll_argument_list,
    STATE(2184), 1,
      aux_sym_block_repeat1,
    ACTIONS(2207), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2629), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2631), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2641), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2643), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2645), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2647), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2635), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [92618] = 16,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1815), 1,
      anon_sym_EQ,
    ACTIONS(2978), 1,
      anon_sym_LPAREN,
    ACTIONS(2992), 1,
      anon_sym_PIPE,
    ACTIONS(2994), 1,
      anon_sym_CARET,
    ACTIONS(3002), 1,
      anon_sym_DOT_DOT,
    ACTIONS(3006), 1,
      sym__and_operator_pre_hook,
    STATE(1033), 1,
      sym_argument_list,
    STATE(2054), 1,
      aux_sym_block_repeat1,
    ACTIONS(2982), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2984), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2998), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3000), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2990), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2996), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1817), 6,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_COMMA,
      sym__blank,
  [92681] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2978), 1,
      anon_sym_LPAREN,
    ACTIONS(2980), 1,
      anon_sym_EQ,
    ACTIONS(2986), 1,
      anon_sym_CARET_CARET,
    ACTIONS(2988), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2992), 1,
      anon_sym_PIPE,
    ACTIONS(2994), 1,
      anon_sym_CARET,
    ACTIONS(3002), 1,
      anon_sym_DOT_DOT,
    ACTIONS(3004), 1,
      sym__blank,
    ACTIONS(3006), 1,
      sym__and_operator_pre_hook,
    STATE(1033), 1,
      sym_argument_list,
    STATE(2054), 1,
      aux_sym_block_repeat1,
    ACTIONS(2982), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2984), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2998), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3000), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(1878), 3,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_COMMA,
    ACTIONS(2990), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2996), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
  [92750] = 17,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1815), 1,
      anon_sym_EQ,
    ACTIONS(2978), 1,
      anon_sym_LPAREN,
    ACTIONS(2986), 1,
      anon_sym_CARET_CARET,
    ACTIONS(2992), 1,
      anon_sym_PIPE,
    ACTIONS(2994), 1,
      anon_sym_CARET,
    ACTIONS(3002), 1,
      anon_sym_DOT_DOT,
    ACTIONS(3006), 1,
      sym__and_operator_pre_hook,
    STATE(1033), 1,
      sym_argument_list,
    STATE(2054), 1,
      aux_sym_block_repeat1,
    ACTIONS(2982), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2984), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2998), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3000), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2990), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2996), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1817), 5,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_PIPE_PIPE,
      anon_sym_COMMA,
      sym__blank,
  [92815] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2003), 1,
      anon_sym_RBRACK,
    ACTIONS(2005), 1,
      sym__blank,
    ACTIONS(2199), 1,
      anon_sym_LPAREN,
    ACTIONS(2209), 1,
      anon_sym_LBRACK,
    ACTIONS(2633), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2637), 1,
      anon_sym_PIPE,
    ACTIONS(2639), 1,
      anon_sym_CARET,
    ACTIONS(2649), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2651), 1,
      anon_sym_AMP,
    ACTIONS(2653), 1,
      anon_sym_QMARK,
    STATE(752), 1,
      sym_hll_argument_list,
    STATE(2186), 1,
      aux_sym_block_repeat1,
    ACTIONS(2207), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2629), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2631), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2641), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2643), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2645), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2647), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2635), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [92888] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3059), 1,
      sym_path,
    STATE(1237), 1,
      aux_sym__path_expression_repeat1,
    ACTIONS(1809), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1811), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [92929] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1880), 1,
      anon_sym_LPAREN,
    ACTIONS(1883), 1,
      anon_sym_DOT,
    STATE(2196), 1,
      aux_sym__function_identifier_repeat1,
    ACTIONS(1635), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(1637), 17,
      sym__and_operator_pre_hook,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [92972] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2941), 1,
      anon_sym_LPAREN,
    ACTIONS(2943), 1,
      anon_sym_EQ,
    ACTIONS(2949), 1,
      anon_sym_CARET_CARET,
    ACTIONS(2951), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2955), 1,
      anon_sym_SLASH,
    ACTIONS(2957), 1,
      anon_sym_PIPE,
    ACTIONS(2959), 1,
      anon_sym_CARET,
    ACTIONS(2967), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2974), 1,
      sym__and_operator_pre_hook,
    ACTIONS(2976), 1,
      sym__blank,
    STATE(1055), 1,
      sym_argument_list,
    STATE(2063), 1,
      aux_sym_block_repeat1,
    ACTIONS(2945), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2947), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2953), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(2963), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2965), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(1887), 3,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
    ACTIONS(2961), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
  [93043] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1907), 1,
      anon_sym_RBRACK,
    ACTIONS(1909), 1,
      sym__blank,
    ACTIONS(2199), 1,
      anon_sym_LPAREN,
    ACTIONS(2209), 1,
      anon_sym_LBRACK,
    ACTIONS(2633), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2637), 1,
      anon_sym_PIPE,
    ACTIONS(2639), 1,
      anon_sym_CARET,
    ACTIONS(2649), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2651), 1,
      anon_sym_AMP,
    ACTIONS(2653), 1,
      anon_sym_QMARK,
    STATE(752), 1,
      sym_hll_argument_list,
    STATE(2069), 1,
      aux_sym_block_repeat1,
    ACTIONS(2207), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2629), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2631), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2641), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2643), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2645), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2647), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2635), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [93116] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2199), 1,
      anon_sym_LPAREN,
    ACTIONS(2209), 1,
      anon_sym_LBRACK,
    STATE(752), 1,
      sym_hll_argument_list,
    ACTIONS(2207), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2561), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3033), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3061), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2201), 6,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
    ACTIONS(2197), 11,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_RBRACK,
  [93167] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2609), 8,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BSLASH,
      anon_sym_sizeof,
      anon_sym_const,
      anon_sym_volatile,
      aux_sym_symbol_token2,
      sym_identifier,
    ACTIONS(2611), 21,
      sym__hll_number_literal_pre_hook,
      anon_sym_LPAREN,
      anon_sym_TILDE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_RBRACK,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      aux_sym_symbol_token1,
      sym__blank,
  [93204] = 17,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2199), 1,
      anon_sym_LPAREN,
    ACTIONS(2209), 1,
      anon_sym_LBRACK,
    ACTIONS(3065), 1,
      anon_sym_PIPE,
    ACTIONS(3067), 1,
      anon_sym_CARET,
    ACTIONS(3075), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3077), 1,
      anon_sym_AMP,
    STATE(752), 1,
      sym_hll_argument_list,
    ACTIONS(2207), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2561), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3033), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3063), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3069), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(3071), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3073), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3061), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2197), 5,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_RBRACK,
  [93269] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2199), 1,
      anon_sym_LPAREN,
    ACTIONS(2209), 1,
      anon_sym_LBRACK,
    STATE(752), 1,
      sym_hll_argument_list,
    ACTIONS(2207), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2561), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3033), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2201), 6,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
    ACTIONS(2197), 14,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_RBRACK,
  [93318] = 16,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2199), 1,
      anon_sym_LPAREN,
    ACTIONS(2201), 1,
      anon_sym_PIPE,
    ACTIONS(2209), 1,
      anon_sym_LBRACK,
    ACTIONS(3067), 1,
      anon_sym_CARET,
    ACTIONS(3077), 1,
      anon_sym_AMP,
    STATE(752), 1,
      sym_hll_argument_list,
    ACTIONS(2207), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2561), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3033), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3063), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3069), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(3071), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3073), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3061), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2197), 6,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_RBRACK,
  [93381] = 15,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2199), 1,
      anon_sym_LPAREN,
    ACTIONS(2201), 1,
      anon_sym_PIPE,
    ACTIONS(2209), 1,
      anon_sym_LBRACK,
    ACTIONS(3077), 1,
      anon_sym_AMP,
    STATE(752), 1,
      sym_hll_argument_list,
    ACTIONS(2207), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2561), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3033), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3063), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3069), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(3071), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3073), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3061), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2197), 7,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_RBRACK,
  [93442] = 17,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2941), 1,
      anon_sym_LPAREN,
    ACTIONS(2955), 1,
      anon_sym_SLASH,
    ACTIONS(2957), 1,
      anon_sym_PIPE,
    ACTIONS(2959), 1,
      anon_sym_CARET,
    ACTIONS(2967), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2974), 1,
      sym__and_operator_pre_hook,
    STATE(1055), 1,
      sym_argument_list,
    STATE(2063), 1,
      aux_sym_block_repeat1,
    ACTIONS(1815), 2,
      anon_sym_EQ,
      sym__blank,
    ACTIONS(2945), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2947), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2953), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(2963), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2965), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2961), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1817), 5,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [93507] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(169), 1,
      anon_sym_AMP,
    STATE(1268), 1,
      sym_macro,
    ACTIONS(2007), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2009), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [93548] = 13,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2199), 1,
      anon_sym_LPAREN,
    ACTIONS(2209), 1,
      anon_sym_LBRACK,
    STATE(752), 1,
      sym_hll_argument_list,
    ACTIONS(2201), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(2207), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2561), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3033), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3063), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3071), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3073), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3061), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2197), 9,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_RBRACK,
  [93605] = 11,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2199), 1,
      anon_sym_LPAREN,
    ACTIONS(2209), 1,
      anon_sym_LBRACK,
    STATE(752), 1,
      sym_hll_argument_list,
    ACTIONS(2207), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2561), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3033), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3063), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3061), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2201), 4,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
    ACTIONS(2197), 11,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_RBRACK,
  [93658] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2453), 1,
      anon_sym_LPAREN,
    ACTIONS(2459), 1,
      anon_sym_LBRACK,
    STATE(904), 1,
      sym_hll_argument_list,
    ACTIONS(2457), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2807), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2201), 7,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2197), 15,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [93705] = 14,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2978), 1,
      anon_sym_LPAREN,
    ACTIONS(3002), 1,
      anon_sym_DOT_DOT,
    ACTIONS(3037), 1,
      sym__and_operator_pre_hook,
    STATE(1033), 1,
      sym_argument_list,
    STATE(2054), 1,
      aux_sym_block_repeat1,
    ACTIONS(2982), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2984), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2998), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3000), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(1815), 3,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
    ACTIONS(2990), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2996), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1817), 6,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_COMMA,
      sym__blank,
  [93764] = 16,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2199), 1,
      anon_sym_LPAREN,
    ACTIONS(2209), 1,
      anon_sym_LBRACK,
    ACTIONS(3065), 1,
      anon_sym_PIPE,
    ACTIONS(3067), 1,
      anon_sym_CARET,
    ACTIONS(3077), 1,
      anon_sym_AMP,
    STATE(752), 1,
      sym_hll_argument_list,
    ACTIONS(2207), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2561), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3033), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3063), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3069), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(3071), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3073), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3061), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2197), 6,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_RBRACK,
  [93827] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(147), 1,
      anon_sym_AMP,
    STATE(1301), 1,
      sym_macro,
    ACTIONS(2007), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(2009), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [93868] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2941), 1,
      anon_sym_LPAREN,
    ACTIONS(2943), 1,
      anon_sym_EQ,
    ACTIONS(2949), 1,
      anon_sym_CARET_CARET,
    ACTIONS(2951), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2955), 1,
      anon_sym_SLASH,
    ACTIONS(2957), 1,
      anon_sym_PIPE,
    ACTIONS(2959), 1,
      anon_sym_CARET,
    ACTIONS(2967), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2974), 1,
      sym__and_operator_pre_hook,
    ACTIONS(2976), 1,
      sym__blank,
    STATE(1055), 1,
      sym_argument_list,
    STATE(2063), 1,
      aux_sym_block_repeat1,
    ACTIONS(2945), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2947), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2953), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(2963), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2965), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(1878), 3,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
    ACTIONS(2961), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
  [93939] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3079), 1,
      sym_path,
    STATE(1237), 1,
      aux_sym__path_expression_repeat1,
    ACTIONS(1791), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1793), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [93980] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2978), 1,
      anon_sym_LPAREN,
    ACTIONS(3002), 1,
      anon_sym_DOT_DOT,
    STATE(1033), 1,
      sym_argument_list,
    STATE(2054), 1,
      aux_sym_block_repeat1,
    ACTIONS(2984), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1798), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1800), 16,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COMMA,
      sym__blank,
  [94027] = 15,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2941), 1,
      anon_sym_LPAREN,
    ACTIONS(2955), 1,
      anon_sym_SLASH,
    ACTIONS(2967), 1,
      anon_sym_DOT_DOT,
    ACTIONS(3028), 1,
      sym__and_operator_pre_hook,
    STATE(1055), 1,
      sym_argument_list,
    STATE(2063), 1,
      aux_sym_block_repeat1,
    ACTIONS(2945), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2947), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2953), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(2963), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2965), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(1815), 4,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      sym__blank,
    ACTIONS(2961), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1817), 5,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [94088] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2978), 1,
      anon_sym_LPAREN,
    ACTIONS(3002), 1,
      anon_sym_DOT_DOT,
    STATE(1033), 1,
      sym_argument_list,
    STATE(2054), 1,
      aux_sym_block_repeat1,
    ACTIONS(2984), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1815), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1817), 16,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COMMA,
      sym__blank,
  [94135] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1911), 1,
      anon_sym_RBRACK,
    ACTIONS(1913), 1,
      sym__blank,
    ACTIONS(2199), 1,
      anon_sym_LPAREN,
    ACTIONS(2209), 1,
      anon_sym_LBRACK,
    ACTIONS(2633), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2637), 1,
      anon_sym_PIPE,
    ACTIONS(2639), 1,
      anon_sym_CARET,
    ACTIONS(2649), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2651), 1,
      anon_sym_AMP,
    ACTIONS(2653), 1,
      anon_sym_QMARK,
    STATE(752), 1,
      sym_hll_argument_list,
    STATE(2199), 1,
      aux_sym_block_repeat1,
    ACTIONS(2207), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2629), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2631), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2641), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2643), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2645), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2647), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2635), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [94208] = 14,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2199), 1,
      anon_sym_LPAREN,
    ACTIONS(2209), 1,
      anon_sym_LBRACK,
    STATE(752), 1,
      sym_hll_argument_list,
    ACTIONS(2201), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(2207), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2561), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3033), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3063), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3069), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(3071), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3073), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3061), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2197), 7,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_RBRACK,
  [94267] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3002), 1,
      anon_sym_DOT_DOT,
    STATE(1033), 1,
      sym_argument_list,
    STATE(2054), 1,
      aux_sym_block_repeat1,
    ACTIONS(2984), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1826), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1828), 17,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COMMA,
      sym__blank,
  [94312] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1987), 7,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(1989), 22,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
      aux_sym_symbol_token3,
  [94349] = 12,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2941), 1,
      anon_sym_LPAREN,
    ACTIONS(2955), 1,
      anon_sym_SLASH,
    ACTIONS(2967), 1,
      anon_sym_DOT_DOT,
    STATE(1055), 1,
      sym_argument_list,
    STATE(2063), 1,
      aux_sym_block_repeat1,
    ACTIONS(2945), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2947), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2953), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(2965), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(1815), 6,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(1817), 10,
      sym__and_operator_pre_hook,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [94404] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2199), 1,
      anon_sym_LPAREN,
    ACTIONS(2209), 1,
      anon_sym_LBRACK,
    ACTIONS(3065), 1,
      anon_sym_PIPE,
    ACTIONS(3067), 1,
      anon_sym_CARET,
    ACTIONS(3075), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3077), 1,
      anon_sym_AMP,
    ACTIONS(3082), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3084), 1,
      anon_sym_QMARK,
    STATE(752), 1,
      sym_hll_argument_list,
    ACTIONS(2207), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2561), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3033), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3063), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3069), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(3071), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3073), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2275), 3,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_RBRACK,
    ACTIONS(3061), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [94473] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2453), 1,
      anon_sym_LPAREN,
    ACTIONS(2459), 1,
      anon_sym_LBRACK,
    STATE(904), 1,
      sym_hll_argument_list,
    ACTIONS(2457), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2807), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2215), 7,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2213), 15,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [94520] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2941), 1,
      anon_sym_LPAREN,
    ACTIONS(2967), 1,
      anon_sym_DOT_DOT,
    STATE(1055), 1,
      sym_argument_list,
    STATE(2063), 1,
      aux_sym_block_repeat1,
    ACTIONS(2947), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1798), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(1800), 14,
      sym__and_operator_pre_hook,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [94567] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2015), 1,
      anon_sym_RBRACK,
    ACTIONS(2017), 1,
      sym__blank,
    ACTIONS(2199), 1,
      anon_sym_LPAREN,
    ACTIONS(2209), 1,
      anon_sym_LBRACK,
    ACTIONS(2633), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2637), 1,
      anon_sym_PIPE,
    ACTIONS(2639), 1,
      anon_sym_CARET,
    ACTIONS(2649), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2651), 1,
      anon_sym_AMP,
    ACTIONS(2653), 1,
      anon_sym_QMARK,
    STATE(752), 1,
      sym_hll_argument_list,
    STATE(2185), 1,
      aux_sym_block_repeat1,
    ACTIONS(2207), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2629), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2631), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2641), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2643), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2645), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2647), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2635), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [94640] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2199), 1,
      anon_sym_LPAREN,
    ACTIONS(2209), 1,
      anon_sym_LBRACK,
    ACTIONS(3065), 1,
      anon_sym_PIPE,
    ACTIONS(3067), 1,
      anon_sym_CARET,
    ACTIONS(3075), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3077), 1,
      anon_sym_AMP,
    ACTIONS(3082), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3084), 1,
      anon_sym_QMARK,
    STATE(752), 1,
      sym_hll_argument_list,
    ACTIONS(2207), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2561), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3033), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3063), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3069), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(3071), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3073), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2283), 3,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_RBRACK,
    ACTIONS(3061), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [94709] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2967), 1,
      anon_sym_DOT_DOT,
    STATE(1055), 1,
      sym_argument_list,
    STATE(2063), 1,
      aux_sym_block_repeat1,
    ACTIONS(2947), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1826), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(1828), 15,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [94754] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2199), 1,
      anon_sym_LPAREN,
    ACTIONS(2209), 1,
      anon_sym_LBRACK,
    ACTIONS(3065), 1,
      anon_sym_PIPE,
    ACTIONS(3067), 1,
      anon_sym_CARET,
    ACTIONS(3075), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3077), 1,
      anon_sym_AMP,
    ACTIONS(3082), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3084), 1,
      anon_sym_QMARK,
    STATE(752), 1,
      sym_hll_argument_list,
    ACTIONS(2207), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2561), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3033), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3063), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3069), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(3071), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3073), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2291), 3,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_RBRACK,
    ACTIONS(3061), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [94823] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2199), 1,
      anon_sym_LPAREN,
    ACTIONS(2209), 1,
      anon_sym_LBRACK,
    ACTIONS(3065), 1,
      anon_sym_PIPE,
    ACTIONS(3067), 1,
      anon_sym_CARET,
    ACTIONS(3075), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3077), 1,
      anon_sym_AMP,
    ACTIONS(3082), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3084), 1,
      anon_sym_QMARK,
    STATE(752), 1,
      sym_hll_argument_list,
    ACTIONS(2207), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2561), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3033), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3063), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3069), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(3071), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3073), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2295), 3,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_RBRACK,
    ACTIONS(3061), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [94892] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2019), 1,
      anon_sym_RBRACK,
    ACTIONS(2021), 1,
      sym__blank,
    ACTIONS(2199), 1,
      anon_sym_LPAREN,
    ACTIONS(2209), 1,
      anon_sym_LBRACK,
    ACTIONS(2633), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2637), 1,
      anon_sym_PIPE,
    ACTIONS(2639), 1,
      anon_sym_CARET,
    ACTIONS(2649), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2651), 1,
      anon_sym_AMP,
    ACTIONS(2653), 1,
      anon_sym_QMARK,
    STATE(752), 1,
      sym_hll_argument_list,
    STATE(2228), 1,
      aux_sym_block_repeat1,
    ACTIONS(2207), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2629), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2631), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2641), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2643), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2645), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2647), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2635), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [94965] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2453), 1,
      anon_sym_LPAREN,
    ACTIONS(2459), 1,
      anon_sym_LBRACK,
    STATE(904), 1,
      sym_hll_argument_list,
    ACTIONS(2457), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2807), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2225), 7,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2223), 15,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [95012] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2453), 1,
      anon_sym_LPAREN,
    ACTIONS(2459), 1,
      anon_sym_LBRACK,
    STATE(904), 1,
      sym_hll_argument_list,
    ACTIONS(2457), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2807), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2229), 7,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2227), 15,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [95059] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2199), 1,
      anon_sym_LPAREN,
    ACTIONS(2209), 1,
      anon_sym_LBRACK,
    ACTIONS(3065), 1,
      anon_sym_PIPE,
    ACTIONS(3067), 1,
      anon_sym_CARET,
    ACTIONS(3075), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3077), 1,
      anon_sym_AMP,
    ACTIONS(3082), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3084), 1,
      anon_sym_QMARK,
    STATE(752), 1,
      sym_hll_argument_list,
    ACTIONS(2207), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2561), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3033), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3063), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3069), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(3071), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3073), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2299), 3,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_RBRACK,
    ACTIONS(3061), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [95128] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2199), 1,
      anon_sym_LPAREN,
    ACTIONS(2209), 1,
      anon_sym_LBRACK,
    ACTIONS(3065), 1,
      anon_sym_PIPE,
    ACTIONS(3067), 1,
      anon_sym_CARET,
    ACTIONS(3075), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3077), 1,
      anon_sym_AMP,
    ACTIONS(3082), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3084), 1,
      anon_sym_QMARK,
    STATE(752), 1,
      sym_hll_argument_list,
    ACTIONS(2207), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2561), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3033), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3063), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3069), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(3071), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3073), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2303), 3,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_RBRACK,
    ACTIONS(3061), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [95197] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2453), 1,
      anon_sym_LPAREN,
    ACTIONS(2459), 1,
      anon_sym_LBRACK,
    STATE(904), 1,
      sym_hll_argument_list,
    ACTIONS(2457), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2807), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2233), 7,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2231), 15,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [95244] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2011), 7,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2013), 22,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
      aux_sym_symbol_token3,
  [95281] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2978), 1,
      anon_sym_LPAREN,
    ACTIONS(2980), 1,
      anon_sym_EQ,
    ACTIONS(2986), 1,
      anon_sym_CARET_CARET,
    ACTIONS(2988), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2992), 1,
      anon_sym_PIPE,
    ACTIONS(2994), 1,
      anon_sym_CARET,
    ACTIONS(3002), 1,
      anon_sym_DOT_DOT,
    ACTIONS(3006), 1,
      sym__and_operator_pre_hook,
    ACTIONS(3020), 1,
      anon_sym_COMMA,
    ACTIONS(3022), 1,
      sym__blank,
    ACTIONS(3086), 1,
      anon_sym_RPAREN,
    STATE(1033), 1,
      sym_argument_list,
    STATE(1853), 1,
      aux_sym_argument_list_repeat1,
    STATE(2000), 1,
      aux_sym_block_repeat1,
    ACTIONS(2982), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2984), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2998), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3000), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2990), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2996), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
  [95354] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2941), 1,
      anon_sym_LPAREN,
    ACTIONS(2943), 1,
      anon_sym_EQ,
    ACTIONS(2949), 1,
      anon_sym_CARET_CARET,
    ACTIONS(2951), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2955), 1,
      anon_sym_SLASH,
    ACTIONS(2957), 1,
      anon_sym_PIPE,
    ACTIONS(2959), 1,
      anon_sym_CARET,
    ACTIONS(2967), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2974), 1,
      sym__and_operator_pre_hook,
    ACTIONS(2976), 1,
      sym__blank,
    STATE(1055), 1,
      sym_argument_list,
    STATE(2063), 1,
      aux_sym_block_repeat1,
    ACTIONS(2945), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2947), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2953), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(2963), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2965), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(1787), 3,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
    ACTIONS(2961), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
  [95425] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3088), 1,
      aux_sym_elif_block_token1,
    ACTIONS(3094), 1,
      sym__blank,
    STATE(1753), 1,
      aux_sym_subroutine_block_repeat1,
    STATE(2014), 1,
      aux_sym_block_repeat1,
    ACTIONS(3091), 2,
      sym_comment,
      sym__blank_line,
    STATE(1263), 2,
      sym_elif_block,
      aux_sym_if_block_repeat1,
    ACTIONS(3046), 6,
      sym_label_identifier,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
    ACTIONS(3048), 15,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
  [95474] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1991), 1,
      anon_sym_RBRACK,
    ACTIONS(1993), 1,
      sym__blank,
    ACTIONS(2199), 1,
      anon_sym_LPAREN,
    ACTIONS(2209), 1,
      anon_sym_LBRACK,
    ACTIONS(2633), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2637), 1,
      anon_sym_PIPE,
    ACTIONS(2639), 1,
      anon_sym_CARET,
    ACTIONS(2649), 1,
      anon_sym_AMP_AMP,
    ACTIONS(2651), 1,
      anon_sym_AMP,
    ACTIONS(2653), 1,
      anon_sym_QMARK,
    STATE(752), 1,
      sym_hll_argument_list,
    STATE(2177), 1,
      aux_sym_block_repeat1,
    ACTIONS(2207), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2629), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2631), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2641), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2643), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2645), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(2647), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2635), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [95547] = 13,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2453), 1,
      anon_sym_LPAREN,
    ACTIONS(2459), 1,
      anon_sym_LBRACK,
    STATE(904), 1,
      sym_hll_argument_list,
    ACTIONS(2201), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(2457), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2807), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3097), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3101), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3103), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3105), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3099), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2197), 8,
      anon_sym_PIPE_PIPE,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [95603] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2941), 1,
      anon_sym_LPAREN,
    ACTIONS(2943), 1,
      anon_sym_EQ,
    ACTIONS(2949), 1,
      anon_sym_CARET_CARET,
    ACTIONS(2951), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2955), 1,
      anon_sym_SLASH,
    ACTIONS(2957), 1,
      anon_sym_PIPE,
    ACTIONS(2959), 1,
      anon_sym_CARET,
    ACTIONS(2967), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2974), 1,
      sym__and_operator_pre_hook,
    ACTIONS(2976), 1,
      sym__blank,
    STATE(1055), 1,
      sym_argument_list,
    STATE(2063), 1,
      aux_sym_block_repeat1,
    ACTIONS(2945), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2947), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2953), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(2963), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2965), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3107), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(2961), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
  [95673] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2443), 1,
      anon_sym_LPAREN,
    ACTIONS(2451), 1,
      anon_sym_LBRACK,
    ACTIONS(3111), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3115), 1,
      anon_sym_SLASH,
    ACTIONS(3117), 1,
      anon_sym_PIPE,
    ACTIONS(3119), 1,
      anon_sym_CARET,
    ACTIONS(3129), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3131), 1,
      anon_sym_AMP,
    ACTIONS(3133), 1,
      anon_sym_QMARK,
    STATE(917), 1,
      sym_hll_argument_list,
    ACTIONS(2299), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(2449), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2561), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3109), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3113), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(3121), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(3123), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3125), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3127), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
  [95743] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1791), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1793), 21,
      sym__and_operator_pre_hook,
      sym_path,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [95779] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2443), 1,
      anon_sym_LPAREN,
    ACTIONS(2451), 1,
      anon_sym_LBRACK,
    ACTIONS(3111), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3115), 1,
      anon_sym_SLASH,
    ACTIONS(3117), 1,
      anon_sym_PIPE,
    ACTIONS(3119), 1,
      anon_sym_CARET,
    ACTIONS(3129), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3131), 1,
      anon_sym_AMP,
    ACTIONS(3133), 1,
      anon_sym_QMARK,
    STATE(917), 1,
      sym_hll_argument_list,
    ACTIONS(2449), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2561), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3107), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(3109), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3113), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(3121), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(3123), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3125), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3127), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
  [95849] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2443), 1,
      anon_sym_LPAREN,
    ACTIONS(2451), 1,
      anon_sym_LBRACK,
    ACTIONS(3111), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3115), 1,
      anon_sym_SLASH,
    ACTIONS(3117), 1,
      anon_sym_PIPE,
    ACTIONS(3119), 1,
      anon_sym_CARET,
    ACTIONS(3129), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3131), 1,
      anon_sym_AMP,
    ACTIONS(3133), 1,
      anon_sym_QMARK,
    STATE(917), 1,
      sym_hll_argument_list,
    ACTIONS(2303), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(2449), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2561), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3109), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3113), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(3121), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(3123), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3125), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3127), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
  [95919] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2941), 1,
      anon_sym_LPAREN,
    ACTIONS(2943), 1,
      anon_sym_EQ,
    ACTIONS(2949), 1,
      anon_sym_CARET_CARET,
    ACTIONS(2951), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2955), 1,
      anon_sym_SLASH,
    ACTIONS(2957), 1,
      anon_sym_PIPE,
    ACTIONS(2959), 1,
      anon_sym_CARET,
    ACTIONS(2967), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2974), 1,
      sym__and_operator_pre_hook,
    ACTIONS(2976), 1,
      sym__blank,
    STATE(1055), 1,
      sym_argument_list,
    STATE(2063), 1,
      aux_sym_block_repeat1,
    ACTIONS(2945), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2947), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2953), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(2963), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2965), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3135), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(2961), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
  [95989] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1603), 1,
      sym__blank,
    STATE(800), 1,
      aux_sym_block_repeat1,
    ACTIONS(2685), 6,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BSLASH,
      anon_sym_sizeof,
      aux_sym_symbol_token2,
      sym_identifier,
    ACTIONS(2687), 20,
      sym__hll_number_literal_pre_hook,
      anon_sym_LPAREN,
      anon_sym_TILDE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      aux_sym_symbol_token1,
  [96029] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2453), 1,
      anon_sym_LPAREN,
    ACTIONS(2459), 1,
      anon_sym_LBRACK,
    STATE(904), 1,
      sym_hll_argument_list,
    ACTIONS(2457), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2807), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3105), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3099), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2201), 6,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
    ACTIONS(2197), 10,
      anon_sym_PIPE_PIPE,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [96079] = 17,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2453), 1,
      anon_sym_LPAREN,
    ACTIONS(2459), 1,
      anon_sym_LBRACK,
    ACTIONS(3137), 1,
      anon_sym_PIPE,
    ACTIONS(3139), 1,
      anon_sym_CARET,
    ACTIONS(3143), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3145), 1,
      anon_sym_AMP,
    STATE(904), 1,
      sym_hll_argument_list,
    ACTIONS(2457), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2807), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3097), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3101), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3103), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3105), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3141), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(3099), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2197), 4,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [96143] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2453), 1,
      anon_sym_LPAREN,
    ACTIONS(2459), 1,
      anon_sym_LBRACK,
    STATE(904), 1,
      sym_hll_argument_list,
    ACTIONS(2457), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2807), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3105), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2201), 6,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
    ACTIONS(2197), 13,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [96191] = 16,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2201), 1,
      anon_sym_PIPE,
    ACTIONS(2453), 1,
      anon_sym_LPAREN,
    ACTIONS(2459), 1,
      anon_sym_LBRACK,
    ACTIONS(3139), 1,
      anon_sym_CARET,
    ACTIONS(3145), 1,
      anon_sym_AMP,
    STATE(904), 1,
      sym_hll_argument_list,
    ACTIONS(2457), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2807), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3097), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3101), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3103), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3105), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3141), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(3099), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2197), 5,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [96253] = 15,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2201), 1,
      anon_sym_PIPE,
    ACTIONS(2453), 1,
      anon_sym_LPAREN,
    ACTIONS(2459), 1,
      anon_sym_LBRACK,
    ACTIONS(3145), 1,
      anon_sym_AMP,
    STATE(904), 1,
      sym_hll_argument_list,
    ACTIONS(2457), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2807), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3097), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3101), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3103), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3105), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3141), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(3099), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2197), 6,
      anon_sym_PIPE_PIPE,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [96313] = 11,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2453), 1,
      anon_sym_LPAREN,
    ACTIONS(2459), 1,
      anon_sym_LBRACK,
    STATE(904), 1,
      sym_hll_argument_list,
    ACTIONS(2457), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2807), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3097), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3105), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3099), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2201), 4,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
    ACTIONS(2197), 10,
      anon_sym_PIPE_PIPE,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [96365] = 16,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2453), 1,
      anon_sym_LPAREN,
    ACTIONS(2459), 1,
      anon_sym_LBRACK,
    ACTIONS(3137), 1,
      anon_sym_PIPE,
    ACTIONS(3139), 1,
      anon_sym_CARET,
    ACTIONS(3145), 1,
      anon_sym_AMP,
    STATE(904), 1,
      sym_hll_argument_list,
    ACTIONS(2457), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2807), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3097), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3101), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3103), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3105), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3141), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(3099), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2197), 5,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [96427] = 14,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2453), 1,
      anon_sym_LPAREN,
    ACTIONS(2459), 1,
      anon_sym_LBRACK,
    STATE(904), 1,
      sym_hll_argument_list,
    ACTIONS(2201), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(2457), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2807), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3097), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3101), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3103), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3105), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3141), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(3099), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2197), 6,
      anon_sym_PIPE_PIPE,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [96485] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2453), 1,
      anon_sym_LPAREN,
    ACTIONS(2459), 1,
      anon_sym_LBRACK,
    ACTIONS(3137), 1,
      anon_sym_PIPE,
    ACTIONS(3139), 1,
      anon_sym_CARET,
    ACTIONS(3143), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3145), 1,
      anon_sym_AMP,
    ACTIONS(3147), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3149), 1,
      anon_sym_QMARK,
    STATE(904), 1,
      sym_hll_argument_list,
    ACTIONS(2275), 2,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
    ACTIONS(2457), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2807), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3097), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3101), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3103), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3105), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3141), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(3099), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [96553] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2453), 1,
      anon_sym_LPAREN,
    ACTIONS(2459), 1,
      anon_sym_LBRACK,
    ACTIONS(3137), 1,
      anon_sym_PIPE,
    ACTIONS(3139), 1,
      anon_sym_CARET,
    ACTIONS(3143), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3145), 1,
      anon_sym_AMP,
    ACTIONS(3147), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3149), 1,
      anon_sym_QMARK,
    STATE(904), 1,
      sym_hll_argument_list,
    ACTIONS(2283), 2,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
    ACTIONS(2457), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2807), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3097), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3101), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3103), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3105), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3141), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(3099), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [96621] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2453), 1,
      anon_sym_LPAREN,
    ACTIONS(2459), 1,
      anon_sym_LBRACK,
    ACTIONS(3137), 1,
      anon_sym_PIPE,
    ACTIONS(3139), 1,
      anon_sym_CARET,
    ACTIONS(3143), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3145), 1,
      anon_sym_AMP,
    ACTIONS(3147), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3149), 1,
      anon_sym_QMARK,
    STATE(904), 1,
      sym_hll_argument_list,
    ACTIONS(2291), 2,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
    ACTIONS(2457), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2807), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3097), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3101), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3103), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3105), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3141), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(3099), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [96689] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2453), 1,
      anon_sym_LPAREN,
    ACTIONS(2459), 1,
      anon_sym_LBRACK,
    ACTIONS(3137), 1,
      anon_sym_PIPE,
    ACTIONS(3139), 1,
      anon_sym_CARET,
    ACTIONS(3143), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3145), 1,
      anon_sym_AMP,
    ACTIONS(3147), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3149), 1,
      anon_sym_QMARK,
    STATE(904), 1,
      sym_hll_argument_list,
    ACTIONS(2295), 2,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
    ACTIONS(2457), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2807), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3097), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3101), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3103), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3105), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3141), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(3099), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [96757] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1802), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(1804), 19,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [96793] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2453), 1,
      anon_sym_LPAREN,
    ACTIONS(2459), 1,
      anon_sym_LBRACK,
    ACTIONS(3137), 1,
      anon_sym_PIPE,
    ACTIONS(3139), 1,
      anon_sym_CARET,
    ACTIONS(3143), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3145), 1,
      anon_sym_AMP,
    ACTIONS(3147), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3149), 1,
      anon_sym_QMARK,
    STATE(904), 1,
      sym_hll_argument_list,
    ACTIONS(2299), 2,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
    ACTIONS(2457), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2807), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3097), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3101), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3103), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3105), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3141), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(3099), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [96861] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2453), 1,
      anon_sym_LPAREN,
    ACTIONS(2459), 1,
      anon_sym_LBRACK,
    ACTIONS(3137), 1,
      anon_sym_PIPE,
    ACTIONS(3139), 1,
      anon_sym_CARET,
    ACTIONS(3143), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3145), 1,
      anon_sym_AMP,
    ACTIONS(3147), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3149), 1,
      anon_sym_QMARK,
    STATE(904), 1,
      sym_hll_argument_list,
    ACTIONS(2303), 2,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
    ACTIONS(2457), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2807), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3097), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3101), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3103), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3105), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3141), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(3099), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [96929] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2978), 1,
      anon_sym_LPAREN,
    ACTIONS(2980), 1,
      anon_sym_EQ,
    ACTIONS(2986), 1,
      anon_sym_CARET_CARET,
    ACTIONS(2988), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2992), 1,
      anon_sym_PIPE,
    ACTIONS(2994), 1,
      anon_sym_CARET,
    ACTIONS(3002), 1,
      anon_sym_DOT_DOT,
    ACTIONS(3006), 1,
      sym__and_operator_pre_hook,
    ACTIONS(3153), 1,
      sym__blank,
    STATE(1033), 1,
      sym_argument_list,
    STATE(2054), 1,
      aux_sym_block_repeat1,
    ACTIONS(2982), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2984), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2998), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3000), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3151), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
    ACTIONS(2990), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2996), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
  [96997] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2941), 1,
      anon_sym_LPAREN,
    ACTIONS(2943), 1,
      anon_sym_EQ,
    ACTIONS(2949), 1,
      anon_sym_CARET_CARET,
    ACTIONS(2951), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2955), 1,
      anon_sym_SLASH,
    ACTIONS(2957), 1,
      anon_sym_PIPE,
    ACTIONS(2959), 1,
      anon_sym_CARET,
    ACTIONS(2967), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2974), 1,
      sym__and_operator_pre_hook,
    ACTIONS(2976), 1,
      sym__blank,
    STATE(1055), 1,
      sym_argument_list,
    STATE(2063), 1,
      aux_sym_block_repeat1,
    ACTIONS(2945), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2947), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2953), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(2963), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2965), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3156), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(2961), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
  [97067] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2941), 1,
      anon_sym_LPAREN,
    ACTIONS(2943), 1,
      anon_sym_EQ,
    ACTIONS(2949), 1,
      anon_sym_CARET_CARET,
    ACTIONS(2951), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2955), 1,
      anon_sym_SLASH,
    ACTIONS(2957), 1,
      anon_sym_PIPE,
    ACTIONS(2959), 1,
      anon_sym_CARET,
    ACTIONS(2967), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2974), 1,
      sym__and_operator_pre_hook,
    ACTIONS(2976), 1,
      sym__blank,
    STATE(1055), 1,
      sym_argument_list,
    STATE(2063), 1,
      aux_sym_block_repeat1,
    ACTIONS(2945), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2947), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2953), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(2963), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2965), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3158), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(2961), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
  [97137] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2443), 1,
      anon_sym_LPAREN,
    ACTIONS(2451), 1,
      anon_sym_LBRACK,
    STATE(917), 1,
      sym_hll_argument_list,
    ACTIONS(2449), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2561), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2215), 7,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
    ACTIONS(2213), 14,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      sym_comment,
      sym__blank_line,
  [97183] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2443), 1,
      anon_sym_LPAREN,
    ACTIONS(2451), 1,
      anon_sym_LBRACK,
    STATE(917), 1,
      sym_hll_argument_list,
    ACTIONS(2449), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2561), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2233), 7,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
    ACTIONS(2231), 14,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      sym_comment,
      sym__blank_line,
  [97229] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2049), 7,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2051), 21,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [97265] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2443), 1,
      anon_sym_LPAREN,
    ACTIONS(2451), 1,
      anon_sym_LBRACK,
    ACTIONS(3111), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3115), 1,
      anon_sym_SLASH,
    ACTIONS(3117), 1,
      anon_sym_PIPE,
    ACTIONS(3119), 1,
      anon_sym_CARET,
    ACTIONS(3129), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3131), 1,
      anon_sym_AMP,
    ACTIONS(3133), 1,
      anon_sym_QMARK,
    STATE(917), 1,
      sym_hll_argument_list,
    ACTIONS(2449), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2561), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3109), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3113), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(3121), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(3123), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3125), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3127), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3160), 2,
      sym_comment,
      sym__blank_line,
  [97335] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1802), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1804), 21,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP,
      anon_sym_COMMA,
      sym__blank,
  [97371] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2941), 1,
      anon_sym_LPAREN,
    ACTIONS(2943), 1,
      anon_sym_EQ,
    ACTIONS(2949), 1,
      anon_sym_CARET_CARET,
    ACTIONS(2951), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2955), 1,
      anon_sym_SLASH,
    ACTIONS(2957), 1,
      anon_sym_PIPE,
    ACTIONS(2959), 1,
      anon_sym_CARET,
    ACTIONS(2967), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2974), 1,
      sym__and_operator_pre_hook,
    ACTIONS(2976), 1,
      sym__blank,
    STATE(1055), 1,
      sym_argument_list,
    STATE(2063), 1,
      aux_sym_block_repeat1,
    ACTIONS(2945), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2947), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2953), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(2963), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2965), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3162), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(2961), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
  [97441] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2035), 7,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2037), 21,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [97477] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1880), 1,
      anon_sym_LPAREN,
    ACTIONS(1883), 1,
      anon_sym_DOT,
    STATE(2196), 1,
      aux_sym__function_identifier_repeat1,
    ACTIONS(2789), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(1635), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(1637), 14,
      sym__and_operator_pre_hook,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
  [97521] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1687), 1,
      sym_path,
    ACTIONS(2007), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2009), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [97559] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2443), 1,
      anon_sym_LPAREN,
    ACTIONS(2451), 1,
      anon_sym_LBRACK,
    ACTIONS(3111), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3115), 1,
      anon_sym_SLASH,
    ACTIONS(3117), 1,
      anon_sym_PIPE,
    ACTIONS(3119), 1,
      anon_sym_CARET,
    ACTIONS(3129), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3131), 1,
      anon_sym_AMP,
    ACTIONS(3133), 1,
      anon_sym_QMARK,
    STATE(917), 1,
      sym_hll_argument_list,
    ACTIONS(2283), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(2449), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2561), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3109), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3113), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(3121), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(3123), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3125), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3127), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
  [97629] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1791), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(1793), 19,
      sym__and_operator_pre_hook,
      sym_path,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [97665] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2443), 1,
      anon_sym_LPAREN,
    ACTIONS(2451), 1,
      anon_sym_LBRACK,
    ACTIONS(3111), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3115), 1,
      anon_sym_SLASH,
    ACTIONS(3117), 1,
      anon_sym_PIPE,
    ACTIONS(3119), 1,
      anon_sym_CARET,
    ACTIONS(3129), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3131), 1,
      anon_sym_AMP,
    ACTIONS(3133), 1,
      anon_sym_QMARK,
    STATE(917), 1,
      sym_hll_argument_list,
    ACTIONS(2291), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(2449), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2561), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3109), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3113), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(3121), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(3123), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3125), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3127), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
  [97735] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2443), 1,
      anon_sym_LPAREN,
    ACTIONS(2451), 1,
      anon_sym_LBRACK,
    ACTIONS(3111), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3115), 1,
      anon_sym_SLASH,
    ACTIONS(3117), 1,
      anon_sym_PIPE,
    ACTIONS(3119), 1,
      anon_sym_CARET,
    ACTIONS(3129), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3131), 1,
      anon_sym_AMP,
    ACTIONS(3133), 1,
      anon_sym_QMARK,
    STATE(917), 1,
      sym_hll_argument_list,
    ACTIONS(2295), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(2449), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2561), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3109), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3113), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(3121), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(3123), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3125), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3127), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
  [97805] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2659), 1,
      sym_path,
    ACTIONS(2007), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(2009), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [97843] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2941), 1,
      anon_sym_LPAREN,
    ACTIONS(2943), 1,
      anon_sym_EQ,
    ACTIONS(2949), 1,
      anon_sym_CARET_CARET,
    ACTIONS(2951), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2955), 1,
      anon_sym_SLASH,
    ACTIONS(2957), 1,
      anon_sym_PIPE,
    ACTIONS(2959), 1,
      anon_sym_CARET,
    ACTIONS(2967), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2974), 1,
      sym__and_operator_pre_hook,
    ACTIONS(2976), 1,
      sym__blank,
    STATE(1055), 1,
      sym_argument_list,
    STATE(2063), 1,
      aux_sym_block_repeat1,
    ACTIONS(2945), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2947), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2953), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(2963), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2965), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3164), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(2961), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
  [97913] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2978), 1,
      anon_sym_LPAREN,
    ACTIONS(2980), 1,
      anon_sym_EQ,
    ACTIONS(2986), 1,
      anon_sym_CARET_CARET,
    ACTIONS(2988), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2992), 1,
      anon_sym_PIPE,
    ACTIONS(2994), 1,
      anon_sym_CARET,
    ACTIONS(3002), 1,
      anon_sym_DOT_DOT,
    ACTIONS(3006), 1,
      sym__and_operator_pre_hook,
    ACTIONS(3168), 1,
      sym__blank,
    STATE(1033), 1,
      sym_argument_list,
    STATE(2054), 1,
      aux_sym_block_repeat1,
    ACTIONS(2982), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2984), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2998), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3000), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3166), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
    ACTIONS(2990), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2996), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
  [97981] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1880), 1,
      anon_sym_LPAREN,
    ACTIONS(1883), 1,
      anon_sym_DOT,
    ACTIONS(2878), 1,
      sym__blank,
    STATE(2196), 1,
      aux_sym__function_identifier_repeat1,
    ACTIONS(2789), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(1635), 8,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1637), 14,
      sym__and_operator_pre_hook,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
  [98027] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2415), 7,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2413), 21,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [98063] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2453), 1,
      anon_sym_LPAREN,
    ACTIONS(2459), 1,
      anon_sym_LBRACK,
    STATE(904), 1,
      sym_hll_argument_list,
    ACTIONS(2457), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2807), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3105), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2241), 6,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
    ACTIONS(2239), 13,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [98111] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2395), 7,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2393), 21,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [98147] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2453), 1,
      anon_sym_LPAREN,
    ACTIONS(2459), 1,
      anon_sym_LBRACK,
    ACTIONS(3137), 1,
      anon_sym_PIPE,
    ACTIONS(3139), 1,
      anon_sym_CARET,
    ACTIONS(3143), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3145), 1,
      anon_sym_AMP,
    ACTIONS(3147), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3149), 1,
      anon_sym_QMARK,
    STATE(904), 1,
      sym_hll_argument_list,
    ACTIONS(2457), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2587), 2,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
    ACTIONS(2807), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3097), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3101), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3103), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3105), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3141), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(3099), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [98215] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2443), 1,
      anon_sym_LPAREN,
    ACTIONS(2451), 1,
      anon_sym_LBRACK,
    STATE(917), 1,
      sym_hll_argument_list,
    ACTIONS(2449), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2311), 7,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
    ACTIONS(2309), 16,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      sym_comment,
      sym__blank_line,
  [98259] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2941), 1,
      anon_sym_LPAREN,
    ACTIONS(2943), 1,
      anon_sym_EQ,
    ACTIONS(2949), 1,
      anon_sym_CARET_CARET,
    ACTIONS(2951), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2955), 1,
      anon_sym_SLASH,
    ACTIONS(2957), 1,
      anon_sym_PIPE,
    ACTIONS(2959), 1,
      anon_sym_CARET,
    ACTIONS(2967), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2974), 1,
      sym__and_operator_pre_hook,
    ACTIONS(2976), 1,
      sym__blank,
    STATE(1055), 1,
      sym_argument_list,
    STATE(2063), 1,
      aux_sym_block_repeat1,
    ACTIONS(2945), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2947), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2953), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(2963), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2965), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3171), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(2961), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
  [98329] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2443), 1,
      anon_sym_LPAREN,
    ACTIONS(2451), 1,
      anon_sym_LBRACK,
    STATE(917), 1,
      sym_hll_argument_list,
    ACTIONS(2449), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2561), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2289), 7,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
    ACTIONS(2287), 14,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      sym_comment,
      sym__blank_line,
  [98375] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2379), 7,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2377), 21,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [98411] = 11,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2443), 1,
      anon_sym_LPAREN,
    ACTIONS(2451), 1,
      anon_sym_LBRACK,
    ACTIONS(3115), 1,
      anon_sym_SLASH,
    STATE(917), 1,
      sym_hll_argument_list,
    ACTIONS(2449), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2561), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3113), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(3127), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2201), 6,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
    ACTIONS(2197), 10,
      anon_sym_PIPE_PIPE,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      sym_comment,
      sym__blank_line,
  [98463] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2443), 1,
      anon_sym_LPAREN,
    ACTIONS(2451), 1,
      anon_sym_LBRACK,
    ACTIONS(3115), 1,
      anon_sym_SLASH,
    ACTIONS(3117), 1,
      anon_sym_PIPE,
    ACTIONS(3119), 1,
      anon_sym_CARET,
    ACTIONS(3129), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3131), 1,
      anon_sym_AMP,
    STATE(917), 1,
      sym_hll_argument_list,
    ACTIONS(2449), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2561), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3109), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3113), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(3121), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(3123), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3125), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3127), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2197), 4,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK,
      sym_comment,
      sym__blank_line,
  [98529] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2443), 1,
      anon_sym_LPAREN,
    ACTIONS(2451), 1,
      anon_sym_LBRACK,
    STATE(917), 1,
      sym_hll_argument_list,
    ACTIONS(2449), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2561), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3127), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2201), 7,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
    ACTIONS(2197), 12,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      sym_comment,
      sym__blank_line,
  [98577] = 17,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2201), 1,
      anon_sym_PIPE,
    ACTIONS(2443), 1,
      anon_sym_LPAREN,
    ACTIONS(2451), 1,
      anon_sym_LBRACK,
    ACTIONS(3115), 1,
      anon_sym_SLASH,
    ACTIONS(3119), 1,
      anon_sym_CARET,
    ACTIONS(3131), 1,
      anon_sym_AMP,
    STATE(917), 1,
      sym_hll_argument_list,
    ACTIONS(2449), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2561), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3109), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3113), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(3121), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(3123), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3125), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3127), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2197), 5,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      sym_comment,
      sym__blank_line,
  [98641] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1603), 1,
      sym__blank,
    STATE(800), 1,
      aux_sym_block_repeat1,
    ACTIONS(2655), 6,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BSLASH,
      anon_sym_sizeof,
      aux_sym_symbol_token2,
      sym_identifier,
    ACTIONS(2657), 20,
      sym__hll_number_literal_pre_hook,
      anon_sym_LPAREN,
      anon_sym_TILDE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      aux_sym_symbol_token1,
  [98681] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2443), 1,
      anon_sym_LPAREN,
    ACTIONS(2451), 1,
      anon_sym_LBRACK,
    STATE(917), 1,
      sym_hll_argument_list,
    ACTIONS(2449), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2561), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3127), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2241), 7,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
    ACTIONS(2239), 12,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      sym_comment,
      sym__blank_line,
  [98729] = 16,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2201), 1,
      anon_sym_PIPE,
    ACTIONS(2443), 1,
      anon_sym_LPAREN,
    ACTIONS(2451), 1,
      anon_sym_LBRACK,
    ACTIONS(3115), 1,
      anon_sym_SLASH,
    ACTIONS(3131), 1,
      anon_sym_AMP,
    STATE(917), 1,
      sym_hll_argument_list,
    ACTIONS(2449), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2561), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3109), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3113), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(3121), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(3123), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3125), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3127), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2197), 6,
      anon_sym_PIPE_PIPE,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      sym_comment,
      sym__blank_line,
  [98791] = 14,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2443), 1,
      anon_sym_LPAREN,
    ACTIONS(2451), 1,
      anon_sym_LBRACK,
    ACTIONS(3115), 1,
      anon_sym_SLASH,
    STATE(917), 1,
      sym_hll_argument_list,
    ACTIONS(2201), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(2449), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2561), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3109), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3113), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(3123), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3125), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3127), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2197), 8,
      anon_sym_PIPE_PIPE,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      sym_comment,
      sym__blank_line,
  [98849] = 12,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2443), 1,
      anon_sym_LPAREN,
    ACTIONS(2451), 1,
      anon_sym_LBRACK,
    ACTIONS(3115), 1,
      anon_sym_SLASH,
    STATE(917), 1,
      sym_hll_argument_list,
    ACTIONS(2449), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2561), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3109), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3113), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(3127), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2201), 4,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
    ACTIONS(2197), 10,
      anon_sym_PIPE_PIPE,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      sym_comment,
      sym__blank_line,
  [98903] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2387), 7,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2385), 21,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [98939] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2391), 7,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2389), 21,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [98975] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2443), 1,
      anon_sym_LPAREN,
    ACTIONS(2451), 1,
      anon_sym_LBRACK,
    STATE(917), 1,
      sym_hll_argument_list,
    ACTIONS(2449), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2561), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2201), 7,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
    ACTIONS(2197), 14,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      sym_comment,
      sym__blank_line,
  [99021] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3173), 1,
      aux_sym_symbol_token3,
    ACTIONS(1889), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1891), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [99059] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1987), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1989), 21,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_symbol_token3,
      sym__blank,
  [99095] = 17,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2443), 1,
      anon_sym_LPAREN,
    ACTIONS(2451), 1,
      anon_sym_LBRACK,
    ACTIONS(3115), 1,
      anon_sym_SLASH,
    ACTIONS(3117), 1,
      anon_sym_PIPE,
    ACTIONS(3119), 1,
      anon_sym_CARET,
    ACTIONS(3131), 1,
      anon_sym_AMP,
    STATE(917), 1,
      sym_hll_argument_list,
    ACTIONS(2449), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2561), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3109), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3113), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(3121), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(3123), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3125), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3127), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2197), 5,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      sym_comment,
      sym__blank_line,
  [99159] = 15,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2443), 1,
      anon_sym_LPAREN,
    ACTIONS(2451), 1,
      anon_sym_LBRACK,
    ACTIONS(3115), 1,
      anon_sym_SLASH,
    STATE(917), 1,
      sym_hll_argument_list,
    ACTIONS(2201), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(2449), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2561), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3109), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3113), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(3121), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(3123), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3125), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3127), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2197), 6,
      anon_sym_PIPE_PIPE,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      sym_comment,
      sym__blank_line,
  [99219] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2941), 1,
      anon_sym_LPAREN,
    ACTIONS(2943), 1,
      anon_sym_EQ,
    ACTIONS(2949), 1,
      anon_sym_CARET_CARET,
    ACTIONS(2951), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2955), 1,
      anon_sym_SLASH,
    ACTIONS(2957), 1,
      anon_sym_PIPE,
    ACTIONS(2959), 1,
      anon_sym_CARET,
    ACTIONS(2967), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2974), 1,
      sym__and_operator_pre_hook,
    ACTIONS(2976), 1,
      sym__blank,
    STATE(1055), 1,
      sym_argument_list,
    STATE(2063), 1,
      aux_sym_block_repeat1,
    ACTIONS(2945), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2947), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2953), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(2963), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2965), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3175), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(2961), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
  [99289] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3181), 1,
      anon_sym_EQ,
    ACTIONS(3183), 1,
      sym__blank,
    STATE(2053), 1,
      aux_sym_block_repeat1,
    ACTIONS(3177), 9,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(3179), 16,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
  [99331] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2443), 1,
      anon_sym_LPAREN,
    ACTIONS(2451), 1,
      anon_sym_LBRACK,
    ACTIONS(3111), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3115), 1,
      anon_sym_SLASH,
    ACTIONS(3117), 1,
      anon_sym_PIPE,
    ACTIONS(3119), 1,
      anon_sym_CARET,
    ACTIONS(3129), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3131), 1,
      anon_sym_AMP,
    ACTIONS(3133), 1,
      anon_sym_QMARK,
    STATE(917), 1,
      sym_hll_argument_list,
    ACTIONS(2449), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2561), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3109), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3113), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(3121), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(3123), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3125), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3127), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3175), 2,
      sym_comment,
      sym__blank_line,
  [99401] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2941), 1,
      anon_sym_LPAREN,
    ACTIONS(2943), 1,
      anon_sym_EQ,
    ACTIONS(2949), 1,
      anon_sym_CARET_CARET,
    ACTIONS(2951), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2955), 1,
      anon_sym_SLASH,
    ACTIONS(2957), 1,
      anon_sym_PIPE,
    ACTIONS(2959), 1,
      anon_sym_CARET,
    ACTIONS(2967), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2974), 1,
      sym__and_operator_pre_hook,
    ACTIONS(2976), 1,
      sym__blank,
    STATE(1055), 1,
      sym_argument_list,
    STATE(2063), 1,
      aux_sym_block_repeat1,
    ACTIONS(2945), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2947), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2953), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(2963), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2965), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3185), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(2961), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
  [99471] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2941), 1,
      anon_sym_LPAREN,
    ACTIONS(2943), 1,
      anon_sym_EQ,
    ACTIONS(2949), 1,
      anon_sym_CARET_CARET,
    ACTIONS(2951), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2955), 1,
      anon_sym_SLASH,
    ACTIONS(2957), 1,
      anon_sym_PIPE,
    ACTIONS(2959), 1,
      anon_sym_CARET,
    ACTIONS(2967), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2974), 1,
      sym__and_operator_pre_hook,
    ACTIONS(2976), 1,
      sym__blank,
    STATE(1055), 1,
      sym_argument_list,
    STATE(2063), 1,
      aux_sym_block_repeat1,
    ACTIONS(2945), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2947), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2953), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(2963), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2965), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3187), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(2961), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
  [99541] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2443), 1,
      anon_sym_LPAREN,
    ACTIONS(2451), 1,
      anon_sym_LBRACK,
    ACTIONS(3111), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3115), 1,
      anon_sym_SLASH,
    ACTIONS(3117), 1,
      anon_sym_PIPE,
    ACTIONS(3119), 1,
      anon_sym_CARET,
    ACTIONS(3129), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3131), 1,
      anon_sym_AMP,
    ACTIONS(3133), 1,
      anon_sym_QMARK,
    STATE(917), 1,
      sym_hll_argument_list,
    ACTIONS(2449), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2561), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3109), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3113), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(3121), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(3123), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3125), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3127), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3187), 2,
      sym_comment,
      sym__blank_line,
  [99611] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2443), 1,
      anon_sym_LPAREN,
    ACTIONS(2451), 1,
      anon_sym_LBRACK,
    ACTIONS(3111), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3115), 1,
      anon_sym_SLASH,
    ACTIONS(3117), 1,
      anon_sym_PIPE,
    ACTIONS(3119), 1,
      anon_sym_CARET,
    ACTIONS(3129), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3131), 1,
      anon_sym_AMP,
    ACTIONS(3133), 1,
      anon_sym_QMARK,
    STATE(917), 1,
      sym_hll_argument_list,
    ACTIONS(2449), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2561), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3109), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3113), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(3121), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(3123), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3125), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3127), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3185), 2,
      sym_comment,
      sym__blank_line,
  [99681] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2941), 1,
      anon_sym_LPAREN,
    ACTIONS(2943), 1,
      anon_sym_EQ,
    ACTIONS(2949), 1,
      anon_sym_CARET_CARET,
    ACTIONS(2951), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2955), 1,
      anon_sym_SLASH,
    ACTIONS(2957), 1,
      anon_sym_PIPE,
    ACTIONS(2959), 1,
      anon_sym_CARET,
    ACTIONS(2967), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2974), 1,
      sym__and_operator_pre_hook,
    ACTIONS(2976), 1,
      sym__blank,
    STATE(1055), 1,
      sym_argument_list,
    STATE(2063), 1,
      aux_sym_block_repeat1,
    ACTIONS(2945), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2947), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2953), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(2963), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2965), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3189), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(2961), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
  [99751] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2941), 1,
      anon_sym_LPAREN,
    ACTIONS(2943), 1,
      anon_sym_EQ,
    ACTIONS(2949), 1,
      anon_sym_CARET_CARET,
    ACTIONS(2951), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2955), 1,
      anon_sym_SLASH,
    ACTIONS(2957), 1,
      anon_sym_PIPE,
    ACTIONS(2959), 1,
      anon_sym_CARET,
    ACTIONS(2967), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2974), 1,
      sym__and_operator_pre_hook,
    ACTIONS(2976), 1,
      sym__blank,
    STATE(1055), 1,
      sym_argument_list,
    STATE(2063), 1,
      aux_sym_block_repeat1,
    ACTIONS(2945), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2947), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2953), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(2963), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2965), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3191), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(2961), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
  [99821] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2978), 1,
      anon_sym_LPAREN,
    ACTIONS(2980), 1,
      anon_sym_EQ,
    ACTIONS(2986), 1,
      anon_sym_CARET_CARET,
    ACTIONS(2988), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2992), 1,
      anon_sym_PIPE,
    ACTIONS(2994), 1,
      anon_sym_CARET,
    ACTIONS(3002), 1,
      anon_sym_DOT_DOT,
    ACTIONS(3006), 1,
      sym__and_operator_pre_hook,
    ACTIONS(3195), 1,
      sym__blank,
    STATE(1033), 1,
      sym_argument_list,
    STATE(2054), 1,
      aux_sym_block_repeat1,
    ACTIONS(2982), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2984), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2998), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3000), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3193), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
    ACTIONS(2990), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2996), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
  [99889] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2011), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2013), 21,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_symbol_token3,
      sym__blank,
  [99925] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2941), 1,
      anon_sym_LPAREN,
    ACTIONS(2943), 1,
      anon_sym_EQ,
    ACTIONS(2949), 1,
      anon_sym_CARET_CARET,
    ACTIONS(2951), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2955), 1,
      anon_sym_SLASH,
    ACTIONS(2957), 1,
      anon_sym_PIPE,
    ACTIONS(2959), 1,
      anon_sym_CARET,
    ACTIONS(2967), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2974), 1,
      sym__and_operator_pre_hook,
    ACTIONS(2976), 1,
      sym__blank,
    STATE(1055), 1,
      sym_argument_list,
    STATE(2063), 1,
      aux_sym_block_repeat1,
    ACTIONS(2945), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2947), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2953), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(2963), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2965), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3198), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(2961), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
  [99995] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3200), 1,
      aux_sym_symbol_token3,
    ACTIONS(1889), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(1891), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [100033] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1987), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(1989), 19,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_symbol_token3,
      sym_comment,
      sym__blank_line,
  [100069] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2941), 1,
      anon_sym_LPAREN,
    ACTIONS(2943), 1,
      anon_sym_EQ,
    ACTIONS(2949), 1,
      anon_sym_CARET_CARET,
    ACTIONS(2951), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2955), 1,
      anon_sym_SLASH,
    ACTIONS(2957), 1,
      anon_sym_PIPE,
    ACTIONS(2959), 1,
      anon_sym_CARET,
    ACTIONS(2967), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2974), 1,
      sym__and_operator_pre_hook,
    ACTIONS(2976), 1,
      sym__blank,
    STATE(1055), 1,
      sym_argument_list,
    STATE(2063), 1,
      aux_sym_block_repeat1,
    ACTIONS(2945), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2947), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2953), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(2963), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2965), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3202), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(2961), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
  [100139] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2443), 1,
      anon_sym_LPAREN,
    ACTIONS(2451), 1,
      anon_sym_LBRACK,
    ACTIONS(3111), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3115), 1,
      anon_sym_SLASH,
    ACTIONS(3117), 1,
      anon_sym_PIPE,
    ACTIONS(3119), 1,
      anon_sym_CARET,
    ACTIONS(3129), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3131), 1,
      anon_sym_AMP,
    ACTIONS(3133), 1,
      anon_sym_QMARK,
    STATE(917), 1,
      sym_hll_argument_list,
    ACTIONS(2449), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2561), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3109), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3113), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(3121), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(3123), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3125), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3127), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3202), 2,
      sym_comment,
      sym__blank_line,
  [100209] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2941), 1,
      anon_sym_LPAREN,
    ACTIONS(2943), 1,
      anon_sym_EQ,
    ACTIONS(2949), 1,
      anon_sym_CARET_CARET,
    ACTIONS(2951), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2955), 1,
      anon_sym_SLASH,
    ACTIONS(2957), 1,
      anon_sym_PIPE,
    ACTIONS(2959), 1,
      anon_sym_CARET,
    ACTIONS(2967), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2974), 1,
      sym__and_operator_pre_hook,
    ACTIONS(2976), 1,
      sym__blank,
    STATE(1055), 1,
      sym_argument_list,
    STATE(2063), 1,
      aux_sym_block_repeat1,
    ACTIONS(2945), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2947), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2953), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(2963), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2965), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3204), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(2961), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
  [100279] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2443), 1,
      anon_sym_LPAREN,
    ACTIONS(2451), 1,
      anon_sym_LBRACK,
    ACTIONS(3111), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3115), 1,
      anon_sym_SLASH,
    ACTIONS(3117), 1,
      anon_sym_PIPE,
    ACTIONS(3119), 1,
      anon_sym_CARET,
    ACTIONS(3129), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3131), 1,
      anon_sym_AMP,
    ACTIONS(3133), 1,
      anon_sym_QMARK,
    STATE(917), 1,
      sym_hll_argument_list,
    ACTIONS(2449), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2561), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3109), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3113), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(3121), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(3123), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3125), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3127), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3204), 2,
      sym_comment,
      sym__blank_line,
  [100349] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2011), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(2013), 19,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_symbol_token3,
      sym_comment,
      sym__blank_line,
  [100385] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2443), 1,
      anon_sym_LPAREN,
    ACTIONS(2451), 1,
      anon_sym_LBRACK,
    STATE(917), 1,
      sym_hll_argument_list,
    ACTIONS(2449), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2561), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2225), 7,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
    ACTIONS(2223), 14,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      sym_comment,
      sym__blank_line,
  [100431] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2443), 1,
      anon_sym_LPAREN,
    ACTIONS(2451), 1,
      anon_sym_LBRACK,
    ACTIONS(3111), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3115), 1,
      anon_sym_SLASH,
    ACTIONS(3117), 1,
      anon_sym_PIPE,
    ACTIONS(3119), 1,
      anon_sym_CARET,
    ACTIONS(3129), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3131), 1,
      anon_sym_AMP,
    ACTIONS(3133), 1,
      anon_sym_QMARK,
    STATE(917), 1,
      sym_hll_argument_list,
    ACTIONS(2275), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(2449), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2561), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3109), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3113), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(3121), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(3123), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3125), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3127), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
  [100501] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2941), 1,
      anon_sym_LPAREN,
    ACTIONS(2943), 1,
      anon_sym_EQ,
    ACTIONS(2949), 1,
      anon_sym_CARET_CARET,
    ACTIONS(2951), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2955), 1,
      anon_sym_SLASH,
    ACTIONS(2957), 1,
      anon_sym_PIPE,
    ACTIONS(2959), 1,
      anon_sym_CARET,
    ACTIONS(2967), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2974), 1,
      sym__and_operator_pre_hook,
    ACTIONS(2976), 1,
      sym__blank,
    STATE(1055), 1,
      sym_argument_list,
    STATE(2063), 1,
      aux_sym_block_repeat1,
    ACTIONS(2945), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2947), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2953), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(2963), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2965), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3206), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(2961), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
  [100571] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2443), 1,
      anon_sym_LPAREN,
    ACTIONS(2451), 1,
      anon_sym_LBRACK,
    ACTIONS(3111), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3115), 1,
      anon_sym_SLASH,
    ACTIONS(3117), 1,
      anon_sym_PIPE,
    ACTIONS(3119), 1,
      anon_sym_CARET,
    ACTIONS(3129), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3131), 1,
      anon_sym_AMP,
    ACTIONS(3133), 1,
      anon_sym_QMARK,
    STATE(917), 1,
      sym_hll_argument_list,
    ACTIONS(2449), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2561), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3109), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3113), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(3121), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(3123), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3125), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3127), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3206), 2,
      sym_comment,
      sym__blank_line,
  [100641] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1647), 1,
      anon_sym_COLON_COLON_COLON,
    ACTIONS(1687), 1,
      sym_path,
    ACTIONS(2789), 1,
      sym__blank,
    ACTIONS(1645), 2,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
    ACTIONS(1635), 3,
      anon_sym_EQ,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1639), 4,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
    ACTIONS(1642), 6,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT_DOT,
    ACTIONS(1637), 10,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
  [100689] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2443), 1,
      anon_sym_LPAREN,
    ACTIONS(2451), 1,
      anon_sym_LBRACK,
    STATE(917), 1,
      sym_hll_argument_list,
    ACTIONS(2449), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2561), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2229), 7,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
    ACTIONS(2227), 14,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      sym_comment,
      sym__blank_line,
  [100735] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2941), 1,
      anon_sym_LPAREN,
    ACTIONS(2943), 1,
      anon_sym_EQ,
    ACTIONS(2949), 1,
      anon_sym_CARET_CARET,
    ACTIONS(2951), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2955), 1,
      anon_sym_SLASH,
    ACTIONS(2957), 1,
      anon_sym_PIPE,
    ACTIONS(2959), 1,
      anon_sym_CARET,
    ACTIONS(2967), 1,
      anon_sym_DOT_DOT,
    ACTIONS(2974), 1,
      sym__and_operator_pre_hook,
    ACTIONS(2976), 1,
      sym__blank,
    STATE(1055), 1,
      sym_argument_list,
    STATE(2063), 1,
      aux_sym_block_repeat1,
    ACTIONS(2945), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2947), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2953), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(2963), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2965), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3160), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(2961), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
  [100805] = 16,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1815), 1,
      anon_sym_EQ,
    ACTIONS(2978), 1,
      anon_sym_LPAREN,
    ACTIONS(3214), 1,
      anon_sym_PIPE,
    ACTIONS(3216), 1,
      anon_sym_CARET,
    ACTIONS(3224), 1,
      anon_sym_DOT_DOT,
    ACTIONS(3226), 1,
      sym__and_operator_pre_hook,
    STATE(1033), 1,
      sym_argument_list,
    STATE(2197), 1,
      aux_sym_block_repeat1,
    ACTIONS(3208), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3210), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3220), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3222), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3212), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1817), 4,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_COMMA,
      sym__blank,
    ACTIONS(3218), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
  [100866] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2199), 1,
      anon_sym_LPAREN,
    ACTIONS(2209), 1,
      anon_sym_LBRACK,
    ACTIONS(3065), 1,
      anon_sym_PIPE,
    ACTIONS(3067), 1,
      anon_sym_CARET,
    ACTIONS(3075), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3077), 1,
      anon_sym_AMP,
    ACTIONS(3082), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3084), 1,
      anon_sym_QMARK,
    ACTIONS(3228), 1,
      anon_sym_RBRACK,
    STATE(752), 1,
      sym_hll_argument_list,
    ACTIONS(2207), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2561), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3033), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3063), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3069), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(3071), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3073), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3061), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [100933] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2978), 1,
      anon_sym_LPAREN,
    ACTIONS(2980), 1,
      anon_sym_EQ,
    ACTIONS(2986), 1,
      anon_sym_CARET_CARET,
    ACTIONS(2988), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2992), 1,
      anon_sym_PIPE,
    ACTIONS(2994), 1,
      anon_sym_CARET,
    ACTIONS(3002), 1,
      anon_sym_DOT_DOT,
    ACTIONS(3004), 1,
      sym__blank,
    ACTIONS(3006), 1,
      sym__and_operator_pre_hook,
    ACTIONS(3230), 1,
      anon_sym_RPAREN,
    STATE(1033), 1,
      sym_argument_list,
    STATE(2054), 1,
      aux_sym_block_repeat1,
    ACTIONS(2982), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2984), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2998), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3000), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2990), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2996), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
  [101000] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2978), 1,
      anon_sym_LPAREN,
    ACTIONS(2980), 1,
      anon_sym_EQ,
    ACTIONS(2986), 1,
      anon_sym_CARET_CARET,
    ACTIONS(2988), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2992), 1,
      anon_sym_PIPE,
    ACTIONS(2994), 1,
      anon_sym_CARET,
    ACTIONS(3002), 1,
      anon_sym_DOT_DOT,
    ACTIONS(3004), 1,
      sym__blank,
    ACTIONS(3006), 1,
      sym__and_operator_pre_hook,
    ACTIONS(3230), 1,
      anon_sym_RBRACE,
    STATE(1033), 1,
      sym_argument_list,
    STATE(2054), 1,
      aux_sym_block_repeat1,
    ACTIONS(2982), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2984), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2998), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3000), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2990), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2996), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
  [101067] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2978), 1,
      anon_sym_LPAREN,
    ACTIONS(2980), 1,
      anon_sym_EQ,
    ACTIONS(2986), 1,
      anon_sym_CARET_CARET,
    ACTIONS(2988), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2992), 1,
      anon_sym_PIPE,
    ACTIONS(2994), 1,
      anon_sym_CARET,
    ACTIONS(3002), 1,
      anon_sym_DOT_DOT,
    ACTIONS(3004), 1,
      sym__blank,
    ACTIONS(3006), 1,
      sym__and_operator_pre_hook,
    ACTIONS(3232), 1,
      anon_sym_RBRACE,
    STATE(1033), 1,
      sym_argument_list,
    STATE(2054), 1,
      aux_sym_block_repeat1,
    ACTIONS(2982), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2984), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2998), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3000), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2990), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2996), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
  [101134] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2199), 1,
      anon_sym_LPAREN,
    ACTIONS(2209), 1,
      anon_sym_LBRACK,
    ACTIONS(3065), 1,
      anon_sym_PIPE,
    ACTIONS(3067), 1,
      anon_sym_CARET,
    ACTIONS(3075), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3077), 1,
      anon_sym_AMP,
    ACTIONS(3082), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3084), 1,
      anon_sym_QMARK,
    ACTIONS(3234), 1,
      anon_sym_RPAREN,
    STATE(752), 1,
      sym_hll_argument_list,
    ACTIONS(2207), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2561), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3033), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3063), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3069), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(3071), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3073), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3061), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [101201] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2199), 1,
      anon_sym_LPAREN,
    ACTIONS(2209), 1,
      anon_sym_LBRACK,
    ACTIONS(3065), 1,
      anon_sym_PIPE,
    ACTIONS(3067), 1,
      anon_sym_CARET,
    ACTIONS(3075), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3077), 1,
      anon_sym_AMP,
    ACTIONS(3082), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3084), 1,
      anon_sym_QMARK,
    ACTIONS(3236), 1,
      anon_sym_RBRACK,
    STATE(752), 1,
      sym_hll_argument_list,
    ACTIONS(2207), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2561), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3033), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3063), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3069), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(3071), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3073), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3061), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [101268] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2199), 1,
      anon_sym_LPAREN,
    ACTIONS(2209), 1,
      anon_sym_LBRACK,
    ACTIONS(3065), 1,
      anon_sym_PIPE,
    ACTIONS(3067), 1,
      anon_sym_CARET,
    ACTIONS(3075), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3077), 1,
      anon_sym_AMP,
    ACTIONS(3082), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3084), 1,
      anon_sym_QMARK,
    ACTIONS(3238), 1,
      anon_sym_RPAREN,
    STATE(752), 1,
      sym_hll_argument_list,
    ACTIONS(2207), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2561), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3033), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3063), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3069), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(3071), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3073), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3061), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [101335] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2199), 1,
      anon_sym_LPAREN,
    ACTIONS(2209), 1,
      anon_sym_LBRACK,
    ACTIONS(3065), 1,
      anon_sym_PIPE,
    ACTIONS(3067), 1,
      anon_sym_CARET,
    ACTIONS(3075), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3077), 1,
      anon_sym_AMP,
    ACTIONS(3082), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3084), 1,
      anon_sym_QMARK,
    ACTIONS(3240), 1,
      anon_sym_RPAREN,
    STATE(752), 1,
      sym_hll_argument_list,
    ACTIONS(2207), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2561), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3033), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3063), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3069), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(3071), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3073), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3061), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [101402] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2199), 1,
      anon_sym_LPAREN,
    ACTIONS(2209), 1,
      anon_sym_LBRACK,
    ACTIONS(3065), 1,
      anon_sym_PIPE,
    ACTIONS(3067), 1,
      anon_sym_CARET,
    ACTIONS(3075), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3077), 1,
      anon_sym_AMP,
    ACTIONS(3082), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3084), 1,
      anon_sym_QMARK,
    ACTIONS(3242), 1,
      anon_sym_COLON,
    STATE(752), 1,
      sym_hll_argument_list,
    ACTIONS(2207), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2561), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3033), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3063), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3069), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(3071), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3073), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3061), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [101469] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2199), 1,
      anon_sym_LPAREN,
    ACTIONS(2209), 1,
      anon_sym_LBRACK,
    ACTIONS(3065), 1,
      anon_sym_PIPE,
    ACTIONS(3067), 1,
      anon_sym_CARET,
    ACTIONS(3075), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3077), 1,
      anon_sym_AMP,
    ACTIONS(3082), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3084), 1,
      anon_sym_QMARK,
    ACTIONS(3244), 1,
      anon_sym_RBRACK,
    STATE(752), 1,
      sym_hll_argument_list,
    ACTIONS(2207), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2561), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3033), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3063), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3069), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(3071), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3073), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3061), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [101536] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2199), 1,
      anon_sym_LPAREN,
    ACTIONS(2209), 1,
      anon_sym_LBRACK,
    ACTIONS(3065), 1,
      anon_sym_PIPE,
    ACTIONS(3067), 1,
      anon_sym_CARET,
    ACTIONS(3075), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3077), 1,
      anon_sym_AMP,
    ACTIONS(3082), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3084), 1,
      anon_sym_QMARK,
    ACTIONS(3246), 1,
      anon_sym_COLON,
    STATE(752), 1,
      sym_hll_argument_list,
    ACTIONS(2207), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2561), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3033), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3063), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3069), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(3071), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3073), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3061), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [101603] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2095), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2097), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [101638] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2061), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(2063), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [101673] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2053), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2055), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [101708] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2049), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(2051), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [101743] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2071), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(2073), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [101778] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2087), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2089), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [101813] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2099), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2101), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [101848] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2065), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(2067), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [101883] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2057), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(2059), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [101918] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3252), 1,
      aux_sym_while_block_token1,
    STATE(1991), 1,
      aux_sym_subroutine_block_repeat1,
    ACTIONS(3255), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(3248), 7,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
    ACTIONS(3250), 16,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [101959] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2199), 1,
      anon_sym_LPAREN,
    ACTIONS(2209), 1,
      anon_sym_LBRACK,
    ACTIONS(3065), 1,
      anon_sym_PIPE,
    ACTIONS(3067), 1,
      anon_sym_CARET,
    ACTIONS(3075), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3077), 1,
      anon_sym_AMP,
    ACTIONS(3082), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3084), 1,
      anon_sym_QMARK,
    ACTIONS(3258), 1,
      anon_sym_COLON,
    STATE(752), 1,
      sym_hll_argument_list,
    ACTIONS(2207), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2561), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3033), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3063), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3069), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(3071), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3073), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3061), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [102026] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2199), 1,
      anon_sym_LPAREN,
    ACTIONS(2209), 1,
      anon_sym_LBRACK,
    ACTIONS(3065), 1,
      anon_sym_PIPE,
    ACTIONS(3067), 1,
      anon_sym_CARET,
    ACTIONS(3075), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3077), 1,
      anon_sym_AMP,
    ACTIONS(3082), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3084), 1,
      anon_sym_QMARK,
    ACTIONS(3260), 1,
      anon_sym_COLON,
    STATE(752), 1,
      sym_hll_argument_list,
    ACTIONS(2207), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2561), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3033), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3063), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3069), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(3071), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3073), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3061), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [102093] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2199), 1,
      anon_sym_LPAREN,
    ACTIONS(2209), 1,
      anon_sym_LBRACK,
    ACTIONS(3065), 1,
      anon_sym_PIPE,
    ACTIONS(3067), 1,
      anon_sym_CARET,
    ACTIONS(3075), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3077), 1,
      anon_sym_AMP,
    ACTIONS(3082), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3084), 1,
      anon_sym_QMARK,
    ACTIONS(3262), 1,
      anon_sym_COLON,
    STATE(752), 1,
      sym_hll_argument_list,
    ACTIONS(2207), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2561), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3033), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3063), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3069), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(3071), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3073), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3061), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [102160] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2969), 1,
      anon_sym_COMMA,
    ACTIONS(2978), 1,
      anon_sym_LPAREN,
    ACTIONS(3214), 1,
      anon_sym_PIPE,
    ACTIONS(3216), 1,
      anon_sym_CARET,
    ACTIONS(3224), 1,
      anon_sym_DOT_DOT,
    ACTIONS(3226), 1,
      sym__and_operator_pre_hook,
    ACTIONS(3264), 1,
      anon_sym_EQ,
    ACTIONS(3266), 1,
      anon_sym_CARET_CARET,
    ACTIONS(3268), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3270), 1,
      sym__blank,
    STATE(1033), 1,
      sym_argument_list,
    STATE(2197), 1,
      aux_sym_block_repeat1,
    ACTIONS(3208), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3210), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3220), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3222), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3212), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(3218), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
  [102227] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3277), 1,
      aux_sym_while_block_token1,
    STATE(1998), 1,
      aux_sym_subroutine_block_repeat1,
    ACTIONS(3280), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(3273), 7,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
    ACTIONS(3275), 16,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [102268] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2199), 1,
      anon_sym_LPAREN,
    ACTIONS(2209), 1,
      anon_sym_LBRACK,
    ACTIONS(3065), 1,
      anon_sym_PIPE,
    ACTIONS(3067), 1,
      anon_sym_CARET,
    ACTIONS(3075), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3077), 1,
      anon_sym_AMP,
    ACTIONS(3082), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3084), 1,
      anon_sym_QMARK,
    ACTIONS(3283), 1,
      anon_sym_COLON,
    STATE(752), 1,
      sym_hll_argument_list,
    ACTIONS(2207), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2561), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3033), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3063), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3069), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(3071), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3073), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3061), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [102335] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3289), 1,
      anon_sym_RPAREN,
    ACTIONS(3285), 9,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      aux_sym_while_block_token2,
      anon_sym_EQ,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(3287), 17,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [102372] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2199), 1,
      anon_sym_LPAREN,
    ACTIONS(2209), 1,
      anon_sym_LBRACK,
    ACTIONS(3065), 1,
      anon_sym_PIPE,
    ACTIONS(3067), 1,
      anon_sym_CARET,
    ACTIONS(3075), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3077), 1,
      anon_sym_AMP,
    ACTIONS(3082), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3084), 1,
      anon_sym_QMARK,
    ACTIONS(3291), 1,
      anon_sym_COLON,
    STATE(752), 1,
      sym_hll_argument_list,
    ACTIONS(2207), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2561), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3033), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3063), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3069), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(3071), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3073), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3061), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [102439] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3285), 10,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_EQ,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(3287), 17,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [102474] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3293), 10,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_EQ,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(3295), 17,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [102509] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2199), 1,
      anon_sym_LPAREN,
    ACTIONS(2209), 1,
      anon_sym_LBRACK,
    ACTIONS(3065), 1,
      anon_sym_PIPE,
    ACTIONS(3067), 1,
      anon_sym_CARET,
    ACTIONS(3075), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3077), 1,
      anon_sym_AMP,
    ACTIONS(3082), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3084), 1,
      anon_sym_QMARK,
    ACTIONS(3297), 1,
      anon_sym_COLON,
    STATE(752), 1,
      sym_hll_argument_list,
    ACTIONS(2207), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2561), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3033), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3063), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3069), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(3071), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3073), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3061), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [102576] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2199), 1,
      anon_sym_LPAREN,
    ACTIONS(2209), 1,
      anon_sym_LBRACK,
    ACTIONS(3065), 1,
      anon_sym_PIPE,
    ACTIONS(3067), 1,
      anon_sym_CARET,
    ACTIONS(3075), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3077), 1,
      anon_sym_AMP,
    ACTIONS(3082), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3084), 1,
      anon_sym_QMARK,
    ACTIONS(3299), 1,
      anon_sym_COLON,
    STATE(752), 1,
      sym_hll_argument_list,
    ACTIONS(2207), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2561), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3033), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3063), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3069), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(3071), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3073), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3061), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [102643] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2057), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(2059), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [102678] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2978), 1,
      anon_sym_LPAREN,
    ACTIONS(2980), 1,
      anon_sym_EQ,
    ACTIONS(2986), 1,
      anon_sym_CARET_CARET,
    ACTIONS(2988), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2992), 1,
      anon_sym_PIPE,
    ACTIONS(2994), 1,
      anon_sym_CARET,
    ACTIONS(3002), 1,
      anon_sym_DOT_DOT,
    ACTIONS(3004), 1,
      sym__blank,
    ACTIONS(3006), 1,
      sym__and_operator_pre_hook,
    ACTIONS(3232), 1,
      anon_sym_RPAREN,
    STATE(1033), 1,
      sym_argument_list,
    STATE(2054), 1,
      aux_sym_block_repeat1,
    ACTIONS(2982), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2984), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2998), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3000), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2990), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2996), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
  [102745] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2061), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(2063), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [102780] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1787), 1,
      anon_sym_COMMA,
    ACTIONS(2978), 1,
      anon_sym_LPAREN,
    ACTIONS(3214), 1,
      anon_sym_PIPE,
    ACTIONS(3216), 1,
      anon_sym_CARET,
    ACTIONS(3224), 1,
      anon_sym_DOT_DOT,
    ACTIONS(3226), 1,
      sym__and_operator_pre_hook,
    ACTIONS(3264), 1,
      anon_sym_EQ,
    ACTIONS(3266), 1,
      anon_sym_CARET_CARET,
    ACTIONS(3268), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3301), 1,
      sym__blank,
    STATE(1033), 1,
      sym_argument_list,
    STATE(2197), 1,
      aux_sym_block_repeat1,
    ACTIONS(3208), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3210), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3220), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3222), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3212), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(3218), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
  [102847] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2978), 1,
      anon_sym_LPAREN,
    ACTIONS(3224), 1,
      anon_sym_DOT_DOT,
    STATE(1033), 1,
      sym_argument_list,
    STATE(2197), 1,
      aux_sym_block_repeat1,
    ACTIONS(3210), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3222), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3212), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1815), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1817), 9,
      sym__and_operator_pre_hook,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_COMMA,
      sym__blank,
  [102896] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2053), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(2055), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [102931] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2199), 1,
      anon_sym_LPAREN,
    ACTIONS(2209), 1,
      anon_sym_LBRACK,
    ACTIONS(3065), 1,
      anon_sym_PIPE,
    ACTIONS(3067), 1,
      anon_sym_CARET,
    ACTIONS(3075), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3077), 1,
      anon_sym_AMP,
    ACTIONS(3082), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3084), 1,
      anon_sym_QMARK,
    ACTIONS(3303), 1,
      anon_sym_RBRACK,
    STATE(752), 1,
      sym_hll_argument_list,
    ACTIONS(2207), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2561), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3033), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3063), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3069), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(3071), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3073), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3061), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [102998] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2057), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2059), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [103033] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2057), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2059), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [103068] = 17,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1815), 1,
      anon_sym_EQ,
    ACTIONS(2978), 1,
      anon_sym_LPAREN,
    ACTIONS(3214), 1,
      anon_sym_PIPE,
    ACTIONS(3216), 1,
      anon_sym_CARET,
    ACTIONS(3224), 1,
      anon_sym_DOT_DOT,
    ACTIONS(3226), 1,
      sym__and_operator_pre_hook,
    ACTIONS(3266), 1,
      anon_sym_CARET_CARET,
    STATE(1033), 1,
      sym_argument_list,
    STATE(2197), 1,
      aux_sym_block_repeat1,
    ACTIONS(3208), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3210), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3220), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3222), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(1817), 3,
      anon_sym_PIPE_PIPE,
      anon_sym_COMMA,
      sym__blank,
    ACTIONS(3212), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(3218), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
  [103131] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2035), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2037), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [103166] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2978), 1,
      anon_sym_LPAREN,
    ACTIONS(3224), 1,
      anon_sym_DOT_DOT,
    STATE(1033), 1,
      sym_argument_list,
    STATE(2197), 1,
      aux_sym_block_repeat1,
    ACTIONS(3210), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3222), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(1815), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1817), 12,
      sym__and_operator_pre_hook,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_COMMA,
      sym__blank,
  [103213] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2061), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2063), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [103248] = 15,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2978), 1,
      anon_sym_LPAREN,
    ACTIONS(3216), 1,
      anon_sym_CARET,
    ACTIONS(3224), 1,
      anon_sym_DOT_DOT,
    ACTIONS(3305), 1,
      sym__and_operator_pre_hook,
    STATE(1033), 1,
      sym_argument_list,
    STATE(2197), 1,
      aux_sym_block_repeat1,
    ACTIONS(1815), 2,
      anon_sym_EQ,
      anon_sym_PIPE,
    ACTIONS(3208), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3210), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3220), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3222), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3212), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1817), 4,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_COMMA,
      sym__blank,
    ACTIONS(3218), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
  [103307] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2061), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2063), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [103342] = 14,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2978), 1,
      anon_sym_LPAREN,
    ACTIONS(3224), 1,
      anon_sym_DOT_DOT,
    ACTIONS(3305), 1,
      sym__and_operator_pre_hook,
    STATE(1033), 1,
      sym_argument_list,
    STATE(2197), 1,
      aux_sym_block_repeat1,
    ACTIONS(3208), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3210), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3220), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3222), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(1815), 3,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
    ACTIONS(3212), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1817), 4,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_COMMA,
      sym__blank,
    ACTIONS(3218), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
  [103399] = 11,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2978), 1,
      anon_sym_LPAREN,
    ACTIONS(3224), 1,
      anon_sym_DOT_DOT,
    STATE(1033), 1,
      sym_argument_list,
    STATE(2197), 1,
      aux_sym_block_repeat1,
    ACTIONS(3208), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3210), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3222), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3212), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1815), 5,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1817), 9,
      sym__and_operator_pre_hook,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_COMMA,
      sym__blank,
  [103450] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2978), 1,
      anon_sym_LPAREN,
    ACTIONS(3224), 1,
      anon_sym_DOT_DOT,
    STATE(1033), 1,
      sym_argument_list,
    STATE(2197), 1,
      aux_sym_block_repeat1,
    ACTIONS(3210), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1798), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1800), 14,
      sym__and_operator_pre_hook,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COMMA,
      sym__blank,
  [103495] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3224), 1,
      anon_sym_DOT_DOT,
    STATE(1033), 1,
      sym_argument_list,
    STATE(2197), 1,
      aux_sym_block_repeat1,
    ACTIONS(3210), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1826), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1828), 15,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COMMA,
      sym__blank,
  [103538] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    STATE(1033), 1,
      sym_argument_list,
    STATE(2197), 1,
      aux_sym_block_repeat1,
    ACTIONS(1815), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1817), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [103577] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2065), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2067), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [103612] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2978), 1,
      anon_sym_LPAREN,
    ACTIONS(3224), 1,
      anon_sym_DOT_DOT,
    STATE(1033), 1,
      sym_argument_list,
    STATE(2197), 1,
      aux_sym_block_repeat1,
    ACTIONS(3210), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1815), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1817), 14,
      sym__and_operator_pre_hook,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COMMA,
      sym__blank,
  [103657] = 16,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1872), 1,
      anon_sym_EQ,
    ACTIONS(2978), 1,
      anon_sym_LPAREN,
    ACTIONS(3214), 1,
      anon_sym_PIPE,
    ACTIONS(3216), 1,
      anon_sym_CARET,
    ACTIONS(3224), 1,
      anon_sym_DOT_DOT,
    ACTIONS(3226), 1,
      sym__and_operator_pre_hook,
    STATE(1033), 1,
      sym_argument_list,
    STATE(2197), 1,
      aux_sym_block_repeat1,
    ACTIONS(3208), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3210), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3220), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3222), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3212), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1874), 4,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_COMMA,
      sym__blank,
    ACTIONS(3218), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
  [103718] = 13,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2978), 1,
      anon_sym_LPAREN,
    ACTIONS(3224), 1,
      anon_sym_DOT_DOT,
    STATE(1033), 1,
      sym_argument_list,
    STATE(2197), 1,
      aux_sym_block_repeat1,
    ACTIONS(3208), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3210), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3220), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3222), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(1872), 3,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
    ACTIONS(3212), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(3218), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(1874), 5,
      sym__and_operator_pre_hook,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_COMMA,
      sym__blank,
  [103773] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1887), 1,
      anon_sym_COMMA,
    ACTIONS(2978), 1,
      anon_sym_LPAREN,
    ACTIONS(3214), 1,
      anon_sym_PIPE,
    ACTIONS(3216), 1,
      anon_sym_CARET,
    ACTIONS(3224), 1,
      anon_sym_DOT_DOT,
    ACTIONS(3226), 1,
      sym__and_operator_pre_hook,
    ACTIONS(3264), 1,
      anon_sym_EQ,
    ACTIONS(3266), 1,
      anon_sym_CARET_CARET,
    ACTIONS(3268), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3301), 1,
      sym__blank,
    STATE(1033), 1,
      sym_argument_list,
    STATE(2197), 1,
      aux_sym_block_repeat1,
    ACTIONS(3208), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3210), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3220), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3222), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3212), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(3218), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
  [103840] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2071), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2073), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [103875] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2199), 1,
      anon_sym_LPAREN,
    ACTIONS(2209), 1,
      anon_sym_LBRACK,
    ACTIONS(3065), 1,
      anon_sym_PIPE,
    ACTIONS(3067), 1,
      anon_sym_CARET,
    ACTIONS(3075), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3077), 1,
      anon_sym_AMP,
    ACTIONS(3082), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3084), 1,
      anon_sym_QMARK,
    ACTIONS(3308), 1,
      anon_sym_COLON,
    STATE(752), 1,
      sym_hll_argument_list,
    ACTIONS(2207), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2561), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3033), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3063), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3069), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(3071), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3073), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3061), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [103942] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2095), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(2097), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [103977] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2035), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(2037), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [104012] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2099), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(2101), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [104047] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1878), 1,
      anon_sym_COMMA,
    ACTIONS(2978), 1,
      anon_sym_LPAREN,
    ACTIONS(3214), 1,
      anon_sym_PIPE,
    ACTIONS(3216), 1,
      anon_sym_CARET,
    ACTIONS(3224), 1,
      anon_sym_DOT_DOT,
    ACTIONS(3226), 1,
      sym__and_operator_pre_hook,
    ACTIONS(3264), 1,
      anon_sym_EQ,
    ACTIONS(3266), 1,
      anon_sym_CARET_CARET,
    ACTIONS(3268), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3301), 1,
      sym__blank,
    STATE(1033), 1,
      sym_argument_list,
    STATE(2197), 1,
      aux_sym_block_repeat1,
    ACTIONS(3208), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3210), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3220), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3222), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3212), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(3218), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
  [104114] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1821), 1,
      anon_sym_COMMA,
    ACTIONS(2978), 1,
      anon_sym_LPAREN,
    ACTIONS(3214), 1,
      anon_sym_PIPE,
    ACTIONS(3216), 1,
      anon_sym_CARET,
    ACTIONS(3224), 1,
      anon_sym_DOT_DOT,
    ACTIONS(3226), 1,
      sym__and_operator_pre_hook,
    ACTIONS(3264), 1,
      anon_sym_EQ,
    ACTIONS(3266), 1,
      anon_sym_CARET_CARET,
    ACTIONS(3268), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3301), 1,
      sym__blank,
    STATE(1033), 1,
      sym_argument_list,
    STATE(2197), 1,
      aux_sym_block_repeat1,
    ACTIONS(3208), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3210), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3220), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3222), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3212), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(3218), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
  [104181] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1545), 1,
      aux_sym_block_token1,
    ACTIONS(3314), 1,
      sym__blank,
    STATE(1429), 1,
      aux_sym_block_repeat1,
    ACTIONS(3310), 8,
      sym_label_identifier,
      ts_builtin_sym_end,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(3312), 16,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
  [104222] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3320), 1,
      anon_sym_RPAREN,
    ACTIONS(3316), 9,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      aux_sym_while_block_token2,
      anon_sym_EQ,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(3318), 17,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [104259] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2978), 1,
      anon_sym_LPAREN,
    ACTIONS(2980), 1,
      anon_sym_EQ,
    ACTIONS(2986), 1,
      anon_sym_CARET_CARET,
    ACTIONS(2988), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2992), 1,
      anon_sym_PIPE,
    ACTIONS(2994), 1,
      anon_sym_CARET,
    ACTIONS(3002), 1,
      anon_sym_DOT_DOT,
    ACTIONS(3004), 1,
      sym__blank,
    ACTIONS(3006), 1,
      sym__and_operator_pre_hook,
    ACTIONS(3322), 1,
      anon_sym_RPAREN,
    STATE(1033), 1,
      sym_argument_list,
    STATE(2054), 1,
      aux_sym_block_repeat1,
    ACTIONS(2982), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2984), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2998), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3000), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2990), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2996), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
  [104326] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2978), 1,
      anon_sym_LPAREN,
    ACTIONS(2980), 1,
      anon_sym_EQ,
    ACTIONS(2986), 1,
      anon_sym_CARET_CARET,
    ACTIONS(2988), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2992), 1,
      anon_sym_PIPE,
    ACTIONS(2994), 1,
      anon_sym_CARET,
    ACTIONS(3002), 1,
      anon_sym_DOT_DOT,
    ACTIONS(3004), 1,
      sym__blank,
    ACTIONS(3006), 1,
      sym__and_operator_pre_hook,
    ACTIONS(3322), 1,
      anon_sym_RBRACE,
    STATE(1033), 1,
      sym_argument_list,
    STATE(2054), 1,
      aux_sym_block_repeat1,
    ACTIONS(2982), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2984), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2998), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3000), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2990), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2996), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
  [104393] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1545), 1,
      aux_sym_block_token1,
    ACTIONS(3314), 1,
      sym__blank,
    STATE(1429), 1,
      aux_sym_block_repeat1,
    ACTIONS(3310), 8,
      sym_label_identifier,
      ts_builtin_sym_end,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(3312), 16,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
  [104434] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3324), 1,
      sym__blank,
    STATE(1429), 1,
      aux_sym_block_repeat1,
    ACTIONS(2120), 9,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(2122), 16,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
  [104473] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2049), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2051), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [104508] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2087), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(2089), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [104543] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3327), 9,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(3329), 17,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [104577] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3331), 9,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(3333), 17,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [104611] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3335), 9,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(3337), 17,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [104645] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(228), 1,
      anon_sym_LPAREN,
    ACTIONS(3214), 1,
      anon_sym_PIPE,
    ACTIONS(3216), 1,
      anon_sym_CARET,
    ACTIONS(3224), 1,
      anon_sym_DOT_DOT,
    ACTIONS(3226), 1,
      sym__and_operator_pre_hook,
    ACTIONS(3264), 1,
      anon_sym_EQ,
    ACTIONS(3266), 1,
      anon_sym_CARET_CARET,
    ACTIONS(3268), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3301), 1,
      sym__blank,
    STATE(348), 1,
      sym_argument_list,
    STATE(2197), 1,
      aux_sym_block_repeat1,
    ACTIONS(3208), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3210), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3220), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3222), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3212), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(3218), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
  [104709] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3339), 9,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(3341), 17,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [104743] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3343), 9,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(3345), 17,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [104777] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3347), 9,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(3349), 17,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [104811] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3351), 9,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(3353), 17,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [104845] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3351), 9,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(3353), 17,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [104879] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3355), 9,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(3357), 17,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [104913] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3359), 9,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(3361), 17,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [104947] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3363), 9,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(3365), 17,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [104981] = 17,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(460), 1,
      anon_sym_struct,
    ACTIONS(462), 1,
      anon_sym_union,
    ACTIONS(464), 1,
      anon_sym_enum,
    ACTIONS(3367), 1,
      sym_identifier,
    ACTIONS(3369), 1,
      sym_hll_primitive_type,
    ACTIONS(3371), 1,
      sym__blank,
    STATE(952), 1,
      aux_sym_block_repeat1,
    STATE(1520), 1,
      aux_sym__hll_declaration_specifiers_repeat1,
    STATE(1589), 1,
      sym__hll_declaration_specifiers,
    STATE(1743), 1,
      aux_sym_hll_sized_type_specifier_repeat1,
    STATE(2232), 1,
      sym__var_definition_command_argument_list_format,
    STATE(2233), 1,
      sym_hll_declaration,
    ACTIONS(458), 2,
      anon_sym_const,
      anon_sym_volatile,
    STATE(2248), 2,
      sym_hll_type_qualifier,
      sym__hll_declaration_modifiers,
    ACTIONS(466), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(1750), 6,
      sym__hll_type_specifier,
      sym_hll_struct_specifier,
      sym_hll_union_specifier,
      sym_hll_enum_specifier,
      sym_hll_sized_type_specifier,
      sym__hll_type_identifier,
  [105043] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2770), 9,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(2772), 17,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [105077] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3373), 9,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(3375), 17,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [105111] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3377), 9,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(3379), 17,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [105145] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3381), 9,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(3383), 17,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [105179] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3385), 9,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(3387), 17,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [105213] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2878), 1,
      sym__blank,
    ACTIONS(2789), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(1635), 8,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1637), 15,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
  [105251] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3389), 9,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(3391), 17,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [105285] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3393), 9,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(3395), 17,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [105319] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3385), 9,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(3387), 17,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [105353] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2978), 1,
      anon_sym_LPAREN,
    ACTIONS(3214), 1,
      anon_sym_PIPE,
    ACTIONS(3216), 1,
      anon_sym_CARET,
    ACTIONS(3224), 1,
      anon_sym_DOT_DOT,
    ACTIONS(3226), 1,
      sym__and_operator_pre_hook,
    ACTIONS(3264), 1,
      anon_sym_EQ,
    ACTIONS(3266), 1,
      anon_sym_CARET_CARET,
    ACTIONS(3268), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3301), 1,
      sym__blank,
    STATE(1033), 1,
      sym_argument_list,
    STATE(2197), 1,
      aux_sym_block_repeat1,
    ACTIONS(3208), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3210), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3220), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3222), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3212), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(3218), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
  [105417] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3397), 9,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(3399), 17,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [105451] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3401), 9,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(3403), 17,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [105485] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3405), 9,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(3407), 17,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [105519] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3409), 9,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(3411), 17,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [105553] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3413), 9,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(3415), 17,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [105587] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3316), 9,
      sym_label_identifier,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_EQ,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(3318), 17,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [105621] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3310), 9,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(3312), 17,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [105655] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3417), 9,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(3419), 17,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [105689] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3421), 9,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(3423), 17,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [105723] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3425), 9,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(3427), 17,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [105757] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3425), 9,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(3427), 17,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [105791] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3429), 9,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(3431), 17,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [105825] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3429), 9,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(3431), 17,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [105859] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3433), 9,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(3435), 17,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [105893] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3327), 9,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(3329), 17,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [105927] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3437), 9,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(3439), 17,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [105961] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3441), 9,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(3443), 17,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [105995] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3445), 9,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(3447), 17,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [106029] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3449), 9,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(3451), 17,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [106063] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3453), 9,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(3455), 17,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [106097] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3457), 9,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(3459), 17,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [106131] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3457), 9,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(3459), 17,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [106165] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3457), 9,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(3459), 17,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [106199] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3457), 9,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(3459), 17,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [106233] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3461), 9,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(3463), 17,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [106267] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3461), 9,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(3463), 17,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [106301] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3465), 9,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(3467), 17,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [106335] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3469), 9,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(3471), 17,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [106369] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3469), 9,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(3471), 17,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [106403] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3473), 9,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(3475), 17,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [106437] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3477), 9,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(3479), 17,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [106471] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3481), 9,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(3483), 17,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [106505] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3477), 9,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(3479), 17,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [106539] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3310), 9,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(3312), 17,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [106573] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1880), 1,
      anon_sym_LPAREN,
    ACTIONS(1883), 1,
      anon_sym_DOT,
    ACTIONS(2789), 1,
      sym__blank,
    STATE(2196), 1,
      aux_sym__function_identifier_repeat1,
    ACTIONS(1635), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1637), 15,
      sym__and_operator_pre_hook,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
  [106615] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3477), 9,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(3479), 17,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [106649] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3046), 9,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(3048), 17,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [106683] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3477), 9,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(3479), 17,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [106717] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3485), 9,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(3487), 17,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [106751] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2697), 9,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(2699), 17,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [106785] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3485), 9,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(3487), 17,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [106819] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3331), 9,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(3333), 17,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [106853] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3489), 9,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(3491), 17,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [106887] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3493), 9,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(3495), 17,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [106921] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2789), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(1635), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(1637), 15,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
  [106957] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3497), 9,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(3499), 17,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [106991] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2941), 1,
      anon_sym_LPAREN,
    ACTIONS(3214), 1,
      anon_sym_PIPE,
    ACTIONS(3216), 1,
      anon_sym_CARET,
    ACTIONS(3224), 1,
      anon_sym_DOT_DOT,
    ACTIONS(3226), 1,
      sym__and_operator_pre_hook,
    ACTIONS(3264), 1,
      anon_sym_EQ,
    ACTIONS(3266), 1,
      anon_sym_CARET_CARET,
    ACTIONS(3268), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3301), 1,
      sym__blank,
    STATE(1055), 1,
      sym_argument_list,
    STATE(2197), 1,
      aux_sym_block_repeat1,
    ACTIONS(3208), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3210), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3220), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3222), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3212), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(3218), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
  [107055] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3481), 9,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(3483), 17,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [107089] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3010), 9,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(3012), 17,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [107123] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3501), 9,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(3503), 17,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [107157] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3425), 9,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(3427), 17,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [107191] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3425), 9,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(3427), 17,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [107225] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3331), 9,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(3333), 17,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [107259] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3331), 9,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(3333), 17,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [107293] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3285), 9,
      sym_label_identifier,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_EQ,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(3287), 17,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [107327] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3505), 6,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BSLASH,
      anon_sym_sizeof,
      aux_sym_symbol_token2,
      sym_identifier,
    ACTIONS(3507), 19,
      sym__hll_number_literal_pre_hook,
      anon_sym_LPAREN,
      anon_sym_TILDE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      aux_sym_symbol_token1,
  [107360] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    STATE(1511), 1,
      aux_sym_subroutine_block_repeat1,
    ACTIONS(3513), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(3511), 5,
      sym_label_identifier,
      aux_sym_block_token1,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
    ACTIONS(3509), 16,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [107396] = 15,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(460), 1,
      anon_sym_struct,
    ACTIONS(462), 1,
      anon_sym_union,
    ACTIONS(464), 1,
      anon_sym_enum,
    ACTIONS(3367), 1,
      sym_identifier,
    ACTIONS(3516), 1,
      anon_sym_RPAREN,
    ACTIONS(3518), 1,
      sym_hll_primitive_type,
    STATE(1521), 1,
      aux_sym__hll_declaration_specifiers_repeat1,
    STATE(1525), 1,
      sym__hll_declaration_specifiers,
    STATE(1743), 1,
      aux_sym_hll_sized_type_specifier_repeat1,
    STATE(2191), 1,
      sym_hll_parameter_declaration,
    ACTIONS(458), 2,
      anon_sym_const,
      anon_sym_volatile,
    STATE(2248), 2,
      sym_hll_type_qualifier,
      sym__hll_declaration_modifiers,
    ACTIONS(466), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(1681), 6,
      sym__hll_type_specifier,
      sym_hll_struct_specifier,
      sym_hll_union_specifier,
      sym_hll_enum_specifier,
      sym_hll_sized_type_specifier,
      sym__hll_type_identifier,
  [107452] = 22,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7), 1,
      sym_identifier,
    ACTIONS(35), 1,
      aux_sym__host_command_with_default_format_token1,
    ACTIONS(3522), 1,
      aux_sym_parameter_declaration_token3,
    ACTIONS(3524), 1,
      aux_sym_subroutine_call_expression_token1,
    ACTIONS(3526), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    STATE(1981), 1,
      sym__hll_var_command_with_default_format,
    STATE(1982), 1,
      sym__var_command_with_non_hll_format,
    STATE(2020), 1,
      sym__command_identifier,
    STATE(2121), 1,
      sym_macro_definition_command,
    STATE(2243), 1,
      sym__hll_default_format_var_command,
    STATE(2265), 1,
      sym__host_command,
    STATE(2267), 1,
      sym__other_command,
    STATE(2271), 1,
      sym__hll_var_definition_command_expression,
    STATE(2285), 1,
      sym__hll_non_default_format_var_command,
    STATE(2288), 1,
      sym__var_command,
    STATE(2298), 1,
      sym__hll_var_command,
    STATE(2314), 1,
      sym__non_hll_var_command,
    STATE(2336), 1,
      sym__hll_var_definition_command,
    STATE(2340), 1,
      sym__host_command_with_default_format,
    ACTIONS(3520), 2,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
    ACTIONS(33), 3,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
  [107522] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2789), 1,
      sym__blank,
    ACTIONS(1635), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1637), 16,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
  [107556] = 15,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(460), 1,
      anon_sym_struct,
    ACTIONS(462), 1,
      anon_sym_union,
    ACTIONS(464), 1,
      anon_sym_enum,
    ACTIONS(3367), 1,
      sym_identifier,
    ACTIONS(3518), 1,
      sym_hll_primitive_type,
    ACTIONS(3528), 1,
      anon_sym_RPAREN,
    STATE(1521), 1,
      aux_sym__hll_declaration_specifiers_repeat1,
    STATE(1525), 1,
      sym__hll_declaration_specifiers,
    STATE(1743), 1,
      aux_sym_hll_sized_type_specifier_repeat1,
    STATE(2206), 1,
      sym_hll_parameter_declaration,
    ACTIONS(458), 2,
      anon_sym_const,
      anon_sym_volatile,
    STATE(2248), 2,
      sym_hll_type_qualifier,
      sym__hll_declaration_modifiers,
    ACTIONS(466), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(1681), 6,
      sym__hll_type_specifier,
      sym_hll_struct_specifier,
      sym_hll_union_specifier,
      sym_hll_enum_specifier,
      sym_hll_sized_type_specifier,
      sym__hll_type_identifier,
  [107612] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3530), 1,
      sym__blank,
    STATE(1516), 1,
      aux_sym_block_repeat1,
    ACTIONS(2120), 7,
      sym_label_identifier,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_EQ,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
    ACTIONS(2122), 15,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
  [107648] = 14,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(460), 1,
      anon_sym_struct,
    ACTIONS(462), 1,
      anon_sym_union,
    ACTIONS(464), 1,
      anon_sym_enum,
    ACTIONS(3367), 1,
      sym_identifier,
    ACTIONS(3518), 1,
      sym_hll_primitive_type,
    STATE(1521), 1,
      aux_sym__hll_declaration_specifiers_repeat1,
    STATE(1525), 1,
      sym__hll_declaration_specifiers,
    STATE(1743), 1,
      aux_sym_hll_sized_type_specifier_repeat1,
    STATE(2328), 1,
      sym_hll_parameter_declaration,
    ACTIONS(458), 2,
      anon_sym_const,
      anon_sym_volatile,
    STATE(2248), 2,
      sym_hll_type_qualifier,
      sym__hll_declaration_modifiers,
    ACTIONS(466), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(1681), 6,
      sym__hll_type_specifier,
      sym_hll_struct_specifier,
      sym_hll_union_specifier,
      sym_hll_enum_specifier,
      sym_hll_sized_type_specifier,
      sym__hll_type_identifier,
  [107701] = 13,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(460), 1,
      anon_sym_struct,
    ACTIONS(462), 1,
      anon_sym_union,
    ACTIONS(464), 1,
      anon_sym_enum,
    ACTIONS(3367), 1,
      sym_identifier,
    ACTIONS(3533), 1,
      sym_hll_primitive_type,
    ACTIONS(3535), 1,
      sym__blank,
    STATE(1524), 1,
      aux_sym_block_repeat1,
    STATE(1743), 1,
      aux_sym_hll_sized_type_specifier_repeat1,
    ACTIONS(458), 2,
      anon_sym_const,
      anon_sym_volatile,
    STATE(1565), 2,
      sym_hll_type_qualifier,
      aux_sym_hll_type_descriptor_repeat1,
    ACTIONS(466), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(1530), 6,
      sym__hll_type_specifier,
      sym_hll_struct_specifier,
      sym_hll_union_specifier,
      sym_hll_enum_specifier,
      sym_hll_sized_type_specifier,
      sym__hll_type_identifier,
  [107751] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3539), 6,
      sym_label_identifier,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(3537), 16,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [107781] = 12,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(460), 1,
      anon_sym_struct,
    ACTIONS(462), 1,
      anon_sym_union,
    ACTIONS(464), 1,
      anon_sym_enum,
    ACTIONS(3367), 1,
      sym_identifier,
    ACTIONS(3541), 1,
      sym_hll_primitive_type,
    STATE(1566), 1,
      aux_sym__hll_declaration_specifiers_repeat1,
    STATE(1743), 1,
      aux_sym_hll_sized_type_specifier_repeat1,
    ACTIONS(458), 2,
      anon_sym_const,
      anon_sym_volatile,
    STATE(2248), 2,
      sym_hll_type_qualifier,
      sym__hll_declaration_modifiers,
    ACTIONS(466), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(1736), 6,
      sym__hll_type_specifier,
      sym_hll_struct_specifier,
      sym_hll_union_specifier,
      sym_hll_enum_specifier,
      sym_hll_sized_type_specifier,
      sym__hll_type_identifier,
  [107828] = 12,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(460), 1,
      anon_sym_struct,
    ACTIONS(462), 1,
      anon_sym_union,
    ACTIONS(464), 1,
      anon_sym_enum,
    ACTIONS(3367), 1,
      sym_identifier,
    ACTIONS(3543), 1,
      sym_hll_primitive_type,
    STATE(1566), 1,
      aux_sym__hll_declaration_specifiers_repeat1,
    STATE(1743), 1,
      aux_sym_hll_sized_type_specifier_repeat1,
    ACTIONS(458), 2,
      anon_sym_const,
      anon_sym_volatile,
    STATE(2248), 2,
      sym_hll_type_qualifier,
      sym__hll_declaration_modifiers,
    ACTIONS(466), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(1684), 6,
      sym__hll_type_specifier,
      sym_hll_struct_specifier,
      sym_hll_union_specifier,
      sym_hll_enum_specifier,
      sym_hll_sized_type_specifier,
      sym__hll_type_identifier,
  [107875] = 11,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3547), 1,
      anon_sym_LPAREN,
    ACTIONS(3549), 1,
      anon_sym_STAR,
    ACTIONS(3551), 1,
      anon_sym_BSLASH,
    ACTIONS(3553), 1,
      anon_sym_LBRACK,
    ACTIONS(3555), 1,
      sym__blank,
    STATE(1523), 1,
      sym__hll_pointer_declarator_specifier,
    STATE(1577), 1,
      aux_sym_block_repeat1,
    ACTIONS(3545), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
    STATE(1747), 5,
      sym__hll_abstract_declarator,
      sym_hll_abstract_pointer_declarator,
      sym_hll_abstract_function_declarator,
      sym_hll_abstract_array_declarator,
      sym_hll_abstract_parenthesized_declarator,
    STATE(1776), 6,
      sym_trace32_hll_variable,
      sym__hll_declarator,
      sym_hll_pointer_declarator,
      sym_hll_function_declarator,
      sym_hll_array_declarator,
      sym_hll_parenthesized_declarator,
  [107919] = 11,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3547), 1,
      anon_sym_LPAREN,
    ACTIONS(3549), 1,
      anon_sym_STAR,
    ACTIONS(3551), 1,
      anon_sym_BSLASH,
    ACTIONS(3553), 1,
      anon_sym_LBRACK,
    ACTIONS(3559), 1,
      sym__blank,
    STATE(1522), 1,
      aux_sym_block_repeat1,
    STATE(1523), 1,
      sym__hll_pointer_declarator_specifier,
    ACTIONS(3557), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
    STATE(1752), 5,
      sym__hll_abstract_declarator,
      sym_hll_abstract_pointer_declarator,
      sym_hll_abstract_function_declarator,
      sym_hll_abstract_array_declarator,
      sym_hll_abstract_parenthesized_declarator,
    STATE(1807), 6,
      sym_trace32_hll_variable,
      sym__hll_declarator,
      sym_hll_pointer_declarator,
      sym_hll_function_declarator,
      sym_hll_array_declarator,
      sym_hll_parenthesized_declarator,
  [107963] = 11,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(460), 1,
      anon_sym_struct,
    ACTIONS(462), 1,
      anon_sym_union,
    ACTIONS(464), 1,
      anon_sym_enum,
    ACTIONS(3367), 1,
      sym_identifier,
    ACTIONS(3371), 1,
      sym__blank,
    ACTIONS(3561), 1,
      sym_hll_primitive_type,
    STATE(952), 1,
      aux_sym_block_repeat1,
    STATE(1743), 1,
      aux_sym_hll_sized_type_specifier_repeat1,
    ACTIONS(466), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(1537), 6,
      sym__hll_type_specifier,
      sym_hll_struct_specifier,
      sym_hll_union_specifier,
      sym_hll_enum_specifier,
      sym_hll_sized_type_specifier,
      sym__hll_type_identifier,
  [108005] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3547), 1,
      anon_sym_LPAREN,
    ACTIONS(3549), 1,
      anon_sym_STAR,
    ACTIONS(3551), 1,
      anon_sym_BSLASH,
    ACTIONS(3553), 1,
      anon_sym_LBRACK,
    STATE(1523), 1,
      sym__hll_pointer_declarator_specifier,
    ACTIONS(3563), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
    STATE(1721), 5,
      sym__hll_abstract_declarator,
      sym_hll_abstract_pointer_declarator,
      sym_hll_abstract_function_declarator,
      sym_hll_abstract_array_declarator,
      sym_hll_abstract_parenthesized_declarator,
    STATE(1768), 6,
      sym_trace32_hll_variable,
      sym__hll_declarator,
      sym_hll_pointer_declarator,
      sym_hll_function_declarator,
      sym_hll_array_declarator,
      sym_hll_parenthesized_declarator,
  [108043] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3044), 6,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      sym__blank,
    ACTIONS(3042), 12,
      anon_sym_BSLASH,
      anon_sym_const,
      anon_sym_volatile,
      anon_sym_struct,
      anon_sym_union,
      anon_sym_enum,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
      sym_hll_primitive_type,
      sym_identifier,
  [108069] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3547), 1,
      anon_sym_LPAREN,
    ACTIONS(3549), 1,
      anon_sym_STAR,
    ACTIONS(3551), 1,
      anon_sym_BSLASH,
    ACTIONS(3553), 1,
      anon_sym_LBRACK,
    ACTIONS(3555), 1,
      sym__blank,
    STATE(1523), 1,
      sym__hll_pointer_declarator_specifier,
    STATE(1577), 1,
      aux_sym_block_repeat1,
    STATE(1771), 5,
      sym__hll_abstract_declarator,
      sym_hll_abstract_pointer_declarator,
      sym_hll_abstract_function_declarator,
      sym_hll_abstract_array_declarator,
      sym_hll_abstract_parenthesized_declarator,
    STATE(1834), 6,
      sym_trace32_hll_variable,
      sym__hll_declarator,
      sym_hll_pointer_declarator,
      sym_hll_function_declarator,
      sym_hll_array_declarator,
      sym_hll_parenthesized_declarator,
  [108109] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3547), 1,
      anon_sym_LPAREN,
    ACTIONS(3549), 1,
      anon_sym_STAR,
    ACTIONS(3551), 1,
      anon_sym_BSLASH,
    ACTIONS(3553), 1,
      anon_sym_LBRACK,
    ACTIONS(3565), 1,
      sym__blank,
    STATE(1523), 1,
      sym__hll_pointer_declarator_specifier,
    STATE(1527), 1,
      aux_sym_block_repeat1,
    STATE(1797), 5,
      sym__hll_abstract_declarator,
      sym_hll_abstract_pointer_declarator,
      sym_hll_abstract_function_declarator,
      sym_hll_abstract_array_declarator,
      sym_hll_abstract_parenthesized_declarator,
    STATE(1828), 6,
      sym_trace32_hll_variable,
      sym__hll_declarator,
      sym_hll_pointer_declarator,
      sym_hll_function_declarator,
      sym_hll_array_declarator,
      sym_hll_parenthesized_declarator,
  [108149] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3573), 1,
      sym__decimal_number_pre_hook,
    ACTIONS(3575), 1,
      sym_hll_number_literal,
    ACTIONS(3571), 2,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
    STATE(2244), 3,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_integer,
    ACTIONS(3567), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(3569), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
  [108182] = 11,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3549), 1,
      anon_sym_STAR,
    ACTIONS(3577), 1,
      anon_sym_RPAREN,
    ACTIONS(3579), 1,
      anon_sym_LPAREN,
    ACTIONS(3581), 1,
      anon_sym_LBRACK,
    ACTIONS(3585), 1,
      sym__blank,
    STATE(1563), 1,
      aux_sym_block_repeat1,
    STATE(1662), 1,
      sym__hll_pointer_declarator_specifier,
    ACTIONS(3583), 2,
      anon_sym_const,
      anon_sym_volatile,
    STATE(1535), 2,
      sym_hll_type_qualifier,
      aux_sym_hll_type_descriptor_repeat2,
    STATE(1775), 5,
      sym__hll_abstract_declarator,
      sym_hll_abstract_pointer_declarator,
      sym_hll_abstract_function_declarator,
      sym_hll_abstract_array_declarator,
      sym_hll_abstract_parenthesized_declarator,
  [108222] = 11,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3549), 1,
      anon_sym_STAR,
    ACTIONS(3579), 1,
      anon_sym_LPAREN,
    ACTIONS(3581), 1,
      anon_sym_LBRACK,
    ACTIONS(3588), 1,
      anon_sym_RPAREN,
    ACTIONS(3591), 1,
      sym__blank,
    STATE(1562), 1,
      aux_sym_block_repeat1,
    STATE(1662), 1,
      sym__hll_pointer_declarator_specifier,
    ACTIONS(3583), 2,
      anon_sym_const,
      anon_sym_volatile,
    STATE(1536), 2,
      sym_hll_type_qualifier,
      aux_sym_hll_type_descriptor_repeat2,
    STATE(1806), 5,
      sym__hll_abstract_declarator,
      sym_hll_abstract_pointer_declarator,
      sym_hll_abstract_function_declarator,
      sym_hll_abstract_array_declarator,
      sym_hll_abstract_parenthesized_declarator,
  [108262] = 11,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3549), 1,
      anon_sym_STAR,
    ACTIONS(3579), 1,
      anon_sym_LPAREN,
    ACTIONS(3581), 1,
      anon_sym_LBRACK,
    ACTIONS(3595), 1,
      anon_sym_RPAREN,
    ACTIONS(3597), 1,
      sym__blank,
    STATE(1561), 1,
      aux_sym_block_repeat1,
    STATE(1662), 1,
      sym__hll_pointer_declarator_specifier,
    ACTIONS(3583), 2,
      anon_sym_const,
      anon_sym_volatile,
    STATE(1668), 2,
      sym_hll_type_qualifier,
      aux_sym_hll_type_descriptor_repeat2,
    STATE(1765), 5,
      sym__hll_abstract_declarator,
      sym_hll_abstract_pointer_declarator,
      sym_hll_abstract_function_declarator,
      sym_hll_abstract_array_declarator,
      sym_hll_abstract_parenthesized_declarator,
  [108302] = 11,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3549), 1,
      anon_sym_STAR,
    ACTIONS(3579), 1,
      anon_sym_LPAREN,
    ACTIONS(3581), 1,
      anon_sym_LBRACK,
    ACTIONS(3600), 1,
      anon_sym_RPAREN,
    ACTIONS(3602), 1,
      sym__blank,
    STATE(1558), 1,
      aux_sym_block_repeat1,
    STATE(1662), 1,
      sym__hll_pointer_declarator_specifier,
    ACTIONS(3583), 2,
      anon_sym_const,
      anon_sym_volatile,
    STATE(1668), 2,
      sym_hll_type_qualifier,
      aux_sym_hll_type_descriptor_repeat2,
    STATE(1781), 5,
      sym__hll_abstract_declarator,
      sym_hll_abstract_pointer_declarator,
      sym_hll_abstract_function_declarator,
      sym_hll_abstract_array_declarator,
      sym_hll_abstract_parenthesized_declarator,
  [108342] = 11,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3549), 1,
      anon_sym_STAR,
    ACTIONS(3579), 1,
      anon_sym_LPAREN,
    ACTIONS(3581), 1,
      anon_sym_LBRACK,
    ACTIONS(3605), 1,
      anon_sym_RPAREN,
    ACTIONS(3607), 1,
      sym__blank,
    STATE(1573), 1,
      aux_sym_block_repeat1,
    STATE(1662), 1,
      sym__hll_pointer_declarator_specifier,
    ACTIONS(3583), 2,
      anon_sym_const,
      anon_sym_volatile,
    STATE(1532), 2,
      sym_hll_type_qualifier,
      aux_sym_hll_type_descriptor_repeat2,
    STATE(1803), 5,
      sym__hll_abstract_declarator,
      sym_hll_abstract_pointer_declarator,
      sym_hll_abstract_function_declarator,
      sym_hll_abstract_array_declarator,
      sym_hll_abstract_parenthesized_declarator,
  [108382] = 11,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3549), 1,
      anon_sym_STAR,
    ACTIONS(3579), 1,
      anon_sym_LPAREN,
    ACTIONS(3581), 1,
      anon_sym_LBRACK,
    ACTIONS(3610), 1,
      anon_sym_RPAREN,
    ACTIONS(3612), 1,
      sym__blank,
    STATE(1567), 1,
      aux_sym_block_repeat1,
    STATE(1662), 1,
      sym__hll_pointer_declarator_specifier,
    ACTIONS(3583), 2,
      anon_sym_const,
      anon_sym_volatile,
    STATE(1668), 2,
      sym_hll_type_qualifier,
      aux_sym_hll_type_descriptor_repeat2,
    STATE(1804), 5,
      sym__hll_abstract_declarator,
      sym_hll_abstract_pointer_declarator,
      sym_hll_abstract_function_declarator,
      sym_hll_abstract_array_declarator,
      sym_hll_abstract_parenthesized_declarator,
  [108422] = 11,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3549), 1,
      anon_sym_STAR,
    ACTIONS(3579), 1,
      anon_sym_LPAREN,
    ACTIONS(3581), 1,
      anon_sym_LBRACK,
    ACTIONS(3615), 1,
      anon_sym_RPAREN,
    ACTIONS(3618), 1,
      sym__blank,
    STATE(1571), 1,
      aux_sym_block_repeat1,
    STATE(1662), 1,
      sym__hll_pointer_declarator_specifier,
    ACTIONS(3583), 2,
      anon_sym_const,
      anon_sym_volatile,
    STATE(1668), 2,
      sym_hll_type_qualifier,
      aux_sym_hll_type_descriptor_repeat2,
    STATE(1798), 5,
      sym__hll_abstract_declarator,
      sym_hll_abstract_pointer_declarator,
      sym_hll_abstract_function_declarator,
      sym_hll_abstract_array_declarator,
      sym_hll_abstract_parenthesized_declarator,
  [108462] = 11,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3549), 1,
      anon_sym_STAR,
    ACTIONS(3579), 1,
      anon_sym_LPAREN,
    ACTIONS(3581), 1,
      anon_sym_LBRACK,
    ACTIONS(3622), 1,
      anon_sym_RPAREN,
    ACTIONS(3624), 1,
      sym__blank,
    STATE(1569), 1,
      aux_sym_block_repeat1,
    STATE(1662), 1,
      sym__hll_pointer_declarator_specifier,
    ACTIONS(3583), 2,
      anon_sym_const,
      anon_sym_volatile,
    STATE(1533), 2,
      sym_hll_type_qualifier,
      aux_sym_hll_type_descriptor_repeat2,
    STATE(1811), 5,
      sym__hll_abstract_declarator,
      sym_hll_abstract_pointer_declarator,
      sym_hll_abstract_function_declarator,
      sym_hll_abstract_array_declarator,
      sym_hll_abstract_parenthesized_declarator,
  [108502] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3627), 3,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOT_DOT,
    ACTIONS(3629), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1769), 4,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
    ACTIONS(1771), 5,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_COLON_COLON_COLON,
  [108529] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3549), 1,
      anon_sym_STAR,
    ACTIONS(3551), 1,
      anon_sym_BSLASH,
    ACTIONS(3633), 1,
      anon_sym_LPAREN,
    ACTIONS(3636), 1,
      anon_sym_LBRACK,
    ACTIONS(3639), 1,
      sym__blank,
    STATE(1619), 1,
      aux_sym_block_repeat1,
    STATE(1640), 1,
      sym__hll_pointer_declarator_specifier,
    ACTIONS(3631), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
    STATE(1795), 6,
      sym_trace32_hll_variable,
      sym__hll_declarator,
      sym_hll_pointer_declarator,
      sym_hll_function_declarator,
      sym_hll_array_declarator,
      sym_hll_parenthesized_declarator,
  [108566] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3549), 1,
      anon_sym_STAR,
    ACTIONS(3551), 1,
      anon_sym_BSLASH,
    ACTIONS(3644), 1,
      anon_sym_LPAREN,
    ACTIONS(3647), 1,
      anon_sym_LBRACK,
    ACTIONS(3650), 1,
      sym__blank,
    STATE(1620), 1,
      aux_sym_block_repeat1,
    STATE(1640), 1,
      sym__hll_pointer_declarator_specifier,
    ACTIONS(3642), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
    STATE(1794), 6,
      sym_trace32_hll_variable,
      sym__hll_declarator,
      sym_hll_pointer_declarator,
      sym_hll_function_declarator,
      sym_hll_array_declarator,
      sym_hll_parenthesized_declarator,
  [108603] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3549), 1,
      anon_sym_STAR,
    ACTIONS(3551), 1,
      anon_sym_BSLASH,
    ACTIONS(3655), 1,
      anon_sym_LPAREN,
    ACTIONS(3658), 1,
      anon_sym_LBRACK,
    ACTIONS(3661), 1,
      sym__blank,
    STATE(1623), 1,
      aux_sym_block_repeat1,
    STATE(1640), 1,
      sym__hll_pointer_declarator_specifier,
    ACTIONS(3653), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
    STATE(1808), 6,
      sym_trace32_hll_variable,
      sym__hll_declarator,
      sym_hll_pointer_declarator,
      sym_hll_function_declarator,
      sym_hll_array_declarator,
      sym_hll_parenthesized_declarator,
  [108640] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3549), 1,
      anon_sym_STAR,
    ACTIONS(3551), 1,
      anon_sym_BSLASH,
    ACTIONS(3666), 1,
      anon_sym_LPAREN,
    ACTIONS(3669), 1,
      anon_sym_LBRACK,
    ACTIONS(3672), 1,
      sym__blank,
    STATE(1628), 1,
      aux_sym_block_repeat1,
    STATE(1640), 1,
      sym__hll_pointer_declarator_specifier,
    ACTIONS(3664), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
    STATE(1800), 6,
      sym_trace32_hll_variable,
      sym__hll_declarator,
      sym_hll_pointer_declarator,
      sym_hll_function_declarator,
      sym_hll_array_declarator,
      sym_hll_parenthesized_declarator,
  [108677] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3549), 1,
      anon_sym_STAR,
    ACTIONS(3551), 1,
      anon_sym_BSLASH,
    ACTIONS(3677), 1,
      anon_sym_LPAREN,
    ACTIONS(3680), 1,
      anon_sym_LBRACK,
    ACTIONS(3683), 1,
      sym__blank,
    STATE(1631), 1,
      aux_sym_block_repeat1,
    STATE(1640), 1,
      sym__hll_pointer_declarator_specifier,
    ACTIONS(3675), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
    STATE(1791), 6,
      sym_trace32_hll_variable,
      sym__hll_declarator,
      sym_hll_pointer_declarator,
      sym_hll_function_declarator,
      sym_hll_array_declarator,
      sym_hll_parenthesized_declarator,
  [108714] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3549), 1,
      anon_sym_STAR,
    ACTIONS(3551), 1,
      anon_sym_BSLASH,
    ACTIONS(3688), 1,
      anon_sym_LPAREN,
    ACTIONS(3691), 1,
      anon_sym_LBRACK,
    ACTIONS(3694), 1,
      sym__blank,
    STATE(1632), 1,
      aux_sym_block_repeat1,
    STATE(1640), 1,
      sym__hll_pointer_declarator_specifier,
    ACTIONS(3686), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
    STATE(1786), 6,
      sym_trace32_hll_variable,
      sym__hll_declarator,
      sym_hll_pointer_declarator,
      sym_hll_function_declarator,
      sym_hll_array_declarator,
      sym_hll_parenthesized_declarator,
  [108751] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3549), 1,
      anon_sym_STAR,
    ACTIONS(3551), 1,
      anon_sym_BSLASH,
    ACTIONS(3699), 1,
      anon_sym_LPAREN,
    ACTIONS(3702), 1,
      anon_sym_LBRACK,
    ACTIONS(3705), 1,
      sym__blank,
    STATE(1633), 1,
      aux_sym_block_repeat1,
    STATE(1640), 1,
      sym__hll_pointer_declarator_specifier,
    ACTIONS(3697), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
    STATE(1784), 6,
      sym_trace32_hll_variable,
      sym__hll_declarator,
      sym_hll_pointer_declarator,
      sym_hll_function_declarator,
      sym_hll_array_declarator,
      sym_hll_parenthesized_declarator,
  [108788] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3627), 3,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOT_DOT,
    ACTIONS(1769), 4,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
    ACTIONS(1771), 8,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_COLON_COLON_COLON,
  [108813] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3710), 1,
      anon_sym_CARET,
    ACTIONS(1769), 2,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
    ACTIONS(3708), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3627), 3,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOT_DOT,
    ACTIONS(3629), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1771), 4,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_PIPE,
      anon_sym_COLON_COLON_COLON,
  [108844] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1769), 2,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
    ACTIONS(3708), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3627), 3,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOT_DOT,
    ACTIONS(3629), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1771), 5,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_COLON_COLON_COLON,
  [108873] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3549), 1,
      anon_sym_STAR,
    ACTIONS(3551), 1,
      anon_sym_BSLASH,
    ACTIONS(3714), 1,
      anon_sym_LPAREN,
    ACTIONS(3717), 1,
      anon_sym_LBRACK,
    ACTIONS(3720), 1,
      sym__blank,
    STATE(1635), 1,
      aux_sym_block_repeat1,
    STATE(1640), 1,
      sym__hll_pointer_declarator_specifier,
    ACTIONS(3712), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
    STATE(1769), 6,
      sym_trace32_hll_variable,
      sym__hll_declarator,
      sym_hll_pointer_declarator,
      sym_hll_function_declarator,
      sym_hll_array_declarator,
      sym_hll_parenthesized_declarator,
  [108910] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1761), 4,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
    ACTIONS(1763), 11,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_DOT_DOT,
      anon_sym_COLON_COLON_COLON,
  [108933] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1769), 4,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
    ACTIONS(1771), 11,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_DOT_DOT,
      anon_sym_COLON_COLON_COLON,
  [108956] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3549), 1,
      anon_sym_STAR,
    ACTIONS(3551), 1,
      anon_sym_BSLASH,
    ACTIONS(3725), 1,
      anon_sym_LPAREN,
    ACTIONS(3728), 1,
      anon_sym_LBRACK,
    ACTIONS(3731), 1,
      sym__blank,
    STATE(1610), 1,
      aux_sym_block_repeat1,
    STATE(1640), 1,
      sym__hll_pointer_declarator_specifier,
    ACTIONS(3723), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
    STATE(1772), 6,
      sym_trace32_hll_variable,
      sym__hll_declarator,
      sym_hll_pointer_declarator,
      sym_hll_function_declarator,
      sym_hll_array_declarator,
      sym_hll_parenthesized_declarator,
  [108993] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3549), 1,
      anon_sym_STAR,
    ACTIONS(3551), 1,
      anon_sym_BSLASH,
    ACTIONS(3736), 1,
      anon_sym_LPAREN,
    ACTIONS(3739), 1,
      anon_sym_LBRACK,
    ACTIONS(3742), 1,
      sym__blank,
    STATE(1614), 1,
      aux_sym_block_repeat1,
    STATE(1640), 1,
      sym__hll_pointer_declarator_specifier,
    ACTIONS(3734), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
    STATE(1778), 6,
      sym_trace32_hll_variable,
      sym__hll_declarator,
      sym_hll_pointer_declarator,
      sym_hll_function_declarator,
      sym_hll_array_declarator,
      sym_hll_parenthesized_declarator,
  [109030] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1757), 4,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
    ACTIONS(1759), 11,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_DOT_DOT,
      anon_sym_COLON_COLON_COLON,
  [109053] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3549), 1,
      anon_sym_STAR,
    ACTIONS(3551), 1,
      anon_sym_BSLASH,
    ACTIONS(3747), 1,
      anon_sym_LPAREN,
    ACTIONS(3750), 1,
      anon_sym_LBRACK,
    ACTIONS(3753), 1,
      sym__blank,
    STATE(1599), 1,
      aux_sym_block_repeat1,
    STATE(1640), 1,
      sym__hll_pointer_declarator_specifier,
    ACTIONS(3745), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
    STATE(1802), 6,
      sym_trace32_hll_variable,
      sym__hll_declarator,
      sym_hll_pointer_declarator,
      sym_hll_function_declarator,
      sym_hll_array_declarator,
      sym_hll_parenthesized_declarator,
  [109090] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1741), 1,
      anon_sym_COLON,
    ACTIONS(1743), 1,
      anon_sym_COLON_COLON_COLON,
    ACTIONS(1745), 1,
      anon_sym_COLON_COLON,
    ACTIONS(3710), 1,
      anon_sym_CARET,
    ACTIONS(3756), 1,
      anon_sym_RPAREN,
    ACTIONS(3758), 1,
      anon_sym_PIPE,
    ACTIONS(3708), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3627), 3,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOT_DOT,
    ACTIONS(3629), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [109126] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1741), 1,
      anon_sym_COLON,
    ACTIONS(1743), 1,
      anon_sym_COLON_COLON_COLON,
    ACTIONS(1745), 1,
      anon_sym_COLON_COLON,
    ACTIONS(3710), 1,
      anon_sym_CARET,
    ACTIONS(3758), 1,
      anon_sym_PIPE,
    ACTIONS(3760), 1,
      anon_sym_RBRACE,
    ACTIONS(3708), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3627), 3,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOT_DOT,
    ACTIONS(3629), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [109162] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3549), 1,
      anon_sym_STAR,
    ACTIONS(3555), 1,
      sym__blank,
    ACTIONS(3579), 1,
      anon_sym_LPAREN,
    ACTIONS(3581), 1,
      anon_sym_LBRACK,
    STATE(1577), 1,
      aux_sym_block_repeat1,
    STATE(1662), 1,
      sym__hll_pointer_declarator_specifier,
    STATE(1726), 1,
      sym_hll_type_qualifier,
    ACTIONS(3583), 2,
      anon_sym_const,
      anon_sym_volatile,
    STATE(1774), 5,
      sym__hll_abstract_declarator,
      sym_hll_abstract_pointer_declarator,
      sym_hll_abstract_function_declarator,
      sym_hll_abstract_array_declarator,
      sym_hll_abstract_parenthesized_declarator,
  [109198] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1741), 1,
      anon_sym_COLON,
    ACTIONS(1743), 1,
      anon_sym_COLON_COLON_COLON,
    ACTIONS(1745), 1,
      anon_sym_COLON_COLON,
    ACTIONS(3710), 1,
      anon_sym_CARET,
    ACTIONS(3758), 1,
      anon_sym_PIPE,
    ACTIONS(3762), 1,
      anon_sym_RBRACE,
    ACTIONS(3708), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3627), 3,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOT_DOT,
    ACTIONS(3629), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [109234] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1741), 1,
      anon_sym_COLON,
    ACTIONS(1743), 1,
      anon_sym_COLON_COLON_COLON,
    ACTIONS(1745), 1,
      anon_sym_COLON_COLON,
    ACTIONS(3710), 1,
      anon_sym_CARET,
    ACTIONS(3758), 1,
      anon_sym_PIPE,
    ACTIONS(3764), 1,
      anon_sym_RBRACE,
    ACTIONS(3708), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3627), 3,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOT_DOT,
    ACTIONS(3629), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [109270] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3549), 1,
      anon_sym_STAR,
    ACTIONS(3555), 1,
      sym__blank,
    ACTIONS(3579), 1,
      anon_sym_LPAREN,
    ACTIONS(3581), 1,
      anon_sym_LBRACK,
    STATE(1577), 1,
      aux_sym_block_repeat1,
    STATE(1662), 1,
      sym__hll_pointer_declarator_specifier,
    STATE(1726), 1,
      sym_hll_type_qualifier,
    ACTIONS(3583), 2,
      anon_sym_const,
      anon_sym_volatile,
    STATE(1792), 5,
      sym__hll_abstract_declarator,
      sym_hll_abstract_pointer_declarator,
      sym_hll_abstract_function_declarator,
      sym_hll_abstract_array_declarator,
      sym_hll_abstract_parenthesized_declarator,
  [109306] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3549), 1,
      anon_sym_STAR,
    ACTIONS(3555), 1,
      sym__blank,
    ACTIONS(3579), 1,
      anon_sym_LPAREN,
    ACTIONS(3581), 1,
      anon_sym_LBRACK,
    STATE(1577), 1,
      aux_sym_block_repeat1,
    STATE(1662), 1,
      sym__hll_pointer_declarator_specifier,
    STATE(1726), 1,
      sym_hll_type_qualifier,
    ACTIONS(3583), 2,
      anon_sym_const,
      anon_sym_volatile,
    STATE(1798), 5,
      sym__hll_abstract_declarator,
      sym_hll_abstract_pointer_declarator,
      sym_hll_abstract_function_declarator,
      sym_hll_abstract_array_declarator,
      sym_hll_abstract_parenthesized_declarator,
  [109342] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3549), 1,
      anon_sym_STAR,
    ACTIONS(3555), 1,
      sym__blank,
    ACTIONS(3579), 1,
      anon_sym_LPAREN,
    ACTIONS(3581), 1,
      anon_sym_LBRACK,
    STATE(1577), 1,
      aux_sym_block_repeat1,
    STATE(1662), 1,
      sym__hll_pointer_declarator_specifier,
    STATE(1726), 1,
      sym_hll_type_qualifier,
    ACTIONS(3583), 2,
      anon_sym_const,
      anon_sym_volatile,
    STATE(1804), 5,
      sym__hll_abstract_declarator,
      sym_hll_abstract_pointer_declarator,
      sym_hll_abstract_function_declarator,
      sym_hll_abstract_array_declarator,
      sym_hll_abstract_parenthesized_declarator,
  [109378] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1741), 1,
      anon_sym_COLON,
    ACTIONS(1743), 1,
      anon_sym_COLON_COLON_COLON,
    ACTIONS(1745), 1,
      anon_sym_COLON_COLON,
    ACTIONS(3710), 1,
      anon_sym_CARET,
    ACTIONS(3758), 1,
      anon_sym_PIPE,
    ACTIONS(3762), 1,
      anon_sym_RPAREN,
    ACTIONS(3708), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3627), 3,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOT_DOT,
    ACTIONS(3629), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [109414] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3771), 1,
      sym__blank,
    ACTIONS(3768), 2,
      anon_sym_const,
      anon_sym_volatile,
    STATE(1565), 2,
      sym_hll_type_qualifier,
      aux_sym_hll_type_descriptor_repeat1,
    ACTIONS(3766), 9,
      anon_sym_struct,
      anon_sym_union,
      anon_sym_enum,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
      sym_hll_primitive_type,
      sym_identifier,
  [109440] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    STATE(1566), 1,
      aux_sym__hll_declaration_specifiers_repeat1,
    ACTIONS(3775), 2,
      anon_sym_const,
      anon_sym_volatile,
    STATE(2248), 2,
      sym_hll_type_qualifier,
      sym__hll_declaration_modifiers,
    ACTIONS(3773), 9,
      anon_sym_struct,
      anon_sym_union,
      anon_sym_enum,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
      sym_hll_primitive_type,
      sym_identifier,
  [109466] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3549), 1,
      anon_sym_STAR,
    ACTIONS(3555), 1,
      sym__blank,
    ACTIONS(3579), 1,
      anon_sym_LPAREN,
    ACTIONS(3581), 1,
      anon_sym_LBRACK,
    STATE(1577), 1,
      aux_sym_block_repeat1,
    STATE(1662), 1,
      sym__hll_pointer_declarator_specifier,
    STATE(1726), 1,
      sym_hll_type_qualifier,
    ACTIONS(3583), 2,
      anon_sym_const,
      anon_sym_volatile,
    STATE(1764), 5,
      sym__hll_abstract_declarator,
      sym_hll_abstract_pointer_declarator,
      sym_hll_abstract_function_declarator,
      sym_hll_abstract_array_declarator,
      sym_hll_abstract_parenthesized_declarator,
  [109502] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1741), 1,
      anon_sym_COLON,
    ACTIONS(1743), 1,
      anon_sym_COLON_COLON_COLON,
    ACTIONS(1745), 1,
      anon_sym_COLON_COLON,
    ACTIONS(3710), 1,
      anon_sym_CARET,
    ACTIONS(3758), 1,
      anon_sym_PIPE,
    ACTIONS(3764), 1,
      anon_sym_RPAREN,
    ACTIONS(3708), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3627), 3,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOT_DOT,
    ACTIONS(3629), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [109538] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3549), 1,
      anon_sym_STAR,
    ACTIONS(3555), 1,
      sym__blank,
    ACTIONS(3579), 1,
      anon_sym_LPAREN,
    ACTIONS(3581), 1,
      anon_sym_LBRACK,
    STATE(1577), 1,
      aux_sym_block_repeat1,
    STATE(1662), 1,
      sym__hll_pointer_declarator_specifier,
    STATE(1726), 1,
      sym_hll_type_qualifier,
    ACTIONS(3583), 2,
      anon_sym_const,
      anon_sym_volatile,
    STATE(1781), 5,
      sym__hll_abstract_declarator,
      sym_hll_abstract_pointer_declarator,
      sym_hll_abstract_function_declarator,
      sym_hll_abstract_array_declarator,
      sym_hll_abstract_parenthesized_declarator,
  [109574] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1741), 1,
      anon_sym_COLON,
    ACTIONS(1743), 1,
      anon_sym_COLON_COLON_COLON,
    ACTIONS(1745), 1,
      anon_sym_COLON_COLON,
    ACTIONS(3710), 1,
      anon_sym_CARET,
    ACTIONS(3756), 1,
      anon_sym_RBRACE,
    ACTIONS(3758), 1,
      anon_sym_PIPE,
    ACTIONS(3708), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3627), 3,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOT_DOT,
    ACTIONS(3629), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [109610] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3549), 1,
      anon_sym_STAR,
    ACTIONS(3555), 1,
      sym__blank,
    ACTIONS(3579), 1,
      anon_sym_LPAREN,
    ACTIONS(3581), 1,
      anon_sym_LBRACK,
    STATE(1577), 1,
      aux_sym_block_repeat1,
    STATE(1662), 1,
      sym__hll_pointer_declarator_specifier,
    STATE(1726), 1,
      sym_hll_type_qualifier,
    ACTIONS(3583), 2,
      anon_sym_const,
      anon_sym_volatile,
    STATE(1789), 5,
      sym__hll_abstract_declarator,
      sym_hll_abstract_pointer_declarator,
      sym_hll_abstract_function_declarator,
      sym_hll_abstract_array_declarator,
      sym_hll_abstract_parenthesized_declarator,
  [109646] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1741), 1,
      anon_sym_COLON,
    ACTIONS(1743), 1,
      anon_sym_COLON_COLON_COLON,
    ACTIONS(1745), 1,
      anon_sym_COLON_COLON,
    ACTIONS(3710), 1,
      anon_sym_CARET,
    ACTIONS(3758), 1,
      anon_sym_PIPE,
    ACTIONS(3760), 1,
      anon_sym_RPAREN,
    ACTIONS(3708), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3627), 3,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOT_DOT,
    ACTIONS(3629), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [109682] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3549), 1,
      anon_sym_STAR,
    ACTIONS(3555), 1,
      sym__blank,
    ACTIONS(3579), 1,
      anon_sym_LPAREN,
    ACTIONS(3581), 1,
      anon_sym_LBRACK,
    STATE(1577), 1,
      aux_sym_block_repeat1,
    STATE(1662), 1,
      sym__hll_pointer_declarator_specifier,
    STATE(1726), 1,
      sym_hll_type_qualifier,
    ACTIONS(3583), 2,
      anon_sym_const,
      anon_sym_volatile,
    STATE(1765), 5,
      sym__hll_abstract_declarator,
      sym_hll_abstract_pointer_declarator,
      sym_hll_abstract_function_declarator,
      sym_hll_abstract_array_declarator,
      sym_hll_abstract_parenthesized_declarator,
  [109718] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3549), 1,
      anon_sym_STAR,
    ACTIONS(3551), 1,
      anon_sym_BSLASH,
    ACTIONS(3555), 1,
      sym__blank,
    ACTIONS(3778), 1,
      anon_sym_LPAREN,
    ACTIONS(3780), 1,
      anon_sym_LBRACK,
    STATE(1577), 1,
      aux_sym_block_repeat1,
    STATE(1640), 1,
      sym__hll_pointer_declarator_specifier,
    STATE(1834), 6,
      sym_trace32_hll_variable,
      sym__hll_declarator,
      sym_hll_pointer_declarator,
      sym_hll_function_declarator,
      sym_hll_array_declarator,
      sym_hll_parenthesized_declarator,
  [109751] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1741), 1,
      anon_sym_COLON,
    ACTIONS(1743), 1,
      anon_sym_COLON_COLON_COLON,
    ACTIONS(1745), 1,
      anon_sym_COLON_COLON,
    ACTIONS(3788), 1,
      anon_sym_PIPE,
    ACTIONS(3790), 1,
      anon_sym_CARET,
    ACTIONS(3782), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3784), 3,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOT_DOT,
    ACTIONS(3786), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [109784] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1769), 2,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
    ACTIONS(3782), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1771), 3,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_COLON_COLON_COLON,
    ACTIONS(3784), 3,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOT_DOT,
    ACTIONS(3786), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [109811] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3792), 1,
      sym__blank,
    STATE(1577), 1,
      aux_sym_block_repeat1,
    ACTIONS(2122), 4,
      anon_sym_BSLASH,
      anon_sym_const,
      anon_sym_volatile,
      sym_identifier,
    ACTIONS(2120), 7,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_LBRACK,
  [109836] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3549), 1,
      anon_sym_STAR,
    ACTIONS(3795), 1,
      anon_sym_LPAREN,
    ACTIONS(3797), 1,
      anon_sym_BSLASH,
    ACTIONS(3799), 1,
      anon_sym_LBRACK,
    ACTIONS(3801), 1,
      sym__blank,
    STATE(1644), 1,
      sym__hll_pointer_declarator_specifier,
    STATE(1651), 1,
      aux_sym_block_repeat1,
    STATE(1711), 6,
      sym_trace32_hll_variable,
      sym__hll_declarator,
      sym_hll_pointer_declarator,
      sym_hll_function_declarator,
      sym_hll_array_declarator,
      sym_hll_parenthesized_declarator,
  [109869] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1743), 1,
      anon_sym_COLON_COLON_COLON,
    ACTIONS(3788), 1,
      anon_sym_PIPE,
    ACTIONS(3790), 1,
      anon_sym_CARET,
    ACTIONS(3803), 1,
      anon_sym_COLON,
    ACTIONS(3805), 1,
      anon_sym_COLON_COLON,
    ACTIONS(3782), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3784), 3,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOT_DOT,
    ACTIONS(3786), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [109902] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3809), 1,
      sym__blank,
    STATE(1585), 1,
      aux_sym_block_repeat1,
    ACTIONS(3807), 11,
      anon_sym_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [109925] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3549), 1,
      anon_sym_STAR,
    ACTIONS(3555), 1,
      sym__blank,
    ACTIONS(3795), 1,
      anon_sym_LPAREN,
    ACTIONS(3797), 1,
      anon_sym_BSLASH,
    ACTIONS(3799), 1,
      anon_sym_LBRACK,
    STATE(1577), 1,
      aux_sym_block_repeat1,
    STATE(1644), 1,
      sym__hll_pointer_declarator_specifier,
    STATE(1728), 6,
      sym_trace32_hll_variable,
      sym__hll_declarator,
      sym_hll_pointer_declarator,
      sym_hll_function_declarator,
      sym_hll_array_declarator,
      sym_hll_parenthesized_declarator,
  [109958] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3549), 1,
      anon_sym_STAR,
    ACTIONS(3555), 1,
      sym__blank,
    ACTIONS(3795), 1,
      anon_sym_LPAREN,
    ACTIONS(3797), 1,
      anon_sym_BSLASH,
    ACTIONS(3799), 1,
      anon_sym_LBRACK,
    STATE(1577), 1,
      aux_sym_block_repeat1,
    STATE(1644), 1,
      sym__hll_pointer_declarator_specifier,
    STATE(1746), 6,
      sym_trace32_hll_variable,
      sym__hll_declarator,
      sym_hll_pointer_declarator,
      sym_hll_function_declarator,
      sym_hll_array_declarator,
      sym_hll_parenthesized_declarator,
  [109991] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3549), 1,
      anon_sym_STAR,
    ACTIONS(3551), 1,
      anon_sym_BSLASH,
    ACTIONS(3778), 1,
      anon_sym_LPAREN,
    ACTIONS(3780), 1,
      anon_sym_LBRACK,
    ACTIONS(3811), 1,
      sym__blank,
    STATE(1599), 1,
      aux_sym_block_repeat1,
    STATE(1640), 1,
      sym__hll_pointer_declarator_specifier,
    STATE(1802), 6,
      sym_trace32_hll_variable,
      sym__hll_declarator,
      sym_hll_pointer_declarator,
      sym_hll_function_declarator,
      sym_hll_array_declarator,
      sym_hll_parenthesized_declarator,
  [110024] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3549), 1,
      anon_sym_STAR,
    ACTIONS(3795), 1,
      anon_sym_LPAREN,
    ACTIONS(3797), 1,
      anon_sym_BSLASH,
    ACTIONS(3799), 1,
      anon_sym_LBRACK,
    ACTIONS(3813), 1,
      sym__blank,
    STATE(1608), 1,
      aux_sym_block_repeat1,
    STATE(1644), 1,
      sym__hll_pointer_declarator_specifier,
    STATE(1737), 6,
      sym_trace32_hll_variable,
      sym__hll_declarator,
      sym_hll_pointer_declarator,
      sym_hll_function_declarator,
      sym_hll_array_declarator,
      sym_hll_parenthesized_declarator,
  [110057] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3371), 1,
      sym__blank,
    STATE(952), 1,
      aux_sym_block_repeat1,
    ACTIONS(3815), 11,
      anon_sym_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [110080] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3549), 1,
      anon_sym_STAR,
    ACTIONS(3555), 1,
      sym__blank,
    ACTIONS(3795), 1,
      anon_sym_LPAREN,
    ACTIONS(3797), 1,
      anon_sym_BSLASH,
    ACTIONS(3799), 1,
      anon_sym_LBRACK,
    STATE(1577), 1,
      aux_sym_block_repeat1,
    STATE(1644), 1,
      sym__hll_pointer_declarator_specifier,
    STATE(1725), 6,
      sym_trace32_hll_variable,
      sym__hll_declarator,
      sym_hll_pointer_declarator,
      sym_hll_function_declarator,
      sym_hll_array_declarator,
      sym_hll_parenthesized_declarator,
  [110113] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3819), 1,
      sym__blank,
    STATE(1595), 1,
      aux_sym_block_repeat1,
    ACTIONS(3817), 11,
      anon_sym_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [110136] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3549), 1,
      anon_sym_STAR,
    ACTIONS(3551), 1,
      anon_sym_BSLASH,
    ACTIONS(3555), 1,
      sym__blank,
    ACTIONS(3778), 1,
      anon_sym_LPAREN,
    ACTIONS(3780), 1,
      anon_sym_LBRACK,
    STATE(1577), 1,
      aux_sym_block_repeat1,
    STATE(1640), 1,
      sym__hll_pointer_declarator_specifier,
    STATE(1776), 6,
      sym_trace32_hll_variable,
      sym__hll_declarator,
      sym_hll_pointer_declarator,
      sym_hll_function_declarator,
      sym_hll_array_declarator,
      sym_hll_parenthesized_declarator,
  [110169] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3549), 1,
      anon_sym_STAR,
    ACTIONS(3795), 1,
      anon_sym_LPAREN,
    ACTIONS(3797), 1,
      anon_sym_BSLASH,
    ACTIONS(3799), 1,
      anon_sym_LBRACK,
    ACTIONS(3821), 1,
      sym__blank,
    STATE(1644), 1,
      sym__hll_pointer_declarator_specifier,
    STATE(1645), 1,
      aux_sym_block_repeat1,
    STATE(1732), 6,
      sym_trace32_hll_variable,
      sym__hll_declarator,
      sym_hll_pointer_declarator,
      sym_hll_function_declarator,
      sym_hll_array_declarator,
      sym_hll_parenthesized_declarator,
  [110202] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3549), 1,
      anon_sym_STAR,
    ACTIONS(3795), 1,
      anon_sym_LPAREN,
    ACTIONS(3797), 1,
      anon_sym_BSLASH,
    ACTIONS(3799), 1,
      anon_sym_LBRACK,
    ACTIONS(3823), 1,
      sym__blank,
    STATE(1644), 1,
      sym__hll_pointer_declarator_specifier,
    STATE(1648), 1,
      aux_sym_block_repeat1,
    STATE(1725), 6,
      sym_trace32_hll_variable,
      sym__hll_declarator,
      sym_hll_pointer_declarator,
      sym_hll_function_declarator,
      sym_hll_array_declarator,
      sym_hll_parenthesized_declarator,
  [110235] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1743), 1,
      anon_sym_COLON_COLON_COLON,
    ACTIONS(1745), 1,
      anon_sym_COLON_COLON,
    ACTIONS(3788), 1,
      anon_sym_PIPE,
    ACTIONS(3790), 1,
      anon_sym_CARET,
    ACTIONS(3825), 1,
      anon_sym_COLON,
    ACTIONS(3782), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3784), 3,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOT_DOT,
    ACTIONS(3786), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [110268] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3549), 1,
      anon_sym_STAR,
    ACTIONS(3551), 1,
      anon_sym_BSLASH,
    ACTIONS(3555), 1,
      sym__blank,
    ACTIONS(3778), 1,
      anon_sym_LPAREN,
    ACTIONS(3780), 1,
      anon_sym_LBRACK,
    STATE(1577), 1,
      aux_sym_block_repeat1,
    STATE(1640), 1,
      sym__hll_pointer_declarator_specifier,
    STATE(1911), 6,
      sym_trace32_hll_variable,
      sym__hll_declarator,
      sym_hll_pointer_declarator,
      sym_hll_function_declarator,
      sym_hll_array_declarator,
      sym_hll_parenthesized_declarator,
  [110301] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3829), 1,
      sym__blank,
    STATE(1594), 1,
      aux_sym_block_repeat1,
    ACTIONS(3827), 11,
      anon_sym_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [110324] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3371), 1,
      sym__blank,
    STATE(952), 1,
      aux_sym_block_repeat1,
    ACTIONS(3831), 11,
      anon_sym_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [110347] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3371), 1,
      sym__blank,
    STATE(952), 1,
      aux_sym_block_repeat1,
    ACTIONS(3833), 11,
      anon_sym_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [110370] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3837), 1,
      sym__blank,
    STATE(1597), 1,
      aux_sym_block_repeat1,
    ACTIONS(3835), 11,
      anon_sym_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [110393] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3371), 1,
      sym__blank,
    STATE(952), 1,
      aux_sym_block_repeat1,
    ACTIONS(3839), 11,
      anon_sym_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [110416] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3549), 1,
      anon_sym_STAR,
    ACTIONS(3551), 1,
      anon_sym_BSLASH,
    ACTIONS(3778), 1,
      anon_sym_LPAREN,
    ACTIONS(3780), 1,
      anon_sym_LBRACK,
    ACTIONS(3841), 1,
      sym__blank,
    STATE(1610), 1,
      aux_sym_block_repeat1,
    STATE(1640), 1,
      sym__hll_pointer_declarator_specifier,
    STATE(1772), 6,
      sym_trace32_hll_variable,
      sym__hll_declarator,
      sym_hll_pointer_declarator,
      sym_hll_function_declarator,
      sym_hll_array_declarator,
      sym_hll_parenthesized_declarator,
  [110449] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3549), 1,
      anon_sym_STAR,
    ACTIONS(3551), 1,
      anon_sym_BSLASH,
    ACTIONS(3555), 1,
      sym__blank,
    ACTIONS(3778), 1,
      anon_sym_LPAREN,
    ACTIONS(3780), 1,
      anon_sym_LBRACK,
    STATE(1577), 1,
      aux_sym_block_repeat1,
    STATE(1640), 1,
      sym__hll_pointer_declarator_specifier,
    STATE(1778), 6,
      sym_trace32_hll_variable,
      sym__hll_declarator,
      sym_hll_pointer_declarator,
      sym_hll_function_declarator,
      sym_hll_array_declarator,
      sym_hll_parenthesized_declarator,
  [110482] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3549), 1,
      anon_sym_STAR,
    ACTIONS(3551), 1,
      anon_sym_BSLASH,
    ACTIONS(3778), 1,
      anon_sym_LPAREN,
    ACTIONS(3780), 1,
      anon_sym_LBRACK,
    ACTIONS(3843), 1,
      sym__blank,
    STATE(1614), 1,
      aux_sym_block_repeat1,
    STATE(1640), 1,
      sym__hll_pointer_declarator_specifier,
    STATE(1778), 6,
      sym_trace32_hll_variable,
      sym__hll_declarator,
      sym_hll_pointer_declarator,
      sym_hll_function_declarator,
      sym_hll_array_declarator,
      sym_hll_parenthesized_declarator,
  [110515] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3847), 1,
      sym__blank,
    STATE(1603), 1,
      aux_sym_block_repeat1,
    ACTIONS(3845), 11,
      anon_sym_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [110538] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3549), 1,
      anon_sym_STAR,
    ACTIONS(3555), 1,
      sym__blank,
    ACTIONS(3795), 1,
      anon_sym_LPAREN,
    ACTIONS(3797), 1,
      anon_sym_BSLASH,
    ACTIONS(3799), 1,
      anon_sym_LBRACK,
    STATE(1577), 1,
      aux_sym_block_repeat1,
    STATE(1644), 1,
      sym__hll_pointer_declarator_specifier,
    STATE(1761), 6,
      sym_trace32_hll_variable,
      sym__hll_declarator,
      sym_hll_pointer_declarator,
      sym_hll_function_declarator,
      sym_hll_array_declarator,
      sym_hll_parenthesized_declarator,
  [110571] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3371), 1,
      sym__blank,
    STATE(952), 1,
      aux_sym_block_repeat1,
    ACTIONS(3849), 11,
      anon_sym_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [110594] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1771), 3,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_COLON_COLON_COLON,
    ACTIONS(3784), 3,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOT_DOT,
    ACTIONS(3786), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1769), 4,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
  [110619] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3853), 1,
      sym__blank,
    STATE(1607), 1,
      aux_sym_block_repeat1,
    ACTIONS(3851), 11,
      anon_sym_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [110642] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3549), 1,
      anon_sym_STAR,
    ACTIONS(3795), 1,
      anon_sym_LPAREN,
    ACTIONS(3797), 1,
      anon_sym_BSLASH,
    ACTIONS(3799), 1,
      anon_sym_LBRACK,
    ACTIONS(3855), 1,
      sym__blank,
    STATE(1586), 1,
      aux_sym_block_repeat1,
    STATE(1644), 1,
      sym__hll_pointer_declarator_specifier,
    STATE(1715), 6,
      sym_trace32_hll_variable,
      sym__hll_declarator,
      sym_hll_pointer_declarator,
      sym_hll_function_declarator,
      sym_hll_array_declarator,
      sym_hll_parenthesized_declarator,
  [110675] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3371), 1,
      sym__blank,
    STATE(952), 1,
      aux_sym_block_repeat1,
    ACTIONS(3857), 11,
      anon_sym_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [110698] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3549), 1,
      anon_sym_STAR,
    ACTIONS(3555), 1,
      sym__blank,
    ACTIONS(3795), 1,
      anon_sym_LPAREN,
    ACTIONS(3797), 1,
      anon_sym_BSLASH,
    ACTIONS(3799), 1,
      anon_sym_LBRACK,
    STATE(1577), 1,
      aux_sym_block_repeat1,
    STATE(1644), 1,
      sym__hll_pointer_declarator_specifier,
    STATE(1702), 6,
      sym_trace32_hll_variable,
      sym__hll_declarator,
      sym_hll_pointer_declarator,
      sym_hll_function_declarator,
      sym_hll_array_declarator,
      sym_hll_parenthesized_declarator,
  [110731] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3861), 1,
      sym__blank,
    STATE(1611), 1,
      aux_sym_block_repeat1,
    ACTIONS(3859), 11,
      anon_sym_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [110754] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3549), 1,
      anon_sym_STAR,
    ACTIONS(3551), 1,
      anon_sym_BSLASH,
    ACTIONS(3555), 1,
      sym__blank,
    ACTIONS(3778), 1,
      anon_sym_LPAREN,
    ACTIONS(3780), 1,
      anon_sym_LBRACK,
    STATE(1577), 1,
      aux_sym_block_repeat1,
    STATE(1640), 1,
      sym__hll_pointer_declarator_specifier,
    STATE(1795), 6,
      sym_trace32_hll_variable,
      sym__hll_declarator,
      sym_hll_pointer_declarator,
      sym_hll_function_declarator,
      sym_hll_array_declarator,
      sym_hll_parenthesized_declarator,
  [110787] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3371), 1,
      sym__blank,
    STATE(952), 1,
      aux_sym_block_repeat1,
    ACTIONS(3863), 11,
      anon_sym_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [110810] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3549), 1,
      anon_sym_STAR,
    ACTIONS(3551), 1,
      anon_sym_BSLASH,
    ACTIONS(3778), 1,
      anon_sym_LPAREN,
    ACTIONS(3780), 1,
      anon_sym_LBRACK,
    ACTIONS(3865), 1,
      sym__blank,
    STATE(1619), 1,
      aux_sym_block_repeat1,
    STATE(1640), 1,
      sym__hll_pointer_declarator_specifier,
    STATE(1795), 6,
      sym_trace32_hll_variable,
      sym__hll_declarator,
      sym_hll_pointer_declarator,
      sym_hll_function_declarator,
      sym_hll_array_declarator,
      sym_hll_parenthesized_declarator,
  [110843] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3549), 1,
      anon_sym_STAR,
    ACTIONS(3551), 1,
      anon_sym_BSLASH,
    ACTIONS(3778), 1,
      anon_sym_LPAREN,
    ACTIONS(3780), 1,
      anon_sym_LBRACK,
    ACTIONS(3867), 1,
      sym__blank,
    STATE(1620), 1,
      aux_sym_block_repeat1,
    STATE(1640), 1,
      sym__hll_pointer_declarator_specifier,
    STATE(1794), 6,
      sym_trace32_hll_variable,
      sym__hll_declarator,
      sym_hll_pointer_declarator,
      sym_hll_function_declarator,
      sym_hll_array_declarator,
      sym_hll_parenthesized_declarator,
  [110876] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3549), 1,
      anon_sym_STAR,
    ACTIONS(3551), 1,
      anon_sym_BSLASH,
    ACTIONS(3555), 1,
      sym__blank,
    ACTIONS(3778), 1,
      anon_sym_LPAREN,
    ACTIONS(3780), 1,
      anon_sym_LBRACK,
    STATE(1577), 1,
      aux_sym_block_repeat1,
    STATE(1640), 1,
      sym__hll_pointer_declarator_specifier,
    STATE(1800), 6,
      sym_trace32_hll_variable,
      sym__hll_declarator,
      sym_hll_pointer_declarator,
      sym_hll_function_declarator,
      sym_hll_array_declarator,
      sym_hll_parenthesized_declarator,
  [110909] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3871), 1,
      sym__blank,
    STATE(1617), 1,
      aux_sym_block_repeat1,
    ACTIONS(3869), 11,
      anon_sym_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [110932] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3549), 1,
      anon_sym_STAR,
    ACTIONS(3551), 1,
      anon_sym_BSLASH,
    ACTIONS(3778), 1,
      anon_sym_LPAREN,
    ACTIONS(3780), 1,
      anon_sym_LBRACK,
    ACTIONS(3873), 1,
      sym__blank,
    STATE(1623), 1,
      aux_sym_block_repeat1,
    STATE(1640), 1,
      sym__hll_pointer_declarator_specifier,
    STATE(1808), 6,
      sym_trace32_hll_variable,
      sym__hll_declarator,
      sym_hll_pointer_declarator,
      sym_hll_function_declarator,
      sym_hll_array_declarator,
      sym_hll_parenthesized_declarator,
  [110965] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3371), 1,
      sym__blank,
    STATE(952), 1,
      aux_sym_block_repeat1,
    ACTIONS(3875), 11,
      anon_sym_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [110988] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3549), 1,
      anon_sym_STAR,
    ACTIONS(3551), 1,
      anon_sym_BSLASH,
    ACTIONS(3778), 1,
      anon_sym_LPAREN,
    ACTIONS(3780), 1,
      anon_sym_LBRACK,
    ACTIONS(3877), 1,
      sym__blank,
    STATE(1628), 1,
      aux_sym_block_repeat1,
    STATE(1640), 1,
      sym__hll_pointer_declarator_specifier,
    STATE(1800), 6,
      sym_trace32_hll_variable,
      sym__hll_declarator,
      sym_hll_pointer_declarator,
      sym_hll_function_declarator,
      sym_hll_array_declarator,
      sym_hll_parenthesized_declarator,
  [111021] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3549), 1,
      anon_sym_STAR,
    ACTIONS(3551), 1,
      anon_sym_BSLASH,
    ACTIONS(3555), 1,
      sym__blank,
    ACTIONS(3778), 1,
      anon_sym_LPAREN,
    ACTIONS(3780), 1,
      anon_sym_LBRACK,
    STATE(1577), 1,
      aux_sym_block_repeat1,
    STATE(1640), 1,
      sym__hll_pointer_declarator_specifier,
    STATE(1780), 6,
      sym_trace32_hll_variable,
      sym__hll_declarator,
      sym_hll_pointer_declarator,
      sym_hll_function_declarator,
      sym_hll_array_declarator,
      sym_hll_parenthesized_declarator,
  [111054] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3549), 1,
      anon_sym_STAR,
    ACTIONS(3551), 1,
      anon_sym_BSLASH,
    ACTIONS(3555), 1,
      sym__blank,
    ACTIONS(3778), 1,
      anon_sym_LPAREN,
    ACTIONS(3780), 1,
      anon_sym_LBRACK,
    STATE(1577), 1,
      aux_sym_block_repeat1,
    STATE(1640), 1,
      sym__hll_pointer_declarator_specifier,
    STATE(1791), 6,
      sym_trace32_hll_variable,
      sym__hll_declarator,
      sym_hll_pointer_declarator,
      sym_hll_function_declarator,
      sym_hll_array_declarator,
      sym_hll_parenthesized_declarator,
  [111087] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3549), 1,
      anon_sym_STAR,
    ACTIONS(3551), 1,
      anon_sym_BSLASH,
    ACTIONS(3778), 1,
      anon_sym_LPAREN,
    ACTIONS(3780), 1,
      anon_sym_LBRACK,
    ACTIONS(3879), 1,
      sym__blank,
    STATE(1574), 1,
      aux_sym_block_repeat1,
    STATE(1640), 1,
      sym__hll_pointer_declarator_specifier,
    STATE(1828), 6,
      sym_trace32_hll_variable,
      sym__hll_declarator,
      sym_hll_pointer_declarator,
      sym_hll_function_declarator,
      sym_hll_array_declarator,
      sym_hll_parenthesized_declarator,
  [111120] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3549), 1,
      anon_sym_STAR,
    ACTIONS(3551), 1,
      anon_sym_BSLASH,
    ACTIONS(3778), 1,
      anon_sym_LPAREN,
    ACTIONS(3780), 1,
      anon_sym_LBRACK,
    ACTIONS(3881), 1,
      sym__blank,
    STATE(1631), 1,
      aux_sym_block_repeat1,
    STATE(1640), 1,
      sym__hll_pointer_declarator_specifier,
    STATE(1791), 6,
      sym_trace32_hll_variable,
      sym__hll_declarator,
      sym_hll_pointer_declarator,
      sym_hll_function_declarator,
      sym_hll_array_declarator,
      sym_hll_parenthesized_declarator,
  [111153] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3549), 1,
      anon_sym_STAR,
    ACTIONS(3551), 1,
      anon_sym_BSLASH,
    ACTIONS(3555), 1,
      sym__blank,
    ACTIONS(3778), 1,
      anon_sym_LPAREN,
    ACTIONS(3780), 1,
      anon_sym_LBRACK,
    STATE(1577), 1,
      aux_sym_block_repeat1,
    STATE(1640), 1,
      sym__hll_pointer_declarator_specifier,
    STATE(1786), 6,
      sym_trace32_hll_variable,
      sym__hll_declarator,
      sym_hll_pointer_declarator,
      sym_hll_function_declarator,
      sym_hll_array_declarator,
      sym_hll_parenthesized_declarator,
  [111186] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3549), 1,
      anon_sym_STAR,
    ACTIONS(3795), 1,
      anon_sym_LPAREN,
    ACTIONS(3797), 1,
      anon_sym_BSLASH,
    ACTIONS(3799), 1,
      anon_sym_LBRACK,
    ACTIONS(3883), 1,
      sym__blank,
    STATE(1627), 1,
      aux_sym_block_repeat1,
    STATE(1644), 1,
      sym__hll_pointer_declarator_specifier,
    STATE(1702), 6,
      sym_trace32_hll_variable,
      sym__hll_declarator,
      sym_hll_pointer_declarator,
      sym_hll_function_declarator,
      sym_hll_array_declarator,
      sym_hll_parenthesized_declarator,
  [111219] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3549), 1,
      anon_sym_STAR,
    ACTIONS(3551), 1,
      anon_sym_BSLASH,
    ACTIONS(3778), 1,
      anon_sym_LPAREN,
    ACTIONS(3780), 1,
      anon_sym_LBRACK,
    ACTIONS(3885), 1,
      sym__blank,
    STATE(1632), 1,
      aux_sym_block_repeat1,
    STATE(1640), 1,
      sym__hll_pointer_declarator_specifier,
    STATE(1786), 6,
      sym_trace32_hll_variable,
      sym__hll_declarator,
      sym_hll_pointer_declarator,
      sym_hll_function_declarator,
      sym_hll_array_declarator,
      sym_hll_parenthesized_declarator,
  [111252] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3549), 1,
      anon_sym_STAR,
    ACTIONS(3551), 1,
      anon_sym_BSLASH,
    ACTIONS(3778), 1,
      anon_sym_LPAREN,
    ACTIONS(3780), 1,
      anon_sym_LBRACK,
    ACTIONS(3887), 1,
      sym__blank,
    STATE(1633), 1,
      aux_sym_block_repeat1,
    STATE(1640), 1,
      sym__hll_pointer_declarator_specifier,
    STATE(1784), 6,
      sym_trace32_hll_variable,
      sym__hll_declarator,
      sym_hll_pointer_declarator,
      sym_hll_function_declarator,
      sym_hll_array_declarator,
      sym_hll_parenthesized_declarator,
  [111285] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3549), 1,
      anon_sym_STAR,
    ACTIONS(3555), 1,
      sym__blank,
    ACTIONS(3795), 1,
      anon_sym_LPAREN,
    ACTIONS(3797), 1,
      anon_sym_BSLASH,
    ACTIONS(3799), 1,
      anon_sym_LBRACK,
    STATE(1577), 1,
      aux_sym_block_repeat1,
    STATE(1644), 1,
      sym__hll_pointer_declarator_specifier,
    STATE(1733), 6,
      sym_trace32_hll_variable,
      sym__hll_declarator,
      sym_hll_pointer_declarator,
      sym_hll_function_declarator,
      sym_hll_array_declarator,
      sym_hll_parenthesized_declarator,
  [111318] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3549), 1,
      anon_sym_STAR,
    ACTIONS(3551), 1,
      anon_sym_BSLASH,
    ACTIONS(3555), 1,
      sym__blank,
    ACTIONS(3778), 1,
      anon_sym_LPAREN,
    ACTIONS(3780), 1,
      anon_sym_LBRACK,
    STATE(1577), 1,
      aux_sym_block_repeat1,
    STATE(1640), 1,
      sym__hll_pointer_declarator_specifier,
    STATE(1790), 6,
      sym_trace32_hll_variable,
      sym__hll_declarator,
      sym_hll_pointer_declarator,
      sym_hll_function_declarator,
      sym_hll_array_declarator,
      sym_hll_parenthesized_declarator,
  [111351] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3549), 1,
      anon_sym_STAR,
    ACTIONS(3555), 1,
      sym__blank,
    ACTIONS(3795), 1,
      anon_sym_LPAREN,
    ACTIONS(3797), 1,
      anon_sym_BSLASH,
    ACTIONS(3799), 1,
      anon_sym_LBRACK,
    STATE(1577), 1,
      aux_sym_block_repeat1,
    STATE(1644), 1,
      sym__hll_pointer_declarator_specifier,
    STATE(1749), 6,
      sym_trace32_hll_variable,
      sym__hll_declarator,
      sym_hll_pointer_declarator,
      sym_hll_function_declarator,
      sym_hll_array_declarator,
      sym_hll_parenthesized_declarator,
  [111384] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3549), 1,
      anon_sym_STAR,
    ACTIONS(3795), 1,
      anon_sym_LPAREN,
    ACTIONS(3797), 1,
      anon_sym_BSLASH,
    ACTIONS(3799), 1,
      anon_sym_LBRACK,
    ACTIONS(3889), 1,
      sym__blank,
    STATE(1582), 1,
      aux_sym_block_repeat1,
    STATE(1644), 1,
      sym__hll_pointer_declarator_specifier,
    STATE(1749), 6,
      sym_trace32_hll_variable,
      sym__hll_declarator,
      sym_hll_pointer_declarator,
      sym_hll_function_declarator,
      sym_hll_array_declarator,
      sym_hll_parenthesized_declarator,
  [111417] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3549), 1,
      anon_sym_STAR,
    ACTIONS(3551), 1,
      anon_sym_BSLASH,
    ACTIONS(3555), 1,
      sym__blank,
    ACTIONS(3778), 1,
      anon_sym_LPAREN,
    ACTIONS(3780), 1,
      anon_sym_LBRACK,
    STATE(1577), 1,
      aux_sym_block_repeat1,
    STATE(1640), 1,
      sym__hll_pointer_declarator_specifier,
    STATE(1788), 6,
      sym_trace32_hll_variable,
      sym__hll_declarator,
      sym_hll_pointer_declarator,
      sym_hll_function_declarator,
      sym_hll_array_declarator,
      sym_hll_parenthesized_declarator,
  [111450] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3549), 1,
      anon_sym_STAR,
    ACTIONS(3551), 1,
      anon_sym_BSLASH,
    ACTIONS(3555), 1,
      sym__blank,
    ACTIONS(3778), 1,
      anon_sym_LPAREN,
    ACTIONS(3780), 1,
      anon_sym_LBRACK,
    STATE(1577), 1,
      aux_sym_block_repeat1,
    STATE(1640), 1,
      sym__hll_pointer_declarator_specifier,
    STATE(1805), 6,
      sym_trace32_hll_variable,
      sym__hll_declarator,
      sym_hll_pointer_declarator,
      sym_hll_function_declarator,
      sym_hll_array_declarator,
      sym_hll_parenthesized_declarator,
  [111483] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3549), 1,
      anon_sym_STAR,
    ACTIONS(3551), 1,
      anon_sym_BSLASH,
    ACTIONS(3555), 1,
      sym__blank,
    ACTIONS(3778), 1,
      anon_sym_LPAREN,
    ACTIONS(3780), 1,
      anon_sym_LBRACK,
    STATE(1577), 1,
      aux_sym_block_repeat1,
    STATE(1640), 1,
      sym__hll_pointer_declarator_specifier,
    STATE(1769), 6,
      sym_trace32_hll_variable,
      sym__hll_declarator,
      sym_hll_pointer_declarator,
      sym_hll_function_declarator,
      sym_hll_array_declarator,
      sym_hll_parenthesized_declarator,
  [111516] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3549), 1,
      anon_sym_STAR,
    ACTIONS(3551), 1,
      anon_sym_BSLASH,
    ACTIONS(3778), 1,
      anon_sym_LPAREN,
    ACTIONS(3780), 1,
      anon_sym_LBRACK,
    ACTIONS(3891), 1,
      sym__blank,
    STATE(1635), 1,
      aux_sym_block_repeat1,
    STATE(1640), 1,
      sym__hll_pointer_declarator_specifier,
    STATE(1769), 6,
      sym_trace32_hll_variable,
      sym__hll_declarator,
      sym_hll_pointer_declarator,
      sym_hll_function_declarator,
      sym_hll_array_declarator,
      sym_hll_parenthesized_declarator,
  [111549] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3549), 1,
      anon_sym_STAR,
    ACTIONS(3551), 1,
      anon_sym_BSLASH,
    ACTIONS(3555), 1,
      sym__blank,
    ACTIONS(3778), 1,
      anon_sym_LPAREN,
    ACTIONS(3780), 1,
      anon_sym_LBRACK,
    STATE(1577), 1,
      aux_sym_block_repeat1,
    STATE(1640), 1,
      sym__hll_pointer_declarator_specifier,
    STATE(1787), 6,
      sym_trace32_hll_variable,
      sym__hll_declarator,
      sym_hll_pointer_declarator,
      sym_hll_function_declarator,
      sym_hll_array_declarator,
      sym_hll_parenthesized_declarator,
  [111582] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3549), 1,
      anon_sym_STAR,
    ACTIONS(3555), 1,
      sym__blank,
    ACTIONS(3795), 1,
      anon_sym_LPAREN,
    ACTIONS(3797), 1,
      anon_sym_BSLASH,
    ACTIONS(3799), 1,
      anon_sym_LBRACK,
    STATE(1577), 1,
      aux_sym_block_repeat1,
    STATE(1644), 1,
      sym__hll_pointer_declarator_specifier,
    STATE(1745), 6,
      sym_trace32_hll_variable,
      sym__hll_declarator,
      sym_hll_pointer_declarator,
      sym_hll_function_declarator,
      sym_hll_array_declarator,
      sym_hll_parenthesized_declarator,
  [111615] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3549), 1,
      anon_sym_STAR,
    ACTIONS(3555), 1,
      sym__blank,
    ACTIONS(3795), 1,
      anon_sym_LPAREN,
    ACTIONS(3797), 1,
      anon_sym_BSLASH,
    ACTIONS(3799), 1,
      anon_sym_LBRACK,
    STATE(1577), 1,
      aux_sym_block_repeat1,
    STATE(1644), 1,
      sym__hll_pointer_declarator_specifier,
    STATE(1755), 6,
      sym_trace32_hll_variable,
      sym__hll_declarator,
      sym_hll_pointer_declarator,
      sym_hll_function_declarator,
      sym_hll_array_declarator,
      sym_hll_parenthesized_declarator,
  [111648] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3549), 1,
      anon_sym_STAR,
    ACTIONS(3795), 1,
      anon_sym_LPAREN,
    ACTIONS(3797), 1,
      anon_sym_BSLASH,
    ACTIONS(3799), 1,
      anon_sym_LBRACK,
    ACTIONS(3893), 1,
      sym__blank,
    STATE(1644), 1,
      sym__hll_pointer_declarator_specifier,
    STATE(1657), 1,
      aux_sym_block_repeat1,
    STATE(1755), 6,
      sym_trace32_hll_variable,
      sym__hll_declarator,
      sym_hll_pointer_declarator,
      sym_hll_function_declarator,
      sym_hll_array_declarator,
      sym_hll_parenthesized_declarator,
  [111681] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3549), 1,
      anon_sym_STAR,
    ACTIONS(3795), 1,
      anon_sym_LPAREN,
    ACTIONS(3797), 1,
      anon_sym_BSLASH,
    ACTIONS(3799), 1,
      anon_sym_LBRACK,
    ACTIONS(3895), 1,
      sym__blank,
    STATE(1581), 1,
      aux_sym_block_repeat1,
    STATE(1644), 1,
      sym__hll_pointer_declarator_specifier,
    STATE(1745), 6,
      sym_trace32_hll_variable,
      sym__hll_declarator,
      sym_hll_pointer_declarator,
      sym_hll_function_declarator,
      sym_hll_array_declarator,
      sym_hll_parenthesized_declarator,
  [111714] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3549), 1,
      anon_sym_STAR,
    ACTIONS(3551), 1,
      anon_sym_BSLASH,
    ACTIONS(3778), 1,
      anon_sym_LPAREN,
    ACTIONS(3780), 1,
      anon_sym_LBRACK,
    ACTIONS(3897), 1,
      sym__blank,
    STATE(1588), 1,
      aux_sym_block_repeat1,
    STATE(1640), 1,
      sym__hll_pointer_declarator_specifier,
    STATE(1807), 6,
      sym_trace32_hll_variable,
      sym__hll_declarator,
      sym_hll_pointer_declarator,
      sym_hll_function_declarator,
      sym_hll_array_declarator,
      sym_hll_parenthesized_declarator,
  [111747] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3371), 1,
      sym__blank,
    STATE(952), 1,
      aux_sym_block_repeat1,
    ACTIONS(3773), 11,
      anon_sym_const,
      anon_sym_volatile,
      anon_sym_struct,
      anon_sym_union,
      anon_sym_enum,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
      sym_hll_primitive_type,
      sym_identifier,
  [111770] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3549), 1,
      anon_sym_STAR,
    ACTIONS(3551), 1,
      anon_sym_BSLASH,
    ACTIONS(3778), 1,
      anon_sym_LPAREN,
    ACTIONS(3780), 1,
      anon_sym_LBRACK,
    ACTIONS(3899), 1,
      sym__blank,
    STATE(1592), 1,
      aux_sym_block_repeat1,
    STATE(1640), 1,
      sym__hll_pointer_declarator_specifier,
    STATE(1827), 6,
      sym_trace32_hll_variable,
      sym__hll_declarator,
      sym_hll_pointer_declarator,
      sym_hll_function_declarator,
      sym_hll_array_declarator,
      sym_hll_parenthesized_declarator,
  [111803] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3549), 1,
      anon_sym_STAR,
    ACTIONS(3795), 1,
      anon_sym_LPAREN,
    ACTIONS(3797), 1,
      anon_sym_BSLASH,
    ACTIONS(3799), 1,
      anon_sym_LBRACK,
    ACTIONS(3901), 1,
      sym__blank,
    STATE(1636), 1,
      aux_sym_block_repeat1,
    STATE(1644), 1,
      sym__hll_pointer_declarator_specifier,
    STATE(1714), 6,
      sym_trace32_hll_variable,
      sym__hll_declarator,
      sym_hll_pointer_declarator,
      sym_hll_function_declarator,
      sym_hll_array_declarator,
      sym_hll_parenthesized_declarator,
  [111836] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3549), 1,
      anon_sym_STAR,
    ACTIONS(3795), 1,
      anon_sym_LPAREN,
    ACTIONS(3797), 1,
      anon_sym_BSLASH,
    ACTIONS(3799), 1,
      anon_sym_LBRACK,
    ACTIONS(3903), 1,
      sym__blank,
    STATE(1602), 1,
      aux_sym_block_repeat1,
    STATE(1644), 1,
      sym__hll_pointer_declarator_specifier,
    STATE(1700), 6,
      sym_trace32_hll_variable,
      sym__hll_declarator,
      sym_hll_pointer_declarator,
      sym_hll_function_declarator,
      sym_hll_array_declarator,
      sym_hll_parenthesized_declarator,
  [111869] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3549), 1,
      anon_sym_STAR,
    ACTIONS(3555), 1,
      sym__blank,
    ACTIONS(3795), 1,
      anon_sym_LPAREN,
    ACTIONS(3797), 1,
      anon_sym_BSLASH,
    ACTIONS(3799), 1,
      anon_sym_LBRACK,
    STATE(1577), 1,
      aux_sym_block_repeat1,
    STATE(1644), 1,
      sym__hll_pointer_declarator_specifier,
    STATE(1712), 6,
      sym_trace32_hll_variable,
      sym__hll_declarator,
      sym_hll_pointer_declarator,
      sym_hll_function_declarator,
      sym_hll_array_declarator,
      sym_hll_parenthesized_declarator,
  [111902] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3790), 1,
      anon_sym_CARET,
    ACTIONS(1769), 2,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
    ACTIONS(1771), 2,
      anon_sym_PIPE,
      anon_sym_COLON_COLON_COLON,
    ACTIONS(3782), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3784), 3,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOT_DOT,
    ACTIONS(3786), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [111931] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3549), 1,
      anon_sym_STAR,
    ACTIONS(3795), 1,
      anon_sym_LPAREN,
    ACTIONS(3797), 1,
      anon_sym_BSLASH,
    ACTIONS(3799), 1,
      anon_sym_LBRACK,
    ACTIONS(3905), 1,
      sym__blank,
    STATE(1629), 1,
      aux_sym_block_repeat1,
    STATE(1644), 1,
      sym__hll_pointer_declarator_specifier,
    STATE(1705), 6,
      sym_trace32_hll_variable,
      sym__hll_declarator,
      sym_hll_pointer_declarator,
      sym_hll_function_declarator,
      sym_hll_array_declarator,
      sym_hll_parenthesized_declarator,
  [111964] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3549), 1,
      anon_sym_STAR,
    ACTIONS(3555), 1,
      sym__blank,
    ACTIONS(3795), 1,
      anon_sym_LPAREN,
    ACTIONS(3797), 1,
      anon_sym_BSLASH,
    ACTIONS(3799), 1,
      anon_sym_LBRACK,
    STATE(1577), 1,
      aux_sym_block_repeat1,
    STATE(1644), 1,
      sym__hll_pointer_declarator_specifier,
    STATE(1711), 6,
      sym_trace32_hll_variable,
      sym__hll_declarator,
      sym_hll_pointer_declarator,
      sym_hll_function_declarator,
      sym_hll_array_declarator,
      sym_hll_parenthesized_declarator,
  [111997] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3549), 1,
      anon_sym_STAR,
    ACTIONS(3795), 1,
      anon_sym_LPAREN,
    ACTIONS(3797), 1,
      anon_sym_BSLASH,
    ACTIONS(3799), 1,
      anon_sym_LBRACK,
    ACTIONS(3907), 1,
      sym__blank,
    STATE(1637), 1,
      aux_sym_block_repeat1,
    STATE(1644), 1,
      sym__hll_pointer_declarator_specifier,
    STATE(1716), 6,
      sym_trace32_hll_variable,
      sym__hll_declarator,
      sym_hll_pointer_declarator,
      sym_hll_function_declarator,
      sym_hll_array_declarator,
      sym_hll_parenthesized_declarator,
  [112030] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1743), 1,
      anon_sym_COLON_COLON_COLON,
    ACTIONS(1745), 1,
      anon_sym_COLON_COLON,
    ACTIONS(3788), 1,
      anon_sym_PIPE,
    ACTIONS(3790), 1,
      anon_sym_CARET,
    ACTIONS(3909), 1,
      anon_sym_COLON,
    ACTIONS(3782), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3784), 3,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOT_DOT,
    ACTIONS(3786), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [112063] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3549), 1,
      anon_sym_STAR,
    ACTIONS(3555), 1,
      sym__blank,
    ACTIONS(3795), 1,
      anon_sym_LPAREN,
    ACTIONS(3797), 1,
      anon_sym_BSLASH,
    ACTIONS(3799), 1,
      anon_sym_LBRACK,
    STATE(1577), 1,
      aux_sym_block_repeat1,
    STATE(1644), 1,
      sym__hll_pointer_declarator_specifier,
    STATE(1719), 6,
      sym_trace32_hll_variable,
      sym__hll_declarator,
      sym_hll_pointer_declarator,
      sym_hll_function_declarator,
      sym_hll_array_declarator,
      sym_hll_parenthesized_declarator,
  [112096] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3913), 1,
      sym__blank,
    STATE(1656), 1,
      aux_sym_block_repeat1,
    ACTIONS(3911), 11,
      anon_sym_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [112119] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3371), 1,
      sym__blank,
    STATE(952), 1,
      aux_sym_block_repeat1,
    ACTIONS(3915), 11,
      anon_sym_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [112142] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3784), 3,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOT_DOT,
    ACTIONS(1769), 4,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
    ACTIONS(1771), 6,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_COLON_COLON_COLON,
  [112165] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3919), 1,
      sym__blank,
    STATE(1653), 1,
      aux_sym_block_repeat1,
    ACTIONS(3917), 11,
      anon_sym_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [112188] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3371), 1,
      sym__blank,
    STATE(952), 1,
      aux_sym_block_repeat1,
    ACTIONS(3921), 11,
      anon_sym_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [112211] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3549), 1,
      anon_sym_STAR,
    ACTIONS(3555), 1,
      sym__blank,
    ACTIONS(3795), 1,
      anon_sym_LPAREN,
    ACTIONS(3797), 1,
      anon_sym_BSLASH,
    ACTIONS(3799), 1,
      anon_sym_LBRACK,
    STATE(1577), 1,
      aux_sym_block_repeat1,
    STATE(1644), 1,
      sym__hll_pointer_declarator_specifier,
    STATE(1756), 6,
      sym_trace32_hll_variable,
      sym__hll_declarator,
      sym_hll_pointer_declarator,
      sym_hll_function_declarator,
      sym_hll_array_declarator,
      sym_hll_parenthesized_declarator,
  [112244] = 12,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3555), 1,
      sym__blank,
    ACTIONS(3923), 1,
      sym_identifier,
    ACTIONS(3927), 1,
      anon_sym_PERCENT,
    STATE(1577), 1,
      aux_sym_block_repeat1,
    STATE(1679), 1,
      aux_sym__hll_var_pattern_command_argument_list_format_repeat1,
    STATE(1704), 1,
      aux_sym_hll_type_pattern_repeat1,
    STATE(1793), 1,
      aux_sym__hll_var_pattern_command_argument_list_format_repeat2,
    STATE(2210), 1,
      sym_hll_type_pattern,
    STATE(2318), 1,
      sym__hll_var_pattern_command_argument_list_format,
    STATE(2319), 1,
      sym_format_expression,
    ACTIONS(3925), 2,
      anon_sym_STAR,
      anon_sym_QMARK,
  [112282] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3545), 1,
      anon_sym_RPAREN,
    ACTIONS(3549), 1,
      anon_sym_STAR,
    ACTIONS(3555), 1,
      sym__blank,
    ACTIONS(3579), 1,
      anon_sym_LPAREN,
    ACTIONS(3581), 1,
      anon_sym_LBRACK,
    STATE(1577), 1,
      aux_sym_block_repeat1,
    STATE(1662), 1,
      sym__hll_pointer_declarator_specifier,
    STATE(1747), 5,
      sym__hll_abstract_declarator,
      sym_hll_abstract_pointer_declarator,
      sym_hll_abstract_function_declarator,
      sym_hll_abstract_array_declarator,
      sym_hll_abstract_parenthesized_declarator,
  [112314] = 11,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3929), 1,
      anon_sym_BSLASH,
    ACTIONS(3931), 1,
      anon_sym_DQUOTE,
    ACTIONS(3933), 1,
      aux_sym_symbol_token1,
    ACTIONS(3935), 1,
      aux_sym_symbol_token2,
    ACTIONS(3939), 1,
      sym__blank,
    STATE(1696), 1,
      aux_sym_block_repeat1,
    STATE(2318), 1,
      sym__hll_var_command_argument_list_non_default_format,
    STATE(2380), 1,
      sym_trace32_hll_variable,
    ACTIONS(3937), 2,
      sym_path,
      sym_file_handle,
    STATE(2317), 2,
      sym_string,
      sym_symbol,
  [112350] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3943), 1,
      anon_sym_BSLASH,
    ACTIONS(3945), 1,
      sym__blank,
    STATE(1671), 1,
      sym_hll_type_qualifier,
    STATE(1783), 1,
      aux_sym_block_repeat1,
    STATE(1961), 1,
      aux_sym__hll_pointer_declarator_specifier_repeat1,
    ACTIONS(3583), 2,
      anon_sym_const,
      anon_sym_volatile,
    ACTIONS(3941), 5,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_COMMA,
      anon_sym_LBRACK,
  [112380] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3549), 1,
      anon_sym_STAR,
    ACTIONS(3557), 1,
      anon_sym_RPAREN,
    ACTIONS(3579), 1,
      anon_sym_LPAREN,
    ACTIONS(3581), 1,
      anon_sym_LBRACK,
    ACTIONS(3948), 1,
      sym__blank,
    STATE(1659), 1,
      aux_sym_block_repeat1,
    STATE(1662), 1,
      sym__hll_pointer_declarator_specifier,
    STATE(1752), 5,
      sym__hll_abstract_declarator,
      sym_hll_abstract_pointer_declarator,
      sym_hll_abstract_function_declarator,
      sym_hll_abstract_array_declarator,
      sym_hll_abstract_parenthesized_declarator,
  [112412] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3950), 1,
      sym_identifier,
    ACTIONS(3952), 1,
      aux_sym_if_block_token1,
    ACTIONS(3956), 1,
      aux_sym__hll_non_default_format_var_command_token5,
    ACTIONS(3960), 2,
      aux_sym__hll_var_definition_command_expression_token1,
      aux_sym__hll_var_definition_command_expression_token2,
    ACTIONS(3954), 3,
      aux_sym__hll_non_default_format_var_command_token2,
      aux_sym__hll_non_default_format_var_command_token3,
      aux_sym__hll_non_default_format_var_command_token4,
    ACTIONS(3958), 3,
      aux_sym__var_command_with_non_hll_format_token1,
      aux_sym__var_command_with_non_hll_format_token2,
      aux_sym__var_command_with_non_hll_format_token3,
  [112439] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3549), 1,
      anon_sym_STAR,
    ACTIONS(3555), 1,
      sym__blank,
    ACTIONS(3579), 1,
      anon_sym_LPAREN,
    ACTIONS(3581), 1,
      anon_sym_LBRACK,
    STATE(1577), 1,
      aux_sym_block_repeat1,
    STATE(1662), 1,
      sym__hll_pointer_declarator_specifier,
    STATE(1771), 5,
      sym__hll_abstract_declarator,
      sym_hll_abstract_pointer_declarator,
      sym_hll_abstract_function_declarator,
      sym_hll_abstract_array_declarator,
      sym_hll_abstract_parenthesized_declarator,
  [112468] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3549), 1,
      anon_sym_STAR,
    ACTIONS(3579), 1,
      anon_sym_LPAREN,
    ACTIONS(3581), 1,
      anon_sym_LBRACK,
    ACTIONS(3962), 1,
      sym__blank,
    STATE(1662), 1,
      sym__hll_pointer_declarator_specifier,
    STATE(1664), 1,
      aux_sym_block_repeat1,
    STATE(1797), 5,
      sym__hll_abstract_declarator,
      sym_hll_abstract_pointer_declarator,
      sym_hll_abstract_function_declarator,
      sym_hll_abstract_array_declarator,
      sym_hll_abstract_parenthesized_declarator,
  [112497] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3950), 1,
      sym_identifier,
    ACTIONS(3956), 1,
      aux_sym__hll_non_default_format_var_command_token5,
    ACTIONS(3960), 2,
      aux_sym__hll_var_definition_command_expression_token1,
      aux_sym__hll_var_definition_command_expression_token2,
    ACTIONS(3954), 3,
      aux_sym__hll_non_default_format_var_command_token2,
      aux_sym__hll_non_default_format_var_command_token3,
      aux_sym__hll_non_default_format_var_command_token4,
    ACTIONS(3958), 3,
      aux_sym__var_command_with_non_hll_format_token1,
      aux_sym__var_command_with_non_hll_format_token2,
      aux_sym__var_command_with_non_hll_format_token3,
  [112521] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3966), 1,
      anon_sym_BSLASH,
    ACTIONS(3970), 1,
      sym__blank,
    STATE(1975), 1,
      aux_sym_block_repeat1,
    ACTIONS(3968), 2,
      anon_sym_const,
      anon_sym_volatile,
    ACTIONS(3964), 5,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_COMMA,
      anon_sym_LBRACK,
  [112545] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3976), 1,
      sym__blank,
    STATE(1927), 1,
      aux_sym_block_repeat1,
    ACTIONS(3973), 2,
      anon_sym_const,
      anon_sym_volatile,
    STATE(1668), 2,
      sym_hll_type_qualifier,
      aux_sym_hll_type_descriptor_repeat2,
    ACTIONS(2611), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
  [112569] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3981), 1,
      anon_sym_BSLASH,
    ACTIONS(3983), 1,
      sym__blank,
    STATE(1722), 1,
      aux_sym_block_repeat1,
    ACTIONS(3979), 7,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_const,
      anon_sym_volatile,
  [112591] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3988), 1,
      anon_sym_BSLASH,
    ACTIONS(3990), 1,
      sym__blank,
    STATE(1975), 1,
      aux_sym_block_repeat1,
    ACTIONS(3968), 2,
      anon_sym_const,
      anon_sym_volatile,
    ACTIONS(3986), 5,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_COMMA,
      anon_sym_LBRACK,
  [112615] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3995), 1,
      anon_sym_BSLASH,
    ACTIONS(3997), 1,
      sym__blank,
    STATE(1975), 1,
      aux_sym_block_repeat1,
    ACTIONS(3968), 2,
      anon_sym_const,
      anon_sym_volatile,
    ACTIONS(3993), 5,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_COMMA,
      anon_sym_LBRACK,
  [112639] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4002), 1,
      anon_sym_BSLASH,
    ACTIONS(4004), 1,
      sym__blank,
    STATE(1722), 1,
      aux_sym_block_repeat1,
    ACTIONS(4000), 7,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_const,
      anon_sym_volatile,
  [112661] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4009), 1,
      anon_sym_BSLASH,
    ACTIONS(4007), 8,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_const,
      anon_sym_volatile,
      sym__blank,
  [112678] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4013), 1,
      anon_sym_BSLASH,
    ACTIONS(4015), 1,
      sym__blank,
    STATE(1674), 1,
      aux_sym__hll_declaration_specifiers_repeat2,
    STATE(1782), 1,
      aux_sym_block_repeat1,
    ACTIONS(4011), 5,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_COMMA,
      anon_sym_LBRACK,
  [112701] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4020), 1,
      anon_sym_BSLASH,
    ACTIONS(4018), 8,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_const,
      anon_sym_volatile,
      sym__blank,
  [112718] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4022), 1,
      anon_sym_BSLASH,
    ACTIONS(2435), 8,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_const,
      anon_sym_volatile,
      sym__blank,
  [112735] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4024), 1,
      anon_sym_AMP,
    ACTIONS(4026), 1,
      aux_sym__host_command_argument_list_default_format_token1,
    ACTIONS(4028), 1,
      anon_sym_DQUOTE,
    ACTIONS(4030), 1,
      sym__blank,
    STATE(1744), 1,
      aux_sym__host_command_argument_list_default_format_repeat1,
    STATE(1842), 1,
      aux_sym_block_repeat1,
    STATE(2284), 1,
      sym__host_command_argument_list_default_format,
    STATE(1917), 2,
      sym_macro,
      sym_string,
  [112764] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4034), 1,
      anon_sym_BSLASH,
    ACTIONS(4036), 1,
      sym__blank,
    STATE(1674), 1,
      aux_sym__hll_declaration_specifiers_repeat2,
    STATE(1782), 1,
      aux_sym_block_repeat1,
    ACTIONS(4032), 5,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_COMMA,
      anon_sym_LBRACK,
  [112787] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3923), 1,
      sym_identifier,
    ACTIONS(3927), 1,
      anon_sym_PERCENT,
    STATE(1704), 1,
      aux_sym_hll_type_pattern_repeat1,
    STATE(1777), 1,
      aux_sym__hll_var_pattern_command_argument_list_format_repeat2,
    STATE(1809), 1,
      aux_sym__hll_var_pattern_command_argument_list_format_repeat1,
    STATE(2147), 1,
      sym_hll_type_pattern,
    STATE(2319), 1,
      sym_format_expression,
    ACTIONS(3925), 2,
      anon_sym_STAR,
      anon_sym_QMARK,
  [112816] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4040), 1,
      anon_sym_BSLASH,
    ACTIONS(4038), 8,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_const,
      anon_sym_volatile,
      sym__blank,
  [112833] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4036), 1,
      sym__blank,
    ACTIONS(4044), 1,
      anon_sym_BSLASH,
    STATE(1682), 1,
      aux_sym__hll_declaration_specifiers_repeat2,
    STATE(1782), 1,
      aux_sym_block_repeat1,
    ACTIONS(4042), 5,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_COMMA,
      anon_sym_LBRACK,
  [112856] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4036), 1,
      sym__blank,
    ACTIONS(4048), 1,
      anon_sym_BSLASH,
    STATE(1674), 1,
      aux_sym__hll_declaration_specifiers_repeat2,
    STATE(1782), 1,
      aux_sym_block_repeat1,
    ACTIONS(4046), 5,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_COMMA,
      anon_sym_LBRACK,
  [112879] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4052), 1,
      anon_sym_BSLASH,
    ACTIONS(4050), 8,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_const,
      anon_sym_volatile,
      sym__blank,
  [112896] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4036), 1,
      sym__blank,
    ACTIONS(4056), 1,
      anon_sym_BSLASH,
    STATE(1678), 1,
      aux_sym__hll_declaration_specifiers_repeat2,
    STATE(1782), 1,
      aux_sym_block_repeat1,
    ACTIONS(4054), 5,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_COMMA,
      anon_sym_LBRACK,
  [112919] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4024), 1,
      anon_sym_AMP,
    ACTIONS(4028), 1,
      anon_sym_DQUOTE,
    ACTIONS(4030), 1,
      sym__blank,
    ACTIONS(4058), 1,
      aux_sym__host_command_argument_list_default_format_token1,
    STATE(1842), 1,
      aux_sym_block_repeat1,
    STATE(1937), 1,
      aux_sym__host_command_argument_list_default_format_repeat1,
    STATE(2221), 2,
      sym_macro,
      sym_string,
  [112945] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(422), 1,
      anon_sym_PERCENT,
    ACTIONS(434), 1,
      anon_sym_SLASH,
    ACTIONS(3371), 1,
      sym__blank,
    STATE(952), 1,
      aux_sym_block_repeat1,
    STATE(1929), 1,
      aux_sym__var_command_argument_list_non_hll_format_repeat1,
    STATE(2329), 1,
      sym__var_command_argument_list_non_hll_format,
    STATE(2004), 2,
      sym_option_expression,
      sym_format_expression,
  [112971] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4060), 1,
      aux_sym_elif_block_token1,
    ACTIONS(4064), 1,
      sym__blank,
    STATE(1452), 1,
      sym_else_block,
    STATE(1491), 1,
      sym_elif_block,
    STATE(1727), 1,
      aux_sym_subroutine_block_repeat1,
    STATE(1831), 1,
      aux_sym_block_repeat1,
    ACTIONS(4062), 2,
      sym_comment,
      sym__blank_line,
  [112997] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4066), 1,
      aux_sym_elif_block_token1,
    ACTIONS(4068), 1,
      sym__blank,
    STATE(1491), 1,
      sym_elif_block,
    STATE(1494), 1,
      sym_else_block,
    STATE(1727), 1,
      aux_sym_subroutine_block_repeat1,
    STATE(1908), 1,
      aux_sym_block_repeat1,
    ACTIONS(4062), 2,
      sym_comment,
      sym__blank_line,
  [113023] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4066), 1,
      aux_sym_elif_block_token1,
    ACTIONS(4070), 1,
      sym__blank,
    STATE(1452), 1,
      sym_else_block,
    STATE(1491), 1,
      sym_elif_block,
    STATE(1727), 1,
      aux_sym_subroutine_block_repeat1,
    STATE(1912), 1,
      aux_sym_block_repeat1,
    ACTIONS(4062), 2,
      sym_comment,
      sym__blank_line,
  [113049] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4060), 1,
      aux_sym_elif_block_token1,
    ACTIONS(4072), 1,
      sym__blank,
    STATE(1491), 1,
      sym_elif_block,
    STATE(1494), 1,
      sym_else_block,
    STATE(1727), 1,
      aux_sym_subroutine_block_repeat1,
    STATE(1919), 1,
      aux_sym_block_repeat1,
    ACTIONS(4062), 2,
      sym_comment,
      sym__blank_line,
  [113075] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4074), 1,
      aux_sym_elif_block_token1,
    ACTIONS(4076), 1,
      sym__blank,
    STATE(1491), 1,
      sym_elif_block,
    STATE(1494), 1,
      sym_else_block,
    STATE(1727), 1,
      aux_sym_subroutine_block_repeat1,
    STATE(1931), 1,
      aux_sym_block_repeat1,
    ACTIONS(4062), 2,
      sym_comment,
      sym__blank_line,
  [113101] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4066), 1,
      aux_sym_elif_block_token1,
    ACTIONS(4078), 1,
      sym__blank,
    STATE(1437), 1,
      sym_else_block,
    STATE(1491), 1,
      sym_elif_block,
    STATE(1727), 1,
      aux_sym_subroutine_block_repeat1,
    STATE(1914), 1,
      aux_sym_block_repeat1,
    ACTIONS(4062), 2,
      sym_comment,
      sym__blank_line,
  [113127] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4074), 1,
      aux_sym_elif_block_token1,
    ACTIONS(4080), 1,
      sym__blank,
    STATE(1452), 1,
      sym_else_block,
    STATE(1491), 1,
      sym_elif_block,
    STATE(1727), 1,
      aux_sym_subroutine_block_repeat1,
    STATE(1933), 1,
      aux_sym_block_repeat1,
    ACTIONS(4062), 2,
      sym_comment,
      sym__blank_line,
  [113153] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4074), 1,
      aux_sym_elif_block_token1,
    ACTIONS(4082), 1,
      sym__blank,
    STATE(1437), 1,
      sym_else_block,
    STATE(1491), 1,
      sym_elif_block,
    STATE(1727), 1,
      aux_sym_subroutine_block_repeat1,
    STATE(1935), 1,
      aux_sym_block_repeat1,
    ACTIONS(4062), 2,
      sym_comment,
      sym__blank_line,
  [113179] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4060), 1,
      aux_sym_elif_block_token1,
    ACTIONS(4084), 1,
      sym__blank,
    STATE(1437), 1,
      sym_else_block,
    STATE(1491), 1,
      sym_elif_block,
    STATE(1727), 1,
      aux_sym_subroutine_block_repeat1,
    STATE(1868), 1,
      aux_sym_block_repeat1,
    ACTIONS(4062), 2,
      sym_comment,
      sym__blank_line,
  [113205] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4086), 1,
      sym__blank,
    STATE(1696), 1,
      aux_sym_block_repeat1,
    ACTIONS(2122), 2,
      anon_sym_BSLASH,
      aux_sym_symbol_token2,
    ACTIONS(2120), 4,
      sym_path,
      anon_sym_DQUOTE,
      aux_sym_symbol_token1,
      sym_file_handle,
  [113225] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4089), 1,
      aux_sym_elif_block_token1,
    ACTIONS(4091), 1,
      sym__blank,
    STATE(1491), 1,
      sym_elif_block,
    STATE(1494), 1,
      sym_else_block,
    STATE(1727), 1,
      aux_sym_subroutine_block_repeat1,
    STATE(1941), 1,
      aux_sym_block_repeat1,
    ACTIONS(4062), 2,
      sym_comment,
      sym__blank_line,
  [113251] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4089), 1,
      aux_sym_elif_block_token1,
    ACTIONS(4093), 1,
      sym__blank,
    STATE(1452), 1,
      sym_else_block,
    STATE(1491), 1,
      sym_elif_block,
    STATE(1727), 1,
      aux_sym_subroutine_block_repeat1,
    STATE(1942), 1,
      aux_sym_block_repeat1,
    ACTIONS(4062), 2,
      sym_comment,
      sym__blank_line,
  [113277] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4089), 1,
      aux_sym_elif_block_token1,
    ACTIONS(4095), 1,
      sym__blank,
    STATE(1437), 1,
      sym_else_block,
    STATE(1491), 1,
      sym_elif_block,
    STATE(1727), 1,
      aux_sym_subroutine_block_repeat1,
    STATE(1944), 1,
      aux_sym_block_repeat1,
    ACTIONS(4062), 2,
      sym_comment,
      sym__blank_line,
  [113303] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4097), 1,
      anon_sym_LPAREN,
    ACTIONS(4101), 1,
      sym__blank,
    STATE(1846), 1,
      sym_hll_parameter_list,
    STATE(1962), 1,
      aux_sym_block_repeat1,
    ACTIONS(4099), 3,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [113324] = 5,
    ACTIONS(4103), 1,
      anon_sym_AMP,
    ACTIONS(4105), 1,
      anon_sym_DQUOTE,
    ACTIONS(4109), 1,
      sym__line_continuation,
    STATE(1740), 2,
      sym_macro,
      aux_sym_string_repeat1,
    ACTIONS(4107), 3,
      sym__ampersand_char,
      aux_sym_string_token1,
      aux_sym_string_token2,
  [113343] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4097), 1,
      anon_sym_LPAREN,
    ACTIONS(4101), 1,
      sym__blank,
    STATE(1846), 1,
      sym_hll_parameter_list,
    STATE(1962), 1,
      aux_sym_block_repeat1,
    ACTIONS(4111), 3,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [113364] = 5,
    ACTIONS(4103), 1,
      anon_sym_AMP,
    ACTIONS(4109), 1,
      sym__line_continuation,
    ACTIONS(4113), 1,
      anon_sym_DQUOTE,
    STATE(1709), 2,
      sym_macro,
      aux_sym_string_repeat1,
    ACTIONS(4115), 3,
      sym__ampersand_char,
      aux_sym_string_token1,
      aux_sym_string_token2,
  [113383] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3923), 1,
      sym_identifier,
    ACTIONS(4121), 1,
      sym__blank,
    STATE(1741), 1,
      aux_sym_hll_type_pattern_repeat1,
    ACTIONS(4117), 2,
      anon_sym_STAR,
      anon_sym_QMARK,
    ACTIONS(4119), 2,
      sym_comment,
      sym__blank_line,
  [113404] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4097), 1,
      anon_sym_LPAREN,
    ACTIONS(4101), 1,
      sym__blank,
    STATE(1846), 1,
      sym_hll_parameter_list,
    STATE(1962), 1,
      aux_sym_block_repeat1,
    ACTIONS(4123), 3,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [113425] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4034), 1,
      anon_sym_BSLASH,
    ACTIONS(4125), 1,
      sym__blank,
    STATE(1674), 1,
      aux_sym__hll_declaration_specifiers_repeat2,
    STATE(1782), 1,
      aux_sym_block_repeat1,
    ACTIONS(4032), 3,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
  [113446] = 5,
    ACTIONS(4103), 1,
      anon_sym_AMP,
    ACTIONS(4109), 1,
      sym__line_continuation,
    ACTIONS(4128), 1,
      anon_sym_DQUOTE,
    STATE(1740), 2,
      sym_macro,
      aux_sym_string_repeat1,
    ACTIONS(4107), 3,
      sym__ampersand_char,
      aux_sym_string_token1,
      aux_sym_string_token2,
  [113465] = 5,
    ACTIONS(4103), 1,
      anon_sym_AMP,
    ACTIONS(4109), 1,
      sym__line_continuation,
    ACTIONS(4130), 1,
      anon_sym_DQUOTE,
    STATE(1707), 2,
      sym_macro,
      aux_sym_string_repeat1,
    ACTIONS(4132), 3,
      sym__ampersand_char,
      aux_sym_string_token1,
      aux_sym_string_token2,
  [113484] = 5,
    ACTIONS(4103), 1,
      anon_sym_AMP,
    ACTIONS(4109), 1,
      sym__line_continuation,
    ACTIONS(4134), 1,
      anon_sym_DQUOTE,
    STATE(1740), 2,
      sym_macro,
      aux_sym_string_repeat1,
    ACTIONS(4107), 3,
      sym__ampersand_char,
      aux_sym_string_token1,
      aux_sym_string_token2,
  [113503] = 5,
    ACTIONS(4103), 1,
      anon_sym_AMP,
    ACTIONS(4109), 1,
      sym__line_continuation,
    ACTIONS(4136), 1,
      anon_sym_DQUOTE,
    STATE(1718), 2,
      sym_macro,
      aux_sym_string_repeat1,
    ACTIONS(4138), 3,
      sym__ampersand_char,
      aux_sym_string_token1,
      aux_sym_string_token2,
  [113522] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4097), 1,
      anon_sym_LPAREN,
    ACTIONS(4101), 1,
      sym__blank,
    STATE(1846), 1,
      sym_hll_parameter_list,
    STATE(1962), 1,
      aux_sym_block_repeat1,
    ACTIONS(4140), 3,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [113543] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4097), 1,
      anon_sym_LPAREN,
    ACTIONS(4101), 1,
      sym__blank,
    STATE(1846), 1,
      sym_hll_parameter_list,
    STATE(1962), 1,
      aux_sym_block_repeat1,
    ACTIONS(4142), 3,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [113564] = 5,
    ACTIONS(4103), 1,
      anon_sym_AMP,
    ACTIONS(4109), 1,
      sym__line_continuation,
    ACTIONS(4144), 1,
      anon_sym_DQUOTE,
    STATE(1720), 2,
      sym_macro,
      aux_sym_string_repeat1,
    ACTIONS(4146), 3,
      sym__ampersand_char,
      aux_sym_string_token1,
      aux_sym_string_token2,
  [113583] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4097), 1,
      anon_sym_LPAREN,
    ACTIONS(4101), 1,
      sym__blank,
    STATE(1846), 1,
      sym_hll_parameter_list,
    STATE(1962), 1,
      aux_sym_block_repeat1,
    ACTIONS(4148), 3,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [113604] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4097), 1,
      anon_sym_LPAREN,
    ACTIONS(4101), 1,
      sym__blank,
    STATE(1846), 1,
      sym_hll_parameter_list,
    STATE(1962), 1,
      aux_sym_block_repeat1,
    ACTIONS(4150), 3,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [113625] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4097), 1,
      anon_sym_LPAREN,
    ACTIONS(4101), 1,
      sym__blank,
    STATE(1846), 1,
      sym_hll_parameter_list,
    STATE(1962), 1,
      aux_sym_block_repeat1,
    ACTIONS(4152), 3,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [113646] = 5,
    ACTIONS(4103), 1,
      anon_sym_AMP,
    ACTIONS(4109), 1,
      sym__line_continuation,
    ACTIONS(4154), 1,
      anon_sym_DQUOTE,
    STATE(1740), 2,
      sym_macro,
      aux_sym_string_repeat1,
    ACTIONS(4107), 3,
      sym__ampersand_char,
      aux_sym_string_token1,
      aux_sym_string_token2,
  [113665] = 5,
    ACTIONS(4103), 1,
      anon_sym_AMP,
    ACTIONS(4109), 1,
      sym__line_continuation,
    ACTIONS(4156), 1,
      anon_sym_DQUOTE,
    STATE(1740), 2,
      sym_macro,
      aux_sym_string_repeat1,
    ACTIONS(4107), 3,
      sym__ampersand_char,
      aux_sym_string_token1,
      aux_sym_string_token2,
  [113684] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4097), 1,
      anon_sym_LPAREN,
    ACTIONS(4101), 1,
      sym__blank,
    STATE(1846), 1,
      sym_hll_parameter_list,
    STATE(1962), 1,
      aux_sym_block_repeat1,
    ACTIONS(4158), 3,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [113705] = 5,
    ACTIONS(4103), 1,
      anon_sym_AMP,
    ACTIONS(4109), 1,
      sym__line_continuation,
    ACTIONS(4160), 1,
      anon_sym_DQUOTE,
    STATE(1740), 2,
      sym_macro,
      aux_sym_string_repeat1,
    ACTIONS(4107), 3,
      sym__ampersand_char,
      aux_sym_string_token1,
      aux_sym_string_token2,
  [113724] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4164), 1,
      anon_sym_LPAREN,
    ACTIONS(4166), 1,
      anon_sym_LBRACK,
    ACTIONS(4168), 1,
      sym__blank,
    STATE(1867), 1,
      sym_hll_parameter_list,
    STATE(1876), 1,
      aux_sym_block_repeat1,
    ACTIONS(4162), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
  [113747] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3371), 1,
      sym__blank,
    STATE(952), 1,
      aux_sym_block_repeat1,
    ACTIONS(4170), 5,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
      sym_identifier,
  [113764] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(9), 1,
      aux_sym_block_token1,
    ACTIONS(4174), 1,
      sym__blank,
    STATE(1498), 1,
      sym_block,
    STATE(1738), 1,
      aux_sym_subroutine_block_repeat1,
    STATE(2218), 1,
      aux_sym_block_repeat1,
    ACTIONS(4172), 2,
      sym_comment,
      sym__blank_line,
  [113787] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4048), 1,
      anon_sym_BSLASH,
    ACTIONS(4176), 1,
      sym__blank,
    STATE(1674), 1,
      aux_sym__hll_declaration_specifiers_repeat2,
    STATE(1782), 1,
      aux_sym_block_repeat1,
    ACTIONS(4046), 3,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
  [113808] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4097), 1,
      anon_sym_LPAREN,
    ACTIONS(4101), 1,
      sym__blank,
    STATE(1846), 1,
      sym_hll_parameter_list,
    STATE(1962), 1,
      aux_sym_block_repeat1,
    ACTIONS(4179), 3,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [113829] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2611), 7,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_const,
      anon_sym_volatile,
      sym__blank,
  [113842] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3509), 1,
      sym__blank,
    STATE(1727), 1,
      aux_sym_subroutine_block_repeat1,
    ACTIONS(4181), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(3511), 3,
      aux_sym_block_token1,
      aux_sym_elif_block_token1,
      aux_sym_while_block_token1,
  [113861] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4097), 1,
      anon_sym_LPAREN,
    ACTIONS(4101), 1,
      sym__blank,
    STATE(1846), 1,
      sym_hll_parameter_list,
    STATE(1962), 1,
      aux_sym_block_repeat1,
    ACTIONS(4184), 3,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [113882] = 5,
    ACTIONS(4103), 1,
      anon_sym_AMP,
    ACTIONS(4109), 1,
      sym__line_continuation,
    ACTIONS(4186), 1,
      anon_sym_DQUOTE,
    STATE(1740), 2,
      sym_macro,
      aux_sym_string_repeat1,
    ACTIONS(4107), 3,
      sym__ampersand_char,
      aux_sym_string_token1,
      aux_sym_string_token2,
  [113901] = 5,
    ACTIONS(4103), 1,
      anon_sym_AMP,
    ACTIONS(4109), 1,
      sym__line_continuation,
    ACTIONS(4188), 1,
      anon_sym_DQUOTE,
    STATE(1731), 2,
      sym_macro,
      aux_sym_string_repeat1,
    ACTIONS(4190), 3,
      sym__ampersand_char,
      aux_sym_string_token1,
      aux_sym_string_token2,
  [113920] = 5,
    ACTIONS(4103), 1,
      anon_sym_AMP,
    ACTIONS(4109), 1,
      sym__line_continuation,
    ACTIONS(4192), 1,
      anon_sym_DQUOTE,
    STATE(1740), 2,
      sym_macro,
      aux_sym_string_repeat1,
    ACTIONS(4107), 3,
      sym__ampersand_char,
      aux_sym_string_token1,
      aux_sym_string_token2,
  [113939] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4097), 1,
      anon_sym_LPAREN,
    ACTIONS(4101), 1,
      sym__blank,
    STATE(1846), 1,
      sym_hll_parameter_list,
    STATE(1962), 1,
      aux_sym_block_repeat1,
    ACTIONS(4194), 3,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [113960] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4097), 1,
      anon_sym_LPAREN,
    ACTIONS(4101), 1,
      sym__blank,
    STATE(1846), 1,
      sym_hll_parameter_list,
    STATE(1962), 1,
      aux_sym_block_repeat1,
    ACTIONS(4196), 3,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [113981] = 5,
    ACTIONS(4103), 1,
      anon_sym_AMP,
    ACTIONS(4109), 1,
      sym__line_continuation,
    ACTIONS(4198), 1,
      anon_sym_DQUOTE,
    STATE(1748), 2,
      sym_macro,
      aux_sym_string_repeat1,
    ACTIONS(4200), 3,
      sym__ampersand_char,
      aux_sym_string_token1,
      aux_sym_string_token2,
  [114000] = 5,
    ACTIONS(4103), 1,
      anon_sym_AMP,
    ACTIONS(4109), 1,
      sym__line_continuation,
    ACTIONS(4202), 1,
      anon_sym_DQUOTE,
    STATE(1740), 2,
      sym_macro,
      aux_sym_string_repeat1,
    ACTIONS(4107), 3,
      sym__ampersand_char,
      aux_sym_string_token1,
      aux_sym_string_token2,
  [114019] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4056), 1,
      anon_sym_BSLASH,
    ACTIONS(4204), 1,
      sym__blank,
    STATE(1706), 1,
      aux_sym__hll_declaration_specifiers_repeat2,
    STATE(1782), 1,
      aux_sym_block_repeat1,
    ACTIONS(4054), 3,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
  [114040] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4097), 1,
      anon_sym_LPAREN,
    ACTIONS(4101), 1,
      sym__blank,
    STATE(1846), 1,
      sym_hll_parameter_list,
    STATE(1962), 1,
      aux_sym_block_repeat1,
    ACTIONS(4207), 3,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [114061] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(9), 1,
      aux_sym_block_token1,
    ACTIONS(4174), 1,
      sym__blank,
    STATE(1436), 1,
      sym_block,
    STATE(1727), 1,
      aux_sym_subroutine_block_repeat1,
    STATE(2218), 1,
      aux_sym_block_repeat1,
    ACTIONS(4062), 2,
      sym_comment,
      sym__blank_line,
  [114084] = 5,
    ACTIONS(4103), 1,
      anon_sym_AMP,
    ACTIONS(4109), 1,
      sym__line_continuation,
    ACTIONS(4209), 1,
      anon_sym_DQUOTE,
    STATE(1735), 2,
      sym_macro,
      aux_sym_string_repeat1,
    ACTIONS(4211), 3,
      sym__ampersand_char,
      aux_sym_string_token1,
      aux_sym_string_token2,
  [114103] = 5,
    ACTIONS(4109), 1,
      sym__line_continuation,
    ACTIONS(4213), 1,
      anon_sym_AMP,
    ACTIONS(4216), 1,
      anon_sym_DQUOTE,
    STATE(1740), 2,
      sym_macro,
      aux_sym_string_repeat1,
    ACTIONS(4218), 3,
      sym__ampersand_char,
      aux_sym_string_token1,
      aux_sym_string_token2,
  [114122] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4221), 1,
      sym_identifier,
    ACTIONS(4229), 1,
      sym__blank,
    STATE(1741), 1,
      aux_sym_hll_type_pattern_repeat1,
    ACTIONS(4224), 2,
      anon_sym_STAR,
      anon_sym_QMARK,
    ACTIONS(4227), 2,
      sym_comment,
      sym__blank_line,
  [114143] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4013), 1,
      anon_sym_BSLASH,
    ACTIONS(4011), 6,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      sym__blank,
  [114158] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3367), 1,
      sym_identifier,
    STATE(1673), 1,
      sym__hll_type_identifier,
    STATE(1785), 1,
      aux_sym_hll_sized_type_specifier_repeat1,
    ACTIONS(4231), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
  [114177] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4233), 1,
      aux_sym__host_command_argument_list_default_format_token1,
    ACTIONS(4237), 1,
      sym__blank,
    STATE(1685), 1,
      aux_sym_block_repeat1,
    STATE(1819), 1,
      aux_sym__host_command_argument_list_default_format_repeat2,
    STATE(1945), 1,
      aux_sym__host_command_argument_list_default_format_repeat1,
    ACTIONS(4235), 2,
      sym_comment,
      sym__blank_line,
  [114200] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4097), 1,
      anon_sym_LPAREN,
    ACTIONS(4101), 1,
      sym__blank,
    STATE(1846), 1,
      sym_hll_parameter_list,
    STATE(1962), 1,
      aux_sym_block_repeat1,
    ACTIONS(4239), 3,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [114221] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4097), 1,
      anon_sym_LPAREN,
    ACTIONS(4101), 1,
      sym__blank,
    STATE(1846), 1,
      sym_hll_parameter_list,
    STATE(1962), 1,
      aux_sym_block_repeat1,
    ACTIONS(4241), 3,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [114242] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4164), 1,
      anon_sym_LPAREN,
    ACTIONS(4166), 1,
      anon_sym_LBRACK,
    ACTIONS(4168), 1,
      sym__blank,
    STATE(1867), 1,
      sym_hll_parameter_list,
    STATE(1876), 1,
      aux_sym_block_repeat1,
    ACTIONS(4243), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
  [114265] = 5,
    ACTIONS(4103), 1,
      anon_sym_AMP,
    ACTIONS(4109), 1,
      sym__line_continuation,
    ACTIONS(4245), 1,
      anon_sym_DQUOTE,
    STATE(1740), 2,
      sym_macro,
      aux_sym_string_repeat1,
    ACTIONS(4107), 3,
      sym__ampersand_char,
      aux_sym_string_token1,
      aux_sym_string_token2,
  [114284] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4097), 1,
      anon_sym_LPAREN,
    ACTIONS(4101), 1,
      sym__blank,
    STATE(1846), 1,
      sym_hll_parameter_list,
    STATE(1962), 1,
      aux_sym_block_repeat1,
    ACTIONS(4247), 3,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [114305] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4044), 1,
      anon_sym_BSLASH,
    ACTIONS(4249), 1,
      sym__blank,
    STATE(1724), 1,
      aux_sym__hll_declaration_specifiers_repeat2,
    STATE(1782), 1,
      aux_sym_block_repeat1,
    ACTIONS(4042), 3,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
  [114326] = 5,
    ACTIONS(4103), 1,
      anon_sym_AMP,
    ACTIONS(4109), 1,
      sym__line_continuation,
    ACTIONS(4252), 1,
      anon_sym_DQUOTE,
    STATE(1701), 2,
      sym_macro,
      aux_sym_string_repeat1,
    ACTIONS(4254), 3,
      sym__ampersand_char,
      aux_sym_string_token1,
      aux_sym_string_token2,
  [114345] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4164), 1,
      anon_sym_LPAREN,
    ACTIONS(4166), 1,
      anon_sym_LBRACK,
    ACTIONS(4168), 1,
      sym__blank,
    STATE(1867), 1,
      sym_hll_parameter_list,
    STATE(1876), 1,
      aux_sym_block_repeat1,
    ACTIONS(4256), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
  [114368] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4258), 1,
      aux_sym_elif_block_token1,
    ACTIONS(4260), 1,
      sym__blank,
    STATE(1491), 1,
      sym_elif_block,
    STATE(1727), 1,
      aux_sym_subroutine_block_repeat1,
    STATE(2016), 1,
      aux_sym_block_repeat1,
    ACTIONS(4062), 2,
      sym_comment,
      sym__blank_line,
  [114391] = 5,
    ACTIONS(4103), 1,
      anon_sym_AMP,
    ACTIONS(4109), 1,
      sym__line_continuation,
    ACTIONS(4262), 1,
      anon_sym_DQUOTE,
    STATE(1760), 2,
      sym_macro,
      aux_sym_string_repeat1,
    ACTIONS(4264), 3,
      sym__ampersand_char,
      aux_sym_string_token1,
      aux_sym_string_token2,
  [114410] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4097), 1,
      anon_sym_LPAREN,
    ACTIONS(4101), 1,
      sym__blank,
    STATE(1846), 1,
      sym_hll_parameter_list,
    STATE(1962), 1,
      aux_sym_block_repeat1,
    ACTIONS(4266), 3,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [114431] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4097), 1,
      anon_sym_LPAREN,
    ACTIONS(4101), 1,
      sym__blank,
    STATE(1846), 1,
      sym_hll_parameter_list,
    STATE(1962), 1,
      aux_sym_block_repeat1,
    ACTIONS(4268), 3,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [114452] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4270), 1,
      aux_sym_elif_block_token1,
    ACTIONS(4272), 1,
      sym__blank,
    STATE(1491), 1,
      sym_elif_block,
    STATE(1727), 1,
      aux_sym_subroutine_block_repeat1,
    STATE(1965), 1,
      aux_sym_block_repeat1,
    ACTIONS(4062), 2,
      sym_comment,
      sym__blank_line,
  [114475] = 5,
    ACTIONS(4103), 1,
      anon_sym_AMP,
    ACTIONS(4109), 1,
      sym__line_continuation,
    ACTIONS(4274), 1,
      anon_sym_DQUOTE,
    STATE(1717), 2,
      sym_macro,
      aux_sym_string_repeat1,
    ACTIONS(4276), 3,
      sym__ampersand_char,
      aux_sym_string_token1,
      aux_sym_string_token2,
  [114494] = 5,
    ACTIONS(4103), 1,
      anon_sym_AMP,
    ACTIONS(4109), 1,
      sym__line_continuation,
    ACTIONS(4278), 1,
      anon_sym_DQUOTE,
    STATE(1762), 2,
      sym_macro,
      aux_sym_string_repeat1,
    ACTIONS(4280), 3,
      sym__ampersand_char,
      aux_sym_string_token1,
      aux_sym_string_token2,
  [114513] = 5,
    ACTIONS(4103), 1,
      anon_sym_AMP,
    ACTIONS(4109), 1,
      sym__line_continuation,
    ACTIONS(4282), 1,
      anon_sym_DQUOTE,
    STATE(1740), 2,
      sym_macro,
      aux_sym_string_repeat1,
    ACTIONS(4107), 3,
      sym__ampersand_char,
      aux_sym_string_token1,
      aux_sym_string_token2,
  [114532] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4097), 1,
      anon_sym_LPAREN,
    ACTIONS(4101), 1,
      sym__blank,
    STATE(1846), 1,
      sym_hll_parameter_list,
    STATE(1962), 1,
      aux_sym_block_repeat1,
    ACTIONS(4284), 3,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [114553] = 5,
    ACTIONS(4103), 1,
      anon_sym_AMP,
    ACTIONS(4109), 1,
      sym__line_continuation,
    ACTIONS(4286), 1,
      anon_sym_DQUOTE,
    STATE(1740), 2,
      sym_macro,
      aux_sym_string_repeat1,
    ACTIONS(4107), 3,
      sym__ampersand_char,
      aux_sym_string_token1,
      aux_sym_string_token2,
  [114572] = 5,
    ACTIONS(4103), 1,
      anon_sym_AMP,
    ACTIONS(4109), 1,
      sym__line_continuation,
    ACTIONS(4288), 1,
      anon_sym_DQUOTE,
    STATE(1729), 2,
      sym_macro,
      aux_sym_string_repeat1,
    ACTIONS(4290), 3,
      sym__ampersand_char,
      aux_sym_string_token1,
      aux_sym_string_token2,
  [114591] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4164), 1,
      anon_sym_LPAREN,
    ACTIONS(4166), 1,
      anon_sym_LBRACK,
    ACTIONS(4168), 1,
      sym__blank,
    ACTIONS(4292), 1,
      anon_sym_RPAREN,
    STATE(1867), 1,
      sym_hll_parameter_list,
    STATE(1876), 1,
      aux_sym_block_repeat1,
  [114613] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4164), 1,
      anon_sym_LPAREN,
    ACTIONS(4166), 1,
      anon_sym_LBRACK,
    ACTIONS(4168), 1,
      sym__blank,
    ACTIONS(4294), 1,
      anon_sym_RPAREN,
    STATE(1867), 1,
      sym_hll_parameter_list,
    STATE(1876), 1,
      aux_sym_block_repeat1,
  [114635] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4296), 1,
      anon_sym_DOT,
    ACTIONS(4301), 1,
      sym__blank,
    STATE(1766), 1,
      aux_sym_format_expression_repeat1,
    ACTIONS(4299), 3,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [114653] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3555), 1,
      sym__blank,
    STATE(1577), 1,
      aux_sym_block_repeat1,
    ACTIONS(4303), 4,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_QMARK,
      sym_identifier,
  [114669] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4164), 1,
      anon_sym_LPAREN,
    ACTIONS(4305), 1,
      sym__blank,
    STATE(1977), 1,
      aux_sym_block_repeat1,
    STATE(1994), 1,
      sym_hll_parameter_list,
    ACTIONS(4162), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
  [114689] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4164), 1,
      anon_sym_LPAREN,
    ACTIONS(4305), 1,
      sym__blank,
    STATE(1977), 1,
      aux_sym_block_repeat1,
    STATE(1994), 1,
      sym_hll_parameter_list,
    ACTIONS(4239), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
  [114709] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3555), 1,
      sym__blank,
    ACTIONS(4164), 1,
      anon_sym_LPAREN,
    ACTIONS(4307), 1,
      anon_sym_RPAREN,
    ACTIONS(4309), 1,
      anon_sym_LBRACK,
    STATE(1577), 1,
      aux_sym_block_repeat1,
    STATE(1926), 1,
      sym_hll_parameter_list,
  [114731] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4164), 1,
      anon_sym_LPAREN,
    ACTIONS(4166), 1,
      anon_sym_LBRACK,
    ACTIONS(4307), 1,
      anon_sym_RPAREN,
    ACTIONS(4311), 1,
      sym__blank,
    STATE(1799), 1,
      aux_sym_block_repeat1,
    STATE(1867), 1,
      sym_hll_parameter_list,
  [114753] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4164), 1,
      anon_sym_LPAREN,
    ACTIONS(4305), 1,
      sym__blank,
    STATE(1977), 1,
      aux_sym_block_repeat1,
    STATE(1994), 1,
      sym_hll_parameter_list,
    ACTIONS(4207), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
  [114773] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4313), 1,
      anon_sym_DOT,
    ACTIONS(4317), 1,
      sym__blank,
    STATE(1766), 1,
      aux_sym_format_expression_repeat1,
    ACTIONS(4315), 3,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [114791] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4164), 1,
      anon_sym_LPAREN,
    ACTIONS(4166), 1,
      anon_sym_LBRACK,
    ACTIONS(4168), 1,
      sym__blank,
    ACTIONS(4319), 1,
      anon_sym_RPAREN,
    STATE(1867), 1,
      sym_hll_parameter_list,
    STATE(1876), 1,
      aux_sym_block_repeat1,
  [114813] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4164), 1,
      anon_sym_LPAREN,
    ACTIONS(4166), 1,
      anon_sym_LBRACK,
    ACTIONS(4168), 1,
      sym__blank,
    ACTIONS(4321), 1,
      anon_sym_RPAREN,
    STATE(1867), 1,
      sym_hll_parameter_list,
    STATE(1876), 1,
      aux_sym_block_repeat1,
  [114835] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4164), 1,
      anon_sym_LPAREN,
    ACTIONS(4305), 1,
      sym__blank,
    STATE(1977), 1,
      aux_sym_block_repeat1,
    STATE(1994), 1,
      sym_hll_parameter_list,
    ACTIONS(4284), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
  [114855] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3923), 1,
      sym_identifier,
    STATE(1704), 1,
      aux_sym_hll_type_pattern_repeat1,
    STATE(1812), 1,
      aux_sym__hll_var_pattern_command_argument_list_format_repeat2,
    STATE(2111), 1,
      sym_hll_type_pattern,
    ACTIONS(3925), 2,
      anon_sym_STAR,
      anon_sym_QMARK,
  [114875] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4164), 1,
      anon_sym_LPAREN,
    ACTIONS(4305), 1,
      sym__blank,
    STATE(1977), 1,
      aux_sym_block_repeat1,
    STATE(1994), 1,
      sym_hll_parameter_list,
    ACTIONS(4179), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
  [114895] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(9), 1,
      aux_sym_block_token1,
    ACTIONS(4174), 1,
      sym__blank,
    ACTIONS(4323), 1,
      sym_comment,
    STATE(1482), 1,
      sym_block,
    STATE(2021), 1,
      aux_sym_labeled_expression_repeat1,
    STATE(2218), 1,
      aux_sym_block_repeat1,
  [114917] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4164), 1,
      anon_sym_LPAREN,
    ACTIONS(4305), 1,
      sym__blank,
    STATE(1977), 1,
      aux_sym_block_repeat1,
    STATE(1994), 1,
      sym_hll_parameter_list,
    ACTIONS(4196), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
  [114937] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4164), 1,
      anon_sym_LPAREN,
    ACTIONS(4166), 1,
      anon_sym_LBRACK,
    ACTIONS(4168), 1,
      sym__blank,
    ACTIONS(4325), 1,
      anon_sym_RPAREN,
    STATE(1867), 1,
      sym_hll_parameter_list,
    STATE(1876), 1,
      aux_sym_block_repeat1,
  [114959] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3371), 1,
      sym__blank,
    STATE(952), 1,
      aux_sym_block_repeat1,
    ACTIONS(3583), 2,
      anon_sym_const,
      anon_sym_volatile,
    STATE(1742), 2,
      sym_hll_type_qualifier,
      sym__hll_declaration_modifiers,
  [114977] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3371), 1,
      sym__blank,
    STATE(952), 1,
      aux_sym_block_repeat1,
    STATE(1667), 1,
      sym_hll_type_qualifier,
    STATE(1978), 1,
      aux_sym__hll_pointer_declarator_specifier_repeat1,
    ACTIONS(3583), 2,
      anon_sym_const,
      anon_sym_volatile,
  [114997] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4164), 1,
      anon_sym_LPAREN,
    ACTIONS(4305), 1,
      sym__blank,
    STATE(1977), 1,
      aux_sym_block_repeat1,
    STATE(1994), 1,
      sym_hll_parameter_list,
    ACTIONS(4148), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
  [115017] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4170), 1,
      sym_identifier,
    STATE(1785), 1,
      aux_sym_hll_sized_type_specifier_repeat1,
    ACTIONS(4327), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
  [115033] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4164), 1,
      anon_sym_LPAREN,
    ACTIONS(4305), 1,
      sym__blank,
    STATE(1977), 1,
      aux_sym_block_repeat1,
    STATE(1994), 1,
      sym_hll_parameter_list,
    ACTIONS(4266), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
  [115053] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4164), 1,
      anon_sym_LPAREN,
    ACTIONS(4305), 1,
      sym__blank,
    STATE(1977), 1,
      aux_sym_block_repeat1,
    STATE(1994), 1,
      sym_hll_parameter_list,
    ACTIONS(4184), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
  [115073] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4164), 1,
      anon_sym_LPAREN,
    ACTIONS(4305), 1,
      sym__blank,
    STATE(1977), 1,
      aux_sym_block_repeat1,
    STATE(1994), 1,
      sym_hll_parameter_list,
    ACTIONS(4241), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
  [115093] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4164), 1,
      anon_sym_LPAREN,
    ACTIONS(4166), 1,
      anon_sym_LBRACK,
    ACTIONS(4168), 1,
      sym__blank,
    ACTIONS(4330), 1,
      anon_sym_RPAREN,
    STATE(1867), 1,
      sym_hll_parameter_list,
    STATE(1876), 1,
      aux_sym_block_repeat1,
  [115115] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4164), 1,
      anon_sym_LPAREN,
    ACTIONS(4305), 1,
      sym__blank,
    STATE(1977), 1,
      aux_sym_block_repeat1,
    STATE(1994), 1,
      sym_hll_parameter_list,
    ACTIONS(4158), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
  [115135] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4164), 1,
      anon_sym_LPAREN,
    ACTIONS(4305), 1,
      sym__blank,
    STATE(1977), 1,
      aux_sym_block_repeat1,
    STATE(1994), 1,
      sym_hll_parameter_list,
    ACTIONS(4247), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
  [115155] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4164), 1,
      anon_sym_LPAREN,
    ACTIONS(4166), 1,
      anon_sym_LBRACK,
    ACTIONS(4168), 1,
      sym__blank,
    ACTIONS(4333), 1,
      anon_sym_RPAREN,
    STATE(1867), 1,
      sym_hll_parameter_list,
    STATE(1876), 1,
      aux_sym_block_repeat1,
  [115177] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3923), 1,
      sym_identifier,
    STATE(1704), 1,
      aux_sym_hll_type_pattern_repeat1,
    STATE(1812), 1,
      aux_sym__hll_var_pattern_command_argument_list_format_repeat2,
    STATE(2147), 1,
      sym_hll_type_pattern,
    ACTIONS(3925), 2,
      anon_sym_STAR,
      anon_sym_QMARK,
  [115197] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4164), 1,
      anon_sym_LPAREN,
    ACTIONS(4305), 1,
      sym__blank,
    STATE(1977), 1,
      aux_sym_block_repeat1,
    STATE(1994), 1,
      sym_hll_parameter_list,
    ACTIONS(4123), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
  [115217] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4164), 1,
      anon_sym_LPAREN,
    ACTIONS(4305), 1,
      sym__blank,
    STATE(1977), 1,
      aux_sym_block_repeat1,
    STATE(1994), 1,
      sym_hll_parameter_list,
    ACTIONS(4111), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
  [115237] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4313), 1,
      anon_sym_DOT,
    ACTIONS(4337), 1,
      sym__blank,
    STATE(1773), 1,
      aux_sym_format_expression_repeat1,
    ACTIONS(4335), 3,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [115255] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4164), 1,
      anon_sym_LPAREN,
    ACTIONS(4166), 1,
      anon_sym_LBRACK,
    ACTIONS(4339), 1,
      anon_sym_RPAREN,
    ACTIONS(4341), 1,
      sym__blank,
    STATE(1770), 1,
      aux_sym_block_repeat1,
    STATE(1867), 1,
      sym_hll_parameter_list,
  [115277] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4164), 1,
      anon_sym_LPAREN,
    ACTIONS(4166), 1,
      anon_sym_LBRACK,
    ACTIONS(4168), 1,
      sym__blank,
    ACTIONS(4343), 1,
      anon_sym_RPAREN,
    STATE(1867), 1,
      sym_hll_parameter_list,
    STATE(1876), 1,
      aux_sym_block_repeat1,
  [115299] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3555), 1,
      sym__blank,
    ACTIONS(4164), 1,
      anon_sym_LPAREN,
    ACTIONS(4309), 1,
      anon_sym_LBRACK,
    ACTIONS(4346), 1,
      anon_sym_RPAREN,
    STATE(1577), 1,
      aux_sym_block_repeat1,
    STATE(1926), 1,
      sym_hll_parameter_list,
  [115321] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4164), 1,
      anon_sym_LPAREN,
    ACTIONS(4305), 1,
      sym__blank,
    STATE(1977), 1,
      aux_sym_block_repeat1,
    STATE(1994), 1,
      sym_hll_parameter_list,
    ACTIONS(4140), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
  [115341] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(9), 1,
      aux_sym_block_token1,
    ACTIONS(4174), 1,
      sym__blank,
    ACTIONS(4323), 1,
      sym_comment,
    STATE(1483), 1,
      sym_block,
    STATE(2021), 1,
      aux_sym_labeled_expression_repeat1,
    STATE(2218), 1,
      aux_sym_block_repeat1,
  [115363] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4164), 1,
      anon_sym_LPAREN,
    ACTIONS(4305), 1,
      sym__blank,
    STATE(1977), 1,
      aux_sym_block_repeat1,
    STATE(1994), 1,
      sym_hll_parameter_list,
    ACTIONS(4150), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
  [115383] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4164), 1,
      anon_sym_LPAREN,
    ACTIONS(4166), 1,
      anon_sym_LBRACK,
    ACTIONS(4168), 1,
      sym__blank,
    ACTIONS(4348), 1,
      anon_sym_RPAREN,
    STATE(1867), 1,
      sym_hll_parameter_list,
    STATE(1876), 1,
      aux_sym_block_repeat1,
  [115405] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4164), 1,
      anon_sym_LPAREN,
    ACTIONS(4166), 1,
      anon_sym_LBRACK,
    ACTIONS(4168), 1,
      sym__blank,
    ACTIONS(4350), 1,
      anon_sym_RPAREN,
    STATE(1867), 1,
      sym_hll_parameter_list,
    STATE(1876), 1,
      aux_sym_block_repeat1,
  [115427] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4164), 1,
      anon_sym_LPAREN,
    ACTIONS(4305), 1,
      sym__blank,
    STATE(1977), 1,
      aux_sym_block_repeat1,
    STATE(1994), 1,
      sym_hll_parameter_list,
    ACTIONS(4268), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
  [115447] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4164), 1,
      anon_sym_LPAREN,
    ACTIONS(4166), 1,
      anon_sym_LBRACK,
    ACTIONS(4168), 1,
      sym__blank,
    ACTIONS(4352), 1,
      anon_sym_RPAREN,
    STATE(1867), 1,
      sym_hll_parameter_list,
    STATE(1876), 1,
      aux_sym_block_repeat1,
  [115469] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4164), 1,
      anon_sym_LPAREN,
    ACTIONS(4305), 1,
      sym__blank,
    STATE(1977), 1,
      aux_sym_block_repeat1,
    STATE(1994), 1,
      sym_hll_parameter_list,
    ACTIONS(4099), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
  [115489] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4164), 1,
      anon_sym_LPAREN,
    ACTIONS(4305), 1,
      sym__blank,
    STATE(1977), 1,
      aux_sym_block_repeat1,
    STATE(1994), 1,
      sym_hll_parameter_list,
    ACTIONS(4152), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
  [115509] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4355), 1,
      anon_sym_PERCENT,
    STATE(1809), 1,
      aux_sym__hll_var_pattern_command_argument_list_format_repeat1,
    STATE(2319), 1,
      sym_format_expression,
    ACTIONS(4303), 3,
      anon_sym_STAR,
      anon_sym_QMARK,
      sym_identifier,
  [115527] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4360), 1,
      sym__blank,
    ACTIONS(4358), 5,
      anon_sym_STAR,
      anon_sym_QMARK,
      sym_identifier,
      sym_comment,
      sym__blank_line,
  [115541] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4164), 1,
      anon_sym_LPAREN,
    ACTIONS(4166), 1,
      anon_sym_LBRACK,
    ACTIONS(4168), 1,
      sym__blank,
    ACTIONS(4362), 1,
      anon_sym_RPAREN,
    STATE(1867), 1,
      sym_hll_parameter_list,
    STATE(1876), 1,
      aux_sym_block_repeat1,
  [115563] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4364), 1,
      sym_identifier,
    STATE(1812), 1,
      aux_sym__hll_var_pattern_command_argument_list_format_repeat2,
    STATE(1822), 1,
      aux_sym_hll_type_pattern_repeat1,
    STATE(2399), 1,
      sym_hll_type_pattern,
    ACTIONS(4367), 2,
      anon_sym_STAR,
      anon_sym_QMARK,
  [115583] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3371), 1,
      sym__blank,
    ACTIONS(4089), 1,
      aux_sym_elif_block_token1,
    STATE(952), 1,
      aux_sym_block_repeat1,
    STATE(1452), 1,
      sym_else_block,
    STATE(1491), 1,
      sym_elif_block,
  [115602] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4372), 1,
      sym__blank,
    STATE(1821), 1,
      aux_sym__command_arguments_repeat3,
    STATE(1951), 1,
      aux_sym_block_repeat1,
    ACTIONS(4370), 2,
      sym_comment,
      sym__blank_line,
  [115619] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4374), 1,
      sym__blank,
    STATE(1815), 1,
      aux_sym_block_repeat1,
    ACTIONS(2120), 3,
      anon_sym_SLASH,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token4,
  [115634] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4377), 1,
      sym__blank,
    STATE(1823), 1,
      aux_sym_block_repeat1,
    STATE(1858), 1,
      aux_sym__command_arguments_repeat3,
    ACTIONS(4370), 2,
      sym_comment,
      sym__blank_line,
  [115651] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4381), 1,
      sym__blank,
    ACTIONS(4379), 4,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [115664] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3555), 1,
      sym__blank,
    ACTIONS(4164), 1,
      anon_sym_LPAREN,
    ACTIONS(4383), 1,
      anon_sym_RPAREN,
    STATE(1577), 1,
      aux_sym_block_repeat1,
    STATE(2026), 1,
      sym_hll_parameter_list,
  [115683] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4237), 1,
      sym__blank,
    STATE(1685), 1,
      aux_sym_block_repeat1,
    STATE(1938), 1,
      aux_sym__host_command_argument_list_default_format_repeat2,
    ACTIONS(4385), 2,
      sym_comment,
      sym__blank_line,
  [115700] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4372), 1,
      sym__blank,
    STATE(1821), 1,
      aux_sym__command_arguments_repeat3,
    STATE(1951), 1,
      aux_sym_block_repeat1,
    ACTIONS(2531), 2,
      sym_comment,
      sym__blank_line,
  [115717] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4389), 1,
      sym__blank,
    STATE(1821), 1,
      aux_sym__command_arguments_repeat3,
    STATE(1951), 1,
      aux_sym_block_repeat1,
    ACTIONS(4387), 2,
      sym_comment,
      sym__blank_line,
  [115734] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4119), 1,
      sym__blank,
    ACTIONS(4392), 1,
      sym_identifier,
    STATE(1839), 1,
      aux_sym_hll_type_pattern_repeat1,
    ACTIONS(4394), 2,
      anon_sym_STAR,
      anon_sym_QMARK,
  [115751] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4024), 1,
      anon_sym_AMP,
    ACTIONS(4396), 1,
      anon_sym_SLASH,
    ACTIONS(4398), 1,
      sym__blank,
    STATE(1815), 1,
      aux_sym_block_repeat1,
    STATE(2237), 1,
      sym_macro,
  [115770] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4402), 1,
      sym__blank,
    ACTIONS(4400), 4,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [115783] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4372), 1,
      sym__blank,
    STATE(1821), 1,
      aux_sym__command_arguments_repeat3,
    STATE(1951), 1,
      aux_sym_block_repeat1,
    ACTIONS(2535), 2,
      sym_comment,
      sym__blank_line,
  [115800] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4404), 1,
      anon_sym_COMMA,
    ACTIONS(4406), 1,
      sym__blank,
    STATE(930), 1,
      aux_sym_block_repeat1,
    ACTIONS(2535), 2,
      sym_comment,
      sym__blank_line,
  [115817] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4164), 1,
      anon_sym_LPAREN,
    ACTIONS(4408), 1,
      anon_sym_RPAREN,
    ACTIONS(4410), 1,
      sym__blank,
    STATE(1910), 1,
      aux_sym_block_repeat1,
    STATE(1994), 1,
      sym_hll_parameter_list,
  [115836] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4164), 1,
      anon_sym_LPAREN,
    ACTIONS(4412), 1,
      anon_sym_RPAREN,
    ACTIONS(4414), 1,
      sym__blank,
    STATE(1833), 1,
      aux_sym_block_repeat1,
    STATE(1994), 1,
      sym_hll_parameter_list,
  [115855] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4377), 1,
      sym__blank,
    STATE(1820), 1,
      aux_sym__command_arguments_repeat3,
    STATE(1823), 1,
      aux_sym_block_repeat1,
    ACTIONS(2535), 2,
      sym_comment,
      sym__blank_line,
  [115872] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3020), 1,
      anon_sym_COMMA,
    ACTIONS(4416), 1,
      anon_sym_RPAREN,
    ACTIONS(4418), 1,
      sym__blank,
    STATE(1918), 1,
      aux_sym_argument_list_repeat1,
    STATE(2193), 1,
      aux_sym_block_repeat1,
  [115891] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3371), 1,
      sym__blank,
    ACTIONS(4060), 1,
      aux_sym_elif_block_token1,
    STATE(952), 1,
      aux_sym_block_repeat1,
    STATE(1437), 1,
      sym_else_block,
    STATE(1451), 1,
      sym_elif_block,
  [115910] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2661), 1,
      anon_sym_COMMA,
    ACTIONS(2665), 1,
      anon_sym_RPAREN,
    ACTIONS(3371), 1,
      sym__blank,
    STATE(952), 1,
      aux_sym_block_repeat1,
    STATE(2226), 1,
      aux_sym_hll_argument_list_repeat1,
  [115929] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3555), 1,
      sym__blank,
    ACTIONS(4164), 1,
      anon_sym_LPAREN,
    ACTIONS(4420), 1,
      anon_sym_RPAREN,
    STATE(1577), 1,
      aux_sym_block_repeat1,
    STATE(2026), 1,
      sym_hll_parameter_list,
  [115948] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4164), 1,
      anon_sym_LPAREN,
    ACTIONS(4420), 1,
      anon_sym_RPAREN,
    ACTIONS(4422), 1,
      sym__blank,
    STATE(1838), 1,
      aux_sym_block_repeat1,
    STATE(1994), 1,
      sym_hll_parameter_list,
  [115967] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3371), 1,
      sym__blank,
    ACTIONS(4060), 1,
      aux_sym_elif_block_token1,
    STATE(952), 1,
      aux_sym_block_repeat1,
    STATE(1437), 1,
      sym_else_block,
    STATE(1491), 1,
      sym_elif_block,
  [115986] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4424), 5,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      sym__blank,
  [115997] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2661), 1,
      anon_sym_COMMA,
    ACTIONS(3371), 1,
      sym__blank,
    ACTIONS(4426), 1,
      anon_sym_RPAREN,
    STATE(952), 1,
      aux_sym_block_repeat1,
    STATE(2044), 1,
      aux_sym_hll_argument_list_repeat1,
  [116016] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3555), 1,
      sym__blank,
    ACTIONS(4164), 1,
      anon_sym_LPAREN,
    ACTIONS(4428), 1,
      anon_sym_RPAREN,
    STATE(1577), 1,
      aux_sym_block_repeat1,
    STATE(2026), 1,
      sym_hll_parameter_list,
  [116035] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4227), 1,
      sym__blank,
    ACTIONS(4430), 1,
      sym_identifier,
    STATE(1839), 1,
      aux_sym_hll_type_pattern_repeat1,
    ACTIONS(4433), 2,
      anon_sym_STAR,
      anon_sym_QMARK,
  [116052] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4436), 5,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      sym__blank,
  [116063] = 3,
    ACTIONS(1665), 1,
      anon_sym_DQUOTE,
    ACTIONS(4109), 1,
      sym__line_continuation,
    ACTIONS(1667), 4,
      sym__ampersand_char,
      anon_sym_AMP,
      aux_sym_string_token1,
      aux_sym_string_token2,
  [116076] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2122), 1,
      aux_sym__host_command_argument_list_default_format_token1,
    ACTIONS(4438), 1,
      sym__blank,
    STATE(1842), 1,
      aux_sym_block_repeat1,
    ACTIONS(2120), 2,
      anon_sym_AMP,
      anon_sym_DQUOTE,
  [116093] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4441), 5,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      sym__blank,
  [116104] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3371), 1,
      sym__blank,
    STATE(952), 1,
      aux_sym_block_repeat1,
    STATE(1223), 1,
      sym_hll_type_qualifier,
    ACTIONS(4443), 2,
      anon_sym_const,
      anon_sym_volatile,
  [116121] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4445), 5,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      sym__blank,
  [116132] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4449), 1,
      sym__blank,
    ACTIONS(4447), 4,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [116145] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4451), 1,
      anon_sym_DOT,
    ACTIONS(4455), 1,
      sym__blank,
    STATE(1862), 1,
      aux_sym__command_identifier_repeat1,
    ACTIONS(4453), 2,
      sym_comment,
      sym__blank_line,
  [116162] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4457), 5,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      sym__blank,
  [116173] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4459), 1,
      anon_sym_SLASH,
    ACTIONS(4462), 1,
      anon_sym_PERCENT,
    STATE(1849), 1,
      aux_sym__var_command_argument_list_non_hll_format_repeat1,
    STATE(2320), 2,
      sym_option_expression,
      sym_format_expression,
  [116190] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4400), 5,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      sym__blank,
  [116201] = 3,
    ACTIONS(1661), 1,
      anon_sym_DQUOTE,
    ACTIONS(4109), 1,
      sym__line_continuation,
    ACTIONS(1663), 4,
      sym__ampersand_char,
      anon_sym_AMP,
      aux_sym_string_token1,
      aux_sym_string_token2,
  [116214] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4465), 5,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      sym__blank,
  [116225] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3020), 1,
      anon_sym_COMMA,
    ACTIONS(4418), 1,
      sym__blank,
    ACTIONS(4467), 1,
      anon_sym_RPAREN,
    STATE(1918), 1,
      aux_sym_argument_list_repeat1,
    STATE(2193), 1,
      aux_sym_block_repeat1,
  [116244] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4469), 1,
      sym_comment,
    ACTIONS(4471), 1,
      sym__blank_line,
    ACTIONS(4473), 1,
      sym__blank,
    STATE(1896), 1,
      aux_sym_macro_definition_repeat1,
    STATE(2003), 1,
      aux_sym_block_repeat1,
  [116263] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3371), 1,
      sym__blank,
    ACTIONS(4060), 1,
      aux_sym_elif_block_token1,
    STATE(952), 1,
      aux_sym_block_repeat1,
    STATE(1491), 1,
      sym_elif_block,
    STATE(1494), 1,
      sym_else_block,
  [116282] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4024), 1,
      anon_sym_AMP,
    ACTIONS(4398), 1,
      sym__blank,
    ACTIONS(4475), 1,
      aux_sym_parameter_declaration_token4,
    STATE(1815), 1,
      aux_sym_block_repeat1,
    STATE(2109), 1,
      sym_macro,
  [116301] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4473), 1,
      sym__blank,
    ACTIONS(4477), 1,
      sym_comment,
    ACTIONS(4479), 1,
      sym__blank_line,
    STATE(1896), 1,
      aux_sym_macro_definition_repeat1,
    STATE(2003), 1,
      aux_sym_block_repeat1,
  [116320] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4372), 1,
      sym__blank,
    STATE(1821), 1,
      aux_sym__command_arguments_repeat3,
    STATE(1951), 1,
      aux_sym_block_repeat1,
    ACTIONS(4481), 2,
      sym_comment,
      sym__blank_line,
  [116337] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4377), 1,
      sym__blank,
    STATE(1823), 1,
      aux_sym_block_repeat1,
    STATE(1884), 1,
      aux_sym__command_arguments_repeat3,
    ACTIONS(4481), 2,
      sym_comment,
      sym__blank_line,
  [116354] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4485), 1,
      sym__blank,
    ACTIONS(4483), 4,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [116367] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4455), 1,
      sym__blank,
    ACTIONS(4487), 1,
      anon_sym_DOT,
    STATE(1862), 1,
      aux_sym__command_identifier_repeat1,
    ACTIONS(4453), 2,
      sym_comment,
      sym__blank_line,
  [116384] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4489), 1,
      anon_sym_DOT,
    ACTIONS(4493), 1,
      sym__blank,
    STATE(1905), 1,
      aux_sym__command_identifier_repeat1,
    ACTIONS(4491), 2,
      sym_comment,
      sym__blank_line,
  [116401] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4489), 1,
      anon_sym_DOT,
    ACTIONS(4497), 1,
      sym__blank,
    STATE(1905), 1,
      aux_sym__command_identifier_repeat1,
    ACTIONS(4495), 2,
      sym_comment,
      sym__blank_line,
  [116418] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4489), 1,
      anon_sym_DOT,
    ACTIONS(4501), 1,
      sym__blank,
    STATE(1863), 1,
      aux_sym__command_identifier_repeat1,
    ACTIONS(4499), 2,
      sym_comment,
      sym__blank_line,
  [116435] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4503), 1,
      sym__blank,
    ACTIONS(4465), 4,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [116448] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2087), 1,
      sym__blank,
    ACTIONS(2089), 4,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [116461] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4505), 5,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      sym__blank,
  [116472] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3371), 1,
      sym__blank,
    ACTIONS(4060), 1,
      aux_sym_elif_block_token1,
    STATE(952), 1,
      aux_sym_block_repeat1,
    STATE(1447), 1,
      sym_else_block,
    STATE(1451), 1,
      sym_elif_block,
  [116491] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4507), 5,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      sym__blank,
  [116502] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3020), 1,
      anon_sym_COMMA,
    ACTIONS(4418), 1,
      sym__blank,
    ACTIONS(4509), 1,
      anon_sym_RPAREN,
    STATE(1918), 1,
      aux_sym_argument_list_repeat1,
    STATE(2193), 1,
      aux_sym_block_repeat1,
  [116521] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2661), 1,
      anon_sym_COMMA,
    ACTIONS(2675), 1,
      anon_sym_RPAREN,
    ACTIONS(3371), 1,
      sym__blank,
    STATE(952), 1,
      aux_sym_block_repeat1,
    STATE(2037), 1,
      aux_sym_hll_argument_list_repeat1,
  [116540] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2661), 1,
      anon_sym_COMMA,
    ACTIONS(3371), 1,
      sym__blank,
    ACTIONS(4511), 1,
      anon_sym_RPAREN,
    STATE(952), 1,
      aux_sym_block_repeat1,
    STATE(2040), 1,
      aux_sym_hll_argument_list_repeat1,
  [116559] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4513), 5,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      sym__blank,
  [116570] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4515), 5,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      sym__blank,
  [116581] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4517), 5,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      sym__blank,
  [116592] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3555), 1,
      sym__blank,
    ACTIONS(4164), 1,
      anon_sym_LPAREN,
    ACTIONS(4309), 1,
      anon_sym_LBRACK,
    STATE(1577), 1,
      aux_sym_block_repeat1,
    STATE(1926), 1,
      sym_hll_parameter_list,
  [116611] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4519), 5,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      sym__blank,
  [116622] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4521), 5,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      sym__blank,
  [116633] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4523), 5,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      sym__blank,
  [116644] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4473), 1,
      sym__blank,
    ACTIONS(4525), 1,
      sym_comment,
    ACTIONS(4527), 1,
      sym__blank_line,
    STATE(1896), 1,
      aux_sym_macro_definition_repeat1,
    STATE(2003), 1,
      aux_sym_block_repeat1,
  [116663] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2661), 1,
      anon_sym_COMMA,
    ACTIONS(2689), 1,
      anon_sym_RPAREN,
    ACTIONS(3371), 1,
      sym__blank,
    STATE(952), 1,
      aux_sym_block_repeat1,
    STATE(2071), 1,
      aux_sym_hll_argument_list_repeat1,
  [116682] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4473), 1,
      sym__blank,
    ACTIONS(4529), 1,
      sym_comment,
    ACTIONS(4531), 1,
      sym__blank_line,
    STATE(1896), 1,
      aux_sym_macro_definition_repeat1,
    STATE(2003), 1,
      aux_sym_block_repeat1,
  [116701] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2661), 1,
      anon_sym_COMMA,
    ACTIONS(3371), 1,
      sym__blank,
    ACTIONS(4533), 1,
      anon_sym_RPAREN,
    STATE(952), 1,
      aux_sym_block_repeat1,
    STATE(2072), 1,
      aux_sym_hll_argument_list_repeat1,
  [116720] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4372), 1,
      sym__blank,
    STATE(1821), 1,
      aux_sym__command_arguments_repeat3,
    STATE(1951), 1,
      aux_sym_block_repeat1,
    ACTIONS(4535), 2,
      sym_comment,
      sym__blank_line,
  [116737] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4024), 1,
      anon_sym_AMP,
    ACTIONS(4398), 1,
      sym__blank,
    ACTIONS(4537), 1,
      aux_sym_parameter_declaration_token4,
    STATE(1815), 1,
      aux_sym_block_repeat1,
    STATE(2109), 1,
      sym_macro,
  [116756] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4473), 1,
      sym__blank,
    ACTIONS(4539), 1,
      sym_comment,
    ACTIONS(4541), 1,
      sym__blank_line,
    STATE(1896), 1,
      aux_sym_macro_definition_repeat1,
    STATE(2003), 1,
      aux_sym_block_repeat1,
  [116775] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2661), 1,
      anon_sym_COMMA,
    ACTIONS(2671), 1,
      anon_sym_RPAREN,
    ACTIONS(3371), 1,
      sym__blank,
    STATE(952), 1,
      aux_sym_block_repeat1,
    STATE(2222), 1,
      aux_sym_hll_argument_list_repeat1,
  [116794] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4473), 1,
      sym__blank,
    ACTIONS(4543), 1,
      sym_comment,
    ACTIONS(4545), 1,
      sym__blank_line,
    STATE(1896), 1,
      aux_sym_macro_definition_repeat1,
    STATE(2003), 1,
      aux_sym_block_repeat1,
  [116813] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4547), 5,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      sym__blank,
  [116824] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4549), 5,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      sym__blank,
  [116835] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4551), 5,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      sym__blank,
  [116846] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4553), 5,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      sym__blank,
  [116857] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4555), 5,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      sym__blank,
  [116868] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4557), 5,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      sym__blank,
  [116879] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4559), 5,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      sym__blank,
  [116890] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4563), 1,
      sym__blank,
    STATE(1896), 1,
      aux_sym_macro_definition_repeat1,
    STATE(2003), 1,
      aux_sym_block_repeat1,
    ACTIONS(4561), 2,
      sym_comment,
      sym__blank_line,
  [116907] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4566), 5,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      sym__blank,
  [116918] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4568), 5,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      sym__blank,
  [116929] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4570), 5,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      sym__blank,
  [116940] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4572), 5,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      sym__blank,
  [116951] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4576), 1,
      sym__blank,
    ACTIONS(4574), 4,
      anon_sym_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [116964] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4578), 5,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      sym__blank,
  [116975] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4372), 1,
      sym__blank,
    STATE(1821), 1,
      aux_sym__command_arguments_repeat3,
    STATE(1951), 1,
      aux_sym_block_repeat1,
    ACTIONS(4580), 2,
      sym_comment,
      sym__blank_line,
  [116992] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4377), 1,
      sym__blank,
    STATE(1814), 1,
      aux_sym__command_arguments_repeat3,
    STATE(1823), 1,
      aux_sym_block_repeat1,
    ACTIONS(4580), 2,
      sym_comment,
      sym__blank_line,
  [117009] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4582), 1,
      anon_sym_DOT,
    ACTIONS(4587), 1,
      sym__blank,
    STATE(1905), 1,
      aux_sym__command_identifier_repeat1,
    ACTIONS(4585), 2,
      sym_comment,
      sym__blank_line,
  [117026] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3371), 1,
      sym__blank,
    ACTIONS(4066), 1,
      aux_sym_elif_block_token1,
    STATE(952), 1,
      aux_sym_block_repeat1,
    STATE(1491), 1,
      sym_elif_block,
    STATE(1494), 1,
      sym_else_block,
  [117045] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4591), 1,
      sym__blank,
    ACTIONS(4589), 4,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [117058] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3371), 1,
      sym__blank,
    ACTIONS(4066), 1,
      aux_sym_elif_block_token1,
    STATE(952), 1,
      aux_sym_block_repeat1,
    STATE(1451), 1,
      sym_elif_block,
    STATE(1452), 1,
      sym_else_block,
  [117077] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3371), 1,
      sym__blank,
    ACTIONS(4066), 1,
      aux_sym_elif_block_token1,
    STATE(952), 1,
      aux_sym_block_repeat1,
    STATE(1452), 1,
      sym_else_block,
    STATE(1491), 1,
      sym_elif_block,
  [117096] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3555), 1,
      sym__blank,
    ACTIONS(4164), 1,
      anon_sym_LPAREN,
    ACTIONS(4593), 1,
      anon_sym_RPAREN,
    STATE(1577), 1,
      aux_sym_block_repeat1,
    STATE(2026), 1,
      sym_hll_parameter_list,
  [117115] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4164), 1,
      anon_sym_LPAREN,
    ACTIONS(4593), 1,
      anon_sym_RPAREN,
    ACTIONS(4595), 1,
      sym__blank,
    STATE(1818), 1,
      aux_sym_block_repeat1,
    STATE(1994), 1,
      sym_hll_parameter_list,
  [117134] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3371), 1,
      sym__blank,
    ACTIONS(4066), 1,
      aux_sym_elif_block_token1,
    STATE(952), 1,
      aux_sym_block_repeat1,
    STATE(1437), 1,
      sym_else_block,
    STATE(1451), 1,
      sym_elif_block,
  [117153] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3371), 1,
      sym__blank,
    ACTIONS(4066), 1,
      aux_sym_elif_block_token1,
    STATE(952), 1,
      aux_sym_block_repeat1,
    STATE(1437), 1,
      sym_else_block,
    STATE(1491), 1,
      sym_elif_block,
  [117172] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3371), 1,
      sym__blank,
    ACTIONS(4066), 1,
      aux_sym_elif_block_token1,
    STATE(952), 1,
      aux_sym_block_repeat1,
    STATE(1447), 1,
      sym_else_block,
    STATE(1451), 1,
      sym_elif_block,
  [117191] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4597), 1,
      sym__blank,
    ACTIONS(4436), 4,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [117204] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4601), 1,
      sym__blank,
    ACTIONS(4599), 4,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [117217] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4237), 1,
      sym__blank,
    STATE(1685), 1,
      aux_sym_block_repeat1,
    STATE(1819), 1,
      aux_sym__host_command_argument_list_default_format_repeat2,
    ACTIONS(4235), 2,
      sym_comment,
      sym__blank_line,
  [117234] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3193), 1,
      anon_sym_RPAREN,
    ACTIONS(4603), 1,
      anon_sym_COMMA,
    ACTIONS(4606), 1,
      sym__blank,
    STATE(1918), 1,
      aux_sym_argument_list_repeat1,
    STATE(2193), 1,
      aux_sym_block_repeat1,
  [117253] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3371), 1,
      sym__blank,
    ACTIONS(4060), 1,
      aux_sym_elif_block_token1,
    STATE(952), 1,
      aux_sym_block_repeat1,
    STATE(1451), 1,
      sym_elif_block,
    STATE(1452), 1,
      sym_else_block,
  [117272] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3371), 1,
      sym__blank,
    ACTIONS(4060), 1,
      aux_sym_elif_block_token1,
    STATE(952), 1,
      aux_sym_block_repeat1,
    STATE(1452), 1,
      sym_else_block,
    STATE(1491), 1,
      sym_elif_block,
  [117291] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4609), 1,
      anon_sym_COMMA,
    ACTIONS(4611), 1,
      sym__blank,
    STATE(929), 1,
      aux_sym_block_repeat1,
    ACTIONS(2527), 2,
      sym_comment,
      sym__blank_line,
  [117308] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4613), 5,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      sym__blank,
  [117319] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4377), 1,
      sym__blank,
    STATE(1823), 1,
      aux_sym_block_repeat1,
    STATE(1825), 1,
      aux_sym__command_arguments_repeat3,
    ACTIONS(2527), 2,
      sym_comment,
      sym__blank_line,
  [117336] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4615), 5,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      sym__blank,
  [117347] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4473), 1,
      sym__blank,
    ACTIONS(4617), 1,
      sym_comment,
    ACTIONS(4619), 1,
      sym__blank_line,
    STATE(1896), 1,
      aux_sym_macro_definition_repeat1,
    STATE(2003), 1,
      aux_sym_block_repeat1,
  [117366] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4621), 5,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      sym__blank,
  [117377] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3371), 1,
      sym__blank,
    STATE(952), 1,
      aux_sym_block_repeat1,
    STATE(1726), 1,
      sym_hll_type_qualifier,
    ACTIONS(3583), 2,
      anon_sym_const,
      anon_sym_volatile,
  [117394] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4473), 1,
      sym__blank,
    ACTIONS(4623), 1,
      sym_comment,
    ACTIONS(4625), 1,
      sym__blank_line,
    STATE(1896), 1,
      aux_sym_macro_definition_repeat1,
    STATE(2003), 1,
      aux_sym_block_repeat1,
  [117413] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(422), 1,
      anon_sym_PERCENT,
    ACTIONS(434), 1,
      anon_sym_SLASH,
    STATE(1849), 1,
      aux_sym__var_command_argument_list_non_hll_format_repeat1,
    STATE(1971), 2,
      sym_option_expression,
      sym_format_expression,
  [117430] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3371), 1,
      sym__blank,
    ACTIONS(4074), 1,
      aux_sym_elif_block_token1,
    STATE(952), 1,
      aux_sym_block_repeat1,
    STATE(1491), 1,
      sym_elif_block,
    STATE(1494), 1,
      sym_else_block,
  [117449] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3371), 1,
      sym__blank,
    ACTIONS(4074), 1,
      aux_sym_elif_block_token1,
    STATE(952), 1,
      aux_sym_block_repeat1,
    STATE(1451), 1,
      sym_elif_block,
    STATE(1452), 1,
      sym_else_block,
  [117468] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3371), 1,
      sym__blank,
    ACTIONS(4074), 1,
      aux_sym_elif_block_token1,
    STATE(952), 1,
      aux_sym_block_repeat1,
    STATE(1452), 1,
      sym_else_block,
    STATE(1491), 1,
      sym_elif_block,
  [117487] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3371), 1,
      sym__blank,
    ACTIONS(4074), 1,
      aux_sym_elif_block_token1,
    STATE(952), 1,
      aux_sym_block_repeat1,
    STATE(1437), 1,
      sym_else_block,
    STATE(1451), 1,
      sym_elif_block,
  [117506] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3371), 1,
      sym__blank,
    ACTIONS(4074), 1,
      aux_sym_elif_block_token1,
    STATE(952), 1,
      aux_sym_block_repeat1,
    STATE(1437), 1,
      sym_else_block,
    STATE(1491), 1,
      sym_elif_block,
  [117525] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3371), 1,
      sym__blank,
    ACTIONS(4074), 1,
      aux_sym_elif_block_token1,
    STATE(952), 1,
      aux_sym_block_repeat1,
    STATE(1447), 1,
      sym_else_block,
    STATE(1451), 1,
      sym_elif_block,
  [117544] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2661), 1,
      anon_sym_COMMA,
    ACTIONS(3371), 1,
      sym__blank,
    ACTIONS(4627), 1,
      anon_sym_RPAREN,
    STATE(952), 1,
      aux_sym_block_repeat1,
    STATE(2133), 1,
      aux_sym_hll_argument_list_repeat1,
  [117563] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4233), 1,
      aux_sym__host_command_argument_list_default_format_token1,
    ACTIONS(4631), 1,
      sym__blank,
    STATE(1945), 1,
      aux_sym__host_command_argument_list_default_format_repeat1,
    ACTIONS(4629), 2,
      sym_comment,
      sym__blank_line,
  [117580] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4633), 1,
      sym__blank,
    STATE(1685), 1,
      aux_sym_block_repeat1,
    STATE(1938), 1,
      aux_sym__host_command_argument_list_default_format_repeat2,
    ACTIONS(4629), 2,
      sym_comment,
      sym__blank_line,
  [117597] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4377), 1,
      sym__blank,
    STATE(1823), 1,
      aux_sym_block_repeat1,
    STATE(1903), 1,
      aux_sym__command_arguments_repeat3,
    ACTIONS(2531), 2,
      sym_comment,
      sym__blank_line,
  [117614] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3371), 1,
      sym__blank,
    ACTIONS(4089), 1,
      aux_sym_elif_block_token1,
    STATE(952), 1,
      aux_sym_block_repeat1,
    STATE(1491), 1,
      sym_elif_block,
    STATE(1494), 1,
      sym_else_block,
  [117633] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3371), 1,
      sym__blank,
    ACTIONS(4089), 1,
      aux_sym_elif_block_token1,
    STATE(952), 1,
      aux_sym_block_repeat1,
    STATE(1451), 1,
      sym_elif_block,
    STATE(1452), 1,
      sym_else_block,
  [117652] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3371), 1,
      sym__blank,
    ACTIONS(4089), 1,
      aux_sym_elif_block_token1,
    STATE(952), 1,
      aux_sym_block_repeat1,
    STATE(1437), 1,
      sym_else_block,
    STATE(1451), 1,
      sym_elif_block,
  [117671] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3371), 1,
      sym__blank,
    ACTIONS(4089), 1,
      aux_sym_elif_block_token1,
    STATE(952), 1,
      aux_sym_block_repeat1,
    STATE(1437), 1,
      sym_else_block,
    STATE(1491), 1,
      sym_elif_block,
  [117690] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3371), 1,
      sym__blank,
    ACTIONS(4089), 1,
      aux_sym_elif_block_token1,
    STATE(952), 1,
      aux_sym_block_repeat1,
    STATE(1447), 1,
      sym_else_block,
    STATE(1451), 1,
      sym_elif_block,
  [117709] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4636), 1,
      aux_sym__host_command_argument_list_default_format_token1,
    ACTIONS(4641), 1,
      sym__blank,
    STATE(1945), 1,
      aux_sym__host_command_argument_list_default_format_repeat1,
    ACTIONS(4639), 2,
      sym_comment,
      sym__blank_line,
  [117726] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4483), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      sym__blank,
  [117736] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3664), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      sym__blank,
  [117746] = 4,
    ACTIONS(4109), 1,
      sym__line_continuation,
    ACTIONS(4643), 1,
      anon_sym_DQUOTE,
    STATE(1950), 1,
      aux_sym_hll_string_literal_repeat1,
    ACTIONS(4645), 2,
      aux_sym_hll_string_literal_token1,
      sym_hll_escape_sequence,
  [117760] = 4,
    ACTIONS(4109), 1,
      sym__line_continuation,
    ACTIONS(4647), 1,
      anon_sym_DQUOTE,
    STATE(1960), 1,
      aux_sym_hll_string_literal_repeat1,
    ACTIONS(4649), 2,
      aux_sym_hll_string_literal_token1,
      sym_hll_escape_sequence,
  [117774] = 4,
    ACTIONS(4109), 1,
      sym__line_continuation,
    ACTIONS(4651), 1,
      anon_sym_DQUOTE,
    STATE(1983), 1,
      aux_sym_hll_string_literal_repeat1,
    ACTIONS(4653), 2,
      aux_sym_hll_string_literal_token1,
      sym_hll_escape_sequence,
  [117788] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4024), 1,
      anon_sym_AMP,
    ACTIONS(4398), 1,
      sym__blank,
    STATE(1815), 1,
      aux_sym_block_repeat1,
    STATE(2237), 1,
      sym_macro,
  [117804] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2623), 1,
      sym__blank,
    STATE(969), 1,
      aux_sym_block_repeat1,
    ACTIONS(2619), 2,
      sym_comment,
      sym__blank_line,
  [117818] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4657), 1,
      sym__blank,
    STATE(119), 1,
      aux_sym_block_repeat1,
    ACTIONS(4655), 2,
      sym_comment,
      sym__blank_line,
  [117832] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4662), 1,
      sym__blank,
    STATE(30), 1,
      aux_sym_block_repeat1,
    ACTIONS(4660), 2,
      sym_comment,
      sym__blank_line,
  [117846] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3371), 1,
      sym__blank,
    ACTIONS(4270), 1,
      aux_sym_elif_block_token1,
    STATE(952), 1,
      aux_sym_block_repeat1,
    STATE(1491), 1,
      sym_elif_block,
  [117862] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3745), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      sym__blank,
  [117872] = 4,
    ACTIONS(4109), 1,
      sym__line_continuation,
    ACTIONS(4664), 1,
      anon_sym_DQUOTE,
    STATE(1969), 1,
      aux_sym_hll_string_literal_repeat1,
    ACTIONS(4666), 2,
      aux_sym_hll_string_literal_token1,
      sym_hll_escape_sequence,
  [117886] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4358), 4,
      anon_sym_STAR,
      anon_sym_QMARK,
      sym_identifier,
      sym__blank,
  [117896] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4670), 1,
      sym__blank,
    STATE(115), 1,
      aux_sym_block_repeat1,
    ACTIONS(4668), 2,
      sym_comment,
      sym__blank_line,
  [117910] = 4,
    ACTIONS(4109), 1,
      sym__line_continuation,
    ACTIONS(4672), 1,
      anon_sym_DQUOTE,
    STATE(1983), 1,
      aux_sym_hll_string_literal_repeat1,
    ACTIONS(4653), 2,
      aux_sym_hll_string_literal_token1,
      sym_hll_escape_sequence,
  [117924] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    STATE(1667), 1,
      sym_hll_type_qualifier,
    STATE(1980), 1,
      aux_sym__hll_pointer_declarator_specifier_repeat1,
    ACTIONS(3583), 2,
      anon_sym_const,
      anon_sym_volatile,
  [117938] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3555), 1,
      sym__blank,
    ACTIONS(4097), 1,
      anon_sym_LPAREN,
    STATE(1577), 1,
      aux_sym_block_repeat1,
    STATE(1916), 1,
      sym_hll_parameter_list,
  [117954] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4674), 1,
      sym__blank,
    STATE(1975), 1,
      aux_sym_block_repeat1,
    ACTIONS(3968), 2,
      anon_sym_const,
      anon_sym_volatile,
  [117968] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4678), 1,
      sym__blank,
    ACTIONS(4676), 3,
      anon_sym_DOT,
      sym_comment,
      sym__blank_line,
  [117980] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3371), 1,
      sym__blank,
    ACTIONS(4270), 1,
      aux_sym_elif_block_token1,
    STATE(952), 1,
      aux_sym_block_repeat1,
    STATE(1451), 1,
      sym_elif_block,
  [117996] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4682), 1,
      sym__blank,
    STATE(2214), 1,
      aux_sym_block_repeat1,
    ACTIONS(4680), 2,
      sym_comment,
      sym__blank_line,
  [118010] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3371), 1,
      sym__blank,
    STATE(952), 1,
      aux_sym_block_repeat1,
    ACTIONS(4684), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [118024] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4688), 1,
      sym__blank,
    STATE(2176), 1,
      aux_sym_block_repeat1,
    ACTIONS(4686), 2,
      sym_comment,
      sym__blank_line,
  [118038] = 4,
    ACTIONS(4109), 1,
      sym__line_continuation,
    ACTIONS(4690), 1,
      anon_sym_DQUOTE,
    STATE(1983), 1,
      aux_sym_hll_string_literal_repeat1,
    ACTIONS(4653), 2,
      aux_sym_hll_string_literal_token1,
      sym_hll_escape_sequence,
  [118052] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4692), 1,
      anon_sym_DOT,
    STATE(2008), 1,
      aux_sym_format_expression_repeat1,
    ACTIONS(4315), 2,
      anon_sym_COMMA,
      sym__blank,
  [118066] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4696), 1,
      sym__blank,
    STATE(1967), 1,
      aux_sym_block_repeat1,
    ACTIONS(4694), 2,
      sym_comment,
      sym__blank_line,
  [118080] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3675), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      sym__blank,
  [118090] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4379), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      sym__blank,
  [118100] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3686), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      sym__blank,
  [118110] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3371), 1,
      sym__blank,
    STATE(952), 1,
      aux_sym_block_repeat1,
    ACTIONS(4698), 2,
      anon_sym_const,
      anon_sym_volatile,
  [118124] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3697), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      sym__blank,
  [118134] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3555), 1,
      sym__blank,
    ACTIONS(4164), 1,
      anon_sym_LPAREN,
    STATE(1577), 1,
      aux_sym_block_repeat1,
    STATE(2026), 1,
      sym_hll_parameter_list,
  [118150] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    STATE(1670), 1,
      sym_hll_type_qualifier,
    STATE(1980), 1,
      aux_sym__hll_pointer_declarator_specifier_repeat1,
    ACTIONS(3583), 2,
      anon_sym_const,
      anon_sym_volatile,
  [118164] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3631), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      sym__blank,
  [118174] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    STATE(1963), 1,
      sym_hll_type_qualifier,
    STATE(1980), 1,
      aux_sym__hll_pointer_declarator_specifier_repeat1,
    ACTIONS(4700), 2,
      anon_sym_const,
      anon_sym_volatile,
  [118188] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4705), 1,
      sym__blank,
    STATE(321), 1,
      aux_sym_block_repeat1,
    ACTIONS(4703), 2,
      sym_comment,
      sym__blank_line,
  [118202] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4709), 1,
      sym__blank,
    STATE(1686), 1,
      aux_sym_block_repeat1,
    ACTIONS(4707), 2,
      sym_comment,
      sym__blank_line,
  [118216] = 4,
    ACTIONS(4109), 1,
      sym__line_continuation,
    ACTIONS(4711), 1,
      anon_sym_DQUOTE,
    STATE(1983), 1,
      aux_sym_hll_string_literal_repeat1,
    ACTIONS(4713), 2,
      aux_sym_hll_string_literal_token1,
      sym_hll_escape_sequence,
  [118230] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3371), 1,
      sym__blank,
    ACTIONS(4716), 1,
      sym_identifier,
    STATE(952), 1,
      aux_sym_block_repeat1,
    STATE(1680), 1,
      sym__hll_type_identifier,
  [118246] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3371), 1,
      sym__blank,
    ACTIONS(4716), 1,
      sym_identifier,
    STATE(952), 1,
      aux_sym_block_repeat1,
    STATE(1675), 1,
      sym__hll_type_identifier,
  [118262] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4720), 1,
      sym__blank,
    STATE(106), 1,
      aux_sym_block_repeat1,
    ACTIONS(4718), 2,
      sym_comment,
      sym__blank_line,
  [118276] = 4,
    ACTIONS(4109), 1,
      sym__line_continuation,
    ACTIONS(4722), 1,
      anon_sym_DQUOTE,
    STATE(1993), 1,
      aux_sym_hll_string_literal_repeat1,
    ACTIONS(4724), 2,
      aux_sym_hll_string_literal_token1,
      sym_hll_escape_sequence,
  [118290] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3371), 1,
      sym__blank,
    ACTIONS(4716), 1,
      sym_identifier,
    STATE(952), 1,
      aux_sym_block_repeat1,
    STATE(1683), 1,
      sym__hll_type_identifier,
  [118306] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2089), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      sym__blank,
  [118316] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4688), 1,
      sym__blank,
    STATE(2176), 1,
      aux_sym_block_repeat1,
    ACTIONS(4726), 2,
      sym_comment,
      sym__blank_line,
  [118330] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4728), 1,
      aux_sym_while_block_token1,
    STATE(1727), 1,
      aux_sym_subroutine_block_repeat1,
    ACTIONS(4062), 2,
      sym_comment,
      sym__blank_line,
  [118344] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3642), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      sym__blank,
  [118354] = 4,
    ACTIONS(4109), 1,
      sym__line_continuation,
    ACTIONS(4730), 1,
      anon_sym_DQUOTE,
    STATE(1983), 1,
      aux_sym_hll_string_literal_repeat1,
    ACTIONS(4653), 2,
      aux_sym_hll_string_literal_token1,
      sym_hll_escape_sequence,
  [118368] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4447), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      sym__blank,
  [118378] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3723), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      sym__blank,
  [118388] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3734), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      sym__blank,
  [118398] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2607), 1,
      sym__blank,
    STATE(1009), 1,
      aux_sym_block_repeat1,
    ACTIONS(2605), 2,
      sym_comment,
      sym__blank_line,
  [118412] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4732), 1,
      aux_sym_while_block_token1,
    STATE(1727), 1,
      aux_sym_subroutine_block_repeat1,
    ACTIONS(4062), 2,
      sym_comment,
      sym__blank_line,
  [118426] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3371), 1,
      sym__blank,
    STATE(952), 1,
      aux_sym_block_repeat1,
    ACTIONS(4734), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
  [118440] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3371), 1,
      sym__blank,
    ACTIONS(4736), 1,
      anon_sym_EQ,
    ACTIONS(4738), 1,
      anon_sym_COMMA,
    STATE(952), 1,
      aux_sym_block_repeat1,
  [118456] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3653), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      sym__blank,
  [118466] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4742), 1,
      sym__blank,
    STATE(31), 1,
      aux_sym_block_repeat1,
    ACTIONS(4740), 2,
      sym_comment,
      sym__blank_line,
  [118480] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4024), 1,
      anon_sym_AMP,
    ACTIONS(4398), 1,
      sym__blank,
    STATE(1815), 1,
      aux_sym_block_repeat1,
    STATE(2109), 1,
      sym_macro,
  [118496] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4696), 1,
      sym__blank,
    STATE(1967), 1,
      aux_sym_block_repeat1,
    ACTIONS(4744), 2,
      sym_comment,
      sym__blank_line,
  [118510] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4748), 1,
      sym__blank,
    STATE(2195), 1,
      aux_sym_block_repeat1,
    ACTIONS(4746), 2,
      sym_comment,
      sym__blank_line,
  [118524] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4692), 1,
      anon_sym_DOT,
    STATE(1970), 1,
      aux_sym_format_expression_repeat1,
    ACTIONS(4335), 2,
      anon_sym_COMMA,
      sym__blank,
  [118538] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4752), 1,
      sym__blank,
    STATE(139), 1,
      aux_sym_block_repeat1,
    ACTIONS(4750), 2,
      sym_comment,
      sym__blank_line,
  [118552] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4754), 1,
      anon_sym_DOT,
    STATE(2008), 1,
      aux_sym_format_expression_repeat1,
    ACTIONS(4299), 2,
      anon_sym_COMMA,
      sym__blank,
  [118566] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4748), 1,
      sym__blank,
    STATE(2195), 1,
      aux_sym_block_repeat1,
    ACTIONS(4757), 2,
      sym_comment,
      sym__blank_line,
  [118580] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4589), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      sym__blank,
  [118590] = 4,
    ACTIONS(4109), 1,
      sym__line_continuation,
    ACTIONS(4759), 1,
      anon_sym_DQUOTE,
    STATE(2012), 1,
      aux_sym_hll_string_literal_repeat1,
    ACTIONS(4761), 2,
      aux_sym_hll_string_literal_token1,
      sym_hll_escape_sequence,
  [118604] = 4,
    ACTIONS(4109), 1,
      sym__line_continuation,
    ACTIONS(4763), 1,
      anon_sym_DQUOTE,
    STATE(1983), 1,
      aux_sym_hll_string_literal_repeat1,
    ACTIONS(4653), 2,
      aux_sym_hll_string_literal_token1,
      sym_hll_escape_sequence,
  [118618] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2601), 1,
      sym__blank,
    STATE(1134), 1,
      aux_sym_block_repeat1,
    ACTIONS(2599), 2,
      sym_comment,
      sym__blank_line,
  [118632] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3371), 1,
      sym__blank,
    ACTIONS(4258), 1,
      aux_sym_elif_block_token1,
    STATE(952), 1,
      aux_sym_block_repeat1,
    STATE(1491), 1,
      sym_elif_block,
  [118648] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4765), 1,
      sym__blank,
    STATE(109), 1,
      aux_sym_block_repeat1,
    ACTIONS(4655), 2,
      sym_comment,
      sym__blank_line,
  [118662] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3371), 1,
      sym__blank,
    ACTIONS(4258), 1,
      aux_sym_elif_block_token1,
    STATE(952), 1,
      aux_sym_block_repeat1,
    STATE(1451), 1,
      sym_elif_block,
  [118678] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4688), 1,
      sym__blank,
    STATE(2176), 1,
      aux_sym_block_repeat1,
    ACTIONS(2595), 2,
      sym_comment,
      sym__blank_line,
  [118692] = 4,
    ACTIONS(4109), 1,
      sym__line_continuation,
    ACTIONS(4767), 1,
      anon_sym_DQUOTE,
    STATE(2019), 1,
      aux_sym_hll_string_literal_repeat1,
    ACTIONS(4769), 2,
      aux_sym_hll_string_literal_token1,
      sym_hll_escape_sequence,
  [118706] = 4,
    ACTIONS(4109), 1,
      sym__line_continuation,
    ACTIONS(4771), 1,
      anon_sym_DQUOTE,
    STATE(1983), 1,
      aux_sym_hll_string_literal_repeat1,
    ACTIONS(4653), 2,
      aux_sym_hll_string_literal_token1,
      sym_hll_escape_sequence,
  [118720] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4775), 1,
      sym__blank,
    STATE(29), 1,
      aux_sym_block_repeat1,
    ACTIONS(4773), 2,
      sym_comment,
      sym__blank_line,
  [118734] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4777), 1,
      aux_sym_block_token1,
    ACTIONS(4779), 1,
      sym_comment,
    ACTIONS(4782), 1,
      sym__blank,
    STATE(2021), 1,
      aux_sym_labeled_expression_repeat1,
  [118750] = 4,
    ACTIONS(4109), 1,
      sym__line_continuation,
    ACTIONS(4784), 1,
      anon_sym_DQUOTE,
    STATE(2027), 1,
      aux_sym_hll_string_literal_repeat1,
    ACTIONS(4786), 2,
      aux_sym_hll_string_literal_token1,
      sym_hll_escape_sequence,
  [118764] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4790), 1,
      sym__blank,
    STATE(140), 1,
      aux_sym_block_repeat1,
    ACTIONS(4788), 2,
      sym_comment,
      sym__blank_line,
  [118778] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4682), 1,
      sym__blank,
    STATE(2214), 1,
      aux_sym_block_repeat1,
    ACTIONS(4792), 2,
      sym_comment,
      sym__blank_line,
  [118792] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3712), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      sym__blank,
  [118802] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4599), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      sym__blank,
  [118812] = 4,
    ACTIONS(4109), 1,
      sym__line_continuation,
    ACTIONS(4794), 1,
      anon_sym_DQUOTE,
    STATE(1983), 1,
      aux_sym_hll_string_literal_repeat1,
    ACTIONS(4653), 2,
      aux_sym_hll_string_literal_token1,
      sym_hll_escape_sequence,
  [118826] = 4,
    ACTIONS(4109), 1,
      sym__line_continuation,
    ACTIONS(4796), 1,
      anon_sym_DQUOTE,
    STATE(1983), 1,
      aux_sym_hll_string_literal_repeat1,
    ACTIONS(4653), 2,
      aux_sym_hll_string_literal_token1,
      sym_hll_escape_sequence,
  [118840] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4688), 1,
      sym__blank,
    STATE(2176), 1,
      aux_sym_block_repeat1,
    ACTIONS(4798), 2,
      sym_comment,
      sym__blank_line,
  [118854] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2627), 1,
      sym__blank,
    STATE(1065), 1,
      aux_sym_block_repeat1,
    ACTIONS(2625), 2,
      sym_comment,
      sym__blank_line,
  [118868] = 4,
    ACTIONS(4109), 1,
      sym__line_continuation,
    ACTIONS(4800), 1,
      anon_sym_DQUOTE,
    STATE(2028), 1,
      aux_sym_hll_string_literal_repeat1,
    ACTIONS(4802), 2,
      aux_sym_hll_string_literal_token1,
      sym_hll_escape_sequence,
  [118882] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3371), 1,
      sym__blank,
    STATE(952), 1,
      aux_sym_block_repeat1,
    ACTIONS(2764), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
  [118896] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4804), 1,
      anon_sym_RPAREN,
    ACTIONS(4806), 1,
      sym__blank,
    STATE(2129), 1,
      aux_sym_block_repeat1,
  [118909] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2661), 1,
      anon_sym_COMMA,
    ACTIONS(2675), 1,
      anon_sym_RPAREN,
    STATE(2223), 1,
      aux_sym_hll_argument_list_repeat1,
  [118922] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4808), 1,
      anon_sym_RPAREN,
    ACTIONS(4810), 1,
      anon_sym_COMMA,
    STATE(2213), 1,
      aux_sym_hll_parameter_list_repeat1,
  [118935] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3371), 1,
      sym__blank,
    ACTIONS(4812), 1,
      anon_sym_RPAREN,
    STATE(952), 1,
      aux_sym_block_repeat1,
  [118948] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2661), 1,
      anon_sym_COMMA,
    ACTIONS(4511), 1,
      anon_sym_RPAREN,
    STATE(2223), 1,
      aux_sym_hll_argument_list_repeat1,
  [118961] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3371), 1,
      sym__blank,
    ACTIONS(4814), 1,
      anon_sym_RBRACK,
    STATE(952), 1,
      aux_sym_block_repeat1,
  [118974] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3371), 1,
      sym__blank,
    ACTIONS(4816), 1,
      anon_sym_RBRACK,
    STATE(952), 1,
      aux_sym_block_repeat1,
  [118987] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2661), 1,
      anon_sym_COMMA,
    ACTIONS(4818), 1,
      anon_sym_RPAREN,
    STATE(2223), 1,
      aux_sym_hll_argument_list_repeat1,
  [119000] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4820), 1,
      sym_identifier,
    ACTIONS(4822), 1,
      anon_sym_LPAREN,
    ACTIONS(4824), 1,
      anon_sym_LBRACE,
  [119013] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4826), 1,
      sym_identifier,
    ACTIONS(4828), 1,
      anon_sym_DQUOTE,
    STATE(941), 1,
      sym_string,
  [119026] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4574), 3,
      anon_sym_DOT,
      anon_sym_COMMA,
      sym__blank,
  [119035] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2661), 1,
      anon_sym_COMMA,
    ACTIONS(4830), 1,
      anon_sym_RPAREN,
    STATE(2223), 1,
      aux_sym_hll_argument_list_repeat1,
  [119048] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3371), 1,
      sym__blank,
    ACTIONS(4832), 1,
      anon_sym_RBRACK,
    STATE(952), 1,
      aux_sym_block_repeat1,
  [119061] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3371), 1,
      sym__blank,
    ACTIONS(4834), 1,
      anon_sym_RBRACK,
    STATE(952), 1,
      aux_sym_block_repeat1,
  [119074] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3371), 1,
      sym__blank,
    ACTIONS(4836), 1,
      anon_sym_RBRACK,
    STATE(952), 1,
      aux_sym_block_repeat1,
  [119087] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1551), 1,
      anon_sym_EQ,
    ACTIONS(3371), 1,
      sym__blank,
    STATE(952), 1,
      aux_sym_block_repeat1,
  [119100] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(434), 1,
      anon_sym_SLASH,
    STATE(1990), 1,
      sym_option_expression,
    STATE(2239), 1,
      aux_sym__command_arguments_repeat2,
  [119113] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4838), 1,
      anon_sym_LPAREN,
    ACTIONS(4840), 1,
      anon_sym_DOT,
    STATE(2050), 1,
      aux_sym__function_identifier_repeat1,
  [119126] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2868), 1,
      anon_sym_RPAREN,
    ACTIONS(2870), 1,
      sym__blank,
    STATE(2057), 1,
      aux_sym_block_repeat1,
  [119139] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4843), 1,
      anon_sym_RPAREN,
    ACTIONS(4845), 1,
      sym__blank,
    STATE(2058), 1,
      aux_sym_block_repeat1,
  [119152] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3371), 1,
      sym__blank,
    ACTIONS(4847), 1,
      anon_sym_EQ,
    STATE(952), 1,
      aux_sym_block_repeat1,
  [119165] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3371), 1,
      sym__blank,
    ACTIONS(4736), 1,
      anon_sym_EQ,
    STATE(952), 1,
      aux_sym_block_repeat1,
  [119178] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3371), 1,
      sym__blank,
    ACTIONS(4849), 1,
      anon_sym_RPAREN,
    STATE(952), 1,
      aux_sym_block_repeat1,
  [119191] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3371), 1,
      sym__blank,
    ACTIONS(4851), 1,
      anon_sym_RPAREN,
    STATE(952), 1,
      aux_sym_block_repeat1,
  [119204] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2872), 1,
      anon_sym_RPAREN,
    ACTIONS(3371), 1,
      sym__blank,
    STATE(952), 1,
      aux_sym_block_repeat1,
  [119217] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3371), 1,
      sym__blank,
    ACTIONS(4853), 1,
      anon_sym_RPAREN,
    STATE(952), 1,
      aux_sym_block_repeat1,
  [119230] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3181), 1,
      anon_sym_EQ,
    ACTIONS(4855), 1,
      sym__blank,
    STATE(2053), 1,
      aux_sym_block_repeat1,
  [119243] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2872), 1,
      anon_sym_RPAREN,
    ACTIONS(2874), 1,
      sym__blank,
    STATE(2064), 1,
      aux_sym_block_repeat1,
  [119256] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4857), 1,
      anon_sym_RPAREN,
    ACTIONS(4859), 1,
      sym__blank,
    STATE(2065), 1,
      aux_sym_block_repeat1,
  [119269] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4861), 1,
      anon_sym_RPAREN,
    ACTIONS(4863), 1,
      sym__blank,
    STATE(2066), 1,
      aux_sym_block_repeat1,
  [119282] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3371), 1,
      sym__blank,
    ACTIONS(4865), 1,
      anon_sym_EQ,
    STATE(952), 1,
      aux_sym_block_repeat1,
  [119295] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3371), 1,
      sym__blank,
    ACTIONS(4867), 1,
      anon_sym_RPAREN,
    STATE(952), 1,
      aux_sym_block_repeat1,
  [119308] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3371), 1,
      sym__blank,
    ACTIONS(4869), 1,
      anon_sym_RPAREN,
    STATE(952), 1,
      aux_sym_block_repeat1,
  [119321] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3371), 1,
      sym__blank,
    ACTIONS(4871), 1,
      anon_sym_RPAREN,
    STATE(952), 1,
      aux_sym_block_repeat1,
  [119334] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4873), 1,
      anon_sym_RPAREN,
    ACTIONS(4875), 1,
      sym__blank,
    STATE(2070), 1,
      aux_sym_block_repeat1,
  [119347] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2661), 1,
      anon_sym_COMMA,
    ACTIONS(2689), 1,
      anon_sym_RPAREN,
    STATE(2223), 1,
      aux_sym_hll_argument_list_repeat1,
  [119360] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3371), 1,
      sym__blank,
    ACTIONS(4877), 1,
      anon_sym_RBRACK,
    STATE(952), 1,
      aux_sym_block_repeat1,
  [119373] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3371), 1,
      sym__blank,
    ACTIONS(4879), 1,
      anon_sym_RPAREN,
    STATE(952), 1,
      aux_sym_block_repeat1,
  [119386] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2661), 1,
      anon_sym_COMMA,
    ACTIONS(4533), 1,
      anon_sym_RPAREN,
    STATE(2223), 1,
      aux_sym_hll_argument_list_repeat1,
  [119399] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2661), 1,
      anon_sym_COMMA,
    ACTIONS(4881), 1,
      anon_sym_RPAREN,
    STATE(2223), 1,
      aux_sym_hll_argument_list_repeat1,
  [119412] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4883), 1,
      sym_identifier,
    ACTIONS(4885), 1,
      anon_sym_LPAREN,
    ACTIONS(4887), 1,
      anon_sym_LBRACE,
  [119425] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(80), 1,
      anon_sym_DQUOTE,
    ACTIONS(4889), 1,
      sym_identifier,
    STATE(1328), 1,
      sym_string,
  [119438] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2833), 1,
      anon_sym_RPAREN,
    ACTIONS(3371), 1,
      sym__blank,
    STATE(952), 1,
      aux_sym_block_repeat1,
  [119451] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3371), 1,
      sym__blank,
    ACTIONS(4891), 1,
      anon_sym_RPAREN,
    STATE(952), 1,
      aux_sym_block_repeat1,
  [119464] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3371), 1,
      sym__blank,
    ACTIONS(4893), 1,
      anon_sym_RPAREN,
    STATE(952), 1,
      aux_sym_block_repeat1,
  [119477] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4895), 1,
      anon_sym_RPAREN,
    ACTIONS(4897), 1,
      sym__blank,
    STATE(2215), 1,
      aux_sym_block_repeat1,
  [119490] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3371), 1,
      sym__blank,
    ACTIONS(4899), 1,
      sym_identifier,
    STATE(952), 1,
      aux_sym_block_repeat1,
  [119503] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4901), 1,
      anon_sym_RPAREN,
    ACTIONS(4903), 1,
      sym__blank,
    STATE(2084), 1,
      aux_sym_block_repeat1,
  [119516] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2833), 1,
      anon_sym_RPAREN,
    ACTIONS(2835), 1,
      sym__blank,
    STATE(2163), 1,
      aux_sym_block_repeat1,
  [119529] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4905), 1,
      sym__blank,
    STATE(1880), 1,
      aux_sym_macro_definition_repeat1,
    STATE(2003), 1,
      aux_sym_block_repeat1,
  [119542] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4907), 1,
      anon_sym_RPAREN,
    ACTIONS(4909), 1,
      sym__blank,
    STATE(2169), 1,
      aux_sym_block_repeat1,
  [119555] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3371), 1,
      sym__blank,
    ACTIONS(4911), 1,
      anon_sym_RPAREN,
    STATE(952), 1,
      aux_sym_block_repeat1,
  [119568] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4913), 1,
      anon_sym_RPAREN,
    ACTIONS(4915), 1,
      sym__blank,
    STATE(2088), 1,
      aux_sym_block_repeat1,
  [119581] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4917), 1,
      anon_sym_RPAREN,
    ACTIONS(4919), 1,
      sym__blank,
    STATE(2089), 1,
      aux_sym_block_repeat1,
  [119594] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4921), 1,
      anon_sym_RPAREN,
    ACTIONS(4923), 1,
      sym__blank,
    STATE(2170), 1,
      aux_sym_block_repeat1,
  [119607] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3371), 1,
      sym__blank,
    ACTIONS(4925), 1,
      anon_sym_RPAREN,
    STATE(952), 1,
      aux_sym_block_repeat1,
  [119620] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3371), 1,
      sym__blank,
    ACTIONS(4927), 1,
      anon_sym_RPAREN,
    STATE(952), 1,
      aux_sym_block_repeat1,
  [119633] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4929), 1,
      anon_sym_RPAREN,
    ACTIONS(4931), 1,
      sym__blank,
    STATE(2091), 1,
      aux_sym_block_repeat1,
  [119646] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3371), 1,
      sym__blank,
    ACTIONS(4933), 1,
      anon_sym_RPAREN,
    STATE(952), 1,
      aux_sym_block_repeat1,
  [119659] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4935), 1,
      sym_identifier,
    ACTIONS(4937), 1,
      anon_sym_LPAREN,
    ACTIONS(4939), 1,
      anon_sym_LBRACE,
  [119672] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4941), 1,
      sym_identifier,
    ACTIONS(4943), 1,
      anon_sym_DQUOTE,
    STATE(1007), 1,
      sym_string,
  [119685] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2661), 1,
      anon_sym_COMMA,
    ACTIONS(2671), 1,
      anon_sym_RPAREN,
    STATE(2223), 1,
      aux_sym_hll_argument_list_repeat1,
  [119698] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3371), 1,
      sym__blank,
    ACTIONS(4945), 1,
      anon_sym_RBRACK,
    STATE(952), 1,
      aux_sym_block_repeat1,
  [119711] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2011), 1,
      sym__blank,
    ACTIONS(2013), 2,
      sym_comment,
      sym__blank_line,
  [119722] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4947), 1,
      anon_sym_RPAREN,
    ACTIONS(4949), 1,
      sym__blank,
    STATE(2099), 1,
      aux_sym_block_repeat1,
  [119735] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4810), 1,
      anon_sym_COMMA,
    ACTIONS(4951), 1,
      anon_sym_RPAREN,
    STATE(2213), 1,
      aux_sym_hll_parameter_list_repeat1,
  [119748] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3371), 1,
      sym__blank,
    ACTIONS(4953), 1,
      anon_sym_RPAREN,
    STATE(952), 1,
      aux_sym_block_repeat1,
  [119761] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4955), 1,
      anon_sym_RPAREN,
    ACTIONS(4957), 1,
      sym__blank,
    STATE(2103), 1,
      aux_sym_block_repeat1,
  [119774] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4959), 1,
      anon_sym_RPAREN,
    ACTIONS(4961), 1,
      sym__blank,
    STATE(2104), 1,
      aux_sym_block_repeat1,
  [119787] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3371), 1,
      sym__blank,
    ACTIONS(4963), 1,
      anon_sym_DOT_DOT,
    STATE(952), 1,
      aux_sym_block_repeat1,
  [119800] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3371), 1,
      sym__blank,
    ACTIONS(4965), 1,
      anon_sym_RPAREN,
    STATE(952), 1,
      aux_sym_block_repeat1,
  [119813] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3371), 1,
      sym__blank,
    ACTIONS(4967), 1,
      anon_sym_RPAREN,
    STATE(952), 1,
      aux_sym_block_repeat1,
  [119826] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4969), 1,
      anon_sym_RPAREN,
    ACTIONS(4971), 1,
      sym__blank,
    STATE(2106), 1,
      aux_sym_block_repeat1,
  [119839] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3371), 1,
      sym__blank,
    ACTIONS(4973), 1,
      anon_sym_RPAREN,
    STATE(952), 1,
      aux_sym_block_repeat1,
  [119852] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4975), 1,
      sym_identifier,
    ACTIONS(4977), 1,
      anon_sym_LPAREN,
    ACTIONS(4979), 1,
      anon_sym_LBRACE,
  [119865] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4981), 1,
      sym_identifier,
    ACTIONS(4983), 1,
      anon_sym_DQUOTE,
    STATE(818), 1,
      sym_string,
  [119878] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4987), 1,
      sym__blank,
    ACTIONS(4985), 2,
      sym_comment,
      sym__blank_line,
  [119889] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4989), 1,
      anon_sym_RPAREN,
    ACTIONS(4991), 1,
      sym__blank,
    STATE(2112), 1,
      aux_sym_block_repeat1,
  [119902] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4995), 1,
      sym__blank,
    ACTIONS(4993), 2,
      sym_comment,
      sym__blank_line,
  [119913] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3371), 1,
      sym__blank,
    ACTIONS(4997), 1,
      anon_sym_RPAREN,
    STATE(952), 1,
      aux_sym_block_repeat1,
  [119926] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4999), 1,
      anon_sym_RPAREN,
    ACTIONS(5001), 1,
      sym__blank,
    STATE(2116), 1,
      aux_sym_block_repeat1,
  [119939] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5003), 1,
      anon_sym_RPAREN,
    ACTIONS(5005), 1,
      sym__blank,
    STATE(2117), 1,
      aux_sym_block_repeat1,
  [119952] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3371), 1,
      sym__blank,
    ACTIONS(5007), 1,
      anon_sym_RBRACK,
    STATE(952), 1,
      aux_sym_block_repeat1,
  [119965] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3371), 1,
      sym__blank,
    ACTIONS(5009), 1,
      anon_sym_RPAREN,
    STATE(952), 1,
      aux_sym_block_repeat1,
  [119978] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3371), 1,
      sym__blank,
    ACTIONS(5011), 1,
      anon_sym_RPAREN,
    STATE(952), 1,
      aux_sym_block_repeat1,
  [119991] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5013), 1,
      anon_sym_RPAREN,
    ACTIONS(5015), 1,
      sym__blank,
    STATE(2119), 1,
      aux_sym_block_repeat1,
  [120004] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3371), 1,
      sym__blank,
    ACTIONS(5017), 1,
      anon_sym_RPAREN,
    STATE(952), 1,
      aux_sym_block_repeat1,
  [120017] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4826), 1,
      sym_identifier,
    ACTIONS(5019), 1,
      anon_sym_DQUOTE,
    STATE(782), 1,
      sym_string,
  [120030] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4905), 1,
      sym__blank,
    STATE(1888), 1,
      aux_sym_macro_definition_repeat1,
    STATE(2003), 1,
      aux_sym_block_repeat1,
  [120043] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3371), 1,
      sym__blank,
    ACTIONS(5021), 1,
      anon_sym_RBRACK,
    STATE(952), 1,
      aux_sym_block_repeat1,
  [120056] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5023), 1,
      anon_sym_RPAREN,
    ACTIONS(5025), 1,
      sym__blank,
    STATE(2125), 1,
      aux_sym_block_repeat1,
  [120069] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3371), 1,
      sym__blank,
    ACTIONS(5027), 1,
      anon_sym_RBRACK,
    STATE(952), 1,
      aux_sym_block_repeat1,
  [120082] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3371), 1,
      sym__blank,
    ACTIONS(5029), 1,
      anon_sym_RPAREN,
    STATE(952), 1,
      aux_sym_block_repeat1,
  [120095] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5031), 1,
      anon_sym_RPAREN,
    ACTIONS(5033), 1,
      sym__blank,
    STATE(2128), 1,
      aux_sym_block_repeat1,
  [120108] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5035), 1,
      anon_sym_COMMA,
    ACTIONS(5037), 1,
      sym__blank,
    STATE(945), 1,
      aux_sym_block_repeat1,
  [120121] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3371), 1,
      sym__blank,
    ACTIONS(5039), 1,
      anon_sym_RPAREN,
    STATE(952), 1,
      aux_sym_block_repeat1,
  [120134] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3371), 1,
      sym__blank,
    ACTIONS(5041), 1,
      anon_sym_RPAREN,
    STATE(952), 1,
      aux_sym_block_repeat1,
  [120147] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5043), 1,
      anon_sym_RPAREN,
    ACTIONS(5045), 1,
      sym__blank,
    STATE(2131), 1,
      aux_sym_block_repeat1,
  [120160] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3371), 1,
      sym__blank,
    ACTIONS(5047), 1,
      anon_sym_RPAREN,
    STATE(952), 1,
      aux_sym_block_repeat1,
  [120173] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4828), 1,
      anon_sym_DQUOTE,
    ACTIONS(4941), 1,
      sym_identifier,
    STATE(941), 1,
      sym_string,
  [120186] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2661), 1,
      anon_sym_COMMA,
    ACTIONS(5049), 1,
      anon_sym_RPAREN,
    STATE(2223), 1,
      aux_sym_hll_argument_list_repeat1,
  [120199] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4905), 1,
      sym__blank,
    STATE(1928), 1,
      aux_sym_macro_definition_repeat1,
    STATE(2003), 1,
      aux_sym_block_repeat1,
  [120212] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5051), 1,
      anon_sym_RPAREN,
    ACTIONS(5053), 1,
      sym__blank,
    STATE(2136), 1,
      aux_sym_block_repeat1,
  [120225] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3371), 1,
      sym__blank,
    ACTIONS(5055), 1,
      anon_sym_RPAREN,
    STATE(952), 1,
      aux_sym_block_repeat1,
  [120238] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5057), 1,
      anon_sym_RPAREN,
    ACTIONS(5059), 1,
      sym__blank,
    STATE(2139), 1,
      aux_sym_block_repeat1,
  [120251] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5061), 1,
      anon_sym_RPAREN,
    ACTIONS(5063), 1,
      sym__blank,
    STATE(2140), 1,
      aux_sym_block_repeat1,
  [120264] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3371), 1,
      sym__blank,
    ACTIONS(5065), 1,
      anon_sym_RPAREN,
    STATE(952), 1,
      aux_sym_block_repeat1,
  [120277] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3371), 1,
      sym__blank,
    ACTIONS(5067), 1,
      anon_sym_RPAREN,
    STATE(952), 1,
      aux_sym_block_repeat1,
  [120290] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5069), 1,
      anon_sym_RPAREN,
    ACTIONS(5071), 1,
      sym__blank,
    STATE(2142), 1,
      aux_sym_block_repeat1,
  [120303] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3371), 1,
      sym__blank,
    ACTIONS(5073), 1,
      anon_sym_RPAREN,
    STATE(952), 1,
      aux_sym_block_repeat1,
  [120316] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4941), 1,
      sym_identifier,
    ACTIONS(5075), 1,
      anon_sym_DQUOTE,
    STATE(723), 1,
      sym_string,
  [120329] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3371), 1,
      sym__blank,
    ACTIONS(5077), 1,
      anon_sym_RBRACK,
    STATE(952), 1,
      aux_sym_block_repeat1,
  [120342] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5079), 3,
      anon_sym_STAR,
      anon_sym_QMARK,
      sym_identifier,
  [120351] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3371), 1,
      sym__blank,
    ACTIONS(5081), 1,
      anon_sym_RBRACK,
    STATE(952), 1,
      aux_sym_block_repeat1,
  [120364] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4995), 1,
      sym__blank,
    ACTIONS(5083), 2,
      sym_comment,
      sym__blank_line,
  [120375] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5085), 1,
      anon_sym_RPAREN,
    ACTIONS(5087), 1,
      sym__blank,
    STATE(2151), 1,
      aux_sym_block_repeat1,
  [120388] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2797), 1,
      anon_sym_RPAREN,
    ACTIONS(2799), 1,
      sym__blank,
    STATE(2166), 1,
      aux_sym_block_repeat1,
  [120401] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5089), 1,
      anon_sym_RPAREN,
    ACTIONS(5091), 1,
      sym__blank,
    STATE(2167), 1,
      aux_sym_block_repeat1,
  [120414] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3371), 1,
      sym__blank,
    ACTIONS(5093), 1,
      anon_sym_RPAREN,
    STATE(952), 1,
      aux_sym_block_repeat1,
  [120427] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5095), 1,
      anon_sym_RPAREN,
    ACTIONS(5097), 1,
      sym__blank,
    STATE(2155), 1,
      aux_sym_block_repeat1,
  [120440] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5099), 1,
      anon_sym_RPAREN,
    ACTIONS(5101), 1,
      sym__blank,
    STATE(2156), 1,
      aux_sym_block_repeat1,
  [120453] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2801), 1,
      anon_sym_RPAREN,
    ACTIONS(2803), 1,
      sym__blank,
    STATE(2075), 1,
      aux_sym_block_repeat1,
  [120466] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3371), 1,
      sym__blank,
    ACTIONS(5103), 1,
      anon_sym_RPAREN,
    STATE(952), 1,
      aux_sym_block_repeat1,
  [120479] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3371), 1,
      sym__blank,
    ACTIONS(5105), 1,
      anon_sym_RPAREN,
    STATE(952), 1,
      aux_sym_block_repeat1,
  [120492] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5107), 1,
      anon_sym_RPAREN,
    ACTIONS(5109), 1,
      sym__blank,
    STATE(2158), 1,
      aux_sym_block_repeat1,
  [120505] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3371), 1,
      sym__blank,
    ACTIONS(5111), 1,
      anon_sym_RPAREN,
    STATE(952), 1,
      aux_sym_block_repeat1,
  [120518] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3931), 1,
      anon_sym_DQUOTE,
    ACTIONS(5113), 1,
      sym_identifier,
    STATE(2256), 1,
      sym_string,
  [120531] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3371), 1,
      sym__blank,
    ACTIONS(5115), 1,
      anon_sym_RBRACK,
    STATE(952), 1,
      aux_sym_block_repeat1,
  [120544] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5117), 1,
      anon_sym_RPAREN,
    ACTIONS(5119), 1,
      sym__blank,
    STATE(2076), 1,
      aux_sym_block_repeat1,
  [120557] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5121), 1,
      sym_identifier,
    ACTIONS(5123), 1,
      anon_sym_DQUOTE,
    STATE(1199), 1,
      sym_string,
  [120570] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3371), 1,
      sym__blank,
    ACTIONS(5125), 1,
      anon_sym_RPAREN,
    STATE(952), 1,
      aux_sym_block_repeat1,
  [120583] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5121), 1,
      sym_identifier,
    ACTIONS(5127), 1,
      anon_sym_DQUOTE,
    STATE(867), 1,
      sym_string,
  [120596] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3371), 1,
      sym__blank,
    ACTIONS(5129), 1,
      anon_sym_RBRACK,
    STATE(952), 1,
      aux_sym_block_repeat1,
  [120609] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2746), 1,
      anon_sym_RPAREN,
    ACTIONS(3371), 1,
      sym__blank,
    STATE(952), 1,
      aux_sym_block_repeat1,
  [120622] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3371), 1,
      sym__blank,
    ACTIONS(5131), 1,
      anon_sym_RPAREN,
    STATE(952), 1,
      aux_sym_block_repeat1,
  [120635] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3371), 1,
      sym__blank,
    ACTIONS(5133), 1,
      anon_sym_RBRACK,
    STATE(952), 1,
      aux_sym_block_repeat1,
  [120648] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3371), 1,
      sym__blank,
    ACTIONS(5135), 1,
      anon_sym_RPAREN,
    STATE(952), 1,
      aux_sym_block_repeat1,
  [120661] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3371), 1,
      sym__blank,
    ACTIONS(5137), 1,
      anon_sym_RPAREN,
    STATE(952), 1,
      aux_sym_block_repeat1,
  [120674] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5139), 1,
      sym_identifier,
    ACTIONS(5141), 1,
      anon_sym_LPAREN,
    ACTIONS(5143), 1,
      anon_sym_LBRACE,
  [120687] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(434), 1,
      anon_sym_SLASH,
    STATE(1816), 1,
      sym_option_expression,
    STATE(2239), 1,
      aux_sym__command_arguments_repeat2,
  [120700] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5147), 1,
      sym__blank,
    ACTIONS(5145), 2,
      sym_comment,
      sym__blank_line,
  [120711] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(126), 1,
      anon_sym_DQUOTE,
    ACTIONS(5149), 1,
      sym_identifier,
    STATE(390), 1,
      sym_string,
  [120724] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5151), 1,
      anon_sym_RPAREN,
    ACTIONS(5153), 1,
      sym__blank,
    STATE(2211), 1,
      aux_sym_block_repeat1,
  [120737] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3371), 1,
      sym__blank,
    ACTIONS(4396), 1,
      anon_sym_SLASH,
    STATE(952), 1,
      aux_sym_block_repeat1,
  [120750] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3371), 1,
      sym__blank,
    ACTIONS(5155), 1,
      anon_sym_RBRACK,
    STATE(952), 1,
      aux_sym_block_repeat1,
  [120763] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(434), 1,
      anon_sym_SLASH,
    STATE(2029), 1,
      sym_option_expression,
    STATE(2239), 1,
      aux_sym__command_arguments_repeat2,
  [120776] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2746), 1,
      anon_sym_RPAREN,
    ACTIONS(2750), 1,
      sym__blank,
    STATE(2055), 1,
      aux_sym_block_repeat1,
  [120789] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5157), 1,
      anon_sym_RPAREN,
    ACTIONS(5159), 1,
      sym__blank,
    STATE(2056), 1,
      aux_sym_block_repeat1,
  [120802] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2661), 1,
      anon_sym_COMMA,
    ACTIONS(2665), 1,
      anon_sym_RPAREN,
    STATE(2223), 1,
      aux_sym_hll_argument_list_repeat1,
  [120815] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(434), 1,
      anon_sym_SLASH,
    STATE(1859), 1,
      sym_option_expression,
    STATE(2239), 1,
      aux_sym__command_arguments_repeat2,
  [120828] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3371), 1,
      sym__blank,
    ACTIONS(5161), 1,
      anon_sym_RBRACK,
    STATE(952), 1,
      aux_sym_block_repeat1,
  [120841] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3371), 1,
      sym__blank,
    ACTIONS(5163), 1,
      anon_sym_RBRACK,
    STATE(952), 1,
      aux_sym_block_repeat1,
  [120854] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3371), 1,
      sym__blank,
    ACTIONS(5165), 1,
      anon_sym_RBRACK,
    STATE(952), 1,
      aux_sym_block_repeat1,
  [120867] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3371), 1,
      sym__blank,
    ACTIONS(5167), 1,
      anon_sym_RBRACK,
    STATE(952), 1,
      aux_sym_block_repeat1,
  [120880] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3371), 1,
      sym__blank,
    ACTIONS(5169), 1,
      sym_identifier,
    STATE(952), 1,
      aux_sym_block_repeat1,
  [120893] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3371), 1,
      sym__blank,
    ACTIONS(5171), 1,
      anon_sym_RBRACK,
    STATE(952), 1,
      aux_sym_block_repeat1,
  [120906] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5173), 1,
      anon_sym_RPAREN,
    ACTIONS(5175), 1,
      sym__blank,
    STATE(2077), 1,
      aux_sym_block_repeat1,
  [120919] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1665), 1,
      sym__blank,
    ACTIONS(1667), 2,
      sym_comment,
      sym__blank_line,
  [120930] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4810), 1,
      anon_sym_COMMA,
    ACTIONS(5177), 1,
      anon_sym_RPAREN,
    STATE(2098), 1,
      aux_sym_hll_parameter_list_repeat1,
  [120943] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4905), 1,
      sym__blank,
    STATE(1882), 1,
      aux_sym_macro_definition_repeat1,
    STATE(2003), 1,
      aux_sym_block_repeat1,
  [120956] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3371), 1,
      sym__blank,
    ACTIONS(4738), 1,
      anon_sym_COMMA,
    STATE(952), 1,
      aux_sym_block_repeat1,
  [120969] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5179), 1,
      sym_identifier,
    ACTIONS(5181), 1,
      anon_sym_LPAREN,
    ACTIONS(5183), 1,
      anon_sym_LBRACE,
  [120982] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3371), 1,
      sym__blank,
    ACTIONS(5185), 1,
      aux_sym_if_block_token1,
    STATE(952), 1,
      aux_sym_block_repeat1,
  [120995] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5187), 1,
      anon_sym_LPAREN,
    ACTIONS(5189), 1,
      anon_sym_DOT,
    STATE(2050), 1,
      aux_sym__function_identifier_repeat1,
  [121008] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3371), 1,
      sym__blank,
    ACTIONS(5191), 1,
      anon_sym_EQ,
    STATE(952), 1,
      aux_sym_block_repeat1,
  [121021] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3371), 1,
      sym__blank,
    ACTIONS(5193), 1,
      sym_identifier,
    STATE(952), 1,
      aux_sym_block_repeat1,
  [121034] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3371), 1,
      sym__blank,
    ACTIONS(5195), 1,
      anon_sym_RBRACK,
    STATE(952), 1,
      aux_sym_block_repeat1,
  [121047] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(197), 1,
      anon_sym_DQUOTE,
    ACTIONS(5197), 1,
      sym_identifier,
    STATE(1344), 1,
      sym_string,
  [121060] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1661), 1,
      sym__blank,
    ACTIONS(1663), 2,
      sym_comment,
      sym__blank_line,
  [121071] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3371), 1,
      sym__blank,
    ACTIONS(5199), 1,
      anon_sym_RBRACK,
    STATE(952), 1,
      aux_sym_block_repeat1,
  [121084] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(434), 1,
      anon_sym_SLASH,
    STATE(1829), 1,
      sym_option_expression,
    STATE(2239), 1,
      aux_sym__command_arguments_repeat2,
  [121097] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2848), 1,
      anon_sym_RPAREN,
    ACTIONS(2850), 1,
      sym__blank,
    STATE(2216), 1,
      aux_sym_block_repeat1,
  [121110] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5201), 1,
      anon_sym_RPAREN,
    ACTIONS(5203), 1,
      sym__blank,
    STATE(2217), 1,
      aux_sym_block_repeat1,
  [121123] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4810), 1,
      anon_sym_COMMA,
    ACTIONS(5205), 1,
      anon_sym_RPAREN,
    STATE(2035), 1,
      aux_sym_hll_parameter_list_repeat1,
  [121136] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4905), 1,
      sym__blank,
    STATE(1925), 1,
      aux_sym_macro_definition_repeat1,
    STATE(2003), 1,
      aux_sym_block_repeat1,
  [121149] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(434), 1,
      anon_sym_SLASH,
    STATE(1968), 1,
      sym_option_expression,
    STATE(2239), 1,
      aux_sym__command_arguments_repeat2,
  [121162] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4905), 1,
      sym__blank,
    STATE(1854), 1,
      aux_sym_macro_definition_repeat1,
    STATE(2003), 1,
      aux_sym_block_repeat1,
  [121175] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4995), 1,
      sym__blank,
    ACTIONS(5207), 2,
      sym_comment,
      sym__blank_line,
  [121186] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3371), 1,
      sym__blank,
    ACTIONS(5209), 1,
      anon_sym_RPAREN,
    STATE(952), 1,
      aux_sym_block_repeat1,
  [121199] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5211), 1,
      sym__blank,
    STATE(1856), 1,
      aux_sym_block_repeat1,
    STATE(1857), 1,
      aux_sym_macro_definition_repeat1,
  [121212] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5213), 1,
      anon_sym_RPAREN,
    ACTIONS(5215), 1,
      anon_sym_COMMA,
    STATE(2213), 1,
      aux_sym_hll_parameter_list_repeat1,
  [121225] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3371), 1,
      sym__blank,
    ACTIONS(5218), 1,
      aux_sym_if_block_token1,
    STATE(952), 1,
      aux_sym_block_repeat1,
  [121238] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3371), 1,
      sym__blank,
    ACTIONS(5220), 1,
      anon_sym_RPAREN,
    STATE(952), 1,
      aux_sym_block_repeat1,
  [121251] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2852), 1,
      anon_sym_RPAREN,
    ACTIONS(3371), 1,
      sym__blank,
    STATE(952), 1,
      aux_sym_block_repeat1,
  [121264] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3371), 1,
      sym__blank,
    ACTIONS(5222), 1,
      anon_sym_RPAREN,
    STATE(952), 1,
      aux_sym_block_repeat1,
  [121277] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1545), 1,
      aux_sym_block_token1,
    ACTIONS(3371), 1,
      sym__blank,
    STATE(952), 1,
      aux_sym_block_repeat1,
  [121290] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2852), 1,
      anon_sym_RPAREN,
    ACTIONS(2854), 1,
      sym__blank,
    STATE(2234), 1,
      aux_sym_block_repeat1,
  [121303] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5224), 1,
      anon_sym_RPAREN,
    ACTIONS(5226), 1,
      sym__blank,
    STATE(2235), 1,
      aux_sym_block_repeat1,
  [121316] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4631), 1,
      sym__blank,
    ACTIONS(4629), 2,
      sym_comment,
      sym__blank_line,
  [121327] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2661), 1,
      anon_sym_COMMA,
    ACTIONS(4627), 1,
      anon_sym_RPAREN,
    STATE(2223), 1,
      aux_sym_hll_argument_list_repeat1,
  [121340] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2731), 1,
      anon_sym_RPAREN,
    ACTIONS(5228), 1,
      anon_sym_COMMA,
    STATE(2223), 1,
      aux_sym_hll_argument_list_repeat1,
  [121353] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5231), 1,
      anon_sym_RPAREN,
    ACTIONS(5233), 1,
      sym__blank,
    STATE(2236), 1,
      aux_sym_block_repeat1,
  [121366] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1987), 1,
      sym__blank,
    ACTIONS(1989), 2,
      sym_comment,
      sym__blank_line,
  [121377] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2661), 1,
      anon_sym_COMMA,
    ACTIONS(4426), 1,
      anon_sym_RPAREN,
    STATE(2223), 1,
      aux_sym_hll_argument_list_repeat1,
  [121390] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5235), 1,
      sym_identifier,
    ACTIONS(5237), 1,
      anon_sym_LPAREN,
    ACTIONS(5239), 1,
      anon_sym_LBRACE,
  [121403] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3371), 1,
      sym__blank,
    ACTIONS(5241), 1,
      anon_sym_RBRACK,
    STATE(952), 1,
      aux_sym_block_repeat1,
  [121416] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5243), 1,
      sym__blank,
    STATE(1885), 1,
      aux_sym_block_repeat1,
    STATE(1886), 1,
      aux_sym_macro_definition_repeat1,
  [121429] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4828), 1,
      anon_sym_DQUOTE,
    ACTIONS(4981), 1,
      sym_identifier,
    STATE(941), 1,
      sym_string,
  [121442] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(434), 1,
      anon_sym_SLASH,
    STATE(1904), 1,
      sym_option_expression,
    STATE(2239), 1,
      aux_sym__command_arguments_repeat2,
  [121455] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5245), 1,
      aux_sym__hll_var_definition_command_token1,
    ACTIONS(5247), 2,
      sym_comment,
      sym__blank_line,
  [121466] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5249), 3,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [121475] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3371), 1,
      sym__blank,
    ACTIONS(5251), 1,
      anon_sym_RPAREN,
    STATE(952), 1,
      aux_sym_block_repeat1,
  [121488] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3371), 1,
      sym__blank,
    ACTIONS(5253), 1,
      anon_sym_RPAREN,
    STATE(952), 1,
      aux_sym_block_repeat1,
  [121501] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3371), 1,
      sym__blank,
    ACTIONS(5255), 1,
      anon_sym_RPAREN,
    STATE(952), 1,
      aux_sym_block_repeat1,
  [121514] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5257), 1,
      sym__blank,
    ACTIONS(4387), 2,
      sym_comment,
      sym__blank_line,
  [121525] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5259), 1,
      anon_sym_RPAREN,
    ACTIONS(5261), 1,
      sym__blank,
    STATE(2036), 1,
      aux_sym_block_repeat1,
  [121538] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5263), 1,
      anon_sym_SLASH,
    STATE(2239), 1,
      aux_sym__command_arguments_repeat2,
    STATE(2261), 1,
      sym_option_expression,
  [121551] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2385), 2,
      sym_comment,
      sym__blank_line,
  [121559] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5266), 1,
      sym__blank,
    STATE(475), 1,
      aux_sym_block_repeat1,
  [121569] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5127), 1,
      anon_sym_DQUOTE,
    STATE(867), 1,
      sym_string,
  [121579] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5268), 2,
      sym_comment,
      sym__blank_line,
  [121587] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5270), 2,
      sym_comment,
      sym__blank_line,
  [121595] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5272), 2,
      sym_comment,
      sym__blank_line,
  [121603] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5274), 2,
      aux_sym_character_token1,
      aux_sym_character_token2,
  [121611] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(197), 1,
      anon_sym_DQUOTE,
    STATE(1344), 1,
      sym_string,
  [121621] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5276), 1,
      sym__blank,
    STATE(1641), 1,
      aux_sym_block_repeat1,
  [121631] = 3,
    ACTIONS(4109), 1,
      sym__line_continuation,
    ACTIONS(5278), 1,
      aux_sym_hll_char_literal_token1,
    ACTIONS(5280), 1,
      sym_hll_escape_sequence,
  [121641] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5282), 1,
      sym__blank,
    STATE(1660), 1,
      aux_sym_block_repeat1,
  [121651] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5284), 1,
      sym__blank,
    STATE(1658), 1,
      aux_sym_block_repeat1,
  [121661] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1667), 2,
      anon_sym_EQ,
      sym__blank,
  [121669] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(695), 1,
      anon_sym_AMP,
    STATE(415), 1,
      sym_macro,
  [121679] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5286), 1,
      sym__blank,
    STATE(132), 1,
      aux_sym_block_repeat1,
  [121689] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(126), 1,
      anon_sym_DQUOTE,
    STATE(390), 1,
      sym_string,
  [121699] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1891), 1,
      sym__blank,
    ACTIONS(5288), 1,
      aux_sym_symbol_token3,
  [121709] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2978), 1,
      anon_sym_LPAREN,
    STATE(1033), 1,
      sym_argument_list,
  [121719] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5290), 1,
      anon_sym_AMP_AMP,
    ACTIONS(5292), 1,
      anon_sym_AMP,
  [121729] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(80), 1,
      anon_sym_DQUOTE,
    STATE(1328), 1,
      sym_string,
  [121739] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5294), 1,
      anon_sym_LPAREN,
    STATE(1070), 1,
      sym_hll_var_call_expression_argument_list,
  [121749] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5296), 1,
      sym__blank,
    STATE(2176), 1,
      aux_sym_block_repeat1,
  [121759] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5298), 1,
      sym__blank,
    STATE(105), 1,
      aux_sym_block_repeat1,
  [121769] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5300), 1,
      sym__blank,
    STATE(2195), 1,
      aux_sym_block_repeat1,
  [121779] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5075), 1,
      anon_sym_DQUOTE,
    STATE(723), 1,
      sym_string,
  [121789] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5302), 1,
      sym_comment,
    ACTIONS(5304), 1,
      sym__blank_line,
  [121799] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1989), 2,
      aux_sym_symbol_token3,
      sym__blank,
  [121807] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5306), 1,
      sym_comment,
    ACTIONS(5308), 1,
      sym__blank_line,
  [121817] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5310), 2,
      sym_comment,
      sym__blank_line,
  [121825] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5312), 2,
      sym_comment,
      sym__blank_line,
  [121833] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2591), 2,
      sym_comment,
      sym__blank_line,
  [121841] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5314), 1,
      sym__blank,
    STATE(1444), 1,
      aux_sym_block_repeat1,
  [121851] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5316), 1,
      sym__blank,
    STATE(472), 1,
      aux_sym_block_repeat1,
  [121861] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5318), 2,
      sym_comment,
      sym__blank_line,
  [121869] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1779), 2,
      sym_comment,
      sym__blank_line,
  [121877] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5320), 2,
      aux_sym_character_token1,
      aux_sym_character_token2,
  [121885] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5322), 1,
      sym__blank,
    STATE(492), 1,
      aux_sym_block_repeat1,
  [121895] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5324), 1,
      sym__blank,
    STATE(131), 1,
      aux_sym_block_repeat1,
  [121905] = 3,
    ACTIONS(4109), 1,
      sym__line_continuation,
    ACTIONS(5326), 1,
      aux_sym_hll_char_literal_token1,
    ACTIONS(5328), 1,
      sym_hll_escape_sequence,
  [121915] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1693), 2,
      sym_comment,
      sym__blank_line,
  [121923] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5330), 2,
      sym_comment,
      sym__blank_line,
  [121931] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5332), 1,
      sym_identifier,
    ACTIONS(5334), 1,
      anon_sym_LPAREN,
  [121941] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5336), 1,
      anon_sym_AMP_AMP,
    ACTIONS(5338), 1,
      anon_sym_AMP,
  [121951] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5340), 1,
      sym_identifier,
    STATE(922), 1,
      sym__hll_field_identifier,
  [121961] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5342), 2,
      sym_comment,
      sym__blank_line,
  [121969] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5268), 2,
      sym_comment,
      sym__blank_line,
  [121977] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3008), 2,
      anon_sym_RPAREN,
      sym__blank,
  [121985] = 3,
    ACTIONS(4109), 1,
      sym__line_continuation,
    ACTIONS(5344), 1,
      aux_sym_hll_char_literal_token1,
    ACTIONS(5346), 1,
      sym_hll_escape_sequence,
  [121995] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5348), 1,
      sym_comment,
    ACTIONS(5350), 1,
      sym__blank_line,
  [122005] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5352), 2,
      anon_sym_LPAREN,
      anon_sym_DOT,
  [122013] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5354), 1,
      sym__blank,
    STATE(118), 1,
      aux_sym_block_repeat1,
  [122023] = 3,
    ACTIONS(4109), 1,
      sym__line_continuation,
    ACTIONS(5356), 1,
      aux_sym_hll_char_literal_token1,
    ACTIONS(5358), 1,
      sym_hll_escape_sequence,
  [122033] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5360), 1,
      anon_sym_AMP_AMP,
    ACTIONS(5362), 1,
      anon_sym_AMP,
  [122043] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5364), 2,
      sym_comment,
      sym__blank_line,
  [122051] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2393), 2,
      sym_comment,
      sym__blank_line,
  [122059] = 3,
    ACTIONS(4109), 1,
      sym__line_continuation,
    ACTIONS(5366), 1,
      aux_sym_hll_char_literal_token1,
    ACTIONS(5368), 1,
      sym_hll_escape_sequence,
  [122069] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5370), 2,
      sym_comment,
      sym__blank_line,
  [122077] = 3,
    ACTIONS(4109), 1,
      sym__line_continuation,
    ACTIONS(5372), 1,
      aux_sym_hll_char_literal_token1,
    ACTIONS(5374), 1,
      sym_hll_escape_sequence,
  [122087] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5376), 2,
      sym_comment,
      sym__blank_line,
  [122095] = 3,
    ACTIONS(4109), 1,
      sym__line_continuation,
    ACTIONS(5378), 1,
      aux_sym_hll_char_literal_token1,
    ACTIONS(5380), 1,
      sym_hll_escape_sequence,
  [122105] = 3,
    ACTIONS(4109), 1,
      sym__line_continuation,
    ACTIONS(5382), 1,
      aux_sym_hll_char_literal_token1,
    ACTIONS(5384), 1,
      sym_hll_escape_sequence,
  [122115] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5386), 1,
      sym__blank,
    STATE(128), 1,
      aux_sym_block_repeat1,
  [122125] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1663), 2,
      anon_sym_EQ,
      sym__blank,
  [122133] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3931), 1,
      anon_sym_DQUOTE,
    STATE(2256), 1,
      sym_string,
  [122143] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5388), 2,
      sym_comment,
      sym__blank_line,
  [122151] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5390), 1,
      sym__blank,
    STATE(123), 1,
      aux_sym_block_repeat1,
  [122161] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5392), 2,
      sym_comment,
      sym__blank_line,
  [122169] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5394), 2,
      aux_sym_character_token1,
      aux_sym_character_token2,
  [122177] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5396), 1,
      sym_comment,
    ACTIONS(5398), 1,
      sym__blank_line,
  [122187] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5400), 1,
      sym__blank,
    STATE(134), 1,
      aux_sym_block_repeat1,
  [122197] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5402), 1,
      sym__blank,
    STATE(135), 1,
      aux_sym_block_repeat1,
  [122207] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5404), 1,
      sym__blank,
    STATE(481), 1,
      aux_sym_block_repeat1,
  [122217] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5406), 1,
      sym__blank,
    STATE(482), 1,
      aux_sym_block_repeat1,
  [122227] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5408), 2,
      sym_comment,
      sym__blank_line,
  [122235] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5376), 2,
      sym_comment,
      sym__blank_line,
  [122243] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5410), 1,
      sym_identifier,
    STATE(817), 1,
      sym__hll_field_identifier,
  [122253] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5412), 2,
      sym_comment,
      sym__blank_line,
  [122261] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5414), 1,
      sym__blank,
    STATE(339), 1,
      aux_sym_block_repeat1,
  [122271] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5416), 2,
      sym_comment,
      sym__blank_line,
  [122279] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5418), 1,
      sym__blank,
    STATE(1767), 1,
      aux_sym_block_repeat1,
  [122289] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5420), 1,
      sym__blank,
    STATE(1967), 1,
      aux_sym_block_repeat1,
  [122299] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5422), 1,
      sym__blank,
    STATE(99), 1,
      aux_sym_block_repeat1,
  [122309] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5425), 1,
      sym_identifier,
    STATE(753), 1,
      sym__hll_field_identifier,
  [122319] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5427), 1,
      sym__blank,
    STATE(136), 1,
      aux_sym_block_repeat1,
  [122329] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5429), 1,
      sym__blank,
    STATE(137), 1,
      aux_sym_block_repeat1,
  [122339] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5431), 1,
      sym__blank,
    STATE(484), 1,
      aux_sym_block_repeat1,
  [122349] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5433), 1,
      sym__blank,
    STATE(138), 1,
      aux_sym_block_repeat1,
  [122359] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5435), 1,
      sym__blank,
    STATE(485), 1,
      aux_sym_block_repeat1,
  [122369] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5213), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
  [122377] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5437), 2,
      sym_comment,
      sym__blank_line,
  [122385] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5439), 2,
      sym_comment,
      sym__blank_line,
  [122393] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2013), 2,
      aux_sym_symbol_token3,
      sym__blank,
  [122401] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5441), 1,
      sym__blank,
    STATE(1984), 1,
      aux_sym_block_repeat1,
  [122411] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2389), 2,
      sym_comment,
      sym__blank_line,
  [122419] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5443), 2,
      sym_comment,
      sym__blank_line,
  [122427] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(169), 1,
      anon_sym_AMP,
    STATE(1268), 1,
      sym_macro,
  [122437] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5445), 2,
      sym_comment,
      sym__blank_line,
  [122445] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5447), 1,
      sym__blank,
    STATE(2214), 1,
      aux_sym_block_repeat1,
  [122455] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5449), 1,
      sym__blank,
    STATE(1985), 1,
      aux_sym_block_repeat1,
  [122465] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5451), 1,
      sym__blank,
    STATE(2198), 1,
      aux_sym_block_repeat1,
  [122475] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5453), 1,
      sym__blank,
    STATE(1677), 1,
      aux_sym_block_repeat1,
  [122485] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5455), 1,
      sym__blank,
    STATE(1320), 1,
      aux_sym_block_repeat1,
  [122495] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(147), 1,
      anon_sym_AMP,
    STATE(1301), 1,
      sym_macro,
  [122505] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5123), 1,
      anon_sym_DQUOTE,
    STATE(1199), 1,
      sym_string,
  [122515] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5457), 1,
      sym_comment,
    ACTIONS(5459), 1,
      sym__blank_line,
  [122525] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5461), 1,
      sym__blank,
    STATE(1722), 1,
      aux_sym_block_repeat1,
  [122535] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5463), 1,
      sym_identifier,
    ACTIONS(5465), 1,
      anon_sym_LPAREN,
  [122545] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5467), 1,
      anon_sym_AMP_AMP,
    ACTIONS(5469), 1,
      anon_sym_AMP,
  [122555] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5471), 1,
      sym__blank,
    STATE(1988), 1,
      aux_sym_block_repeat1,
  [122565] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2941), 1,
      anon_sym_LPAREN,
    STATE(1055), 1,
      sym_argument_list,
  [122575] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5473), 1,
      sym__blank,
    STATE(2079), 1,
      aux_sym_block_repeat1,
  [122585] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5475), 1,
      sym_identifier,
    STATE(895), 1,
      sym__hll_field_identifier,
  [122595] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4828), 1,
      anon_sym_DQUOTE,
    STATE(941), 1,
      sym_string,
  [122605] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4943), 1,
      anon_sym_DQUOTE,
    STATE(1007), 1,
      sym_string,
  [122615] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(228), 1,
      anon_sym_LPAREN,
    STATE(348), 1,
      sym_argument_list,
  [122625] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5477), 1,
      anon_sym_LPAREN,
    STATE(349), 1,
      sym_hll_var_call_expression_argument_list,
  [122635] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5479), 1,
      sym__blank,
    STATE(2187), 1,
      aux_sym_block_repeat1,
  [122645] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5481), 1,
      sym__blank,
    STATE(90), 1,
      aux_sym_block_repeat1,
  [122655] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5483), 1,
      sym__blank,
    STATE(436), 1,
      aux_sym_block_repeat1,
  [122665] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5485), 1,
      anon_sym_LPAREN,
    STATE(1058), 1,
      sym_hll_var_call_expression_argument_list,
  [122675] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5487), 1,
      sym_comment,
    ACTIONS(5489), 1,
      sym__blank_line,
  [122685] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5019), 1,
      anon_sym_DQUOTE,
    STATE(782), 1,
      sym_string,
  [122695] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5491), 1,
      sym__blank,
    STATE(98), 1,
      aux_sym_block_repeat1,
  [122705] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4983), 1,
      anon_sym_DQUOTE,
    STATE(818), 1,
      sym_string,
  [122715] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5493), 1,
      sym_identifier,
  [122722] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5495), 1,
      anon_sym_SQUOTE,
  [122729] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5497), 1,
      sym_identifier,
  [122736] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1687), 1,
      sym_path,
  [122743] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5499), 1,
      anon_sym_SQUOTE,
  [122750] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5501), 1,
      sym_identifier,
  [122757] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5503), 1,
      sym_identifier,
  [122764] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5505), 1,
      anon_sym_RPAREN,
  [122771] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5507), 1,
      anon_sym_COLON,
  [122778] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5509), 1,
      anon_sym_SQUOTE,
  [122785] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5511), 1,
      sym__decimal_number,
  [122792] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5513), 1,
      sym_identifier,
  [122799] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5515), 1,
      anon_sym_LPAREN,
  [122806] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5517), 1,
      sym_identifier,
  [122813] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5519), 1,
      anon_sym_SQUOTE,
  [122820] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5521), 1,
      anon_sym_SQUOTE,
  [122827] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2067), 1,
      sym__blank,
  [122834] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5523), 1,
      anon_sym_SQUOTE,
  [122841] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5525), 1,
      sym__blank,
  [122848] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5527), 1,
      sym_identifier,
  [122855] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5529), 1,
      anon_sym_DOT,
  [122862] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1667), 1,
      sym_path,
  [122869] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1663), 1,
      sym_path,
  [122876] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5531), 1,
      sym_identifier,
  [122883] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5505), 1,
      anon_sym_RBRACE,
  [122890] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5533), 1,
      anon_sym_SQUOTE,
  [122897] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5535), 1,
      sym_hll_number_literal,
  [122904] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5537), 1,
      sym_identifier,
  [122911] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5539), 1,
      sym_hll_number_literal,
  [122918] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5541), 1,
      sym_identifier,
  [122925] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5543), 1,
      sym_identifier,
  [122932] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5545), 1,
      sym_identifier,
  [122939] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2837), 1,
      anon_sym_RBRACK,
  [122946] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5547), 1,
      sym_identifier,
  [122953] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5549), 1,
      anon_sym_RBRACE,
  [122960] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5551), 1,
      sym__blank,
  [122967] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5553), 1,
      ts_builtin_sym_end,
  [122974] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2876), 1,
      anon_sym_RBRACK,
  [122981] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5555), 1,
      anon_sym_RBRACE,
  [122988] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5557), 1,
      sym_identifier,
  [122995] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5559), 1,
      sym_identifier,
  [123002] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5561), 1,
      anon_sym_RPAREN,
  [123009] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5563), 1,
      sym__blank,
  [123016] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5565), 1,
      anon_sym_RBRACE,
  [123023] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2051), 1,
      sym__blank,
  [123030] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5567), 1,
      sym_identifier,
  [123037] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5569), 1,
      anon_sym_RPAREN,
  [123044] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5571), 1,
      sym__decimal_number,
  [123051] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5569), 1,
      anon_sym_RBRACE,
  [123058] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5573), 1,
      anon_sym_SQUOTE,
  [123065] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5575), 1,
      sym_identifier,
  [123072] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5577), 1,
      sym__blank,
  [123079] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5579), 1,
      anon_sym_SQUOTE,
  [123086] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2659), 1,
      sym_path,
  [123093] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5581), 1,
      sym_identifier,
  [123100] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5583), 1,
      sym_identifier,
  [123107] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5585), 1,
      anon_sym_DOT,
  [123114] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5587), 1,
      anon_sym_RPAREN,
  [123121] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1649), 1,
      sym_path,
  [123128] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5589), 1,
      sym_identifier,
  [123135] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5587), 1,
      anon_sym_RBRACE,
  [123142] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5591), 1,
      sym_identifier,
  [123149] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5593), 1,
      sym_identifier,
  [123156] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5595), 1,
      anon_sym_SQUOTE,
  [123163] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5597), 1,
      sym__decimal_number,
  [123170] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5599), 1,
      sym_identifier,
  [123177] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5565), 1,
      anon_sym_RPAREN,
  [123184] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5601), 1,
      sym_identifier,
  [123191] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2856), 1,
      anon_sym_RBRACK,
  [123198] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5603), 1,
      sym_identifier,
  [123205] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5605), 1,
      sym_identifier,
  [123212] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5549), 1,
      anon_sym_RPAREN,
  [123219] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5607), 1,
      sym_hll_number_literal,
  [123226] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5113), 1,
      sym_identifier,
  [123233] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5609), 1,
      sym_hll_number_literal,
  [123240] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5611), 1,
      sym_hll_number_literal,
  [123247] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5613), 1,
      sym_identifier,
  [123254] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2037), 1,
      sym__blank,
  [123261] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5615), 1,
      sym__blank,
  [123268] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5617), 1,
      sym_hll_number_literal,
  [123275] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5619), 1,
      anon_sym_SQUOTE,
  [123282] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5621), 1,
      sym_hll_number_literal,
  [123289] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2727), 1,
      anon_sym_RBRACK,
  [123296] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5555), 1,
      anon_sym_RPAREN,
  [123303] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5623), 1,
      sym_identifier,
  [123310] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5625), 1,
      sym__decimal_number,
  [123317] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5561), 1,
      anon_sym_RBRACE,
};

static const uint32_t ts_small_parse_table_map[] = {
  [SMALL_STATE(90)] = 0,
  [SMALL_STATE(91)] = 149,
  [SMALL_STATE(92)] = 298,
  [SMALL_STATE(93)] = 447,
  [SMALL_STATE(94)] = 596,
  [SMALL_STATE(95)] = 745,
  [SMALL_STATE(96)] = 894,
  [SMALL_STATE(97)] = 1043,
  [SMALL_STATE(98)] = 1188,
  [SMALL_STATE(99)] = 1337,
  [SMALL_STATE(100)] = 1488,
  [SMALL_STATE(101)] = 1633,
  [SMALL_STATE(102)] = 1740,
  [SMALL_STATE(103)] = 1847,
  [SMALL_STATE(104)] = 1954,
  [SMALL_STATE(105)] = 2061,
  [SMALL_STATE(106)] = 2210,
  [SMALL_STATE(107)] = 2355,
  [SMALL_STATE(108)] = 2504,
  [SMALL_STATE(109)] = 2653,
  [SMALL_STATE(110)] = 2804,
  [SMALL_STATE(111)] = 2953,
  [SMALL_STATE(112)] = 3102,
  [SMALL_STATE(113)] = 3247,
  [SMALL_STATE(114)] = 3396,
  [SMALL_STATE(115)] = 3545,
  [SMALL_STATE(116)] = 3690,
  [SMALL_STATE(117)] = 3839,
  [SMALL_STATE(118)] = 3988,
  [SMALL_STATE(119)] = 4137,
  [SMALL_STATE(120)] = 4288,
  [SMALL_STATE(121)] = 4437,
  [SMALL_STATE(122)] = 4586,
  [SMALL_STATE(123)] = 4693,
  [SMALL_STATE(124)] = 4842,
  [SMALL_STATE(125)] = 4991,
  [SMALL_STATE(126)] = 5140,
  [SMALL_STATE(127)] = 5247,
  [SMALL_STATE(128)] = 5354,
  [SMALL_STATE(129)] = 5503,
  [SMALL_STATE(130)] = 5652,
  [SMALL_STATE(131)] = 5759,
  [SMALL_STATE(132)] = 5908,
  [SMALL_STATE(133)] = 6057,
  [SMALL_STATE(134)] = 6202,
  [SMALL_STATE(135)] = 6351,
  [SMALL_STATE(136)] = 6500,
  [SMALL_STATE(137)] = 6649,
  [SMALL_STATE(138)] = 6798,
  [SMALL_STATE(139)] = 6947,
  [SMALL_STATE(140)] = 7092,
  [SMALL_STATE(141)] = 7237,
  [SMALL_STATE(142)] = 7386,
  [SMALL_STATE(143)] = 7532,
  [SMALL_STATE(144)] = 7678,
  [SMALL_STATE(145)] = 7824,
  [SMALL_STATE(146)] = 7967,
  [SMALL_STATE(147)] = 8110,
  [SMALL_STATE(148)] = 8253,
  [SMALL_STATE(149)] = 8396,
  [SMALL_STATE(150)] = 8539,
  [SMALL_STATE(151)] = 8682,
  [SMALL_STATE(152)] = 8825,
  [SMALL_STATE(153)] = 8968,
  [SMALL_STATE(154)] = 9111,
  [SMALL_STATE(155)] = 9254,
  [SMALL_STATE(156)] = 9397,
  [SMALL_STATE(157)] = 9540,
  [SMALL_STATE(158)] = 9683,
  [SMALL_STATE(159)] = 9826,
  [SMALL_STATE(160)] = 9969,
  [SMALL_STATE(161)] = 10112,
  [SMALL_STATE(162)] = 10255,
  [SMALL_STATE(163)] = 10398,
  [SMALL_STATE(164)] = 10541,
  [SMALL_STATE(165)] = 10684,
  [SMALL_STATE(166)] = 10827,
  [SMALL_STATE(167)] = 10970,
  [SMALL_STATE(168)] = 11113,
  [SMALL_STATE(169)] = 11256,
  [SMALL_STATE(170)] = 11399,
  [SMALL_STATE(171)] = 11542,
  [SMALL_STATE(172)] = 11685,
  [SMALL_STATE(173)] = 11828,
  [SMALL_STATE(174)] = 11971,
  [SMALL_STATE(175)] = 12114,
  [SMALL_STATE(176)] = 12257,
  [SMALL_STATE(177)] = 12400,
  [SMALL_STATE(178)] = 12543,
  [SMALL_STATE(179)] = 12686,
  [SMALL_STATE(180)] = 12829,
  [SMALL_STATE(181)] = 12972,
  [SMALL_STATE(182)] = 13115,
  [SMALL_STATE(183)] = 13258,
  [SMALL_STATE(184)] = 13401,
  [SMALL_STATE(185)] = 13544,
  [SMALL_STATE(186)] = 13687,
  [SMALL_STATE(187)] = 13830,
  [SMALL_STATE(188)] = 13973,
  [SMALL_STATE(189)] = 14116,
  [SMALL_STATE(190)] = 14259,
  [SMALL_STATE(191)] = 14402,
  [SMALL_STATE(192)] = 14545,
  [SMALL_STATE(193)] = 14688,
  [SMALL_STATE(194)] = 14827,
  [SMALL_STATE(195)] = 14970,
  [SMALL_STATE(196)] = 15113,
  [SMALL_STATE(197)] = 15256,
  [SMALL_STATE(198)] = 15399,
  [SMALL_STATE(199)] = 15542,
  [SMALL_STATE(200)] = 15685,
  [SMALL_STATE(201)] = 15828,
  [SMALL_STATE(202)] = 15967,
  [SMALL_STATE(203)] = 16110,
  [SMALL_STATE(204)] = 16253,
  [SMALL_STATE(205)] = 16396,
  [SMALL_STATE(206)] = 16539,
  [SMALL_STATE(207)] = 16682,
  [SMALL_STATE(208)] = 16825,
  [SMALL_STATE(209)] = 16968,
  [SMALL_STATE(210)] = 17111,
  [SMALL_STATE(211)] = 17254,
  [SMALL_STATE(212)] = 17397,
  [SMALL_STATE(213)] = 17540,
  [SMALL_STATE(214)] = 17683,
  [SMALL_STATE(215)] = 17826,
  [SMALL_STATE(216)] = 17965,
  [SMALL_STATE(217)] = 18108,
  [SMALL_STATE(218)] = 18251,
  [SMALL_STATE(219)] = 18394,
  [SMALL_STATE(220)] = 18533,
  [SMALL_STATE(221)] = 18676,
  [SMALL_STATE(222)] = 18819,
  [SMALL_STATE(223)] = 18958,
  [SMALL_STATE(224)] = 19101,
  [SMALL_STATE(225)] = 19244,
  [SMALL_STATE(226)] = 19387,
  [SMALL_STATE(227)] = 19526,
  [SMALL_STATE(228)] = 19665,
  [SMALL_STATE(229)] = 19808,
  [SMALL_STATE(230)] = 19947,
  [SMALL_STATE(231)] = 20086,
  [SMALL_STATE(232)] = 20225,
  [SMALL_STATE(233)] = 20368,
  [SMALL_STATE(234)] = 20511,
  [SMALL_STATE(235)] = 20654,
  [SMALL_STATE(236)] = 20797,
  [SMALL_STATE(237)] = 20940,
  [SMALL_STATE(238)] = 21079,
  [SMALL_STATE(239)] = 21222,
  [SMALL_STATE(240)] = 21361,
  [SMALL_STATE(241)] = 21504,
  [SMALL_STATE(242)] = 21643,
  [SMALL_STATE(243)] = 21786,
  [SMALL_STATE(244)] = 21933,
  [SMALL_STATE(245)] = 22080,
  [SMALL_STATE(246)] = 22227,
  [SMALL_STATE(247)] = 22374,
  [SMALL_STATE(248)] = 22521,
  [SMALL_STATE(249)] = 22668,
  [SMALL_STATE(250)] = 22815,
  [SMALL_STATE(251)] = 22961,
  [SMALL_STATE(252)] = 23107,
  [SMALL_STATE(253)] = 23253,
  [SMALL_STATE(254)] = 23399,
  [SMALL_STATE(255)] = 23545,
  [SMALL_STATE(256)] = 23691,
  [SMALL_STATE(257)] = 23837,
  [SMALL_STATE(258)] = 23983,
  [SMALL_STATE(259)] = 24129,
  [SMALL_STATE(260)] = 24275,
  [SMALL_STATE(261)] = 24421,
  [SMALL_STATE(262)] = 24567,
  [SMALL_STATE(263)] = 24713,
  [SMALL_STATE(264)] = 24859,
  [SMALL_STATE(265)] = 25005,
  [SMALL_STATE(266)] = 25151,
  [SMALL_STATE(267)] = 25297,
  [SMALL_STATE(268)] = 25443,
  [SMALL_STATE(269)] = 25589,
  [SMALL_STATE(270)] = 25735,
  [SMALL_STATE(271)] = 25881,
  [SMALL_STATE(272)] = 26027,
  [SMALL_STATE(273)] = 26173,
  [SMALL_STATE(274)] = 26319,
  [SMALL_STATE(275)] = 26465,
  [SMALL_STATE(276)] = 26611,
  [SMALL_STATE(277)] = 26757,
  [SMALL_STATE(278)] = 26903,
  [SMALL_STATE(279)] = 27049,
  [SMALL_STATE(280)] = 27195,
  [SMALL_STATE(281)] = 27341,
  [SMALL_STATE(282)] = 27487,
  [SMALL_STATE(283)] = 27633,
  [SMALL_STATE(284)] = 27779,
  [SMALL_STATE(285)] = 27925,
  [SMALL_STATE(286)] = 28071,
  [SMALL_STATE(287)] = 28217,
  [SMALL_STATE(288)] = 28363,
  [SMALL_STATE(289)] = 28509,
  [SMALL_STATE(290)] = 28655,
  [SMALL_STATE(291)] = 28801,
  [SMALL_STATE(292)] = 28947,
  [SMALL_STATE(293)] = 29093,
  [SMALL_STATE(294)] = 29239,
  [SMALL_STATE(295)] = 29380,
  [SMALL_STATE(296)] = 29521,
  [SMALL_STATE(297)] = 29662,
  [SMALL_STATE(298)] = 29803,
  [SMALL_STATE(299)] = 29943,
  [SMALL_STATE(300)] = 30083,
  [SMALL_STATE(301)] = 30223,
  [SMALL_STATE(302)] = 30360,
  [SMALL_STATE(303)] = 30497,
  [SMALL_STATE(304)] = 30634,
  [SMALL_STATE(305)] = 30771,
  [SMALL_STATE(306)] = 30908,
  [SMALL_STATE(307)] = 31045,
  [SMALL_STATE(308)] = 31182,
  [SMALL_STATE(309)] = 31319,
  [SMALL_STATE(310)] = 31453,
  [SMALL_STATE(311)] = 31587,
  [SMALL_STATE(312)] = 31721,
  [SMALL_STATE(313)] = 31855,
  [SMALL_STATE(314)] = 31955,
  [SMALL_STATE(315)] = 32055,
  [SMALL_STATE(316)] = 32155,
  [SMALL_STATE(317)] = 32255,
  [SMALL_STATE(318)] = 32355,
  [SMALL_STATE(319)] = 32455,
  [SMALL_STATE(320)] = 32555,
  [SMALL_STATE(321)] = 32655,
  [SMALL_STATE(322)] = 32757,
  [SMALL_STATE(323)] = 32857,
  [SMALL_STATE(324)] = 32957,
  [SMALL_STATE(325)] = 33057,
  [SMALL_STATE(326)] = 33157,
  [SMALL_STATE(327)] = 33256,
  [SMALL_STATE(328)] = 33355,
  [SMALL_STATE(329)] = 33422,
  [SMALL_STATE(330)] = 33521,
  [SMALL_STATE(331)] = 33620,
  [SMALL_STATE(332)] = 33719,
  [SMALL_STATE(333)] = 33818,
  [SMALL_STATE(334)] = 33875,
  [SMALL_STATE(335)] = 33932,
  [SMALL_STATE(336)] = 34031,
  [SMALL_STATE(337)] = 34130,
  [SMALL_STATE(338)] = 34229,
  [SMALL_STATE(339)] = 34328,
  [SMALL_STATE(340)] = 34427,
  [SMALL_STATE(341)] = 34526,
  [SMALL_STATE(342)] = 34589,
  [SMALL_STATE(343)] = 34688,
  [SMALL_STATE(344)] = 34744,
  [SMALL_STATE(345)] = 34800,
  [SMALL_STATE(346)] = 34856,
  [SMALL_STATE(347)] = 34912,
  [SMALL_STATE(348)] = 34976,
  [SMALL_STATE(349)] = 35032,
  [SMALL_STATE(350)] = 35088,
  [SMALL_STATE(351)] = 35152,
  [SMALL_STATE(352)] = 35226,
  [SMALL_STATE(353)] = 35304,
  [SMALL_STATE(354)] = 35360,
  [SMALL_STATE(355)] = 35416,
  [SMALL_STATE(356)] = 35472,
  [SMALL_STATE(357)] = 35534,
  [SMALL_STATE(358)] = 35590,
  [SMALL_STATE(359)] = 35648,
  [SMALL_STATE(360)] = 35714,
  [SMALL_STATE(361)] = 35778,
  [SMALL_STATE(362)] = 35834,
  [SMALL_STATE(363)] = 35890,
  [SMALL_STATE(364)] = 35964,
  [SMALL_STATE(365)] = 36024,
  [SMALL_STATE(366)] = 36084,
  [SMALL_STATE(367)] = 36175,
  [SMALL_STATE(368)] = 36234,
  [SMALL_STATE(369)] = 36299,
  [SMALL_STATE(370)] = 36360,
  [SMALL_STATE(371)] = 36453,
  [SMALL_STATE(372)] = 36512,
  [SMALL_STATE(373)] = 36597,
  [SMALL_STATE(374)] = 36688,
  [SMALL_STATE(375)] = 36769,
  [SMALL_STATE(376)] = 36832,
  [SMALL_STATE(377)] = 36905,
  [SMALL_STATE(378)] = 36998,
  [SMALL_STATE(379)] = 37075,
  [SMALL_STATE(380)] = 37158,
  [SMALL_STATE(381)] = 37249,
  [SMALL_STATE(382)] = 37316,
  [SMALL_STATE(383)] = 37377,
  [SMALL_STATE(384)] = 37468,
  [SMALL_STATE(385)] = 37547,
  [SMALL_STATE(386)] = 37612,
  [SMALL_STATE(387)] = 37705,
  [SMALL_STATE(388)] = 37776,
  [SMALL_STATE(389)] = 37835,
  [SMALL_STATE(390)] = 37918,
  [SMALL_STATE(391)] = 37974,
  [SMALL_STATE(392)] = 38064,
  [SMALL_STATE(393)] = 38154,
  [SMALL_STATE(394)] = 38244,
  [SMALL_STATE(395)] = 38334,
  [SMALL_STATE(396)] = 38424,
  [SMALL_STATE(397)] = 38514,
  [SMALL_STATE(398)] = 38604,
  [SMALL_STATE(399)] = 38694,
  [SMALL_STATE(400)] = 38784,
  [SMALL_STATE(401)] = 38874,
  [SMALL_STATE(402)] = 38964,
  [SMALL_STATE(403)] = 39054,
  [SMALL_STATE(404)] = 39144,
  [SMALL_STATE(405)] = 39234,
  [SMALL_STATE(406)] = 39324,
  [SMALL_STATE(407)] = 39414,
  [SMALL_STATE(408)] = 39504,
  [SMALL_STATE(409)] = 39594,
  [SMALL_STATE(410)] = 39684,
  [SMALL_STATE(411)] = 39774,
  [SMALL_STATE(412)] = 39864,
  [SMALL_STATE(413)] = 39954,
  [SMALL_STATE(414)] = 40044,
  [SMALL_STATE(415)] = 40134,
  [SMALL_STATE(416)] = 40188,
  [SMALL_STATE(417)] = 40278,
  [SMALL_STATE(418)] = 40332,
  [SMALL_STATE(419)] = 40422,
  [SMALL_STATE(420)] = 40512,
  [SMALL_STATE(421)] = 40602,
  [SMALL_STATE(422)] = 40692,
  [SMALL_STATE(423)] = 40748,
  [SMALL_STATE(424)] = 40804,
  [SMALL_STATE(425)] = 40858,
  [SMALL_STATE(426)] = 40948,
  [SMALL_STATE(427)] = 41038,
  [SMALL_STATE(428)] = 41128,
  [SMALL_STATE(429)] = 41215,
  [SMALL_STATE(430)] = 41302,
  [SMALL_STATE(431)] = 41389,
  [SMALL_STATE(432)] = 41476,
  [SMALL_STATE(433)] = 41563,
  [SMALL_STATE(434)] = 41650,
  [SMALL_STATE(435)] = 41737,
  [SMALL_STATE(436)] = 41824,
  [SMALL_STATE(437)] = 41911,
  [SMALL_STATE(438)] = 41998,
  [SMALL_STATE(439)] = 42051,
  [SMALL_STATE(440)] = 42138,
  [SMALL_STATE(441)] = 42225,
  [SMALL_STATE(442)] = 42312,
  [SMALL_STATE(443)] = 42399,
  [SMALL_STATE(444)] = 42486,
  [SMALL_STATE(445)] = 42573,
  [SMALL_STATE(446)] = 42660,
  [SMALL_STATE(447)] = 42747,
  [SMALL_STATE(448)] = 42834,
  [SMALL_STATE(449)] = 42887,
  [SMALL_STATE(450)] = 42940,
  [SMALL_STATE(451)] = 42993,
  [SMALL_STATE(452)] = 43046,
  [SMALL_STATE(453)] = 43099,
  [SMALL_STATE(454)] = 43152,
  [SMALL_STATE(455)] = 43239,
  [SMALL_STATE(456)] = 43326,
  [SMALL_STATE(457)] = 43413,
  [SMALL_STATE(458)] = 43466,
  [SMALL_STATE(459)] = 43553,
  [SMALL_STATE(460)] = 43606,
  [SMALL_STATE(461)] = 43693,
  [SMALL_STATE(462)] = 43780,
  [SMALL_STATE(463)] = 43867,
  [SMALL_STATE(464)] = 43954,
  [SMALL_STATE(465)] = 44041,
  [SMALL_STATE(466)] = 44128,
  [SMALL_STATE(467)] = 44215,
  [SMALL_STATE(468)] = 44302,
  [SMALL_STATE(469)] = 44389,
  [SMALL_STATE(470)] = 44476,
  [SMALL_STATE(471)] = 44563,
  [SMALL_STATE(472)] = 44650,
  [SMALL_STATE(473)] = 44737,
  [SMALL_STATE(474)] = 44790,
  [SMALL_STATE(475)] = 44843,
  [SMALL_STATE(476)] = 44930,
  [SMALL_STATE(477)] = 45017,
  [SMALL_STATE(478)] = 45104,
  [SMALL_STATE(479)] = 45191,
  [SMALL_STATE(480)] = 45244,
  [SMALL_STATE(481)] = 45297,
  [SMALL_STATE(482)] = 45384,
  [SMALL_STATE(483)] = 45471,
  [SMALL_STATE(484)] = 45558,
  [SMALL_STATE(485)] = 45645,
  [SMALL_STATE(486)] = 45732,
  [SMALL_STATE(487)] = 45819,
  [SMALL_STATE(488)] = 45906,
  [SMALL_STATE(489)] = 45993,
  [SMALL_STATE(490)] = 46080,
  [SMALL_STATE(491)] = 46167,
  [SMALL_STATE(492)] = 46254,
  [SMALL_STATE(493)] = 46341,
  [SMALL_STATE(494)] = 46428,
  [SMALL_STATE(495)] = 46515,
  [SMALL_STATE(496)] = 46599,
  [SMALL_STATE(497)] = 46683,
  [SMALL_STATE(498)] = 46767,
  [SMALL_STATE(499)] = 46851,
  [SMALL_STATE(500)] = 46935,
  [SMALL_STATE(501)] = 47007,
  [SMALL_STATE(502)] = 47091,
  [SMALL_STATE(503)] = 47175,
  [SMALL_STATE(504)] = 47259,
  [SMALL_STATE(505)] = 47343,
  [SMALL_STATE(506)] = 47427,
  [SMALL_STATE(507)] = 47511,
  [SMALL_STATE(508)] = 47595,
  [SMALL_STATE(509)] = 47679,
  [SMALL_STATE(510)] = 47763,
  [SMALL_STATE(511)] = 47847,
  [SMALL_STATE(512)] = 47931,
  [SMALL_STATE(513)] = 48015,
  [SMALL_STATE(514)] = 48099,
  [SMALL_STATE(515)] = 48183,
  [SMALL_STATE(516)] = 48267,
  [SMALL_STATE(517)] = 48351,
  [SMALL_STATE(518)] = 48432,
  [SMALL_STATE(519)] = 48513,
  [SMALL_STATE(520)] = 48594,
  [SMALL_STATE(521)] = 48675,
  [SMALL_STATE(522)] = 48756,
  [SMALL_STATE(523)] = 48837,
  [SMALL_STATE(524)] = 48918,
  [SMALL_STATE(525)] = 48999,
  [SMALL_STATE(526)] = 49062,
  [SMALL_STATE(527)] = 49143,
  [SMALL_STATE(528)] = 49224,
  [SMALL_STATE(529)] = 49305,
  [SMALL_STATE(530)] = 49386,
  [SMALL_STATE(531)] = 49467,
  [SMALL_STATE(532)] = 49548,
  [SMALL_STATE(533)] = 49629,
  [SMALL_STATE(534)] = 49710,
  [SMALL_STATE(535)] = 49791,
  [SMALL_STATE(536)] = 49872,
  [SMALL_STATE(537)] = 49953,
  [SMALL_STATE(538)] = 50034,
  [SMALL_STATE(539)] = 50115,
  [SMALL_STATE(540)] = 50196,
  [SMALL_STATE(541)] = 50277,
  [SMALL_STATE(542)] = 50358,
  [SMALL_STATE(543)] = 50439,
  [SMALL_STATE(544)] = 50520,
  [SMALL_STATE(545)] = 50601,
  [SMALL_STATE(546)] = 50682,
  [SMALL_STATE(547)] = 50745,
  [SMALL_STATE(548)] = 50826,
  [SMALL_STATE(549)] = 50877,
  [SMALL_STATE(550)] = 50958,
  [SMALL_STATE(551)] = 51039,
  [SMALL_STATE(552)] = 51120,
  [SMALL_STATE(553)] = 51201,
  [SMALL_STATE(554)] = 51282,
  [SMALL_STATE(555)] = 51363,
  [SMALL_STATE(556)] = 51444,
  [SMALL_STATE(557)] = 51525,
  [SMALL_STATE(558)] = 51606,
  [SMALL_STATE(559)] = 51687,
  [SMALL_STATE(560)] = 51768,
  [SMALL_STATE(561)] = 51819,
  [SMALL_STATE(562)] = 51900,
  [SMALL_STATE(563)] = 51981,
  [SMALL_STATE(564)] = 52062,
  [SMALL_STATE(565)] = 52143,
  [SMALL_STATE(566)] = 52224,
  [SMALL_STATE(567)] = 52305,
  [SMALL_STATE(568)] = 52386,
  [SMALL_STATE(569)] = 52467,
  [SMALL_STATE(570)] = 52548,
  [SMALL_STATE(571)] = 52629,
  [SMALL_STATE(572)] = 52710,
  [SMALL_STATE(573)] = 52773,
  [SMALL_STATE(574)] = 52854,
  [SMALL_STATE(575)] = 52935,
  [SMALL_STATE(576)] = 53016,
  [SMALL_STATE(577)] = 53097,
  [SMALL_STATE(578)] = 53178,
  [SMALL_STATE(579)] = 53259,
  [SMALL_STATE(580)] = 53340,
  [SMALL_STATE(581)] = 53403,
  [SMALL_STATE(582)] = 53484,
  [SMALL_STATE(583)] = 53565,
  [SMALL_STATE(584)] = 53628,
  [SMALL_STATE(585)] = 53709,
  [SMALL_STATE(586)] = 53790,
  [SMALL_STATE(587)] = 53871,
  [SMALL_STATE(588)] = 53952,
  [SMALL_STATE(589)] = 54033,
  [SMALL_STATE(590)] = 54114,
  [SMALL_STATE(591)] = 54195,
  [SMALL_STATE(592)] = 54276,
  [SMALL_STATE(593)] = 54357,
  [SMALL_STATE(594)] = 54420,
  [SMALL_STATE(595)] = 54501,
  [SMALL_STATE(596)] = 54582,
  [SMALL_STATE(597)] = 54663,
  [SMALL_STATE(598)] = 54744,
  [SMALL_STATE(599)] = 54825,
  [SMALL_STATE(600)] = 54906,
  [SMALL_STATE(601)] = 54987,
  [SMALL_STATE(602)] = 55068,
  [SMALL_STATE(603)] = 55149,
  [SMALL_STATE(604)] = 55230,
  [SMALL_STATE(605)] = 55311,
  [SMALL_STATE(606)] = 55392,
  [SMALL_STATE(607)] = 55473,
  [SMALL_STATE(608)] = 55554,
  [SMALL_STATE(609)] = 55635,
  [SMALL_STATE(610)] = 55716,
  [SMALL_STATE(611)] = 55797,
  [SMALL_STATE(612)] = 55878,
  [SMALL_STATE(613)] = 55959,
  [SMALL_STATE(614)] = 56040,
  [SMALL_STATE(615)] = 56121,
  [SMALL_STATE(616)] = 56202,
  [SMALL_STATE(617)] = 56283,
  [SMALL_STATE(618)] = 56364,
  [SMALL_STATE(619)] = 56445,
  [SMALL_STATE(620)] = 56526,
  [SMALL_STATE(621)] = 56607,
  [SMALL_STATE(622)] = 56688,
  [SMALL_STATE(623)] = 56769,
  [SMALL_STATE(624)] = 56850,
  [SMALL_STATE(625)] = 56931,
  [SMALL_STATE(626)] = 57012,
  [SMALL_STATE(627)] = 57093,
  [SMALL_STATE(628)] = 57174,
  [SMALL_STATE(629)] = 57255,
  [SMALL_STATE(630)] = 57336,
  [SMALL_STATE(631)] = 57417,
  [SMALL_STATE(632)] = 57498,
  [SMALL_STATE(633)] = 57579,
  [SMALL_STATE(634)] = 57660,
  [SMALL_STATE(635)] = 57741,
  [SMALL_STATE(636)] = 57822,
  [SMALL_STATE(637)] = 57903,
  [SMALL_STATE(638)] = 57984,
  [SMALL_STATE(639)] = 58065,
  [SMALL_STATE(640)] = 58146,
  [SMALL_STATE(641)] = 58227,
  [SMALL_STATE(642)] = 58292,
  [SMALL_STATE(643)] = 58373,
  [SMALL_STATE(644)] = 58454,
  [SMALL_STATE(645)] = 58535,
  [SMALL_STATE(646)] = 58616,
  [SMALL_STATE(647)] = 58697,
  [SMALL_STATE(648)] = 58778,
  [SMALL_STATE(649)] = 58859,
  [SMALL_STATE(650)] = 58940,
  [SMALL_STATE(651)] = 59021,
  [SMALL_STATE(652)] = 59102,
  [SMALL_STATE(653)] = 59183,
  [SMALL_STATE(654)] = 59264,
  [SMALL_STATE(655)] = 59345,
  [SMALL_STATE(656)] = 59426,
  [SMALL_STATE(657)] = 59507,
  [SMALL_STATE(658)] = 59588,
  [SMALL_STATE(659)] = 59669,
  [SMALL_STATE(660)] = 59750,
  [SMALL_STATE(661)] = 59831,
  [SMALL_STATE(662)] = 59912,
  [SMALL_STATE(663)] = 59993,
  [SMALL_STATE(664)] = 60074,
  [SMALL_STATE(665)] = 60155,
  [SMALL_STATE(666)] = 60236,
  [SMALL_STATE(667)] = 60317,
  [SMALL_STATE(668)] = 60398,
  [SMALL_STATE(669)] = 60479,
  [SMALL_STATE(670)] = 60560,
  [SMALL_STATE(671)] = 60641,
  [SMALL_STATE(672)] = 60722,
  [SMALL_STATE(673)] = 60803,
  [SMALL_STATE(674)] = 60870,
  [SMALL_STATE(675)] = 60953,
  [SMALL_STATE(676)] = 61018,
  [SMALL_STATE(677)] = 61097,
  [SMALL_STATE(678)] = 61174,
  [SMALL_STATE(679)] = 61247,
  [SMALL_STATE(680)] = 61328,
  [SMALL_STATE(681)] = 61397,
  [SMALL_STATE(682)] = 61478,
  [SMALL_STATE(683)] = 61553,
  [SMALL_STATE(684)] = 61634,
  [SMALL_STATE(685)] = 61721,
  [SMALL_STATE(686)] = 61802,
  [SMALL_STATE(687)] = 61883,
  [SMALL_STATE(688)] = 61964,
  [SMALL_STATE(689)] = 62045,
  [SMALL_STATE(690)] = 62126,
  [SMALL_STATE(691)] = 62207,
  [SMALL_STATE(692)] = 62294,
  [SMALL_STATE(693)] = 62375,
  [SMALL_STATE(694)] = 62438,
  [SMALL_STATE(695)] = 62525,
  [SMALL_STATE(696)] = 62606,
  [SMALL_STATE(697)] = 62687,
  [SMALL_STATE(698)] = 62768,
  [SMALL_STATE(699)] = 62849,
  [SMALL_STATE(700)] = 62930,
  [SMALL_STATE(701)] = 63011,
  [SMALL_STATE(702)] = 63092,
  [SMALL_STATE(703)] = 63173,
  [SMALL_STATE(704)] = 63254,
  [SMALL_STATE(705)] = 63335,
  [SMALL_STATE(706)] = 63416,
  [SMALL_STATE(707)] = 63503,
  [SMALL_STATE(708)] = 63584,
  [SMALL_STATE(709)] = 63665,
  [SMALL_STATE(710)] = 63746,
  [SMALL_STATE(711)] = 63833,
  [SMALL_STATE(712)] = 63914,
  [SMALL_STATE(713)] = 64001,
  [SMALL_STATE(714)] = 64082,
  [SMALL_STATE(715)] = 64163,
  [SMALL_STATE(716)] = 64244,
  [SMALL_STATE(717)] = 64325,
  [SMALL_STATE(718)] = 64406,
  [SMALL_STATE(719)] = 64487,
  [SMALL_STATE(720)] = 64568,
  [SMALL_STATE(721)] = 64649,
  [SMALL_STATE(722)] = 64730,
  [SMALL_STATE(723)] = 64811,
  [SMALL_STATE(724)] = 64864,
  [SMALL_STATE(725)] = 64945,
  [SMALL_STATE(726)] = 65026,
  [SMALL_STATE(727)] = 65107,
  [SMALL_STATE(728)] = 65188,
  [SMALL_STATE(729)] = 65269,
  [SMALL_STATE(730)] = 65350,
  [SMALL_STATE(731)] = 65431,
  [SMALL_STATE(732)] = 65512,
  [SMALL_STATE(733)] = 65593,
  [SMALL_STATE(734)] = 65674,
  [SMALL_STATE(735)] = 65755,
  [SMALL_STATE(736)] = 65836,
  [SMALL_STATE(737)] = 65917,
  [SMALL_STATE(738)] = 65998,
  [SMALL_STATE(739)] = 66079,
  [SMALL_STATE(740)] = 66140,
  [SMALL_STATE(741)] = 66221,
  [SMALL_STATE(742)] = 66271,
  [SMALL_STATE(743)] = 66355,
  [SMALL_STATE(744)] = 66433,
  [SMALL_STATE(745)] = 66517,
  [SMALL_STATE(746)] = 66567,
  [SMALL_STATE(747)] = 66617,
  [SMALL_STATE(748)] = 66667,
  [SMALL_STATE(749)] = 66747,
  [SMALL_STATE(750)] = 66797,
  [SMALL_STATE(751)] = 66847,
  [SMALL_STATE(752)] = 66897,
  [SMALL_STATE(753)] = 66947,
  [SMALL_STATE(754)] = 66997,
  [SMALL_STATE(755)] = 67081,
  [SMALL_STATE(756)] = 67151,
  [SMALL_STATE(757)] = 67201,
  [SMALL_STATE(758)] = 67251,
  [SMALL_STATE(759)] = 67327,
  [SMALL_STATE(760)] = 67377,
  [SMALL_STATE(761)] = 67461,
  [SMALL_STATE(762)] = 67511,
  [SMALL_STATE(763)] = 67583,
  [SMALL_STATE(764)] = 67633,
  [SMALL_STATE(765)] = 67695,
  [SMALL_STATE(766)] = 67745,
  [SMALL_STATE(767)] = 67795,
  [SMALL_STATE(768)] = 67859,
  [SMALL_STATE(769)] = 67909,
  [SMALL_STATE(770)] = 67969,
  [SMALL_STATE(771)] = 68019,
  [SMALL_STATE(772)] = 68077,
  [SMALL_STATE(773)] = 68137,
  [SMALL_STATE(774)] = 68199,
  [SMALL_STATE(775)] = 68283,
  [SMALL_STATE(776)] = 68343,
  [SMALL_STATE(777)] = 68403,
  [SMALL_STATE(778)] = 68487,
  [SMALL_STATE(779)] = 68541,
  [SMALL_STATE(780)] = 68591,
  [SMALL_STATE(781)] = 68651,
  [SMALL_STATE(782)] = 68705,
  [SMALL_STATE(783)] = 68757,
  [SMALL_STATE(784)] = 68823,
  [SMALL_STATE(785)] = 68883,
  [SMALL_STATE(786)] = 68957,
  [SMALL_STATE(787)] = 69007,
  [SMALL_STATE(788)] = 69057,
  [SMALL_STATE(789)] = 69107,
  [SMALL_STATE(790)] = 69167,
  [SMALL_STATE(791)] = 69216,
  [SMALL_STATE(792)] = 69265,
  [SMALL_STATE(793)] = 69314,
  [SMALL_STATE(794)] = 69363,
  [SMALL_STATE(795)] = 69412,
  [SMALL_STATE(796)] = 69461,
  [SMALL_STATE(797)] = 69510,
  [SMALL_STATE(798)] = 69559,
  [SMALL_STATE(799)] = 69614,
  [SMALL_STATE(800)] = 69669,
  [SMALL_STATE(801)] = 69722,
  [SMALL_STATE(802)] = 69771,
  [SMALL_STATE(803)] = 69820,
  [SMALL_STATE(804)] = 69869,
  [SMALL_STATE(805)] = 69918,
  [SMALL_STATE(806)] = 69967,
  [SMALL_STATE(807)] = 70020,
  [SMALL_STATE(808)] = 70073,
  [SMALL_STATE(809)] = 70122,
  [SMALL_STATE(810)] = 70171,
  [SMALL_STATE(811)] = 70232,
  [SMALL_STATE(812)] = 70287,
  [SMALL_STATE(813)] = 70342,
  [SMALL_STATE(814)] = 70391,
  [SMALL_STATE(815)] = 70440,
  [SMALL_STATE(816)] = 70489,
  [SMALL_STATE(817)] = 70538,
  [SMALL_STATE(818)] = 70587,
  [SMALL_STATE(819)] = 70637,
  [SMALL_STATE(820)] = 70697,
  [SMALL_STATE(821)] = 70755,
  [SMALL_STATE(822)] = 70813,
  [SMALL_STATE(823)] = 70871,
  [SMALL_STATE(824)] = 70929,
  [SMALL_STATE(825)] = 70987,
  [SMALL_STATE(826)] = 71045,
  [SMALL_STATE(827)] = 71107,
  [SMALL_STATE(828)] = 71185,
  [SMALL_STATE(829)] = 71245,
  [SMALL_STATE(830)] = 71319,
  [SMALL_STATE(831)] = 71391,
  [SMALL_STATE(832)] = 71459,
  [SMALL_STATE(833)] = 71523,
  [SMALL_STATE(834)] = 71599,
  [SMALL_STATE(835)] = 71669,
  [SMALL_STATE(836)] = 71751,
  [SMALL_STATE(837)] = 71833,
  [SMALL_STATE(838)] = 71915,
  [SMALL_STATE(839)] = 71997,
  [SMALL_STATE(840)] = 72079,
  [SMALL_STATE(841)] = 72161,
  [SMALL_STATE(842)] = 72213,
  [SMALL_STATE(843)] = 72265,
  [SMALL_STATE(844)] = 72321,
  [SMALL_STATE(845)] = 72379,
  [SMALL_STATE(846)] = 72439,
  [SMALL_STATE(847)] = 72487,
  [SMALL_STATE(848)] = 72545,
  [SMALL_STATE(849)] = 72603,
  [SMALL_STATE(850)] = 72661,
  [SMALL_STATE(851)] = 72719,
  [SMALL_STATE(852)] = 72777,
  [SMALL_STATE(853)] = 72839,
  [SMALL_STATE(854)] = 72917,
  [SMALL_STATE(855)] = 72977,
  [SMALL_STATE(856)] = 73051,
  [SMALL_STATE(857)] = 73123,
  [SMALL_STATE(858)] = 73191,
  [SMALL_STATE(859)] = 73255,
  [SMALL_STATE(860)] = 73331,
  [SMALL_STATE(861)] = 73401,
  [SMALL_STATE(862)] = 73483,
  [SMALL_STATE(863)] = 73565,
  [SMALL_STATE(864)] = 73647,
  [SMALL_STATE(865)] = 73729,
  [SMALL_STATE(866)] = 73811,
  [SMALL_STATE(867)] = 73893,
  [SMALL_STATE(868)] = 73943,
  [SMALL_STATE(869)] = 73991,
  [SMALL_STATE(870)] = 74039,
  [SMALL_STATE(871)] = 74097,
  [SMALL_STATE(872)] = 74153,
  [SMALL_STATE(873)] = 74211,
  [SMALL_STATE(874)] = 74259,
  [SMALL_STATE(875)] = 74306,
  [SMALL_STATE(876)] = 74353,
  [SMALL_STATE(877)] = 74400,
  [SMALL_STATE(878)] = 74447,
  [SMALL_STATE(879)] = 74494,
  [SMALL_STATE(880)] = 74541,
  [SMALL_STATE(881)] = 74588,
  [SMALL_STATE(882)] = 74635,
  [SMALL_STATE(883)] = 74682,
  [SMALL_STATE(884)] = 74729,
  [SMALL_STATE(885)] = 74780,
  [SMALL_STATE(886)] = 74831,
  [SMALL_STATE(887)] = 74878,
  [SMALL_STATE(888)] = 74925,
  [SMALL_STATE(889)] = 74972,
  [SMALL_STATE(890)] = 75025,
  [SMALL_STATE(891)] = 75078,
  [SMALL_STATE(892)] = 75125,
  [SMALL_STATE(893)] = 75176,
  [SMALL_STATE(894)] = 75227,
  [SMALL_STATE(895)] = 75274,
  [SMALL_STATE(896)] = 75321,
  [SMALL_STATE(897)] = 75368,
  [SMALL_STATE(898)] = 75415,
  [SMALL_STATE(899)] = 75466,
  [SMALL_STATE(900)] = 75513,
  [SMALL_STATE(901)] = 75564,
  [SMALL_STATE(902)] = 75611,
  [SMALL_STATE(903)] = 75658,
  [SMALL_STATE(904)] = 75705,
  [SMALL_STATE(905)] = 75752,
  [SMALL_STATE(906)] = 75799,
  [SMALL_STATE(907)] = 75846,
  [SMALL_STATE(908)] = 75893,
  [SMALL_STATE(909)] = 75940,
  [SMALL_STATE(910)] = 75987,
  [SMALL_STATE(911)] = 76034,
  [SMALL_STATE(912)] = 76081,
  [SMALL_STATE(913)] = 76128,
  [SMALL_STATE(914)] = 76175,
  [SMALL_STATE(915)] = 76222,
  [SMALL_STATE(916)] = 76273,
  [SMALL_STATE(917)] = 76324,
  [SMALL_STATE(918)] = 76371,
  [SMALL_STATE(919)] = 76418,
  [SMALL_STATE(920)] = 76465,
  [SMALL_STATE(921)] = 76512,
  [SMALL_STATE(922)] = 76559,
  [SMALL_STATE(923)] = 76606,
  [SMALL_STATE(924)] = 76653,
  [SMALL_STATE(925)] = 76708,
  [SMALL_STATE(926)] = 76763,
  [SMALL_STATE(927)] = 76818,
  [SMALL_STATE(928)] = 76867,
  [SMALL_STATE(929)] = 76922,
  [SMALL_STATE(930)] = 76979,
  [SMALL_STATE(931)] = 77036,
  [SMALL_STATE(932)] = 77086,
  [SMALL_STATE(933)] = 77136,
  [SMALL_STATE(934)] = 77186,
  [SMALL_STATE(935)] = 77236,
  [SMALL_STATE(936)] = 77283,
  [SMALL_STATE(937)] = 77325,
  [SMALL_STATE(938)] = 77371,
  [SMALL_STATE(939)] = 77417,
  [SMALL_STATE(940)] = 77463,
  [SMALL_STATE(941)] = 77509,
  [SMALL_STATE(942)] = 77553,
  [SMALL_STATE(943)] = 77599,
  [SMALL_STATE(944)] = 77645,
  [SMALL_STATE(945)] = 77687,
  [SMALL_STATE(946)] = 77735,
  [SMALL_STATE(947)] = 77776,
  [SMALL_STATE(948)] = 77817,
  [SMALL_STATE(949)] = 77858,
  [SMALL_STATE(950)] = 77899,
  [SMALL_STATE(951)] = 77940,
  [SMALL_STATE(952)] = 77981,
  [SMALL_STATE(953)] = 78026,
  [SMALL_STATE(954)] = 78067,
  [SMALL_STATE(955)] = 78149,
  [SMALL_STATE(956)] = 78231,
  [SMALL_STATE(957)] = 78313,
  [SMALL_STATE(958)] = 78395,
  [SMALL_STATE(959)] = 78477,
  [SMALL_STATE(960)] = 78525,
  [SMALL_STATE(961)] = 78607,
  [SMALL_STATE(962)] = 78689,
  [SMALL_STATE(963)] = 78771,
  [SMALL_STATE(964)] = 78810,
  [SMALL_STATE(965)] = 78849,
  [SMALL_STATE(966)] = 78922,
  [SMALL_STATE(967)] = 78995,
  [SMALL_STATE(968)] = 79040,
  [SMALL_STATE(969)] = 79107,
  [SMALL_STATE(970)] = 79156,
  [SMALL_STATE(971)] = 79205,
  [SMALL_STATE(972)] = 79256,
  [SMALL_STATE(973)] = 79301,
  [SMALL_STATE(974)] = 79364,
  [SMALL_STATE(975)] = 79433,
  [SMALL_STATE(976)] = 79482,
  [SMALL_STATE(977)] = 79529,
  [SMALL_STATE(978)] = 79578,
  [SMALL_STATE(979)] = 79629,
  [SMALL_STATE(980)] = 79702,
  [SMALL_STATE(981)] = 79751,
  [SMALL_STATE(982)] = 79830,
  [SMALL_STATE(983)] = 79879,
  [SMALL_STATE(984)] = 79928,
  [SMALL_STATE(985)] = 80007,
  [SMALL_STATE(986)] = 80056,
  [SMALL_STATE(987)] = 80105,
  [SMALL_STATE(988)] = 80154,
  [SMALL_STATE(989)] = 80205,
  [SMALL_STATE(990)] = 80284,
  [SMALL_STATE(991)] = 80363,
  [SMALL_STATE(992)] = 80442,
  [SMALL_STATE(993)] = 80495,
  [SMALL_STATE(994)] = 80570,
  [SMALL_STATE(995)] = 80609,
  [SMALL_STATE(996)] = 80676,
  [SMALL_STATE(997)] = 80741,
  [SMALL_STATE(998)] = 80816,
  [SMALL_STATE(999)] = 80895,
  [SMALL_STATE(1000)] = 80968,
  [SMALL_STATE(1001)] = 81043,
  [SMALL_STATE(1002)] = 81118,
  [SMALL_STATE(1003)] = 81169,
  [SMALL_STATE(1004)] = 81230,
  [SMALL_STATE(1005)] = 81269,
  [SMALL_STATE(1006)] = 81326,
  [SMALL_STATE(1007)] = 81401,
  [SMALL_STATE(1008)] = 81442,
  [SMALL_STATE(1009)] = 81515,
  [SMALL_STATE(1010)] = 81564,
  [SMALL_STATE(1011)] = 81613,
  [SMALL_STATE(1012)] = 81664,
  [SMALL_STATE(1013)] = 81743,
  [SMALL_STATE(1014)] = 81796,
  [SMALL_STATE(1015)] = 81845,
  [SMALL_STATE(1016)] = 81918,
  [SMALL_STATE(1017)] = 81957,
  [SMALL_STATE(1018)] = 82006,
  [SMALL_STATE(1019)] = 82081,
  [SMALL_STATE(1020)] = 82120,
  [SMALL_STATE(1021)] = 82175,
  [SMALL_STATE(1022)] = 82246,
  [SMALL_STATE(1023)] = 82297,
  [SMALL_STATE(1024)] = 82364,
  [SMALL_STATE(1025)] = 82429,
  [SMALL_STATE(1026)] = 82490,
  [SMALL_STATE(1027)] = 82547,
  [SMALL_STATE(1028)] = 82598,
  [SMALL_STATE(1029)] = 82667,
  [SMALL_STATE(1030)] = 82730,
  [SMALL_STATE(1031)] = 82781,
  [SMALL_STATE(1032)] = 82836,
  [SMALL_STATE(1033)] = 82915,
  [SMALL_STATE(1034)] = 82953,
  [SMALL_STATE(1035)] = 82995,
  [SMALL_STATE(1036)] = 83037,
  [SMALL_STATE(1037)] = 83075,
  [SMALL_STATE(1038)] = 83113,
  [SMALL_STATE(1039)] = 83155,
  [SMALL_STATE(1040)] = 83193,
  [SMALL_STATE(1041)] = 83245,
  [SMALL_STATE(1042)] = 83285,
  [SMALL_STATE(1043)] = 83331,
  [SMALL_STATE(1044)] = 83387,
  [SMALL_STATE(1045)] = 83431,
  [SMALL_STATE(1046)] = 83509,
  [SMALL_STATE(1047)] = 83555,
  [SMALL_STATE(1048)] = 83593,
  [SMALL_STATE(1049)] = 83667,
  [SMALL_STATE(1050)] = 83705,
  [SMALL_STATE(1051)] = 83757,
  [SMALL_STATE(1052)] = 83805,
  [SMALL_STATE(1053)] = 83851,
  [SMALL_STATE(1054)] = 83895,
  [SMALL_STATE(1055)] = 83933,
  [SMALL_STATE(1056)] = 83971,
  [SMALL_STATE(1057)] = 84025,
  [SMALL_STATE(1058)] = 84101,
  [SMALL_STATE(1059)] = 84139,
  [SMALL_STATE(1060)] = 84177,
  [SMALL_STATE(1061)] = 84223,
  [SMALL_STATE(1062)] = 84261,
  [SMALL_STATE(1063)] = 84299,
  [SMALL_STATE(1064)] = 84373,
  [SMALL_STATE(1065)] = 84429,
  [SMALL_STATE(1066)] = 84475,
  [SMALL_STATE(1067)] = 84513,
  [SMALL_STATE(1068)] = 84551,
  [SMALL_STATE(1069)] = 84589,
  [SMALL_STATE(1070)] = 84641,
  [SMALL_STATE(1071)] = 84679,
  [SMALL_STATE(1072)] = 84733,
  [SMALL_STATE(1073)] = 84785,
  [SMALL_STATE(1074)] = 84829,
  [SMALL_STATE(1075)] = 84867,
  [SMALL_STATE(1076)] = 84905,
  [SMALL_STATE(1077)] = 84943,
  [SMALL_STATE(1078)] = 84993,
  [SMALL_STATE(1079)] = 85031,
  [SMALL_STATE(1080)] = 85075,
  [SMALL_STATE(1081)] = 85121,
  [SMALL_STATE(1082)] = 85159,
  [SMALL_STATE(1083)] = 85235,
  [SMALL_STATE(1084)] = 85311,
  [SMALL_STATE(1085)] = 85357,
  [SMALL_STATE(1086)] = 85431,
  [SMALL_STATE(1087)] = 85507,
  [SMALL_STATE(1088)] = 85545,
  [SMALL_STATE(1089)] = 85623,
  [SMALL_STATE(1090)] = 85675,
  [SMALL_STATE(1091)] = 85713,
  [SMALL_STATE(1092)] = 85765,
  [SMALL_STATE(1093)] = 85811,
  [SMALL_STATE(1094)] = 85887,
  [SMALL_STATE(1095)] = 85963,
  [SMALL_STATE(1096)] = 86001,
  [SMALL_STATE(1097)] = 86079,
  [SMALL_STATE(1098)] = 86125,
  [SMALL_STATE(1099)] = 86171,
  [SMALL_STATE(1100)] = 86227,
  [SMALL_STATE(1101)] = 86271,
  [SMALL_STATE(1102)] = 86323,
  [SMALL_STATE(1103)] = 86399,
  [SMALL_STATE(1104)] = 86437,
  [SMALL_STATE(1105)] = 86513,
  [SMALL_STATE(1106)] = 86591,
  [SMALL_STATE(1107)] = 86643,
  [SMALL_STATE(1108)] = 86681,
  [SMALL_STATE(1109)] = 86723,
  [SMALL_STATE(1110)] = 86761,
  [SMALL_STATE(1111)] = 86803,
  [SMALL_STATE(1112)] = 86855,
  [SMALL_STATE(1113)] = 86907,
  [SMALL_STATE(1114)] = 86981,
  [SMALL_STATE(1115)] = 87033,
  [SMALL_STATE(1116)] = 87085,
  [SMALL_STATE(1117)] = 87137,
  [SMALL_STATE(1118)] = 87189,
  [SMALL_STATE(1119)] = 87241,
  [SMALL_STATE(1120)] = 87279,
  [SMALL_STATE(1121)] = 87317,
  [SMALL_STATE(1122)] = 87355,
  [SMALL_STATE(1123)] = 87393,
  [SMALL_STATE(1124)] = 87445,
  [SMALL_STATE(1125)] = 87497,
  [SMALL_STATE(1126)] = 87541,
  [SMALL_STATE(1127)] = 87579,
  [SMALL_STATE(1128)] = 87619,
  [SMALL_STATE(1129)] = 87667,
  [SMALL_STATE(1130)] = 87713,
  [SMALL_STATE(1131)] = 87771,
  [SMALL_STATE(1132)] = 87809,
  [SMALL_STATE(1133)] = 87847,
  [SMALL_STATE(1134)] = 87885,
  [SMALL_STATE(1135)] = 87931,
  [SMALL_STATE(1136)] = 88004,
  [SMALL_STATE(1137)] = 88077,
  [SMALL_STATE(1138)] = 88118,
  [SMALL_STATE(1139)] = 88191,
  [SMALL_STATE(1140)] = 88262,
  [SMALL_STATE(1141)] = 88333,
  [SMALL_STATE(1142)] = 88402,
  [SMALL_STATE(1143)] = 88475,
  [SMALL_STATE(1144)] = 88526,
  [SMALL_STATE(1145)] = 88599,
  [SMALL_STATE(1146)] = 88666,
  [SMALL_STATE(1147)] = 88739,
  [SMALL_STATE(1148)] = 88788,
  [SMALL_STATE(1149)] = 88859,
  [SMALL_STATE(1150)] = 88926,
  [SMALL_STATE(1151)] = 88999,
  [SMALL_STATE(1152)] = 89048,
  [SMALL_STATE(1153)] = 89121,
  [SMALL_STATE(1154)] = 89184,
  [SMALL_STATE(1155)] = 89245,
  [SMALL_STATE(1156)] = 89302,
  [SMALL_STATE(1157)] = 89351,
  [SMALL_STATE(1158)] = 89400,
  [SMALL_STATE(1159)] = 89453,
  [SMALL_STATE(1160)] = 89518,
  [SMALL_STATE(1161)] = 89565,
  [SMALL_STATE(1162)] = 89606,
  [SMALL_STATE(1163)] = 89665,
  [SMALL_STATE(1164)] = 89718,
  [SMALL_STATE(1165)] = 89789,
  [SMALL_STATE(1166)] = 89862,
  [SMALL_STATE(1167)] = 89903,
  [SMALL_STATE(1168)] = 89976,
  [SMALL_STATE(1169)] = 90049,
  [SMALL_STATE(1170)] = 90098,
  [SMALL_STATE(1171)] = 90161,
  [SMALL_STATE(1172)] = 90234,
  [SMALL_STATE(1173)] = 90275,
  [SMALL_STATE(1174)] = 90328,
  [SMALL_STATE(1175)] = 90373,
  [SMALL_STATE(1176)] = 90420,
  [SMALL_STATE(1177)] = 90469,
  [SMALL_STATE(1178)] = 90542,
  [SMALL_STATE(1179)] = 90615,
  [SMALL_STATE(1180)] = 90656,
  [SMALL_STATE(1181)] = 90717,
  [SMALL_STATE(1182)] = 90764,
  [SMALL_STATE(1183)] = 90837,
  [SMALL_STATE(1184)] = 90884,
  [SMALL_STATE(1185)] = 90955,
  [SMALL_STATE(1186)] = 91002,
  [SMALL_STATE(1187)] = 91049,
  [SMALL_STATE(1188)] = 91096,
  [SMALL_STATE(1189)] = 91167,
  [SMALL_STATE(1190)] = 91238,
  [SMALL_STATE(1191)] = 91311,
  [SMALL_STATE(1192)] = 91354,
  [SMALL_STATE(1193)] = 91427,
  [SMALL_STATE(1194)] = 91498,
  [SMALL_STATE(1195)] = 91569,
  [SMALL_STATE(1196)] = 91614,
  [SMALL_STATE(1197)] = 91679,
  [SMALL_STATE(1198)] = 91726,
  [SMALL_STATE(1199)] = 91789,
  [SMALL_STATE(1200)] = 91828,
  [SMALL_STATE(1201)] = 91877,
  [SMALL_STATE(1202)] = 91946,
  [SMALL_STATE(1203)] = 91997,
  [SMALL_STATE(1204)] = 92054,
  [SMALL_STATE(1205)] = 92091,
  [SMALL_STATE(1206)] = 92136,
  [SMALL_STATE(1207)] = 92181,
  [SMALL_STATE(1208)] = 92230,
  [SMALL_STATE(1209)] = 92289,
  [SMALL_STATE(1210)] = 92362,
  [SMALL_STATE(1211)] = 92403,
  [SMALL_STATE(1212)] = 92476,
  [SMALL_STATE(1213)] = 92545,
  [SMALL_STATE(1214)] = 92618,
  [SMALL_STATE(1215)] = 92681,
  [SMALL_STATE(1216)] = 92750,
  [SMALL_STATE(1217)] = 92815,
  [SMALL_STATE(1218)] = 92888,
  [SMALL_STATE(1219)] = 92929,
  [SMALL_STATE(1220)] = 92972,
  [SMALL_STATE(1221)] = 93043,
  [SMALL_STATE(1222)] = 93116,
  [SMALL_STATE(1223)] = 93167,
  [SMALL_STATE(1224)] = 93204,
  [SMALL_STATE(1225)] = 93269,
  [SMALL_STATE(1226)] = 93318,
  [SMALL_STATE(1227)] = 93381,
  [SMALL_STATE(1228)] = 93442,
  [SMALL_STATE(1229)] = 93507,
  [SMALL_STATE(1230)] = 93548,
  [SMALL_STATE(1231)] = 93605,
  [SMALL_STATE(1232)] = 93658,
  [SMALL_STATE(1233)] = 93705,
  [SMALL_STATE(1234)] = 93764,
  [SMALL_STATE(1235)] = 93827,
  [SMALL_STATE(1236)] = 93868,
  [SMALL_STATE(1237)] = 93939,
  [SMALL_STATE(1238)] = 93980,
  [SMALL_STATE(1239)] = 94027,
  [SMALL_STATE(1240)] = 94088,
  [SMALL_STATE(1241)] = 94135,
  [SMALL_STATE(1242)] = 94208,
  [SMALL_STATE(1243)] = 94267,
  [SMALL_STATE(1244)] = 94312,
  [SMALL_STATE(1245)] = 94349,
  [SMALL_STATE(1246)] = 94404,
  [SMALL_STATE(1247)] = 94473,
  [SMALL_STATE(1248)] = 94520,
  [SMALL_STATE(1249)] = 94567,
  [SMALL_STATE(1250)] = 94640,
  [SMALL_STATE(1251)] = 94709,
  [SMALL_STATE(1252)] = 94754,
  [SMALL_STATE(1253)] = 94823,
  [SMALL_STATE(1254)] = 94892,
  [SMALL_STATE(1255)] = 94965,
  [SMALL_STATE(1256)] = 95012,
  [SMALL_STATE(1257)] = 95059,
  [SMALL_STATE(1258)] = 95128,
  [SMALL_STATE(1259)] = 95197,
  [SMALL_STATE(1260)] = 95244,
  [SMALL_STATE(1261)] = 95281,
  [SMALL_STATE(1262)] = 95354,
  [SMALL_STATE(1263)] = 95425,
  [SMALL_STATE(1264)] = 95474,
  [SMALL_STATE(1265)] = 95547,
  [SMALL_STATE(1266)] = 95603,
  [SMALL_STATE(1267)] = 95673,
  [SMALL_STATE(1268)] = 95743,
  [SMALL_STATE(1269)] = 95779,
  [SMALL_STATE(1270)] = 95849,
  [SMALL_STATE(1271)] = 95919,
  [SMALL_STATE(1272)] = 95989,
  [SMALL_STATE(1273)] = 96029,
  [SMALL_STATE(1274)] = 96079,
  [SMALL_STATE(1275)] = 96143,
  [SMALL_STATE(1276)] = 96191,
  [SMALL_STATE(1277)] = 96253,
  [SMALL_STATE(1278)] = 96313,
  [SMALL_STATE(1279)] = 96365,
  [SMALL_STATE(1280)] = 96427,
  [SMALL_STATE(1281)] = 96485,
  [SMALL_STATE(1282)] = 96553,
  [SMALL_STATE(1283)] = 96621,
  [SMALL_STATE(1284)] = 96689,
  [SMALL_STATE(1285)] = 96757,
  [SMALL_STATE(1286)] = 96793,
  [SMALL_STATE(1287)] = 96861,
  [SMALL_STATE(1288)] = 96929,
  [SMALL_STATE(1289)] = 96997,
  [SMALL_STATE(1290)] = 97067,
  [SMALL_STATE(1291)] = 97137,
  [SMALL_STATE(1292)] = 97183,
  [SMALL_STATE(1293)] = 97229,
  [SMALL_STATE(1294)] = 97265,
  [SMALL_STATE(1295)] = 97335,
  [SMALL_STATE(1296)] = 97371,
  [SMALL_STATE(1297)] = 97441,
  [SMALL_STATE(1298)] = 97477,
  [SMALL_STATE(1299)] = 97521,
  [SMALL_STATE(1300)] = 97559,
  [SMALL_STATE(1301)] = 97629,
  [SMALL_STATE(1302)] = 97665,
  [SMALL_STATE(1303)] = 97735,
  [SMALL_STATE(1304)] = 97805,
  [SMALL_STATE(1305)] = 97843,
  [SMALL_STATE(1306)] = 97913,
  [SMALL_STATE(1307)] = 97981,
  [SMALL_STATE(1308)] = 98027,
  [SMALL_STATE(1309)] = 98063,
  [SMALL_STATE(1310)] = 98111,
  [SMALL_STATE(1311)] = 98147,
  [SMALL_STATE(1312)] = 98215,
  [SMALL_STATE(1313)] = 98259,
  [SMALL_STATE(1314)] = 98329,
  [SMALL_STATE(1315)] = 98375,
  [SMALL_STATE(1316)] = 98411,
  [SMALL_STATE(1317)] = 98463,
  [SMALL_STATE(1318)] = 98529,
  [SMALL_STATE(1319)] = 98577,
  [SMALL_STATE(1320)] = 98641,
  [SMALL_STATE(1321)] = 98681,
  [SMALL_STATE(1322)] = 98729,
  [SMALL_STATE(1323)] = 98791,
  [SMALL_STATE(1324)] = 98849,
  [SMALL_STATE(1325)] = 98903,
  [SMALL_STATE(1326)] = 98939,
  [SMALL_STATE(1327)] = 98975,
  [SMALL_STATE(1328)] = 99021,
  [SMALL_STATE(1329)] = 99059,
  [SMALL_STATE(1330)] = 99095,
  [SMALL_STATE(1331)] = 99159,
  [SMALL_STATE(1332)] = 99219,
  [SMALL_STATE(1333)] = 99289,
  [SMALL_STATE(1334)] = 99331,
  [SMALL_STATE(1335)] = 99401,
  [SMALL_STATE(1336)] = 99471,
  [SMALL_STATE(1337)] = 99541,
  [SMALL_STATE(1338)] = 99611,
  [SMALL_STATE(1339)] = 99681,
  [SMALL_STATE(1340)] = 99751,
  [SMALL_STATE(1341)] = 99821,
  [SMALL_STATE(1342)] = 99889,
  [SMALL_STATE(1343)] = 99925,
  [SMALL_STATE(1344)] = 99995,
  [SMALL_STATE(1345)] = 100033,
  [SMALL_STATE(1346)] = 100069,
  [SMALL_STATE(1347)] = 100139,
  [SMALL_STATE(1348)] = 100209,
  [SMALL_STATE(1349)] = 100279,
  [SMALL_STATE(1350)] = 100349,
  [SMALL_STATE(1351)] = 100385,
  [SMALL_STATE(1352)] = 100431,
  [SMALL_STATE(1353)] = 100501,
  [SMALL_STATE(1354)] = 100571,
  [SMALL_STATE(1355)] = 100641,
  [SMALL_STATE(1356)] = 100689,
  [SMALL_STATE(1357)] = 100735,
  [SMALL_STATE(1358)] = 100805,
  [SMALL_STATE(1359)] = 100866,
  [SMALL_STATE(1360)] = 100933,
  [SMALL_STATE(1361)] = 101000,
  [SMALL_STATE(1362)] = 101067,
  [SMALL_STATE(1363)] = 101134,
  [SMALL_STATE(1364)] = 101201,
  [SMALL_STATE(1365)] = 101268,
  [SMALL_STATE(1366)] = 101335,
  [SMALL_STATE(1367)] = 101402,
  [SMALL_STATE(1368)] = 101469,
  [SMALL_STATE(1369)] = 101536,
  [SMALL_STATE(1370)] = 101603,
  [SMALL_STATE(1371)] = 101638,
  [SMALL_STATE(1372)] = 101673,
  [SMALL_STATE(1373)] = 101708,
  [SMALL_STATE(1374)] = 101743,
  [SMALL_STATE(1375)] = 101778,
  [SMALL_STATE(1376)] = 101813,
  [SMALL_STATE(1377)] = 101848,
  [SMALL_STATE(1378)] = 101883,
  [SMALL_STATE(1379)] = 101918,
  [SMALL_STATE(1380)] = 101959,
  [SMALL_STATE(1381)] = 102026,
  [SMALL_STATE(1382)] = 102093,
  [SMALL_STATE(1383)] = 102160,
  [SMALL_STATE(1384)] = 102227,
  [SMALL_STATE(1385)] = 102268,
  [SMALL_STATE(1386)] = 102335,
  [SMALL_STATE(1387)] = 102372,
  [SMALL_STATE(1388)] = 102439,
  [SMALL_STATE(1389)] = 102474,
  [SMALL_STATE(1390)] = 102509,
  [SMALL_STATE(1391)] = 102576,
  [SMALL_STATE(1392)] = 102643,
  [SMALL_STATE(1393)] = 102678,
  [SMALL_STATE(1394)] = 102745,
  [SMALL_STATE(1395)] = 102780,
  [SMALL_STATE(1396)] = 102847,
  [SMALL_STATE(1397)] = 102896,
  [SMALL_STATE(1398)] = 102931,
  [SMALL_STATE(1399)] = 102998,
  [SMALL_STATE(1400)] = 103033,
  [SMALL_STATE(1401)] = 103068,
  [SMALL_STATE(1402)] = 103131,
  [SMALL_STATE(1403)] = 103166,
  [SMALL_STATE(1404)] = 103213,
  [SMALL_STATE(1405)] = 103248,
  [SMALL_STATE(1406)] = 103307,
  [SMALL_STATE(1407)] = 103342,
  [SMALL_STATE(1408)] = 103399,
  [SMALL_STATE(1409)] = 103450,
  [SMALL_STATE(1410)] = 103495,
  [SMALL_STATE(1411)] = 103538,
  [SMALL_STATE(1412)] = 103577,
  [SMALL_STATE(1413)] = 103612,
  [SMALL_STATE(1414)] = 103657,
  [SMALL_STATE(1415)] = 103718,
  [SMALL_STATE(1416)] = 103773,
  [SMALL_STATE(1417)] = 103840,
  [SMALL_STATE(1418)] = 103875,
  [SMALL_STATE(1419)] = 103942,
  [SMALL_STATE(1420)] = 103977,
  [SMALL_STATE(1421)] = 104012,
  [SMALL_STATE(1422)] = 104047,
  [SMALL_STATE(1423)] = 104114,
  [SMALL_STATE(1424)] = 104181,
  [SMALL_STATE(1425)] = 104222,
  [SMALL_STATE(1426)] = 104259,
  [SMALL_STATE(1427)] = 104326,
  [SMALL_STATE(1428)] = 104393,
  [SMALL_STATE(1429)] = 104434,
  [SMALL_STATE(1430)] = 104473,
  [SMALL_STATE(1431)] = 104508,
  [SMALL_STATE(1432)] = 104543,
  [SMALL_STATE(1433)] = 104577,
  [SMALL_STATE(1434)] = 104611,
  [SMALL_STATE(1435)] = 104645,
  [SMALL_STATE(1436)] = 104709,
  [SMALL_STATE(1437)] = 104743,
  [SMALL_STATE(1438)] = 104777,
  [SMALL_STATE(1439)] = 104811,
  [SMALL_STATE(1440)] = 104845,
  [SMALL_STATE(1441)] = 104879,
  [SMALL_STATE(1442)] = 104913,
  [SMALL_STATE(1443)] = 104947,
  [SMALL_STATE(1444)] = 104981,
  [SMALL_STATE(1445)] = 105043,
  [SMALL_STATE(1446)] = 105077,
  [SMALL_STATE(1447)] = 105111,
  [SMALL_STATE(1448)] = 105145,
  [SMALL_STATE(1449)] = 105179,
  [SMALL_STATE(1450)] = 105213,
  [SMALL_STATE(1451)] = 105251,
  [SMALL_STATE(1452)] = 105285,
  [SMALL_STATE(1453)] = 105319,
  [SMALL_STATE(1454)] = 105353,
  [SMALL_STATE(1455)] = 105417,
  [SMALL_STATE(1456)] = 105451,
  [SMALL_STATE(1457)] = 105485,
  [SMALL_STATE(1458)] = 105519,
  [SMALL_STATE(1459)] = 105553,
  [SMALL_STATE(1460)] = 105587,
  [SMALL_STATE(1461)] = 105621,
  [SMALL_STATE(1462)] = 105655,
  [SMALL_STATE(1463)] = 105689,
  [SMALL_STATE(1464)] = 105723,
  [SMALL_STATE(1465)] = 105757,
  [SMALL_STATE(1466)] = 105791,
  [SMALL_STATE(1467)] = 105825,
  [SMALL_STATE(1468)] = 105859,
  [SMALL_STATE(1469)] = 105893,
  [SMALL_STATE(1470)] = 105927,
  [SMALL_STATE(1471)] = 105961,
  [SMALL_STATE(1472)] = 105995,
  [SMALL_STATE(1473)] = 106029,
  [SMALL_STATE(1474)] = 106063,
  [SMALL_STATE(1475)] = 106097,
  [SMALL_STATE(1476)] = 106131,
  [SMALL_STATE(1477)] = 106165,
  [SMALL_STATE(1478)] = 106199,
  [SMALL_STATE(1479)] = 106233,
  [SMALL_STATE(1480)] = 106267,
  [SMALL_STATE(1481)] = 106301,
  [SMALL_STATE(1482)] = 106335,
  [SMALL_STATE(1483)] = 106369,
  [SMALL_STATE(1484)] = 106403,
  [SMALL_STATE(1485)] = 106437,
  [SMALL_STATE(1486)] = 106471,
  [SMALL_STATE(1487)] = 106505,
  [SMALL_STATE(1488)] = 106539,
  [SMALL_STATE(1489)] = 106573,
  [SMALL_STATE(1490)] = 106615,
  [SMALL_STATE(1491)] = 106649,
  [SMALL_STATE(1492)] = 106683,
  [SMALL_STATE(1493)] = 106717,
  [SMALL_STATE(1494)] = 106751,
  [SMALL_STATE(1495)] = 106785,
  [SMALL_STATE(1496)] = 106819,
  [SMALL_STATE(1497)] = 106853,
  [SMALL_STATE(1498)] = 106887,
  [SMALL_STATE(1499)] = 106921,
  [SMALL_STATE(1500)] = 106957,
  [SMALL_STATE(1501)] = 106991,
  [SMALL_STATE(1502)] = 107055,
  [SMALL_STATE(1503)] = 107089,
  [SMALL_STATE(1504)] = 107123,
  [SMALL_STATE(1505)] = 107157,
  [SMALL_STATE(1506)] = 107191,
  [SMALL_STATE(1507)] = 107225,
  [SMALL_STATE(1508)] = 107259,
  [SMALL_STATE(1509)] = 107293,
  [SMALL_STATE(1510)] = 107327,
  [SMALL_STATE(1511)] = 107360,
  [SMALL_STATE(1512)] = 107396,
  [SMALL_STATE(1513)] = 107452,
  [SMALL_STATE(1514)] = 107522,
  [SMALL_STATE(1515)] = 107556,
  [SMALL_STATE(1516)] = 107612,
  [SMALL_STATE(1517)] = 107648,
  [SMALL_STATE(1518)] = 107701,
  [SMALL_STATE(1519)] = 107751,
  [SMALL_STATE(1520)] = 107781,
  [SMALL_STATE(1521)] = 107828,
  [SMALL_STATE(1522)] = 107875,
  [SMALL_STATE(1523)] = 107919,
  [SMALL_STATE(1524)] = 107963,
  [SMALL_STATE(1525)] = 108005,
  [SMALL_STATE(1526)] = 108043,
  [SMALL_STATE(1527)] = 108069,
  [SMALL_STATE(1528)] = 108109,
  [SMALL_STATE(1529)] = 108149,
  [SMALL_STATE(1530)] = 108182,
  [SMALL_STATE(1531)] = 108222,
  [SMALL_STATE(1532)] = 108262,
  [SMALL_STATE(1533)] = 108302,
  [SMALL_STATE(1534)] = 108342,
  [SMALL_STATE(1535)] = 108382,
  [SMALL_STATE(1536)] = 108422,
  [SMALL_STATE(1537)] = 108462,
  [SMALL_STATE(1538)] = 108502,
  [SMALL_STATE(1539)] = 108529,
  [SMALL_STATE(1540)] = 108566,
  [SMALL_STATE(1541)] = 108603,
  [SMALL_STATE(1542)] = 108640,
  [SMALL_STATE(1543)] = 108677,
  [SMALL_STATE(1544)] = 108714,
  [SMALL_STATE(1545)] = 108751,
  [SMALL_STATE(1546)] = 108788,
  [SMALL_STATE(1547)] = 108813,
  [SMALL_STATE(1548)] = 108844,
  [SMALL_STATE(1549)] = 108873,
  [SMALL_STATE(1550)] = 108910,
  [SMALL_STATE(1551)] = 108933,
  [SMALL_STATE(1552)] = 108956,
  [SMALL_STATE(1553)] = 108993,
  [SMALL_STATE(1554)] = 109030,
  [SMALL_STATE(1555)] = 109053,
  [SMALL_STATE(1556)] = 109090,
  [SMALL_STATE(1557)] = 109126,
  [SMALL_STATE(1558)] = 109162,
  [SMALL_STATE(1559)] = 109198,
  [SMALL_STATE(1560)] = 109234,
  [SMALL_STATE(1561)] = 109270,
  [SMALL_STATE(1562)] = 109306,
  [SMALL_STATE(1563)] = 109342,
  [SMALL_STATE(1564)] = 109378,
  [SMALL_STATE(1565)] = 109414,
  [SMALL_STATE(1566)] = 109440,
  [SMALL_STATE(1567)] = 109466,
  [SMALL_STATE(1568)] = 109502,
  [SMALL_STATE(1569)] = 109538,
  [SMALL_STATE(1570)] = 109574,
  [SMALL_STATE(1571)] = 109610,
  [SMALL_STATE(1572)] = 109646,
  [SMALL_STATE(1573)] = 109682,
  [SMALL_STATE(1574)] = 109718,
  [SMALL_STATE(1575)] = 109751,
  [SMALL_STATE(1576)] = 109784,
  [SMALL_STATE(1577)] = 109811,
  [SMALL_STATE(1578)] = 109836,
  [SMALL_STATE(1579)] = 109869,
  [SMALL_STATE(1580)] = 109902,
  [SMALL_STATE(1581)] = 109925,
  [SMALL_STATE(1582)] = 109958,
  [SMALL_STATE(1583)] = 109991,
  [SMALL_STATE(1584)] = 110024,
  [SMALL_STATE(1585)] = 110057,
  [SMALL_STATE(1586)] = 110080,
  [SMALL_STATE(1587)] = 110113,
  [SMALL_STATE(1588)] = 110136,
  [SMALL_STATE(1589)] = 110169,
  [SMALL_STATE(1590)] = 110202,
  [SMALL_STATE(1591)] = 110235,
  [SMALL_STATE(1592)] = 110268,
  [SMALL_STATE(1593)] = 110301,
  [SMALL_STATE(1594)] = 110324,
  [SMALL_STATE(1595)] = 110347,
  [SMALL_STATE(1596)] = 110370,
  [SMALL_STATE(1597)] = 110393,
  [SMALL_STATE(1598)] = 110416,
  [SMALL_STATE(1599)] = 110449,
  [SMALL_STATE(1600)] = 110482,
  [SMALL_STATE(1601)] = 110515,
  [SMALL_STATE(1602)] = 110538,
  [SMALL_STATE(1603)] = 110571,
  [SMALL_STATE(1604)] = 110594,
  [SMALL_STATE(1605)] = 110619,
  [SMALL_STATE(1606)] = 110642,
  [SMALL_STATE(1607)] = 110675,
  [SMALL_STATE(1608)] = 110698,
  [SMALL_STATE(1609)] = 110731,
  [SMALL_STATE(1610)] = 110754,
  [SMALL_STATE(1611)] = 110787,
  [SMALL_STATE(1612)] = 110810,
  [SMALL_STATE(1613)] = 110843,
  [SMALL_STATE(1614)] = 110876,
  [SMALL_STATE(1615)] = 110909,
  [SMALL_STATE(1616)] = 110932,
  [SMALL_STATE(1617)] = 110965,
  [SMALL_STATE(1618)] = 110988,
  [SMALL_STATE(1619)] = 111021,
  [SMALL_STATE(1620)] = 111054,
  [SMALL_STATE(1621)] = 111087,
  [SMALL_STATE(1622)] = 111120,
  [SMALL_STATE(1623)] = 111153,
  [SMALL_STATE(1624)] = 111186,
  [SMALL_STATE(1625)] = 111219,
  [SMALL_STATE(1626)] = 111252,
  [SMALL_STATE(1627)] = 111285,
  [SMALL_STATE(1628)] = 111318,
  [SMALL_STATE(1629)] = 111351,
  [SMALL_STATE(1630)] = 111384,
  [SMALL_STATE(1631)] = 111417,
  [SMALL_STATE(1632)] = 111450,
  [SMALL_STATE(1633)] = 111483,
  [SMALL_STATE(1634)] = 111516,
  [SMALL_STATE(1635)] = 111549,
  [SMALL_STATE(1636)] = 111582,
  [SMALL_STATE(1637)] = 111615,
  [SMALL_STATE(1638)] = 111648,
  [SMALL_STATE(1639)] = 111681,
  [SMALL_STATE(1640)] = 111714,
  [SMALL_STATE(1641)] = 111747,
  [SMALL_STATE(1642)] = 111770,
  [SMALL_STATE(1643)] = 111803,
  [SMALL_STATE(1644)] = 111836,
  [SMALL_STATE(1645)] = 111869,
  [SMALL_STATE(1646)] = 111902,
  [SMALL_STATE(1647)] = 111931,
  [SMALL_STATE(1648)] = 111964,
  [SMALL_STATE(1649)] = 111997,
  [SMALL_STATE(1650)] = 112030,
  [SMALL_STATE(1651)] = 112063,
  [SMALL_STATE(1652)] = 112096,
  [SMALL_STATE(1653)] = 112119,
  [SMALL_STATE(1654)] = 112142,
  [SMALL_STATE(1655)] = 112165,
  [SMALL_STATE(1656)] = 112188,
  [SMALL_STATE(1657)] = 112211,
  [SMALL_STATE(1658)] = 112244,
  [SMALL_STATE(1659)] = 112282,
  [SMALL_STATE(1660)] = 112314,
  [SMALL_STATE(1661)] = 112350,
  [SMALL_STATE(1662)] = 112380,
  [SMALL_STATE(1663)] = 112412,
  [SMALL_STATE(1664)] = 112439,
  [SMALL_STATE(1665)] = 112468,
  [SMALL_STATE(1666)] = 112497,
  [SMALL_STATE(1667)] = 112521,
  [SMALL_STATE(1668)] = 112545,
  [SMALL_STATE(1669)] = 112569,
  [SMALL_STATE(1670)] = 112591,
  [SMALL_STATE(1671)] = 112615,
  [SMALL_STATE(1672)] = 112639,
  [SMALL_STATE(1673)] = 112661,
  [SMALL_STATE(1674)] = 112678,
  [SMALL_STATE(1675)] = 112701,
  [SMALL_STATE(1676)] = 112718,
  [SMALL_STATE(1677)] = 112735,
  [SMALL_STATE(1678)] = 112764,
  [SMALL_STATE(1679)] = 112787,
  [SMALL_STATE(1680)] = 112816,
  [SMALL_STATE(1681)] = 112833,
  [SMALL_STATE(1682)] = 112856,
  [SMALL_STATE(1683)] = 112879,
  [SMALL_STATE(1684)] = 112896,
  [SMALL_STATE(1685)] = 112919,
  [SMALL_STATE(1686)] = 112945,
  [SMALL_STATE(1687)] = 112971,
  [SMALL_STATE(1688)] = 112997,
  [SMALL_STATE(1689)] = 113023,
  [SMALL_STATE(1690)] = 113049,
  [SMALL_STATE(1691)] = 113075,
  [SMALL_STATE(1692)] = 113101,
  [SMALL_STATE(1693)] = 113127,
  [SMALL_STATE(1694)] = 113153,
  [SMALL_STATE(1695)] = 113179,
  [SMALL_STATE(1696)] = 113205,
  [SMALL_STATE(1697)] = 113225,
  [SMALL_STATE(1698)] = 113251,
  [SMALL_STATE(1699)] = 113277,
  [SMALL_STATE(1700)] = 113303,
  [SMALL_STATE(1701)] = 113324,
  [SMALL_STATE(1702)] = 113343,
  [SMALL_STATE(1703)] = 113364,
  [SMALL_STATE(1704)] = 113383,
  [SMALL_STATE(1705)] = 113404,
  [SMALL_STATE(1706)] = 113425,
  [SMALL_STATE(1707)] = 113446,
  [SMALL_STATE(1708)] = 113465,
  [SMALL_STATE(1709)] = 113484,
  [SMALL_STATE(1710)] = 113503,
  [SMALL_STATE(1711)] = 113522,
  [SMALL_STATE(1712)] = 113543,
  [SMALL_STATE(1713)] = 113564,
  [SMALL_STATE(1714)] = 113583,
  [SMALL_STATE(1715)] = 113604,
  [SMALL_STATE(1716)] = 113625,
  [SMALL_STATE(1717)] = 113646,
  [SMALL_STATE(1718)] = 113665,
  [SMALL_STATE(1719)] = 113684,
  [SMALL_STATE(1720)] = 113705,
  [SMALL_STATE(1721)] = 113724,
  [SMALL_STATE(1722)] = 113747,
  [SMALL_STATE(1723)] = 113764,
  [SMALL_STATE(1724)] = 113787,
  [SMALL_STATE(1725)] = 113808,
  [SMALL_STATE(1726)] = 113829,
  [SMALL_STATE(1727)] = 113842,
  [SMALL_STATE(1728)] = 113861,
  [SMALL_STATE(1729)] = 113882,
  [SMALL_STATE(1730)] = 113901,
  [SMALL_STATE(1731)] = 113920,
  [SMALL_STATE(1732)] = 113939,
  [SMALL_STATE(1733)] = 113960,
  [SMALL_STATE(1734)] = 113981,
  [SMALL_STATE(1735)] = 114000,
  [SMALL_STATE(1736)] = 114019,
  [SMALL_STATE(1737)] = 114040,
  [SMALL_STATE(1738)] = 114061,
  [SMALL_STATE(1739)] = 114084,
  [SMALL_STATE(1740)] = 114103,
  [SMALL_STATE(1741)] = 114122,
  [SMALL_STATE(1742)] = 114143,
  [SMALL_STATE(1743)] = 114158,
  [SMALL_STATE(1744)] = 114177,
  [SMALL_STATE(1745)] = 114200,
  [SMALL_STATE(1746)] = 114221,
  [SMALL_STATE(1747)] = 114242,
  [SMALL_STATE(1748)] = 114265,
  [SMALL_STATE(1749)] = 114284,
  [SMALL_STATE(1750)] = 114305,
  [SMALL_STATE(1751)] = 114326,
  [SMALL_STATE(1752)] = 114345,
  [SMALL_STATE(1753)] = 114368,
  [SMALL_STATE(1754)] = 114391,
  [SMALL_STATE(1755)] = 114410,
  [SMALL_STATE(1756)] = 114431,
  [SMALL_STATE(1757)] = 114452,
  [SMALL_STATE(1758)] = 114475,
  [SMALL_STATE(1759)] = 114494,
  [SMALL_STATE(1760)] = 114513,
  [SMALL_STATE(1761)] = 114532,
  [SMALL_STATE(1762)] = 114553,
  [SMALL_STATE(1763)] = 114572,
  [SMALL_STATE(1764)] = 114591,
  [SMALL_STATE(1765)] = 114613,
  [SMALL_STATE(1766)] = 114635,
  [SMALL_STATE(1767)] = 114653,
  [SMALL_STATE(1768)] = 114669,
  [SMALL_STATE(1769)] = 114689,
  [SMALL_STATE(1770)] = 114709,
  [SMALL_STATE(1771)] = 114731,
  [SMALL_STATE(1772)] = 114753,
  [SMALL_STATE(1773)] = 114773,
  [SMALL_STATE(1774)] = 114791,
  [SMALL_STATE(1775)] = 114813,
  [SMALL_STATE(1776)] = 114835,
  [SMALL_STATE(1777)] = 114855,
  [SMALL_STATE(1778)] = 114875,
  [SMALL_STATE(1779)] = 114895,
  [SMALL_STATE(1780)] = 114917,
  [SMALL_STATE(1781)] = 114937,
  [SMALL_STATE(1782)] = 114959,
  [SMALL_STATE(1783)] = 114977,
  [SMALL_STATE(1784)] = 114997,
  [SMALL_STATE(1785)] = 115017,
  [SMALL_STATE(1786)] = 115033,
  [SMALL_STATE(1787)] = 115053,
  [SMALL_STATE(1788)] = 115073,
  [SMALL_STATE(1789)] = 115093,
  [SMALL_STATE(1790)] = 115115,
  [SMALL_STATE(1791)] = 115135,
  [SMALL_STATE(1792)] = 115155,
  [SMALL_STATE(1793)] = 115177,
  [SMALL_STATE(1794)] = 115197,
  [SMALL_STATE(1795)] = 115217,
  [SMALL_STATE(1796)] = 115237,
  [SMALL_STATE(1797)] = 115255,
  [SMALL_STATE(1798)] = 115277,
  [SMALL_STATE(1799)] = 115299,
  [SMALL_STATE(1800)] = 115321,
  [SMALL_STATE(1801)] = 115341,
  [SMALL_STATE(1802)] = 115363,
  [SMALL_STATE(1803)] = 115383,
  [SMALL_STATE(1804)] = 115405,
  [SMALL_STATE(1805)] = 115427,
  [SMALL_STATE(1806)] = 115447,
  [SMALL_STATE(1807)] = 115469,
  [SMALL_STATE(1808)] = 115489,
  [SMALL_STATE(1809)] = 115509,
  [SMALL_STATE(1810)] = 115527,
  [SMALL_STATE(1811)] = 115541,
  [SMALL_STATE(1812)] = 115563,
  [SMALL_STATE(1813)] = 115583,
  [SMALL_STATE(1814)] = 115602,
  [SMALL_STATE(1815)] = 115619,
  [SMALL_STATE(1816)] = 115634,
  [SMALL_STATE(1817)] = 115651,
  [SMALL_STATE(1818)] = 115664,
  [SMALL_STATE(1819)] = 115683,
  [SMALL_STATE(1820)] = 115700,
  [SMALL_STATE(1821)] = 115717,
  [SMALL_STATE(1822)] = 115734,
  [SMALL_STATE(1823)] = 115751,
  [SMALL_STATE(1824)] = 115770,
  [SMALL_STATE(1825)] = 115783,
  [SMALL_STATE(1826)] = 115800,
  [SMALL_STATE(1827)] = 115817,
  [SMALL_STATE(1828)] = 115836,
  [SMALL_STATE(1829)] = 115855,
  [SMALL_STATE(1830)] = 115872,
  [SMALL_STATE(1831)] = 115891,
  [SMALL_STATE(1832)] = 115910,
  [SMALL_STATE(1833)] = 115929,
  [SMALL_STATE(1834)] = 115948,
  [SMALL_STATE(1835)] = 115967,
  [SMALL_STATE(1836)] = 115986,
  [SMALL_STATE(1837)] = 115997,
  [SMALL_STATE(1838)] = 116016,
  [SMALL_STATE(1839)] = 116035,
  [SMALL_STATE(1840)] = 116052,
  [SMALL_STATE(1841)] = 116063,
  [SMALL_STATE(1842)] = 116076,
  [SMALL_STATE(1843)] = 116093,
  [SMALL_STATE(1844)] = 116104,
  [SMALL_STATE(1845)] = 116121,
  [SMALL_STATE(1846)] = 116132,
  [SMALL_STATE(1847)] = 116145,
  [SMALL_STATE(1848)] = 116162,
  [SMALL_STATE(1849)] = 116173,
  [SMALL_STATE(1850)] = 116190,
  [SMALL_STATE(1851)] = 116201,
  [SMALL_STATE(1852)] = 116214,
  [SMALL_STATE(1853)] = 116225,
  [SMALL_STATE(1854)] = 116244,
  [SMALL_STATE(1855)] = 116263,
  [SMALL_STATE(1856)] = 116282,
  [SMALL_STATE(1857)] = 116301,
  [SMALL_STATE(1858)] = 116320,
  [SMALL_STATE(1859)] = 116337,
  [SMALL_STATE(1860)] = 116354,
  [SMALL_STATE(1861)] = 116367,
  [SMALL_STATE(1862)] = 116384,
  [SMALL_STATE(1863)] = 116401,
  [SMALL_STATE(1864)] = 116418,
  [SMALL_STATE(1865)] = 116435,
  [SMALL_STATE(1866)] = 116448,
  [SMALL_STATE(1867)] = 116461,
  [SMALL_STATE(1868)] = 116472,
  [SMALL_STATE(1869)] = 116491,
  [SMALL_STATE(1870)] = 116502,
  [SMALL_STATE(1871)] = 116521,
  [SMALL_STATE(1872)] = 116540,
  [SMALL_STATE(1873)] = 116559,
  [SMALL_STATE(1874)] = 116570,
  [SMALL_STATE(1875)] = 116581,
  [SMALL_STATE(1876)] = 116592,
  [SMALL_STATE(1877)] = 116611,
  [SMALL_STATE(1878)] = 116622,
  [SMALL_STATE(1879)] = 116633,
  [SMALL_STATE(1880)] = 116644,
  [SMALL_STATE(1881)] = 116663,
  [SMALL_STATE(1882)] = 116682,
  [SMALL_STATE(1883)] = 116701,
  [SMALL_STATE(1884)] = 116720,
  [SMALL_STATE(1885)] = 116737,
  [SMALL_STATE(1886)] = 116756,
  [SMALL_STATE(1887)] = 116775,
  [SMALL_STATE(1888)] = 116794,
  [SMALL_STATE(1889)] = 116813,
  [SMALL_STATE(1890)] = 116824,
  [SMALL_STATE(1891)] = 116835,
  [SMALL_STATE(1892)] = 116846,
  [SMALL_STATE(1893)] = 116857,
  [SMALL_STATE(1894)] = 116868,
  [SMALL_STATE(1895)] = 116879,
  [SMALL_STATE(1896)] = 116890,
  [SMALL_STATE(1897)] = 116907,
  [SMALL_STATE(1898)] = 116918,
  [SMALL_STATE(1899)] = 116929,
  [SMALL_STATE(1900)] = 116940,
  [SMALL_STATE(1901)] = 116951,
  [SMALL_STATE(1902)] = 116964,
  [SMALL_STATE(1903)] = 116975,
  [SMALL_STATE(1904)] = 116992,
  [SMALL_STATE(1905)] = 117009,
  [SMALL_STATE(1906)] = 117026,
  [SMALL_STATE(1907)] = 117045,
  [SMALL_STATE(1908)] = 117058,
  [SMALL_STATE(1909)] = 117077,
  [SMALL_STATE(1910)] = 117096,
  [SMALL_STATE(1911)] = 117115,
  [SMALL_STATE(1912)] = 117134,
  [SMALL_STATE(1913)] = 117153,
  [SMALL_STATE(1914)] = 117172,
  [SMALL_STATE(1915)] = 117191,
  [SMALL_STATE(1916)] = 117204,
  [SMALL_STATE(1917)] = 117217,
  [SMALL_STATE(1918)] = 117234,
  [SMALL_STATE(1919)] = 117253,
  [SMALL_STATE(1920)] = 117272,
  [SMALL_STATE(1921)] = 117291,
  [SMALL_STATE(1922)] = 117308,
  [SMALL_STATE(1923)] = 117319,
  [SMALL_STATE(1924)] = 117336,
  [SMALL_STATE(1925)] = 117347,
  [SMALL_STATE(1926)] = 117366,
  [SMALL_STATE(1927)] = 117377,
  [SMALL_STATE(1928)] = 117394,
  [SMALL_STATE(1929)] = 117413,
  [SMALL_STATE(1930)] = 117430,
  [SMALL_STATE(1931)] = 117449,
  [SMALL_STATE(1932)] = 117468,
  [SMALL_STATE(1933)] = 117487,
  [SMALL_STATE(1934)] = 117506,
  [SMALL_STATE(1935)] = 117525,
  [SMALL_STATE(1936)] = 117544,
  [SMALL_STATE(1937)] = 117563,
  [SMALL_STATE(1938)] = 117580,
  [SMALL_STATE(1939)] = 117597,
  [SMALL_STATE(1940)] = 117614,
  [SMALL_STATE(1941)] = 117633,
  [SMALL_STATE(1942)] = 117652,
  [SMALL_STATE(1943)] = 117671,
  [SMALL_STATE(1944)] = 117690,
  [SMALL_STATE(1945)] = 117709,
  [SMALL_STATE(1946)] = 117726,
  [SMALL_STATE(1947)] = 117736,
  [SMALL_STATE(1948)] = 117746,
  [SMALL_STATE(1949)] = 117760,
  [SMALL_STATE(1950)] = 117774,
  [SMALL_STATE(1951)] = 117788,
  [SMALL_STATE(1952)] = 117804,
  [SMALL_STATE(1953)] = 117818,
  [SMALL_STATE(1954)] = 117832,
  [SMALL_STATE(1955)] = 117846,
  [SMALL_STATE(1956)] = 117862,
  [SMALL_STATE(1957)] = 117872,
  [SMALL_STATE(1958)] = 117886,
  [SMALL_STATE(1959)] = 117896,
  [SMALL_STATE(1960)] = 117910,
  [SMALL_STATE(1961)] = 117924,
  [SMALL_STATE(1962)] = 117938,
  [SMALL_STATE(1963)] = 117954,
  [SMALL_STATE(1964)] = 117968,
  [SMALL_STATE(1965)] = 117980,
  [SMALL_STATE(1966)] = 117996,
  [SMALL_STATE(1967)] = 118010,
  [SMALL_STATE(1968)] = 118024,
  [SMALL_STATE(1969)] = 118038,
  [SMALL_STATE(1970)] = 118052,
  [SMALL_STATE(1971)] = 118066,
  [SMALL_STATE(1972)] = 118080,
  [SMALL_STATE(1973)] = 118090,
  [SMALL_STATE(1974)] = 118100,
  [SMALL_STATE(1975)] = 118110,
  [SMALL_STATE(1976)] = 118124,
  [SMALL_STATE(1977)] = 118134,
  [SMALL_STATE(1978)] = 118150,
  [SMALL_STATE(1979)] = 118164,
  [SMALL_STATE(1980)] = 118174,
  [SMALL_STATE(1981)] = 118188,
  [SMALL_STATE(1982)] = 118202,
  [SMALL_STATE(1983)] = 118216,
  [SMALL_STATE(1984)] = 118230,
  [SMALL_STATE(1985)] = 118246,
  [SMALL_STATE(1986)] = 118262,
  [SMALL_STATE(1987)] = 118276,
  [SMALL_STATE(1988)] = 118290,
  [SMALL_STATE(1989)] = 118306,
  [SMALL_STATE(1990)] = 118316,
  [SMALL_STATE(1991)] = 118330,
  [SMALL_STATE(1992)] = 118344,
  [SMALL_STATE(1993)] = 118354,
  [SMALL_STATE(1994)] = 118368,
  [SMALL_STATE(1995)] = 118378,
  [SMALL_STATE(1996)] = 118388,
  [SMALL_STATE(1997)] = 118398,
  [SMALL_STATE(1998)] = 118412,
  [SMALL_STATE(1999)] = 118426,
  [SMALL_STATE(2000)] = 118440,
  [SMALL_STATE(2001)] = 118456,
  [SMALL_STATE(2002)] = 118466,
  [SMALL_STATE(2003)] = 118480,
  [SMALL_STATE(2004)] = 118496,
  [SMALL_STATE(2005)] = 118510,
  [SMALL_STATE(2006)] = 118524,
  [SMALL_STATE(2007)] = 118538,
  [SMALL_STATE(2008)] = 118552,
  [SMALL_STATE(2009)] = 118566,
  [SMALL_STATE(2010)] = 118580,
  [SMALL_STATE(2011)] = 118590,
  [SMALL_STATE(2012)] = 118604,
  [SMALL_STATE(2013)] = 118618,
  [SMALL_STATE(2014)] = 118632,
  [SMALL_STATE(2015)] = 118648,
  [SMALL_STATE(2016)] = 118662,
  [SMALL_STATE(2017)] = 118678,
  [SMALL_STATE(2018)] = 118692,
  [SMALL_STATE(2019)] = 118706,
  [SMALL_STATE(2020)] = 118720,
  [SMALL_STATE(2021)] = 118734,
  [SMALL_STATE(2022)] = 118750,
  [SMALL_STATE(2023)] = 118764,
  [SMALL_STATE(2024)] = 118778,
  [SMALL_STATE(2025)] = 118792,
  [SMALL_STATE(2026)] = 118802,
  [SMALL_STATE(2027)] = 118812,
  [SMALL_STATE(2028)] = 118826,
  [SMALL_STATE(2029)] = 118840,
  [SMALL_STATE(2030)] = 118854,
  [SMALL_STATE(2031)] = 118868,
  [SMALL_STATE(2032)] = 118882,
  [SMALL_STATE(2033)] = 118896,
  [SMALL_STATE(2034)] = 118909,
  [SMALL_STATE(2035)] = 118922,
  [SMALL_STATE(2036)] = 118935,
  [SMALL_STATE(2037)] = 118948,
  [SMALL_STATE(2038)] = 118961,
  [SMALL_STATE(2039)] = 118974,
  [SMALL_STATE(2040)] = 118987,
  [SMALL_STATE(2041)] = 119000,
  [SMALL_STATE(2042)] = 119013,
  [SMALL_STATE(2043)] = 119026,
  [SMALL_STATE(2044)] = 119035,
  [SMALL_STATE(2045)] = 119048,
  [SMALL_STATE(2046)] = 119061,
  [SMALL_STATE(2047)] = 119074,
  [SMALL_STATE(2048)] = 119087,
  [SMALL_STATE(2049)] = 119100,
  [SMALL_STATE(2050)] = 119113,
  [SMALL_STATE(2051)] = 119126,
  [SMALL_STATE(2052)] = 119139,
  [SMALL_STATE(2053)] = 119152,
  [SMALL_STATE(2054)] = 119165,
  [SMALL_STATE(2055)] = 119178,
  [SMALL_STATE(2056)] = 119191,
  [SMALL_STATE(2057)] = 119204,
  [SMALL_STATE(2058)] = 119217,
  [SMALL_STATE(2059)] = 119230,
  [SMALL_STATE(2060)] = 119243,
  [SMALL_STATE(2061)] = 119256,
  [SMALL_STATE(2062)] = 119269,
  [SMALL_STATE(2063)] = 119282,
  [SMALL_STATE(2064)] = 119295,
  [SMALL_STATE(2065)] = 119308,
  [SMALL_STATE(2066)] = 119321,
  [SMALL_STATE(2067)] = 119334,
  [SMALL_STATE(2068)] = 119347,
  [SMALL_STATE(2069)] = 119360,
  [SMALL_STATE(2070)] = 119373,
  [SMALL_STATE(2071)] = 119386,
  [SMALL_STATE(2072)] = 119399,
  [SMALL_STATE(2073)] = 119412,
  [SMALL_STATE(2074)] = 119425,
  [SMALL_STATE(2075)] = 119438,
  [SMALL_STATE(2076)] = 119451,
  [SMALL_STATE(2077)] = 119464,
  [SMALL_STATE(2078)] = 119477,
  [SMALL_STATE(2079)] = 119490,
  [SMALL_STATE(2080)] = 119503,
  [SMALL_STATE(2081)] = 119516,
  [SMALL_STATE(2082)] = 119529,
  [SMALL_STATE(2083)] = 119542,
  [SMALL_STATE(2084)] = 119555,
  [SMALL_STATE(2085)] = 119568,
  [SMALL_STATE(2086)] = 119581,
  [SMALL_STATE(2087)] = 119594,
  [SMALL_STATE(2088)] = 119607,
  [SMALL_STATE(2089)] = 119620,
  [SMALL_STATE(2090)] = 119633,
  [SMALL_STATE(2091)] = 119646,
  [SMALL_STATE(2092)] = 119659,
  [SMALL_STATE(2093)] = 119672,
  [SMALL_STATE(2094)] = 119685,
  [SMALL_STATE(2095)] = 119698,
  [SMALL_STATE(2096)] = 119711,
  [SMALL_STATE(2097)] = 119722,
  [SMALL_STATE(2098)] = 119735,
  [SMALL_STATE(2099)] = 119748,
  [SMALL_STATE(2100)] = 119761,
  [SMALL_STATE(2101)] = 119774,
  [SMALL_STATE(2102)] = 119787,
  [SMALL_STATE(2103)] = 119800,
  [SMALL_STATE(2104)] = 119813,
  [SMALL_STATE(2105)] = 119826,
  [SMALL_STATE(2106)] = 119839,
  [SMALL_STATE(2107)] = 119852,
  [SMALL_STATE(2108)] = 119865,
  [SMALL_STATE(2109)] = 119878,
  [SMALL_STATE(2110)] = 119889,
  [SMALL_STATE(2111)] = 119902,
  [SMALL_STATE(2112)] = 119913,
  [SMALL_STATE(2113)] = 119926,
  [SMALL_STATE(2114)] = 119939,
  [SMALL_STATE(2115)] = 119952,
  [SMALL_STATE(2116)] = 119965,
  [SMALL_STATE(2117)] = 119978,
  [SMALL_STATE(2118)] = 119991,
  [SMALL_STATE(2119)] = 120004,
  [SMALL_STATE(2120)] = 120017,
  [SMALL_STATE(2121)] = 120030,
  [SMALL_STATE(2122)] = 120043,
  [SMALL_STATE(2123)] = 120056,
  [SMALL_STATE(2124)] = 120069,
  [SMALL_STATE(2125)] = 120082,
  [SMALL_STATE(2126)] = 120095,
  [SMALL_STATE(2127)] = 120108,
  [SMALL_STATE(2128)] = 120121,
  [SMALL_STATE(2129)] = 120134,
  [SMALL_STATE(2130)] = 120147,
  [SMALL_STATE(2131)] = 120160,
  [SMALL_STATE(2132)] = 120173,
  [SMALL_STATE(2133)] = 120186,
  [SMALL_STATE(2134)] = 120199,
  [SMALL_STATE(2135)] = 120212,
  [SMALL_STATE(2136)] = 120225,
  [SMALL_STATE(2137)] = 120238,
  [SMALL_STATE(2138)] = 120251,
  [SMALL_STATE(2139)] = 120264,
  [SMALL_STATE(2140)] = 120277,
  [SMALL_STATE(2141)] = 120290,
  [SMALL_STATE(2142)] = 120303,
  [SMALL_STATE(2143)] = 120316,
  [SMALL_STATE(2144)] = 120329,
  [SMALL_STATE(2145)] = 120342,
  [SMALL_STATE(2146)] = 120351,
  [SMALL_STATE(2147)] = 120364,
  [SMALL_STATE(2148)] = 120375,
  [SMALL_STATE(2149)] = 120388,
  [SMALL_STATE(2150)] = 120401,
  [SMALL_STATE(2151)] = 120414,
  [SMALL_STATE(2152)] = 120427,
  [SMALL_STATE(2153)] = 120440,
  [SMALL_STATE(2154)] = 120453,
  [SMALL_STATE(2155)] = 120466,
  [SMALL_STATE(2156)] = 120479,
  [SMALL_STATE(2157)] = 120492,
  [SMALL_STATE(2158)] = 120505,
  [SMALL_STATE(2159)] = 120518,
  [SMALL_STATE(2160)] = 120531,
  [SMALL_STATE(2161)] = 120544,
  [SMALL_STATE(2162)] = 120557,
  [SMALL_STATE(2163)] = 120570,
  [SMALL_STATE(2164)] = 120583,
  [SMALL_STATE(2165)] = 120596,
  [SMALL_STATE(2166)] = 120609,
  [SMALL_STATE(2167)] = 120622,
  [SMALL_STATE(2168)] = 120635,
  [SMALL_STATE(2169)] = 120648,
  [SMALL_STATE(2170)] = 120661,
  [SMALL_STATE(2171)] = 120674,
  [SMALL_STATE(2172)] = 120687,
  [SMALL_STATE(2173)] = 120700,
  [SMALL_STATE(2174)] = 120711,
  [SMALL_STATE(2175)] = 120724,
  [SMALL_STATE(2176)] = 120737,
  [SMALL_STATE(2177)] = 120750,
  [SMALL_STATE(2178)] = 120763,
  [SMALL_STATE(2179)] = 120776,
  [SMALL_STATE(2180)] = 120789,
  [SMALL_STATE(2181)] = 120802,
  [SMALL_STATE(2182)] = 120815,
  [SMALL_STATE(2183)] = 120828,
  [SMALL_STATE(2184)] = 120841,
  [SMALL_STATE(2185)] = 120854,
  [SMALL_STATE(2186)] = 120867,
  [SMALL_STATE(2187)] = 120880,
  [SMALL_STATE(2188)] = 120893,
  [SMALL_STATE(2189)] = 120906,
  [SMALL_STATE(2190)] = 120919,
  [SMALL_STATE(2191)] = 120930,
  [SMALL_STATE(2192)] = 120943,
  [SMALL_STATE(2193)] = 120956,
  [SMALL_STATE(2194)] = 120969,
  [SMALL_STATE(2195)] = 120982,
  [SMALL_STATE(2196)] = 120995,
  [SMALL_STATE(2197)] = 121008,
  [SMALL_STATE(2198)] = 121021,
  [SMALL_STATE(2199)] = 121034,
  [SMALL_STATE(2200)] = 121047,
  [SMALL_STATE(2201)] = 121060,
  [SMALL_STATE(2202)] = 121071,
  [SMALL_STATE(2203)] = 121084,
  [SMALL_STATE(2204)] = 121097,
  [SMALL_STATE(2205)] = 121110,
  [SMALL_STATE(2206)] = 121123,
  [SMALL_STATE(2207)] = 121136,
  [SMALL_STATE(2208)] = 121149,
  [SMALL_STATE(2209)] = 121162,
  [SMALL_STATE(2210)] = 121175,
  [SMALL_STATE(2211)] = 121186,
  [SMALL_STATE(2212)] = 121199,
  [SMALL_STATE(2213)] = 121212,
  [SMALL_STATE(2214)] = 121225,
  [SMALL_STATE(2215)] = 121238,
  [SMALL_STATE(2216)] = 121251,
  [SMALL_STATE(2217)] = 121264,
  [SMALL_STATE(2218)] = 121277,
  [SMALL_STATE(2219)] = 121290,
  [SMALL_STATE(2220)] = 121303,
  [SMALL_STATE(2221)] = 121316,
  [SMALL_STATE(2222)] = 121327,
  [SMALL_STATE(2223)] = 121340,
  [SMALL_STATE(2224)] = 121353,
  [SMALL_STATE(2225)] = 121366,
  [SMALL_STATE(2226)] = 121377,
  [SMALL_STATE(2227)] = 121390,
  [SMALL_STATE(2228)] = 121403,
  [SMALL_STATE(2229)] = 121416,
  [SMALL_STATE(2230)] = 121429,
  [SMALL_STATE(2231)] = 121442,
  [SMALL_STATE(2232)] = 121455,
  [SMALL_STATE(2233)] = 121466,
  [SMALL_STATE(2234)] = 121475,
  [SMALL_STATE(2235)] = 121488,
  [SMALL_STATE(2236)] = 121501,
  [SMALL_STATE(2237)] = 121514,
  [SMALL_STATE(2238)] = 121525,
  [SMALL_STATE(2239)] = 121538,
  [SMALL_STATE(2240)] = 121551,
  [SMALL_STATE(2241)] = 121559,
  [SMALL_STATE(2242)] = 121569,
  [SMALL_STATE(2243)] = 121579,
  [SMALL_STATE(2244)] = 121587,
  [SMALL_STATE(2245)] = 121595,
  [SMALL_STATE(2246)] = 121603,
  [SMALL_STATE(2247)] = 121611,
  [SMALL_STATE(2248)] = 121621,
  [SMALL_STATE(2249)] = 121631,
  [SMALL_STATE(2250)] = 121641,
  [SMALL_STATE(2251)] = 121651,
  [SMALL_STATE(2252)] = 121661,
  [SMALL_STATE(2253)] = 121669,
  [SMALL_STATE(2254)] = 121679,
  [SMALL_STATE(2255)] = 121689,
  [SMALL_STATE(2256)] = 121699,
  [SMALL_STATE(2257)] = 121709,
  [SMALL_STATE(2258)] = 121719,
  [SMALL_STATE(2259)] = 121729,
  [SMALL_STATE(2260)] = 121739,
  [SMALL_STATE(2261)] = 121749,
  [SMALL_STATE(2262)] = 121759,
  [SMALL_STATE(2263)] = 121769,
  [SMALL_STATE(2264)] = 121779,
  [SMALL_STATE(2265)] = 121789,
  [SMALL_STATE(2266)] = 121799,
  [SMALL_STATE(2267)] = 121807,
  [SMALL_STATE(2268)] = 121817,
  [SMALL_STATE(2269)] = 121825,
  [SMALL_STATE(2270)] = 121833,
  [SMALL_STATE(2271)] = 121841,
  [SMALL_STATE(2272)] = 121851,
  [SMALL_STATE(2273)] = 121861,
  [SMALL_STATE(2274)] = 121869,
  [SMALL_STATE(2275)] = 121877,
  [SMALL_STATE(2276)] = 121885,
  [SMALL_STATE(2277)] = 121895,
  [SMALL_STATE(2278)] = 121905,
  [SMALL_STATE(2279)] = 121915,
  [SMALL_STATE(2280)] = 121923,
  [SMALL_STATE(2281)] = 121931,
  [SMALL_STATE(2282)] = 121941,
  [SMALL_STATE(2283)] = 121951,
  [SMALL_STATE(2284)] = 121961,
  [SMALL_STATE(2285)] = 121969,
  [SMALL_STATE(2286)] = 121977,
  [SMALL_STATE(2287)] = 121985,
  [SMALL_STATE(2288)] = 121995,
  [SMALL_STATE(2289)] = 122005,
  [SMALL_STATE(2290)] = 122013,
  [SMALL_STATE(2291)] = 122023,
  [SMALL_STATE(2292)] = 122033,
  [SMALL_STATE(2293)] = 122043,
  [SMALL_STATE(2294)] = 122051,
  [SMALL_STATE(2295)] = 122059,
  [SMALL_STATE(2296)] = 122069,
  [SMALL_STATE(2297)] = 122077,
  [SMALL_STATE(2298)] = 122087,
  [SMALL_STATE(2299)] = 122095,
  [SMALL_STATE(2300)] = 122105,
  [SMALL_STATE(2301)] = 122115,
  [SMALL_STATE(2302)] = 122125,
  [SMALL_STATE(2303)] = 122133,
  [SMALL_STATE(2304)] = 122143,
  [SMALL_STATE(2305)] = 122151,
  [SMALL_STATE(2306)] = 122161,
  [SMALL_STATE(2307)] = 122169,
  [SMALL_STATE(2308)] = 122177,
  [SMALL_STATE(2309)] = 122187,
  [SMALL_STATE(2310)] = 122197,
  [SMALL_STATE(2311)] = 122207,
  [SMALL_STATE(2312)] = 122217,
  [SMALL_STATE(2313)] = 122227,
  [SMALL_STATE(2314)] = 122235,
  [SMALL_STATE(2315)] = 122243,
  [SMALL_STATE(2316)] = 122253,
  [SMALL_STATE(2317)] = 122261,
  [SMALL_STATE(2318)] = 122271,
  [SMALL_STATE(2319)] = 122279,
  [SMALL_STATE(2320)] = 122289,
  [SMALL_STATE(2321)] = 122299,
  [SMALL_STATE(2322)] = 122309,
  [SMALL_STATE(2323)] = 122319,
  [SMALL_STATE(2324)] = 122329,
  [SMALL_STATE(2325)] = 122339,
  [SMALL_STATE(2326)] = 122349,
  [SMALL_STATE(2327)] = 122359,
  [SMALL_STATE(2328)] = 122369,
  [SMALL_STATE(2329)] = 122377,
  [SMALL_STATE(2330)] = 122385,
  [SMALL_STATE(2331)] = 122393,
  [SMALL_STATE(2332)] = 122401,
  [SMALL_STATE(2333)] = 122411,
  [SMALL_STATE(2334)] = 122419,
  [SMALL_STATE(2335)] = 122427,
  [SMALL_STATE(2336)] = 122437,
  [SMALL_STATE(2337)] = 122445,
  [SMALL_STATE(2338)] = 122455,
  [SMALL_STATE(2339)] = 122465,
  [SMALL_STATE(2340)] = 122475,
  [SMALL_STATE(2341)] = 122485,
  [SMALL_STATE(2342)] = 122495,
  [SMALL_STATE(2343)] = 122505,
  [SMALL_STATE(2344)] = 122515,
  [SMALL_STATE(2345)] = 122525,
  [SMALL_STATE(2346)] = 122535,
  [SMALL_STATE(2347)] = 122545,
  [SMALL_STATE(2348)] = 122555,
  [SMALL_STATE(2349)] = 122565,
  [SMALL_STATE(2350)] = 122575,
  [SMALL_STATE(2351)] = 122585,
  [SMALL_STATE(2352)] = 122595,
  [SMALL_STATE(2353)] = 122605,
  [SMALL_STATE(2354)] = 122615,
  [SMALL_STATE(2355)] = 122625,
  [SMALL_STATE(2356)] = 122635,
  [SMALL_STATE(2357)] = 122645,
  [SMALL_STATE(2358)] = 122655,
  [SMALL_STATE(2359)] = 122665,
  [SMALL_STATE(2360)] = 122675,
  [SMALL_STATE(2361)] = 122685,
  [SMALL_STATE(2362)] = 122695,
  [SMALL_STATE(2363)] = 122705,
  [SMALL_STATE(2364)] = 122715,
  [SMALL_STATE(2365)] = 122722,
  [SMALL_STATE(2366)] = 122729,
  [SMALL_STATE(2367)] = 122736,
  [SMALL_STATE(2368)] = 122743,
  [SMALL_STATE(2369)] = 122750,
  [SMALL_STATE(2370)] = 122757,
  [SMALL_STATE(2371)] = 122764,
  [SMALL_STATE(2372)] = 122771,
  [SMALL_STATE(2373)] = 122778,
  [SMALL_STATE(2374)] = 122785,
  [SMALL_STATE(2375)] = 122792,
  [SMALL_STATE(2376)] = 122799,
  [SMALL_STATE(2377)] = 122806,
  [SMALL_STATE(2378)] = 122813,
  [SMALL_STATE(2379)] = 122820,
  [SMALL_STATE(2380)] = 122827,
  [SMALL_STATE(2381)] = 122834,
  [SMALL_STATE(2382)] = 122841,
  [SMALL_STATE(2383)] = 122848,
  [SMALL_STATE(2384)] = 122855,
  [SMALL_STATE(2385)] = 122862,
  [SMALL_STATE(2386)] = 122869,
  [SMALL_STATE(2387)] = 122876,
  [SMALL_STATE(2388)] = 122883,
  [SMALL_STATE(2389)] = 122890,
  [SMALL_STATE(2390)] = 122897,
  [SMALL_STATE(2391)] = 122904,
  [SMALL_STATE(2392)] = 122911,
  [SMALL_STATE(2393)] = 122918,
  [SMALL_STATE(2394)] = 122925,
  [SMALL_STATE(2395)] = 122932,
  [SMALL_STATE(2396)] = 122939,
  [SMALL_STATE(2397)] = 122946,
  [SMALL_STATE(2398)] = 122953,
  [SMALL_STATE(2399)] = 122960,
  [SMALL_STATE(2400)] = 122967,
  [SMALL_STATE(2401)] = 122974,
  [SMALL_STATE(2402)] = 122981,
  [SMALL_STATE(2403)] = 122988,
  [SMALL_STATE(2404)] = 122995,
  [SMALL_STATE(2405)] = 123002,
  [SMALL_STATE(2406)] = 123009,
  [SMALL_STATE(2407)] = 123016,
  [SMALL_STATE(2408)] = 123023,
  [SMALL_STATE(2409)] = 123030,
  [SMALL_STATE(2410)] = 123037,
  [SMALL_STATE(2411)] = 123044,
  [SMALL_STATE(2412)] = 123051,
  [SMALL_STATE(2413)] = 123058,
  [SMALL_STATE(2414)] = 123065,
  [SMALL_STATE(2415)] = 123072,
  [SMALL_STATE(2416)] = 123079,
  [SMALL_STATE(2417)] = 123086,
  [SMALL_STATE(2418)] = 123093,
  [SMALL_STATE(2419)] = 123100,
  [SMALL_STATE(2420)] = 123107,
  [SMALL_STATE(2421)] = 123114,
  [SMALL_STATE(2422)] = 123121,
  [SMALL_STATE(2423)] = 123128,
  [SMALL_STATE(2424)] = 123135,
  [SMALL_STATE(2425)] = 123142,
  [SMALL_STATE(2426)] = 123149,
  [SMALL_STATE(2427)] = 123156,
  [SMALL_STATE(2428)] = 123163,
  [SMALL_STATE(2429)] = 123170,
  [SMALL_STATE(2430)] = 123177,
  [SMALL_STATE(2431)] = 123184,
  [SMALL_STATE(2432)] = 123191,
  [SMALL_STATE(2433)] = 123198,
  [SMALL_STATE(2434)] = 123205,
  [SMALL_STATE(2435)] = 123212,
  [SMALL_STATE(2436)] = 123219,
  [SMALL_STATE(2437)] = 123226,
  [SMALL_STATE(2438)] = 123233,
  [SMALL_STATE(2439)] = 123240,
  [SMALL_STATE(2440)] = 123247,
  [SMALL_STATE(2441)] = 123254,
  [SMALL_STATE(2442)] = 123261,
  [SMALL_STATE(2443)] = 123268,
  [SMALL_STATE(2444)] = 123275,
  [SMALL_STATE(2445)] = 123282,
  [SMALL_STATE(2446)] = 123289,
  [SMALL_STATE(2447)] = 123296,
  [SMALL_STATE(2448)] = 123303,
  [SMALL_STATE(2449)] = 123310,
  [SMALL_STATE(2450)] = 123317,
};

static const TSParseActionEntry ts_parse_actions[] = {
  [0] = {.entry = {.count = 0, .reusable = false}},
  [1] = {.entry = {.count = 1, .reusable = false}}, RECOVER(),
  [3] = {.entry = {.count = 1, .reusable = true}}, SHIFT_EXTRA(),
  [5] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_script, 0, 0, 0),
  [7] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1864),
  [9] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2334),
  [11] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2339),
  [13] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2254),
  [15] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2262),
  [17] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2276),
  [19] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1986),
  [21] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2281),
  [23] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2194),
  [25] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1513),
  [27] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2209),
  [29] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2212),
  [31] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2356),
  [33] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2442),
  [35] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2384),
  [37] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1861),
  [39] = {.entry = {.count = 1, .reusable = true}}, SHIFT(248),
  [41] = {.entry = {.count = 1, .reusable = false}}, SHIFT(304),
  [43] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2372),
  [45] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_address, 1, 0, 0), SHIFT(1191),
  [48] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_address, 1, 0, 0), SHIFT(216),
  [51] = {.entry = {.count = 1, .reusable = true}}, SHIFT(217),
  [53] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_address, 1, 0, 0),
  [55] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_address, 1, 0, 0),
  [57] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_address, 1, 0, 0), SHIFT(162),
  [60] = {.entry = {.count = 1, .reusable = true}}, SHIFT(162),
  [62] = {.entry = {.count = 1, .reusable = false}}, SHIFT(162),
  [64] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_address, 1, 0, 0), SHIFT(163),
  [67] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_address, 1, 0, 0), SHIFT(1417),
  [70] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_address, 1, 0, 0), SHIFT(2171),
  [73] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_address, 1, 0, 0), SHIFT(2420),
  [76] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2074),
  [78] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2275),
  [80] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1739),
  [82] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7),
  [84] = {.entry = {.count = 1, .reusable = false}}, SHIFT(362),
  [86] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1435),
  [88] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1372),
  [90] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1430),
  [92] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2259),
  [94] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1435),
  [96] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2428),
  [98] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1179),
  [100] = {.entry = {.count = 1, .reusable = false}}, SHIFT(382),
  [102] = {.entry = {.count = 1, .reusable = true}}, SHIFT(194),
  [104] = {.entry = {.count = 1, .reusable = true}}, SHIFT(195),
  [106] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__prefix_postfix_expression, 2, 0, 27),
  [108] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__prefix_postfix_expression, 2, 0, 27),
  [110] = {.entry = {.count = 1, .reusable = false}}, SHIFT(219),
  [112] = {.entry = {.count = 1, .reusable = true}}, SHIFT(219),
  [114] = {.entry = {.count = 1, .reusable = true}}, SHIFT(222),
  [116] = {.entry = {.count = 1, .reusable = true}}, SHIFT(459),
  [118] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2171),
  [120] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2420),
  [122] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2174),
  [124] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2246),
  [126] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1759),
  [128] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2),
  [130] = {.entry = {.count = 1, .reusable = false}}, SHIFT(388),
  [132] = {.entry = {.count = 1, .reusable = false}}, SHIFT(449),
  [134] = {.entry = {.count = 1, .reusable = true}}, SHIFT(448),
  [136] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2255),
  [138] = {.entry = {.count = 1, .reusable = true}}, SHIFT(388),
  [140] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1191),
  [142] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_address, 1, 0, 0), SHIFT(212),
  [145] = {.entry = {.count = 1, .reusable = true}}, SHIFT(213),
  [147] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2227),
  [149] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1047),
  [151] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1501),
  [153] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1501),
  [155] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2374),
  [157] = {.entry = {.count = 1, .reusable = true}}, SHIFT(204),
  [159] = {.entry = {.count = 1, .reusable = true}}, SHIFT(205),
  [161] = {.entry = {.count = 1, .reusable = false}}, SHIFT(218),
  [163] = {.entry = {.count = 1, .reusable = true}}, SHIFT(218),
  [165] = {.entry = {.count = 1, .reusable = true}}, SHIFT(223),
  [167] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1417),
  [169] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2073),
  [171] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1095),
  [173] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1210),
  [175] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1210),
  [177] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2449),
  [179] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1219),
  [181] = {.entry = {.count = 1, .reusable = true}}, SHIFT(160),
  [183] = {.entry = {.count = 1, .reusable = true}}, SHIFT(185),
  [185] = {.entry = {.count = 1, .reusable = false}}, SHIFT(197),
  [187] = {.entry = {.count = 1, .reusable = true}}, SHIFT(197),
  [189] = {.entry = {.count = 1, .reusable = true}}, SHIFT(199),
  [191] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1374),
  [193] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2200),
  [195] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2307),
  [197] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1758),
  [199] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4),
  [201] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1166),
  [203] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1397),
  [205] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1373),
  [207] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2247),
  [209] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1166),
  [211] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1161),
  [213] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_address, 1, 0, 0), SHIFT(220),
  [216] = {.entry = {.count = 1, .reusable = true}}, SHIFT(221),
  [218] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1454),
  [220] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1454),
  [222] = {.entry = {.count = 1, .reusable = true}}, SHIFT(163),
  [224] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1411),
  [226] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1411),
  [228] = {.entry = {.count = 1, .reusable = true}}, SHIFT(144),
  [230] = {.entry = {.count = 1, .reusable = false}}, SHIFT(133),
  [232] = {.entry = {.count = 1, .reusable = false}}, SHIFT(227),
  [234] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3),
  [236] = {.entry = {.count = 1, .reusable = true}}, SHIFT(229),
  [238] = {.entry = {.count = 1, .reusable = true}}, SHIFT(230),
  [240] = {.entry = {.count = 1, .reusable = true}}, SHIFT(231),
  [242] = {.entry = {.count = 1, .reusable = false}}, SHIFT(231),
  [244] = {.entry = {.count = 1, .reusable = false}}, SHIFT(237),
  [246] = {.entry = {.count = 1, .reusable = false}}, SHIFT(239),
  [248] = {.entry = {.count = 1, .reusable = true}}, SHIFT(241),
  [250] = {.entry = {.count = 1, .reusable = false}}, SHIFT(241),
  [252] = {.entry = {.count = 1, .reusable = true}}, SHIFT(193),
  [254] = {.entry = {.count = 1, .reusable = true}}, SHIFT(226),
  [256] = {.entry = {.count = 1, .reusable = true}}, SHIFT(274),
  [258] = {.entry = {.count = 1, .reusable = false}}, SHIFT(306),
  [260] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2347),
  [262] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2309),
  [264] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2310),
  [266] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2311),
  [268] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1959),
  [270] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2346),
  [272] = {.entry = {.count = 1, .reusable = true}}, SHIFT(261),
  [274] = {.entry = {.count = 1, .reusable = false}}, SHIFT(303),
  [276] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2324),
  [278] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2362),
  [280] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2241),
  [282] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2007),
  [284] = {.entry = {.count = 1, .reusable = true}}, SHIFT(281),
  [286] = {.entry = {.count = 1, .reusable = false}}, SHIFT(305),
  [288] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2326),
  [290] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2357),
  [292] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2358),
  [294] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2023),
  [296] = {.entry = {.count = 1, .reusable = true}}, SHIFT(289),
  [298] = {.entry = {.count = 1, .reusable = false}}, SHIFT(302),
  [300] = {.entry = {.count = 1, .reusable = false}}, SHIFT(778),
  [302] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_sizeof_expression, 6, 0, 85),
  [304] = {.entry = {.count = 1, .reusable = true}}, SHIFT(71),
  [306] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_hll_sizeof_expression, 6, 0, 85),
  [308] = {.entry = {.count = 1, .reusable = false}}, SHIFT(650),
  [310] = {.entry = {.count = 1, .reusable = true}}, SHIFT(650),
  [312] = {.entry = {.count = 1, .reusable = true}}, SHIFT(651),
  [314] = {.entry = {.count = 1, .reusable = false}}, SHIFT(620),
  [316] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2143),
  [318] = {.entry = {.count = 1, .reusable = false}}, SHIFT(652),
  [320] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2291),
  [322] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2011),
  [324] = {.entry = {.count = 1, .reusable = true}}, SHIFT(763),
  [326] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2264),
  [328] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2438),
  [330] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_sizeof_expression, 5, 0, 85),
  [332] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_hll_sizeof_expression, 5, 0, 85),
  [334] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_sizeof_expression, 5, 0, 67),
  [336] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_hll_sizeof_expression, 5, 0, 67),
  [338] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_sizeof_expression, 4, 0, 67),
  [340] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_hll_sizeof_expression, 4, 0, 67),
  [342] = {.entry = {.count = 1, .reusable = false}}, SHIFT(806),
  [344] = {.entry = {.count = 1, .reusable = true}}, SHIFT(67),
  [346] = {.entry = {.count = 1, .reusable = false}}, SHIFT(642),
  [348] = {.entry = {.count = 1, .reusable = true}}, SHIFT(642),
  [350] = {.entry = {.count = 1, .reusable = true}}, SHIFT(643),
  [352] = {.entry = {.count = 1, .reusable = false}}, SHIFT(577),
  [354] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2120),
  [356] = {.entry = {.count = 1, .reusable = false}}, SHIFT(644),
  [358] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2287),
  [360] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1987),
  [362] = {.entry = {.count = 1, .reusable = true}}, SHIFT(808),
  [364] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2361),
  [366] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2390),
  [368] = {.entry = {.count = 1, .reusable = false}}, SHIFT(898),
  [370] = {.entry = {.count = 1, .reusable = true}}, SHIFT(65),
  [372] = {.entry = {.count = 1, .reusable = false}}, SHIFT(631),
  [374] = {.entry = {.count = 1, .reusable = true}}, SHIFT(631),
  [376] = {.entry = {.count = 1, .reusable = true}}, SHIFT(632),
  [378] = {.entry = {.count = 1, .reusable = false}}, SHIFT(689),
  [380] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2108),
  [382] = {.entry = {.count = 1, .reusable = false}}, SHIFT(634),
  [384] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2278),
  [386] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1949),
  [388] = {.entry = {.count = 1, .reusable = true}}, SHIFT(920),
  [390] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2363),
  [392] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2392),
  [394] = {.entry = {.count = 1, .reusable = false}}, SHIFT(892),
  [396] = {.entry = {.count = 1, .reusable = true}}, SHIFT(77),
  [398] = {.entry = {.count = 1, .reusable = false}}, SHIFT(662),
  [400] = {.entry = {.count = 1, .reusable = true}}, SHIFT(662),
  [402] = {.entry = {.count = 1, .reusable = true}}, SHIFT(663),
  [404] = {.entry = {.count = 1, .reusable = false}}, SHIFT(633),
  [406] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2164),
  [408] = {.entry = {.count = 1, .reusable = false}}, SHIFT(664),
  [410] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2299),
  [412] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1948),
  [414] = {.entry = {.count = 1, .reusable = true}}, SHIFT(908),
  [416] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2242),
  [418] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2436),
  [420] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2403),
  [422] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2404),
  [424] = {.entry = {.count = 1, .reusable = true}}, SHIFT(931),
  [426] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1139),
  [428] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1139),
  [430] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__other_command, 2, 0, 3),
  [432] = {.entry = {.count = 1, .reusable = false}}, SHIFT(927),
  [434] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2403),
  [436] = {.entry = {.count = 1, .reusable = true}}, SHIFT(935),
  [438] = {.entry = {.count = 1, .reusable = false}}, SHIFT(810),
  [440] = {.entry = {.count = 1, .reusable = true}}, SHIFT(59),
  [442] = {.entry = {.count = 1, .reusable = false}}, SHIFT(618),
  [444] = {.entry = {.count = 1, .reusable = true}}, SHIFT(618),
  [446] = {.entry = {.count = 1, .reusable = true}}, SHIFT(619),
  [448] = {.entry = {.count = 1, .reusable = true}}, SHIFT(620),
  [450] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2093),
  [452] = {.entry = {.count = 1, .reusable = false}}, SHIFT(621),
  [454] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2249),
  [456] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2031),
  [458] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1526),
  [460] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2332),
  [462] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2338),
  [464] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2348),
  [466] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1672),
  [468] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1534),
  [470] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1074),
  [472] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2353),
  [474] = {.entry = {.count = 1, .reusable = true}}, SHIFT(74),
  [476] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2439),
  [478] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__command_arguments_repeat1, 2, 0, 0), SHIFT_REPEAT(1191),
  [481] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__command_arguments_repeat1, 2, 0, 0), SHIFT_REPEAT(204),
  [484] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__command_arguments_repeat1, 2, 0, 0), SHIFT_REPEAT(205),
  [487] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__command_arguments_repeat1, 2, 0, 0), SHIFT_REPEAT(162),
  [490] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__command_arguments_repeat1, 2, 0, 0), SHIFT_REPEAT(162),
  [493] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__command_arguments_repeat1, 2, 0, 0), SHIFT_REPEAT(163),
  [496] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__command_arguments_repeat1, 2, 0, 0), SHIFT_REPEAT(1417),
  [499] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__command_arguments_repeat1, 2, 0, 0), SHIFT_REPEAT(2369),
  [502] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__command_arguments_repeat1, 2, 0, 0), SHIFT_REPEAT(2073),
  [505] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__command_arguments_repeat1, 2, 0, 0), SHIFT_REPEAT(942),
  [508] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__command_arguments_repeat1, 2, 0, 0), SHIFT_REPEAT(2420),
  [511] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__command_arguments_repeat1, 2, 0, 0), SHIFT_REPEAT(2074),
  [514] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__command_arguments_repeat1, 2, 0, 0), SHIFT_REPEAT(2275),
  [517] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__command_arguments_repeat1, 2, 0, 0), SHIFT_REPEAT(1739),
  [520] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__command_arguments_repeat1, 2, 0, 0), SHIFT_REPEAT(7),
  [523] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__command_arguments_repeat1, 2, 0, 0), SHIFT_REPEAT(1095),
  [526] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__command_arguments_repeat1, 2, 0, 0), SHIFT_REPEAT(1383),
  [529] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__command_arguments_repeat1, 2, 0, 0), SHIFT_REPEAT(1372),
  [532] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__command_arguments_repeat1, 2, 0, 0), SHIFT_REPEAT(1430),
  [535] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__command_arguments_repeat1, 2, 0, 0), SHIFT_REPEAT(2259),
  [538] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__command_arguments_repeat1, 2, 0, 0), SHIFT_REPEAT(1383),
  [541] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__command_arguments_repeat1, 2, 0, 0), SHIFT_REPEAT(2449),
  [544] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__command_arguments_repeat1, 2, 0, 0), SHIFT_REPEAT(1179),
  [547] = {.entry = {.count = 1, .reusable = false}}, SHIFT(798),
  [549] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1531),
  [551] = {.entry = {.count = 1, .reusable = true}}, SHIFT(500),
  [553] = {.entry = {.count = 1, .reusable = true}}, SHIFT(40),
  [555] = {.entry = {.count = 1, .reusable = true}}, SHIFT(38),
  [557] = {.entry = {.count = 1, .reusable = true}}, SHIFT(43),
  [559] = {.entry = {.count = 1, .reusable = false}}, SHIFT(811),
  [561] = {.entry = {.count = 1, .reusable = true}}, SHIFT(49),
  [563] = {.entry = {.count = 1, .reusable = false}}, SHIFT(575),
  [565] = {.entry = {.count = 1, .reusable = true}}, SHIFT(575),
  [567] = {.entry = {.count = 1, .reusable = true}}, SHIFT(576),
  [569] = {.entry = {.count = 1, .reusable = true}}, SHIFT(577),
  [571] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2042),
  [573] = {.entry = {.count = 1, .reusable = false}}, SHIFT(578),
  [575] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2300),
  [577] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1957),
  [579] = {.entry = {.count = 1, .reusable = true}}, SHIFT(949),
  [581] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2352),
  [583] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2443),
  [585] = {.entry = {.count = 1, .reusable = true}}, SHIFT(46),
  [587] = {.entry = {.count = 1, .reusable = true}}, SHIFT(48),
  [589] = {.entry = {.count = 1, .reusable = true}}, SHIFT(50),
  [591] = {.entry = {.count = 1, .reusable = true}}, SHIFT(52),
  [593] = {.entry = {.count = 1, .reusable = true}}, SHIFT(54),
  [595] = {.entry = {.count = 1, .reusable = true}}, SHIFT(81),
  [597] = {.entry = {.count = 1, .reusable = true}}, SHIFT(934),
  [599] = {.entry = {.count = 1, .reusable = true}}, SHIFT(58),
  [601] = {.entry = {.count = 1, .reusable = true}}, SHIFT(60),
  [603] = {.entry = {.count = 1, .reusable = true}}, SHIFT(62),
  [605] = {.entry = {.count = 1, .reusable = true}}, SHIFT(64),
  [607] = {.entry = {.count = 1, .reusable = true}}, SHIFT(66),
  [609] = {.entry = {.count = 1, .reusable = true}}, SHIFT(68),
  [611] = {.entry = {.count = 1, .reusable = true}}, SHIFT(70),
  [613] = {.entry = {.count = 1, .reusable = true}}, SHIFT(72),
  [615] = {.entry = {.count = 1, .reusable = true}}, SHIFT(76),
  [617] = {.entry = {.count = 1, .reusable = true}}, SHIFT(78),
  [619] = {.entry = {.count = 1, .reusable = false}}, SHIFT(841),
  [621] = {.entry = {.count = 1, .reusable = true}}, SHIFT(69),
  [623] = {.entry = {.count = 1, .reusable = false}}, SHIFT(646),
  [625] = {.entry = {.count = 1, .reusable = true}}, SHIFT(646),
  [627] = {.entry = {.count = 1, .reusable = true}}, SHIFT(647),
  [629] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2132),
  [631] = {.entry = {.count = 1, .reusable = false}}, SHIFT(648),
  [633] = {.entry = {.count = 1, .reusable = false}}, SHIFT(889),
  [635] = {.entry = {.count = 1, .reusable = true}}, SHIFT(75),
  [637] = {.entry = {.count = 1, .reusable = false}}, SHIFT(658),
  [639] = {.entry = {.count = 1, .reusable = true}}, SHIFT(658),
  [641] = {.entry = {.count = 1, .reusable = true}}, SHIFT(659),
  [643] = {.entry = {.count = 1, .reusable = true}}, SHIFT(633),
  [645] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2162),
  [647] = {.entry = {.count = 1, .reusable = false}}, SHIFT(660),
  [649] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2295),
  [651] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2018),
  [653] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1293),
  [655] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2343),
  [657] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2445),
  [659] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1266),
  [661] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1266),
  [663] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1289),
  [665] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1289),
  [667] = {.entry = {.count = 1, .reusable = true}}, SHIFT(107),
  [669] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1201),
  [671] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1201),
  [673] = {.entry = {.count = 1, .reusable = true}}, SHIFT(93),
  [675] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1212),
  [677] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1212),
  [679] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1215),
  [681] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1215),
  [683] = {.entry = {.count = 1, .reusable = true}}, SHIFT(95),
  [685] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1141),
  [687] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1141),
  [689] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1262),
  [691] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1262),
  [693] = {.entry = {.count = 1, .reusable = true}}, SHIFT(116),
  [695] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2171),
  [697] = {.entry = {.count = 1, .reusable = false}}, SHIFT(380),
  [699] = {.entry = {.count = 1, .reusable = true}}, SHIFT(380),
  [701] = {.entry = {.count = 1, .reusable = true}}, SHIFT(100),
  [703] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1353),
  [705] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1353),
  [707] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1489),
  [709] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1514),
  [711] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1514),
  [713] = {.entry = {.count = 1, .reusable = false}}, SHIFT(373),
  [715] = {.entry = {.count = 1, .reusable = true}}, SHIFT(373),
  [717] = {.entry = {.count = 1, .reusable = false}}, SHIFT(884),
  [719] = {.entry = {.count = 1, .reusable = true}}, SHIFT(32),
  [721] = {.entry = {.count = 1, .reusable = false}}, SHIFT(654),
  [723] = {.entry = {.count = 1, .reusable = true}}, SHIFT(654),
  [725] = {.entry = {.count = 1, .reusable = true}}, SHIFT(655),
  [727] = {.entry = {.count = 1, .reusable = false}}, SHIFT(656),
  [729] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1332),
  [731] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1332),
  [733] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9),
  [735] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9),
  [737] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1339),
  [739] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1339),
  [741] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1340),
  [743] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1340),
  [745] = {.entry = {.count = 1, .reusable = true}}, SHIFT(111),
  [747] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1298),
  [749] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1499),
  [751] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1499),
  [753] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1395),
  [755] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1395),
  [757] = {.entry = {.count = 1, .reusable = true}}, SHIFT(141),
  [759] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1290),
  [761] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1290),
  [763] = {.entry = {.count = 1, .reusable = false}}, SHIFT(383),
  [765] = {.entry = {.count = 1, .reusable = true}}, SHIFT(383),
  [767] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1422),
  [769] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1422),
  [771] = {.entry = {.count = 1, .reusable = true}}, SHIFT(114),
  [773] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1423),
  [775] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1423),
  [777] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10),
  [779] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10),
  [781] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1220),
  [783] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1220),
  [785] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1236),
  [787] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1236),
  [789] = {.entry = {.count = 1, .reusable = true}}, SHIFT(121),
  [791] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1305),
  [793] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1305),
  [795] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1307),
  [797] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1450),
  [799] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1450),
  [801] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1341),
  [803] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1341),
  [805] = {.entry = {.count = 1, .reusable = true}}, SHIFT(124),
  [807] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1140),
  [809] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1140),
  [811] = {.entry = {.count = 1, .reusable = false}}, SHIFT(915),
  [813] = {.entry = {.count = 1, .reusable = true}}, SHIFT(39),
  [815] = {.entry = {.count = 1, .reusable = false}}, SHIFT(734),
  [817] = {.entry = {.count = 1, .reusable = true}}, SHIFT(734),
  [819] = {.entry = {.count = 1, .reusable = true}}, SHIFT(638),
  [821] = {.entry = {.count = 1, .reusable = true}}, SHIFT(689),
  [823] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2230),
  [825] = {.entry = {.count = 1, .reusable = false}}, SHIFT(545),
  [827] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1271),
  [829] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1271),
  [831] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1288),
  [833] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1288),
  [835] = {.entry = {.count = 1, .reusable = true}}, SHIFT(129),
  [837] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1296),
  [839] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1296),
  [841] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1306),
  [843] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1306),
  [845] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1313),
  [847] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1313),
  [849] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1357),
  [851] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1357),
  [853] = {.entry = {.count = 1, .reusable = false}}, SHIFT(366),
  [855] = {.entry = {.count = 1, .reusable = true}}, SHIFT(366),
  [857] = {.entry = {.count = 1, .reusable = true}}, SHIFT(112),
  [859] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1335),
  [861] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1335),
  [863] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1336),
  [865] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1336),
  [867] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1343),
  [869] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1343),
  [871] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1346),
  [873] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1346),
  [875] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1348),
  [877] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1348),
  [879] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11),
  [881] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11),
  [883] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12),
  [885] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12),
  [887] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1416),
  [889] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1416),
  [891] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1103),
  [893] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1177),
  [895] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1177),
  [897] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1133),
  [899] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1261),
  [901] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1261),
  [903] = {.entry = {.count = 1, .reusable = true}}, SHIFT(361),
  [905] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1152),
  [907] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1152),
  [909] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1401),
  [911] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1401),
  [913] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1202),
  [915] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1202),
  [917] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1214),
  [919] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1214),
  [921] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1216),
  [923] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1216),
  [925] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1200),
  [927] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1200),
  [929] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_memory_space, 2, 0, 30), SHIFT(1191),
  [932] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_memory_space, 2, 0, 30), SHIFT(204),
  [935] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_memory_space, 2, 0, 30), SHIFT(205),
  [938] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_memory_space, 2, 0, 30), SHIFT(162),
  [941] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_memory_space, 2, 0, 30), SHIFT(162),
  [944] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_memory_space, 2, 0, 30), SHIFT(163),
  [947] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_memory_space, 2, 0, 30), SHIFT(1417),
  [950] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_memory_space, 2, 0, 30), SHIFT(2073),
  [953] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_memory_space, 2, 0, 30), SHIFT(2420),
  [956] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_memory_space, 2, 0, 30), SHIFT(2074),
  [959] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_memory_space, 2, 0, 30), SHIFT(2275),
  [962] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_memory_space, 2, 0, 30), SHIFT(1739),
  [965] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_memory_space, 2, 0, 30), SHIFT(7),
  [968] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_memory_space, 2, 0, 30), SHIFT(1095),
  [971] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_memory_space, 2, 0, 30), SHIFT(1454),
  [974] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_memory_space, 2, 0, 30), SHIFT(1372),
  [977] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_memory_space, 2, 0, 30), SHIFT(1430),
  [980] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_memory_space, 2, 0, 30), SHIFT(2259),
  [983] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_memory_space, 2, 0, 30), SHIFT(1454),
  [986] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_memory_space, 2, 0, 30), SHIFT(2449),
  [989] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_memory_space, 2, 0, 30), SHIFT(1179),
  [992] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_memory_space, 2, 0, 31), SHIFT(1191),
  [995] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_memory_space, 2, 0, 31), SHIFT(204),
  [998] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_memory_space, 2, 0, 31), SHIFT(205),
  [1001] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_memory_space, 2, 0, 31), SHIFT(162),
  [1004] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_memory_space, 2, 0, 31), SHIFT(162),
  [1007] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_memory_space, 2, 0, 31), SHIFT(163),
  [1010] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_memory_space, 2, 0, 31), SHIFT(1417),
  [1013] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_memory_space, 2, 0, 31), SHIFT(2073),
  [1016] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_memory_space, 2, 0, 31), SHIFT(2420),
  [1019] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_memory_space, 2, 0, 31), SHIFT(2074),
  [1022] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_memory_space, 2, 0, 31), SHIFT(2275),
  [1025] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_memory_space, 2, 0, 31), SHIFT(1739),
  [1028] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_memory_space, 2, 0, 31), SHIFT(7),
  [1031] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_memory_space, 2, 0, 31), SHIFT(1095),
  [1034] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_memory_space, 2, 0, 31), SHIFT(1454),
  [1037] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_memory_space, 2, 0, 31), SHIFT(1372),
  [1040] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_memory_space, 2, 0, 31), SHIFT(1430),
  [1043] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_memory_space, 2, 0, 31), SHIFT(2259),
  [1046] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_memory_space, 2, 0, 31), SHIFT(1454),
  [1049] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_memory_space, 2, 0, 31), SHIFT(2449),
  [1052] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_memory_space, 2, 0, 31), SHIFT(1179),
  [1055] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1180),
  [1057] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1180),
  [1059] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1393),
  [1061] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1393),
  [1063] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1233),
  [1065] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1233),
  [1067] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1409),
  [1069] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1409),
  [1071] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1410),
  [1073] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1410),
  [1075] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1173),
  [1077] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1173),
  [1079] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1396),
  [1081] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1396),
  [1083] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1240),
  [1085] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1240),
  [1087] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1358),
  [1089] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1358),
  [1091] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1403),
  [1093] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1403),
  [1095] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1405),
  [1097] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1405),
  [1099] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1407),
  [1101] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1407),
  [1103] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1408),
  [1105] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1408),
  [1107] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1413),
  [1109] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1413),
  [1111] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1414),
  [1113] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1414),
  [1115] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1415),
  [1117] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1415),
  [1119] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1198),
  [1121] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1198),
  [1123] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1203),
  [1125] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1203),
  [1127] = {.entry = {.count = 1, .reusable = true}}, SHIFT(212),
  [1129] = {.entry = {.count = 1, .reusable = true}}, SHIFT(216),
  [1131] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1362),
  [1133] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1362),
  [1135] = {.entry = {.count = 1, .reusable = true}}, SHIFT(220),
  [1137] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1196),
  [1139] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1196),
  [1141] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1208),
  [1143] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1208),
  [1145] = {.entry = {.count = 1, .reusable = false}}, SHIFT(385),
  [1147] = {.entry = {.count = 1, .reusable = true}}, SHIFT(385),
  [1149] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1360),
  [1151] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1360),
  [1153] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1361),
  [1155] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1361),
  [1157] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1248),
  [1159] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1248),
  [1161] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1251),
  [1163] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1251),
  [1165] = {.entry = {.count = 1, .reusable = false}}, SHIFT(379),
  [1167] = {.entry = {.count = 1, .reusable = true}}, SHIFT(379),
  [1169] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1163),
  [1171] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1163),
  [1173] = {.entry = {.count = 3, .reusable = false}}, REDUCE(sym_memory_space, 2, 0, 31), REDUCE(sym_memory_space, 4, 0, 61), SHIFT(1191),
  [1177] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_memory_space, 2, 0, 31), REDUCE(sym_memory_space, 4, 0, 61), SHIFT(204),
  [1181] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_memory_space, 2, 0, 31), REDUCE(sym_memory_space, 4, 0, 61), SHIFT(205),
  [1185] = {.entry = {.count = 3, .reusable = false}}, REDUCE(sym_memory_space, 2, 0, 31), REDUCE(sym_memory_space, 4, 0, 61), SHIFT(162),
  [1189] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_memory_space, 2, 0, 31), REDUCE(sym_memory_space, 4, 0, 61), SHIFT(162),
  [1193] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_memory_space, 2, 0, 31), REDUCE(sym_memory_space, 4, 0, 61), SHIFT(163),
  [1197] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_memory_space, 2, 0, 31), REDUCE(sym_memory_space, 4, 0, 61), SHIFT(1417),
  [1201] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_memory_space, 2, 0, 31), REDUCE(sym_memory_space, 4, 0, 61), SHIFT(2073),
  [1205] = {.entry = {.count = 3, .reusable = false}}, REDUCE(sym_memory_space, 2, 0, 31), REDUCE(sym_memory_space, 4, 0, 61), SHIFT(2420),
  [1209] = {.entry = {.count = 3, .reusable = false}}, REDUCE(sym_memory_space, 2, 0, 31), REDUCE(sym_memory_space, 4, 0, 61), SHIFT(2074),
  [1213] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_memory_space, 2, 0, 31), REDUCE(sym_memory_space, 4, 0, 61), SHIFT(2275),
  [1217] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_memory_space, 2, 0, 31), REDUCE(sym_memory_space, 4, 0, 61), SHIFT(1739),
  [1221] = {.entry = {.count = 3, .reusable = false}}, REDUCE(sym_memory_space, 2, 0, 31), REDUCE(sym_memory_space, 4, 0, 61), SHIFT(7),
  [1225] = {.entry = {.count = 3, .reusable = false}}, REDUCE(sym_memory_space, 2, 0, 31), REDUCE(sym_memory_space, 4, 0, 61), SHIFT(1095),
  [1229] = {.entry = {.count = 3, .reusable = false}}, REDUCE(sym_memory_space, 2, 0, 31), REDUCE(sym_memory_space, 4, 0, 61), SHIFT(1454),
  [1233] = {.entry = {.count = 3, .reusable = false}}, REDUCE(sym_memory_space, 2, 0, 31), REDUCE(sym_memory_space, 4, 0, 61), SHIFT(1372),
  [1237] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_memory_space, 2, 0, 31), REDUCE(sym_memory_space, 4, 0, 61), SHIFT(1430),
  [1241] = {.entry = {.count = 3, .reusable = false}}, REDUCE(sym_memory_space, 2, 0, 31), REDUCE(sym_memory_space, 4, 0, 61), SHIFT(2259),
  [1245] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_memory_space, 2, 0, 31), REDUCE(sym_memory_space, 4, 0, 61), SHIFT(1454),
  [1249] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_memory_space, 2, 0, 31), REDUCE(sym_memory_space, 4, 0, 61), SHIFT(2449),
  [1253] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_memory_space, 2, 0, 31), REDUCE(sym_memory_space, 4, 0, 61), SHIFT(1179),
  [1257] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1426),
  [1259] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1426),
  [1261] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1427),
  [1263] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1427),
  [1265] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1228),
  [1267] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1228),
  [1269] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1149),
  [1271] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1149),
  [1273] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1157),
  [1275] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1157),
  [1277] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1170),
  [1279] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1170),
  [1281] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1239),
  [1283] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1239),
  [1285] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1245),
  [1287] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1245),
  [1289] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1160),
  [1291] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1160),
  [1293] = {.entry = {.count = 1, .reusable = false}}, SHIFT(378),
  [1295] = {.entry = {.count = 1, .reusable = true}}, SHIFT(378),
  [1297] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1238),
  [1299] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1238),
  [1301] = {.entry = {.count = 1, .reusable = false}}, SHIFT(368),
  [1303] = {.entry = {.count = 1, .reusable = true}}, SHIFT(368),
  [1305] = {.entry = {.count = 1, .reusable = false}}, SHIFT(375),
  [1307] = {.entry = {.count = 1, .reusable = true}}, SHIFT(375),
  [1309] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1243),
  [1311] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1243),
  [1313] = {.entry = {.count = 1, .reusable = false}}, SHIFT(387),
  [1315] = {.entry = {.count = 1, .reusable = true}}, SHIFT(387),
  [1317] = {.entry = {.count = 1, .reusable = false}}, SHIFT(389),
  [1319] = {.entry = {.count = 1, .reusable = true}}, SHIFT(389),
  [1321] = {.entry = {.count = 1, .reusable = false}}, SHIFT(372),
  [1323] = {.entry = {.count = 1, .reusable = true}}, SHIFT(372),
  [1325] = {.entry = {.count = 1, .reusable = false}}, SHIFT(381),
  [1327] = {.entry = {.count = 1, .reusable = true}}, SHIFT(381),
  [1329] = {.entry = {.count = 1, .reusable = false}}, SHIFT(374),
  [1331] = {.entry = {.count = 1, .reusable = true}}, SHIFT(374),
  [1333] = {.entry = {.count = 1, .reusable = false}}, SHIFT(384),
  [1335] = {.entry = {.count = 1, .reusable = true}}, SHIFT(384),
  [1337] = {.entry = {.count = 1, .reusable = false}}, SHIFT(376),
  [1339] = {.entry = {.count = 1, .reusable = true}}, SHIFT(376),
  [1341] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2313),
  [1343] = {.entry = {.count = 1, .reusable = true}}, SHIFT(244),
  [1345] = {.entry = {.count = 1, .reusable = false}}, SHIFT(298),
  [1347] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2296),
  [1349] = {.entry = {.count = 1, .reusable = true}}, SHIFT(249),
  [1351] = {.entry = {.count = 1, .reusable = false}}, SHIFT(300),
  [1353] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_script_repeat1, 2, 0, 0),
  [1355] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_script_repeat1, 2, 0, 0), SHIFT_REPEAT(1864),
  [1358] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_script_repeat1, 2, 0, 0), SHIFT_REPEAT(2334),
  [1361] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_script_repeat1, 2, 0, 0), SHIFT_REPEAT(2339),
  [1364] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_script_repeat1, 2, 0, 0), SHIFT_REPEAT(2254),
  [1367] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_script_repeat1, 2, 0, 0), SHIFT_REPEAT(2262),
  [1370] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_script_repeat1, 2, 0, 0), SHIFT_REPEAT(2276),
  [1373] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_script_repeat1, 2, 0, 0), SHIFT_REPEAT(1986),
  [1376] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_script_repeat1, 2, 0, 0), SHIFT_REPEAT(2281),
  [1379] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_script_repeat1, 2, 0, 0), SHIFT_REPEAT(2194),
  [1382] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_script_repeat1, 2, 0, 0), SHIFT_REPEAT(1513),
  [1385] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_script_repeat1, 2, 0, 0), SHIFT_REPEAT(2209),
  [1388] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_script_repeat1, 2, 0, 0), SHIFT_REPEAT(2212),
  [1391] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_script_repeat1, 2, 0, 0), SHIFT_REPEAT(2356),
  [1394] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_script_repeat1, 2, 0, 0), SHIFT_REPEAT(2442),
  [1397] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_script_repeat1, 2, 0, 0), SHIFT_REPEAT(2384),
  [1400] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_script_repeat1, 2, 0, 0), SHIFT_REPEAT(1861),
  [1403] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_script_repeat1, 2, 0, 0), SHIFT_REPEAT(245),
  [1406] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_script_repeat1, 2, 0, 0), SHIFT_REPEAT(304),
  [1409] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_script_repeat1, 2, 0, 0), SHIFT_REPEAT(2372),
  [1412] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2269),
  [1414] = {.entry = {.count = 1, .reusable = true}}, SHIFT(247),
  [1416] = {.entry = {.count = 1, .reusable = false}}, SHIFT(299),
  [1418] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_script, 1, 0, 0),
  [1420] = {.entry = {.count = 1, .reusable = true}}, SHIFT(245),
  [1422] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat2, 2, 0, 0), SHIFT_REPEAT(1864),
  [1425] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_block_repeat2, 2, 0, 0), SHIFT_REPEAT(2334),
  [1428] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_block_repeat2, 2, 0, 0),
  [1430] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat2, 2, 0, 0), SHIFT_REPEAT(2339),
  [1433] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat2, 2, 0, 0), SHIFT_REPEAT(2309),
  [1436] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat2, 2, 0, 0), SHIFT_REPEAT(2310),
  [1439] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_block_repeat2, 2, 0, 0), SHIFT_REPEAT(2311),
  [1442] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat2, 2, 0, 0), SHIFT_REPEAT(1959),
  [1445] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_block_repeat2, 2, 0, 0), SHIFT_REPEAT(2346),
  [1448] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat2, 2, 0, 0), SHIFT_REPEAT(2194),
  [1451] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_block_repeat2, 2, 0, 0), SHIFT_REPEAT(1513),
  [1454] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat2, 2, 0, 0), SHIFT_REPEAT(2209),
  [1457] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat2, 2, 0, 0), SHIFT_REPEAT(2212),
  [1460] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat2, 2, 0, 0), SHIFT_REPEAT(2356),
  [1463] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat2, 2, 0, 0), SHIFT_REPEAT(2442),
  [1466] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat2, 2, 0, 0), SHIFT_REPEAT(2384),
  [1469] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat2, 2, 0, 0), SHIFT_REPEAT(1861),
  [1472] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_block_repeat2, 2, 0, 0), SHIFT_REPEAT(249),
  [1475] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat2, 2, 0, 0), SHIFT_REPEAT(301),
  [1478] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_block_repeat2, 2, 0, 0), SHIFT_REPEAT(2372),
  [1481] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1511),
  [1483] = {.entry = {.count = 1, .reusable = false}}, SHIFT(307),
  [1485] = {.entry = {.count = 1, .reusable = false}}, SHIFT(308),
  [1487] = {.entry = {.count = 1, .reusable = true}}, SHIFT(279),
  [1489] = {.entry = {.count = 1, .reusable = true}}, SHIFT(256),
  [1491] = {.entry = {.count = 1, .reusable = true}}, SHIFT(258),
  [1493] = {.entry = {.count = 1, .reusable = false}}, SHIFT(301),
  [1495] = {.entry = {.count = 1, .reusable = true}}, SHIFT(262),
  [1497] = {.entry = {.count = 1, .reusable = true}}, SHIFT(263),
  [1499] = {.entry = {.count = 1, .reusable = true}}, SHIFT(264),
  [1501] = {.entry = {.count = 1, .reusable = true}}, SHIFT(266),
  [1503] = {.entry = {.count = 1, .reusable = true}}, SHIFT(269),
  [1505] = {.entry = {.count = 1, .reusable = true}}, SHIFT(271),
  [1507] = {.entry = {.count = 1, .reusable = true}}, SHIFT(273),
  [1509] = {.entry = {.count = 1, .reusable = true}}, SHIFT(252),
  [1511] = {.entry = {.count = 1, .reusable = true}}, SHIFT(254),
  [1513] = {.entry = {.count = 1, .reusable = true}}, SHIFT(250),
  [1515] = {.entry = {.count = 1, .reusable = true}}, SHIFT(278),
  [1517] = {.entry = {.count = 1, .reusable = true}}, SHIFT(282),
  [1519] = {.entry = {.count = 1, .reusable = true}}, SHIFT(283),
  [1521] = {.entry = {.count = 1, .reusable = true}}, SHIFT(285),
  [1523] = {.entry = {.count = 1, .reusable = true}}, SHIFT(287),
  [1525] = {.entry = {.count = 1, .reusable = true}}, SHIFT(290),
  [1527] = {.entry = {.count = 1, .reusable = true}}, SHIFT(291),
  [1529] = {.entry = {.count = 1, .reusable = true}}, SHIFT(251),
  [1531] = {.entry = {.count = 1, .reusable = true}}, SHIFT(267),
  [1533] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1151),
  [1535] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1156),
  [1537] = {.entry = {.count = 1, .reusable = false}}, SHIFT(309),
  [1539] = {.entry = {.count = 1, .reusable = false}}, SHIFT(310),
  [1541] = {.entry = {.count = 1, .reusable = false}}, SHIFT(311),
  [1543] = {.entry = {.count = 1, .reusable = false}}, SHIFT(312),
  [1545] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2268),
  [1547] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1516),
  [1549] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2280),
  [1551] = {.entry = {.count = 1, .reusable = true}}, SHIFT(97),
  [1553] = {.entry = {.count = 1, .reusable = true}}, SHIFT(402),
  [1555] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1555),
  [1557] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1204),
  [1559] = {.entry = {.count = 1, .reusable = true}}, SHIFT(332),
  [1561] = {.entry = {.count = 1, .reusable = true}}, SHIFT(407),
  [1563] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1879),
  [1565] = {.entry = {.count = 1, .reusable = true}}, SHIFT(336),
  [1567] = {.entry = {.count = 1, .reusable = true}}, SHIFT(400),
  [1569] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1848),
  [1571] = {.entry = {.count = 1, .reusable = true}}, SHIFT(338),
  [1573] = {.entry = {.count = 1, .reusable = true}}, SHIFT(399),
  [1575] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1845),
  [1577] = {.entry = {.count = 1, .reusable = true}}, SHIFT(335),
  [1579] = {.entry = {.count = 1, .reusable = true}}, SHIFT(396),
  [1581] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1956),
  [1583] = {.entry = {.count = 1, .reusable = true}}, SHIFT(331),
  [1585] = {.entry = {.count = 1, .reusable = true}}, SHIFT(409),
  [1587] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1553),
  [1589] = {.entry = {.count = 1, .reusable = true}}, SHIFT(337),
  [1591] = {.entry = {.count = 1, .reusable = true}}, SHIFT(426),
  [1593] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1590),
  [1595] = {.entry = {.count = 1, .reusable = true}}, SHIFT(340),
  [1597] = {.entry = {.count = 1, .reusable = true}}, SHIFT(420),
  [1599] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1600),
  [1601] = {.entry = {.count = 1, .reusable = true}}, SHIFT(330),
  [1603] = {.entry = {.count = 1, .reusable = true}}, SHIFT(800),
  [1605] = {.entry = {.count = 1, .reusable = true}}, SHIFT(391),
  [1607] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1606),
  [1609] = {.entry = {.count = 1, .reusable = true}}, SHIFT(329),
  [1611] = {.entry = {.count = 1, .reusable = true}}, SHIFT(393),
  [1613] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1996),
  [1615] = {.entry = {.count = 1, .reusable = true}}, SHIFT(327),
  [1617] = {.entry = {.count = 1, .reusable = true}}, SHIFT(394),
  [1619] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1924),
  [1621] = {.entry = {.count = 1, .reusable = true}}, SHIFT(342),
  [1623] = {.entry = {.count = 1, .reusable = true}}, SHIFT(418),
  [1625] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1583),
  [1627] = {.entry = {.count = 1, .reusable = true}}, SHIFT(326),
  [1629] = {.entry = {.count = 1, .reusable = true}}, SHIFT(419),
  [1631] = {.entry = {.count = 1, .reusable = true}}, SHIFT(397),
  [1633] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1947),
  [1635] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__expression, 1, 0, 0),
  [1637] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__expression, 1, 0, 0),
  [1639] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__expression, 1, 0, 0), REDUCE(sym__address_expression, 1, 0, 0),
  [1642] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__expression, 1, 0, 0), REDUCE(sym__address_expression, 1, 0, 0),
  [1645] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__address_expression, 1, 0, 0),
  [1647] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__address_expression, 1, 0, 0),
  [1649] = {.entry = {.count = 1, .reusable = true}}, SHIFT(473),
  [1651] = {.entry = {.count = 1, .reusable = true}}, SHIFT(425),
  [1653] = {.entry = {.count = 1, .reusable = true}}, SHIFT(421),
  [1655] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1618),
  [1657] = {.entry = {.count = 1, .reusable = true}}, SHIFT(392),
  [1659] = {.entry = {.count = 1, .reusable = true}}, SHIFT(408),
  [1661] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_macro, 4, 0, 35),
  [1663] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_macro, 4, 0, 35),
  [1665] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_macro, 2, 0, 7),
  [1667] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_macro, 2, 0, 7),
  [1669] = {.entry = {.count = 1, .reusable = true}}, SHIFT(405),
  [1671] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1877),
  [1673] = {.entry = {.count = 1, .reusable = true}}, SHIFT(410),
  [1675] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1895),
  [1677] = {.entry = {.count = 1, .reusable = true}}, SHIFT(411),
  [1679] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1542),
  [1681] = {.entry = {.count = 1, .reusable = true}}, SHIFT(406),
  [1683] = {.entry = {.count = 1, .reusable = true}}, SHIFT(395),
  [1685] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1578),
  [1687] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1295),
  [1689] = {.entry = {.count = 1, .reusable = true}}, SHIFT(398),
  [1691] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_integer, 2, 0, 0),
  [1693] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_integer, 2, 0, 0),
  [1695] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_hll_var_call_expression_argument_list, 3, 0, 0),
  [1697] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_var_call_expression_argument_list, 3, 0, 0),
  [1699] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_call_expression, 1, 0, 12),
  [1701] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_call_expression, 1, 0, 12),
  [1703] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_argument_list, 4, 0, 0),
  [1705] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_argument_list, 4, 0, 0),
  [1707] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_call_expression, 2, 0, 28),
  [1709] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_call_expression, 2, 0, 28),
  [1711] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__hll_var_call_expression, 2, 0, 28),
  [1713] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__hll_var_call_expression, 2, 0, 28),
  [1715] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__literal, 1, 0, 0),
  [1717] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__literal, 1, 0, 0),
  [1719] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__literal, 1, 0, 0), REDUCE(sym__address_expression, 1, 0, 0),
  [1722] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__literal, 1, 0, 0), REDUCE(sym__address_expression, 1, 0, 0),
  [1725] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_address, 2, 0, 32),
  [1727] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_address, 2, 0, 32),
  [1729] = {.entry = {.count = 1, .reusable = false}}, SHIFT(180),
  [1731] = {.entry = {.count = 1, .reusable = true}}, SHIFT(181),
  [1733] = {.entry = {.count = 1, .reusable = true}}, SHIFT(182),
  [1735] = {.entry = {.count = 1, .reusable = false}}, SHIFT(182),
  [1737] = {.entry = {.count = 1, .reusable = false}}, SHIFT(183),
  [1739] = {.entry = {.count = 1, .reusable = false}}, SHIFT(184),
  [1741] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1062),
  [1743] = {.entry = {.count = 1, .reusable = true}}, SHIFT(152),
  [1745] = {.entry = {.count = 1, .reusable = false}}, SHIFT(153),
  [1747] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_address, 3, 0, 43),
  [1749] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_address, 2, 0, 32), REDUCE(sym_address, 3, 0, 43),
  [1752] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_address, 3, 0, 43),
  [1754] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_address, 2, 0, 32), REDUCE(sym_address, 3, 0, 43),
  [1757] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__parenthesized_address_expression, 3, 0, 0),
  [1759] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__parenthesized_address_expression, 3, 0, 0),
  [1761] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__address_expression, 1, 0, 11),
  [1763] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__address_expression, 1, 0, 11),
  [1765] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_argument_list, 3, 0, 0),
  [1767] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_argument_list, 3, 0, 0),
  [1769] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__address_binary_expression, 3, 0, 38),
  [1771] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__address_binary_expression, 3, 0, 38),
  [1773] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_argument_list, 2, 0, 0),
  [1775] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_argument_list, 2, 0, 0),
  [1777] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_integer, 1, 0, 0),
  [1779] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_integer, 1, 0, 0),
  [1781] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_address, 2, 0, 26),
  [1783] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_address, 2, 0, 26),
  [1785] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_assignment_expression, 3, 0, 38),
  [1787] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_assignment_expression, 3, 0, 38),
  [1789] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2048),
  [1791] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__path_expression_repeat1, 2, 0, 0),
  [1793] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__path_expression_repeat1, 2, 0, 0),
  [1795] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__path_expression_repeat1, 2, 0, 0), SHIFT_REPEAT(2253),
  [1798] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__unary_expression, 2, 0, 25),
  [1800] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__unary_expression, 2, 0, 25),
  [1802] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__path_expression_repeat2, 2, 0, 0),
  [1804] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__path_expression_repeat2, 2, 0, 0),
  [1806] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__path_expression_repeat2, 2, 0, 0), SHIFT_REPEAT(2107),
  [1809] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__path_expression, 1, 0, 0),
  [1811] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__path_expression, 1, 0, 0),
  [1813] = {.entry = {.count = 1, .reusable = true}}, SHIFT(422),
  [1815] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__binary_expression, 3, 0, 38),
  [1817] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__binary_expression, 3, 0, 38),
  [1819] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_assignment_expression, 5, 0, 72),
  [1821] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_assignment_expression, 5, 0, 72),
  [1823] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__binary_expression, 3, 0, 38), SHIFT(2347),
  [1826] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__prefix_postfix_expression, 2, 0, 25),
  [1828] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__prefix_postfix_expression, 2, 0, 25),
  [1830] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__hll_var_command_argument_list_default_format_repeat2, 2, 0, 0), SHIFT_REPEAT(889),
  [1833] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__hll_var_command_argument_list_default_format_repeat2, 2, 0, 0), SHIFT_REPEAT(75),
  [1836] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__hll_var_command_argument_list_default_format_repeat2, 2, 0, 0), SHIFT_REPEAT(658),
  [1839] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__hll_var_command_argument_list_default_format_repeat2, 2, 0, 0), SHIFT_REPEAT(658),
  [1842] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__hll_var_command_argument_list_default_format_repeat2, 2, 0, 0), SHIFT_REPEAT(659),
  [1845] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__hll_var_command_argument_list_default_format_repeat2, 2, 0, 0), SHIFT_REPEAT(633),
  [1848] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__hll_var_command_argument_list_default_format_repeat2, 2, 0, 0), SHIFT_REPEAT(2369),
  [1851] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__hll_var_command_argument_list_default_format_repeat2, 2, 0, 0), SHIFT_REPEAT(2162),
  [1854] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__hll_var_command_argument_list_default_format_repeat2, 2, 0, 0), SHIFT_REPEAT(660),
  [1857] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__hll_var_command_argument_list_default_format_repeat2, 2, 0, 0), SHIFT_REPEAT(2295),
  [1860] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__hll_var_command_argument_list_default_format_repeat2, 2, 0, 0), SHIFT_REPEAT(2018),
  [1863] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__hll_var_command_argument_list_default_format_repeat2, 2, 0, 0), SHIFT_REPEAT(1293),
  [1866] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__hll_var_command_argument_list_default_format_repeat2, 2, 0, 0), SHIFT_REPEAT(2343),
  [1869] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__hll_var_command_argument_list_default_format_repeat2, 2, 0, 0), SHIFT_REPEAT(2445),
  [1872] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__and_expression, 4, 0, 53),
  [1874] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__and_expression, 4, 0, 53),
  [1876] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_assignment_expression, 4, 0, 53),
  [1878] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_assignment_expression, 4, 0, 53),
  [1880] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__expression, 1, 0, 0), REDUCE(sym__function_identifier, 1, 0, 9),
  [1883] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2387),
  [1885] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_assignment_expression, 4, 0, 52),
  [1887] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_assignment_expression, 4, 0, 52),
  [1889] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_symbol, 2, 0, 0),
  [1891] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_symbol, 2, 0, 0),
  [1893] = {.entry = {.count = 1, .reusable = true}}, SHIFT(438),
  [1895] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1584),
  [1897] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2188),
  [1899] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1992),
  [1901] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2160),
  [1903] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2001),
  [1905] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2038),
  [1907] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1843),
  [1909] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2069),
  [1911] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1643),
  [1913] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2199),
  [1915] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1995),
  [1917] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2202),
  [1919] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1976),
  [1921] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2039),
  [1923] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1874),
  [1925] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2045),
  [1927] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1875),
  [1929] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2046),
  [1931] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1878),
  [1933] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2047),
  [1935] = {.entry = {.count = 1, .reusable = true}}, SHIFT(815),
  [1937] = {.entry = {.count = 1, .reusable = true}}, SHIFT(403),
  [1939] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1552),
  [1941] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2095),
  [1943] = {.entry = {.count = 1, .reusable = true}}, SHIFT(792),
  [1945] = {.entry = {.count = 1, .reusable = true}}, SHIFT(911),
  [1947] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1891),
  [1949] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2115),
  [1951] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1893),
  [1953] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2122),
  [1955] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1894),
  [1957] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2124),
  [1959] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1540),
  [1961] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2144),
  [1963] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1541),
  [1965] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2146),
  [1967] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1900),
  [1969] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2165),
  [1971] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1545),
  [1973] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2168),
  [1975] = {.entry = {.count = 1, .reusable = true}}, SHIFT(747),
  [1977] = {.entry = {.count = 1, .reusable = true}}, SHIFT(413),
  [1979] = {.entry = {.count = 1, .reusable = true}}, SHIFT(787),
  [1981] = {.entry = {.count = 1, .reusable = true}}, SHIFT(921),
  [1983] = {.entry = {.count = 1, .reusable = true}}, SHIFT(416),
  [1985] = {.entry = {.count = 1, .reusable = true}}, SHIFT(897),
  [1987] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_string, 2, 0, 0),
  [1989] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_string, 2, 0, 0),
  [1991] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1598),
  [1993] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2177),
  [1995] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1613),
  [1997] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2183),
  [1999] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1616),
  [2001] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2184),
  [2003] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1626),
  [2005] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2186),
  [2007] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__path_expression, 2, 0, 0),
  [2009] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__path_expression, 2, 0, 0),
  [2011] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_string, 3, 0, 0),
  [2013] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_string, 3, 0, 0),
  [2015] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1647),
  [2017] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2185),
  [2019] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1649),
  [2021] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2228),
  [2023] = {.entry = {.count = 1, .reusable = true}}, SHIFT(899),
  [2025] = {.entry = {.count = 1, .reusable = true}}, SHIFT(404),
  [2027] = {.entry = {.count = 1, .reusable = true}}, SHIFT(435),
  [2029] = {.entry = {.count = 1, .reusable = true}}, SHIFT(433),
  [2031] = {.entry = {.count = 1, .reusable = true}}, SHIFT(491),
  [2033] = {.entry = {.count = 1, .reusable = true}}, SHIFT(456),
  [2035] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_symbol, 3, 0, 0),
  [2037] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_symbol, 3, 0, 0),
  [2039] = {.entry = {.count = 1, .reusable = true}}, SHIFT(441),
  [2041] = {.entry = {.count = 1, .reusable = true}}, SHIFT(444),
  [2043] = {.entry = {.count = 1, .reusable = true}}, SHIFT(471),
  [2045] = {.entry = {.count = 1, .reusable = true}}, SHIFT(446),
  [2047] = {.entry = {.count = 1, .reusable = true}}, SHIFT(455),
  [2049] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_symbol, 1, 0, 0),
  [2051] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_symbol, 1, 0, 0),
  [2053] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_bitmask, 1, 0, 0),
  [2055] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_bitmask, 1, 0, 0),
  [2057] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_unary_expression, 1, 0, 10),
  [2059] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_unary_expression, 1, 0, 10),
  [2061] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_binary_expression, 1, 0, 11),
  [2063] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_binary_expression, 1, 0, 11),
  [2065] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_symbol, 1, 0, 13),
  [2067] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_symbol, 1, 0, 13),
  [2069] = {.entry = {.count = 1, .reusable = true}}, SHIFT(467),
  [2071] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__special_command_operator, 1, 0, 0),
  [2073] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__special_command_operator, 1, 0, 0),
  [2075] = {.entry = {.count = 1, .reusable = true}}, SHIFT(454),
  [2077] = {.entry = {.count = 1, .reusable = true}}, SHIFT(432),
  [2079] = {.entry = {.count = 1, .reusable = true}}, SHIFT(464),
  [2081] = {.entry = {.count = 1, .reusable = true}}, SHIFT(439),
  [2083] = {.entry = {.count = 1, .reusable = true}}, SHIFT(468),
  [2085] = {.entry = {.count = 1, .reusable = true}}, SHIFT(461),
  [2087] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_trace32_hll_variable, 2, 0, 7),
  [2089] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_trace32_hll_variable, 2, 0, 7),
  [2091] = {.entry = {.count = 1, .reusable = true}}, SHIFT(477),
  [2093] = {.entry = {.count = 1, .reusable = true}}, SHIFT(437),
  [2095] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__parenthesized_expression, 3, 0, 0),
  [2097] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__parenthesized_expression, 3, 0, 0),
  [2099] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_character, 3, 0, 0),
  [2101] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_character, 3, 0, 0),
  [2103] = {.entry = {.count = 1, .reusable = true}}, SHIFT(489),
  [2105] = {.entry = {.count = 1, .reusable = true}}, SHIFT(487),
  [2107] = {.entry = {.count = 1, .reusable = true}}, SHIFT(490),
  [2109] = {.entry = {.count = 1, .reusable = true}}, SHIFT(469),
  [2111] = {.entry = {.count = 1, .reusable = true}}, SHIFT(430),
  [2113] = {.entry = {.count = 1, .reusable = true}}, SHIFT(732),
  [2115] = {.entry = {.count = 1, .reusable = true}}, SHIFT(597),
  [2117] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT(1676),
  [2120] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0),
  [2122] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0),
  [2124] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT(2332),
  [2127] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT(2338),
  [2130] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT(2348),
  [2133] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT(1672),
  [2136] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT(1530),
  [2139] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(800),
  [2142] = {.entry = {.count = 1, .reusable = true}}, SHIFT(722),
  [2144] = {.entry = {.count = 1, .reusable = true}}, SHIFT(629),
  [2146] = {.entry = {.count = 1, .reusable = true}}, SHIFT(539),
  [2148] = {.entry = {.count = 1, .reusable = true}}, SHIFT(617),
  [2150] = {.entry = {.count = 1, .reusable = true}}, SHIFT(683),
  [2152] = {.entry = {.count = 1, .reusable = true}}, SHIFT(520),
  [2154] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__hll_var_command_argument_list_default_format_repeat1, 2, 0, 0), SHIFT_REPEAT(884),
  [2157] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__hll_var_command_argument_list_default_format_repeat1, 2, 0, 0), SHIFT_REPEAT(32),
  [2160] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__hll_var_command_argument_list_default_format_repeat1, 2, 0, 0), SHIFT_REPEAT(654),
  [2163] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__hll_var_command_argument_list_default_format_repeat1, 2, 0, 0), SHIFT_REPEAT(654),
  [2166] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__hll_var_command_argument_list_default_format_repeat1, 2, 0, 0), SHIFT_REPEAT(655),
  [2169] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__hll_var_command_argument_list_default_format_repeat1, 2, 0, 0), SHIFT_REPEAT(633),
  [2172] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__hll_var_command_argument_list_default_format_repeat1, 2, 0, 0), SHIFT_REPEAT(2162),
  [2175] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__hll_var_command_argument_list_default_format_repeat1, 2, 0, 0), SHIFT_REPEAT(656),
  [2178] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__hll_var_command_argument_list_default_format_repeat1, 2, 0, 0), SHIFT_REPEAT(2295),
  [2181] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__hll_var_command_argument_list_default_format_repeat1, 2, 0, 0), SHIFT_REPEAT(2018),
  [2184] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__hll_var_command_argument_list_default_format_repeat1, 2, 0, 0), SHIFT_REPEAT(1293),
  [2187] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__hll_var_command_argument_list_default_format_repeat1, 2, 0, 0), SHIFT_REPEAT(2343),
  [2190] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__hll_var_command_argument_list_default_format_repeat1, 2, 0, 0), SHIFT_REPEAT(2445),
  [2193] = {.entry = {.count = 1, .reusable = true}}, SHIFT(538),
  [2195] = {.entry = {.count = 1, .reusable = true}}, SHIFT(562),
  [2197] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_binary_expression, 3, 0, 38),
  [2199] = {.entry = {.count = 1, .reusable = true}}, SHIFT(412),
  [2201] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_hll_binary_expression, 3, 0, 38),
  [2203] = {.entry = {.count = 1, .reusable = true}}, SHIFT(757),
  [2205] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2322),
  [2207] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2322),
  [2209] = {.entry = {.count = 1, .reusable = true}}, SHIFT(511),
  [2211] = {.entry = {.count = 1, .reusable = true}}, SHIFT(41),
  [2213] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_cast_expression, 4, 0, 64),
  [2215] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_hll_cast_expression, 4, 0, 64),
  [2217] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_pointer_expression, 2, 0, 25),
  [2219] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_hll_pointer_expression, 2, 0, 25),
  [2221] = {.entry = {.count = 1, .reusable = true}}, SHIFT(42),
  [2223] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_cast_expression, 5, 0, 78),
  [2225] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_hll_cast_expression, 5, 0, 78),
  [2227] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_cast_expression, 5, 0, 82),
  [2229] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_hll_cast_expression, 5, 0, 82),
  [2231] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_cast_expression, 6, 0, 96),
  [2233] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_hll_cast_expression, 6, 0, 96),
  [2235] = {.entry = {.count = 1, .reusable = true}}, SHIFT(45),
  [2237] = {.entry = {.count = 1, .reusable = true}}, SHIFT(51),
  [2239] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_sizeof_expression, 2, 0, 33),
  [2241] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_hll_sizeof_expression, 2, 0, 33),
  [2243] = {.entry = {.count = 1, .reusable = false}}, SHIFT(665),
  [2245] = {.entry = {.count = 1, .reusable = true}}, SHIFT(53),
  [2247] = {.entry = {.count = 1, .reusable = true}}, SHIFT(55),
  [2249] = {.entry = {.count = 1, .reusable = true}}, SHIFT(61),
  [2251] = {.entry = {.count = 1, .reusable = true}}, SHIFT(47),
  [2253] = {.entry = {.count = 1, .reusable = true}}, SHIFT(57),
  [2255] = {.entry = {.count = 1, .reusable = true}}, SHIFT(63),
  [2257] = {.entry = {.count = 1, .reusable = false}}, SHIFT(645),
  [2259] = {.entry = {.count = 1, .reusable = false}}, SHIFT(640),
  [2261] = {.entry = {.count = 1, .reusable = false}}, SHIFT(649),
  [2263] = {.entry = {.count = 1, .reusable = false}}, SHIFT(653),
  [2265] = {.entry = {.count = 1, .reusable = true}}, SHIFT(657),
  [2267] = {.entry = {.count = 1, .reusable = false}}, SHIFT(661),
  [2269] = {.entry = {.count = 1, .reusable = true}}, SHIFT(661),
  [2271] = {.entry = {.count = 1, .reusable = true}}, SHIFT(668),
  [2273] = {.entry = {.count = 1, .reusable = false}}, SHIFT(670),
  [2275] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_assignment_expression, 3, 0, 38),
  [2277] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_hll_assignment_expression, 3, 0, 38),
  [2279] = {.entry = {.count = 1, .reusable = true}}, SHIFT(740),
  [2281] = {.entry = {.count = 1, .reusable = true}}, SHIFT(507),
  [2283] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_conditional_expression, 4, 0, 68),
  [2285] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_hll_conditional_expression, 4, 0, 68),
  [2287] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_update_expression, 2, 0, 25),
  [2289] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_hll_update_expression, 2, 0, 25),
  [2291] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_assignment_expression, 4, 0, 52),
  [2293] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_hll_assignment_expression, 4, 0, 52),
  [2295] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_assignment_expression, 4, 0, 53),
  [2297] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_hll_assignment_expression, 4, 0, 53),
  [2299] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_conditional_expression, 5, 0, 86),
  [2301] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_hll_conditional_expression, 5, 0, 86),
  [2303] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_assignment_expression, 5, 0, 72),
  [2305] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_hll_assignment_expression, 5, 0, 72),
  [2307] = {.entry = {.count = 1, .reusable = true}}, SHIFT(745),
  [2309] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_unary_expression, 2, 0, 25),
  [2311] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_hll_unary_expression, 2, 0, 25),
  [2313] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_argument_list, 6, 0, 0),
  [2315] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_hll_argument_list, 6, 0, 0),
  [2317] = {.entry = {.count = 1, .reusable = true}}, SHIFT(401),
  [2319] = {.entry = {.count = 1, .reusable = false}}, SHIFT(542),
  [2321] = {.entry = {.count = 1, .reusable = true}}, SHIFT(803),
  [2323] = {.entry = {.count = 1, .reusable = true}}, SHIFT(564),
  [2325] = {.entry = {.count = 1, .reusable = false}}, SHIFT(571),
  [2327] = {.entry = {.count = 1, .reusable = false}}, SHIFT(590),
  [2329] = {.entry = {.count = 1, .reusable = false}}, SHIFT(594),
  [2331] = {.entry = {.count = 1, .reusable = true}}, SHIFT(610),
  [2333] = {.entry = {.count = 1, .reusable = false}}, SHIFT(623),
  [2335] = {.entry = {.count = 1, .reusable = true}}, SHIFT(623),
  [2337] = {.entry = {.count = 1, .reusable = false}}, SHIFT(624),
  [2339] = {.entry = {.count = 1, .reusable = true}}, SHIFT(627),
  [2341] = {.entry = {.count = 1, .reusable = false}}, SHIFT(630),
  [2343] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2315),
  [2345] = {.entry = {.count = 1, .reusable = true}}, SHIFT(505),
  [2347] = {.entry = {.count = 1, .reusable = true}}, SHIFT(499),
  [2349] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_subscript_expression, 4, 0, 69),
  [2351] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_hll_subscript_expression, 4, 0, 69),
  [2353] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_argument_list, 2, 0, 0),
  [2355] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_hll_argument_list, 2, 0, 0),
  [2357] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__hll_field_identifier, 1, 0, 46),
  [2359] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__hll_field_identifier, 1, 0, 46),
  [2361] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_parenthesized_expression, 5, 0, 0),
  [2363] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_hll_parenthesized_expression, 5, 0, 0),
  [2365] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_call_expression, 2, 0, 28),
  [2367] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_hll_call_expression, 2, 0, 28),
  [2369] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_field_expression, 3, 0, 47),
  [2371] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_hll_field_expression, 3, 0, 47),
  [2373] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_argument_list, 4, 0, 0),
  [2375] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_hll_argument_list, 4, 0, 0),
  [2377] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_update_expression, 2, 0, 27),
  [2379] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_hll_update_expression, 2, 0, 27),
  [2381] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_argument_list, 5, 0, 0),
  [2383] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_hll_argument_list, 5, 0, 0),
  [2385] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_char_literal, 3, 0, 0),
  [2387] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_hll_char_literal, 3, 0, 0),
  [2389] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_string_literal, 3, 0, 0),
  [2391] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_hll_string_literal, 3, 0, 0),
  [2393] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_string_literal, 2, 0, 0),
  [2395] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_hll_string_literal, 2, 0, 0),
  [2397] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__hll_expression, 1, 0, 0),
  [2399] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__hll_expression, 1, 0, 0), REDUCE(sym__hll_assignment_left_expression, 1, 0, 0),
  [2402] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__hll_expression, 1, 0, 0),
  [2404] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__hll_expression, 1, 0, 0), REDUCE(sym__hll_assignment_left_expression, 1, 0, 0),
  [2407] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_parenthesized_expression, 4, 0, 0),
  [2409] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_hll_parenthesized_expression, 4, 0, 0),
  [2411] = {.entry = {.count = 1, .reusable = true}}, SHIFT(809),
  [2413] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__hll_expression, 2, 0, 0),
  [2415] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__hll_expression, 2, 0, 0),
  [2417] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_argument_list, 3, 0, 0),
  [2419] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_hll_argument_list, 3, 0, 0),
  [2421] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_parenthesized_expression, 3, 0, 0),
  [2423] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_hll_parenthesized_expression, 3, 0, 0),
  [2425] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__hll_assignment_left_expression, 1, 0, 0),
  [2427] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__hll_assignment_left_expression, 1, 0, 0),
  [2429] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__hll_expression, 1, 0, 0), REDUCE(sym__hll_type_identifier, 1, 0, 23),
  [2432] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__hll_expression, 1, 0, 0), REDUCE(sym__hll_type_identifier, 1, 0, 23),
  [2435] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__hll_type_identifier, 1, 0, 23),
  [2437] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym__hll_expression, 1, 0, 0), REDUCE(sym__hll_assignment_left_expression, 1, 0, 0), REDUCE(sym__hll_type_identifier, 1, 0, 23),
  [2441] = {.entry = {.count = 1, .reusable = true}}, SHIFT(876),
  [2443] = {.entry = {.count = 1, .reusable = true}}, SHIFT(427),
  [2445] = {.entry = {.count = 1, .reusable = true}}, SHIFT(877),
  [2447] = {.entry = {.count = 1, .reusable = false}}, SHIFT(718),
  [2449] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2283),
  [2451] = {.entry = {.count = 1, .reusable = true}}, SHIFT(498),
  [2453] = {.entry = {.count = 1, .reusable = true}}, SHIFT(414),
  [2455] = {.entry = {.count = 1, .reusable = true}}, SHIFT(879),
  [2457] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2351),
  [2459] = {.entry = {.count = 1, .reusable = true}}, SHIFT(496),
  [2461] = {.entry = {.count = 1, .reusable = false}}, SHIFT(695),
  [2463] = {.entry = {.count = 1, .reusable = false}}, SHIFT(690),
  [2465] = {.entry = {.count = 1, .reusable = false}}, SHIFT(711),
  [2467] = {.entry = {.count = 1, .reusable = false}}, SHIFT(715),
  [2469] = {.entry = {.count = 1, .reusable = true}}, SHIFT(716),
  [2471] = {.entry = {.count = 1, .reusable = false}}, SHIFT(717),
  [2473] = {.entry = {.count = 1, .reusable = true}}, SHIFT(717),
  [2475] = {.entry = {.count = 1, .reusable = true}}, SHIFT(719),
  [2477] = {.entry = {.count = 1, .reusable = false}}, SHIFT(720),
  [2479] = {.entry = {.count = 1, .reusable = true}}, SHIFT(517),
  [2481] = {.entry = {.count = 1, .reusable = true}}, SHIFT(501),
  [2483] = {.entry = {.count = 1, .reusable = false}}, SHIFT(556),
  [2485] = {.entry = {.count = 1, .reusable = false}}, SHIFT(551),
  [2487] = {.entry = {.count = 1, .reusable = false}}, SHIFT(549),
  [2489] = {.entry = {.count = 1, .reusable = false}}, SHIFT(552),
  [2491] = {.entry = {.count = 1, .reusable = false}}, SHIFT(553),
  [2493] = {.entry = {.count = 1, .reusable = true}}, SHIFT(554),
  [2495] = {.entry = {.count = 1, .reusable = false}}, SHIFT(555),
  [2497] = {.entry = {.count = 1, .reusable = true}}, SHIFT(555),
  [2499] = {.entry = {.count = 1, .reusable = true}}, SHIFT(557),
  [2501] = {.entry = {.count = 1, .reusable = false}}, SHIFT(558),
  [2503] = {.entry = {.count = 1, .reusable = true}}, SHIFT(550),
  [2505] = {.entry = {.count = 1, .reusable = true}}, SHIFT(513),
  [2507] = {.entry = {.count = 1, .reusable = true}}, SHIFT(910),
  [2509] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__command_arguments_repeat1, 3, 0, 0),
  [2511] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__command_arguments_repeat1, 3, 0, 0),
  [2513] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__command_arguments_repeat1, 2, 0, 0),
  [2515] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__command_arguments_repeat1, 2, 0, 0),
  [2517] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(927),
  [2520] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__command_arguments_repeat1, 2, 0, 0), SHIFT_REPEAT(940),
  [2523] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__command_arguments_repeat1, 1, 0, 0),
  [2525] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__command_arguments_repeat1, 1, 0, 0),
  [2527] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__command_arguments, 1, 0, 0),
  [2529] = {.entry = {.count = 1, .reusable = false}}, SHIFT(928),
  [2531] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__command_arguments, 3, 0, 0),
  [2533] = {.entry = {.count = 1, .reusable = false}}, SHIFT(924),
  [2535] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__command_arguments, 2, 0, 0),
  [2537] = {.entry = {.count = 1, .reusable = false}}, SHIFT(925),
  [2539] = {.entry = {.count = 1, .reusable = false}}, SHIFT(926),
  [2541] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(935),
  [2544] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__command_arguments_repeat1, 4, 0, 0),
  [2546] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__command_arguments_repeat1, 4, 0, 0),
  [2548] = {.entry = {.count = 1, .reusable = true}}, SHIFT(937),
  [2550] = {.entry = {.count = 1, .reusable = true}}, SHIFT(947),
  [2552] = {.entry = {.count = 1, .reusable = true}}, SHIFT(939),
  [2554] = {.entry = {.count = 1, .reusable = true}}, SHIFT(938),
  [2556] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(952),
  [2559] = {.entry = {.count = 1, .reusable = false}}, SHIFT(696),
  [2561] = {.entry = {.count = 1, .reusable = true}}, SHIFT(953),
  [2563] = {.entry = {.count = 1, .reusable = true}}, SHIFT(697),
  [2565] = {.entry = {.count = 1, .reusable = true}}, SHIFT(698),
  [2567] = {.entry = {.count = 1, .reusable = false}}, SHIFT(698),
  [2569] = {.entry = {.count = 1, .reusable = false}}, SHIFT(699),
  [2571] = {.entry = {.count = 1, .reusable = true}}, SHIFT(700),
  [2573] = {.entry = {.count = 1, .reusable = true}}, SHIFT(701),
  [2575] = {.entry = {.count = 1, .reusable = false}}, SHIFT(702),
  [2577] = {.entry = {.count = 1, .reusable = true}}, SHIFT(702),
  [2579] = {.entry = {.count = 1, .reusable = true}}, SHIFT(703),
  [2581] = {.entry = {.count = 1, .reusable = true}}, SHIFT(704),
  [2583] = {.entry = {.count = 1, .reusable = false}}, SHIFT(705),
  [2585] = {.entry = {.count = 1, .reusable = true}}, SHIFT(495),
  [2587] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1510),
  [2589] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1510),
  [2591] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__hll_var_command_argument_list_non_default_format, 5, 0, 0),
  [2593] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1092),
  [2595] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__hll_var_command_argument_list_default_format, 3, 0, 0),
  [2597] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1014),
  [2599] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__hll_var_command_argument_list_non_default_format, 4, 0, 0),
  [2601] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1134),
  [2603] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1084),
  [2605] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__hll_var_command_argument_list_default_format, 1, 0, 0),
  [2607] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1009),
  [2609] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_hll_type_descriptor_repeat2, 2, 0, 0),
  [2611] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_hll_type_descriptor_repeat2, 2, 0, 0),
  [2613] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_hll_type_descriptor_repeat2, 2, 0, 0), SHIFT_REPEAT(1204),
  [2616] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_hll_type_descriptor_repeat2, 2, 0, 0), SHIFT_REPEAT(1844),
  [2619] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__hll_var_command_argument_list_default_format, 2, 0, 0),
  [2621] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1017),
  [2623] = {.entry = {.count = 1, .reusable = false}}, SHIFT(969),
  [2625] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__hll_var_command_argument_list_non_default_format, 3, 0, 0),
  [2627] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1065),
  [2629] = {.entry = {.count = 1, .reusable = false}}, SHIFT(573),
  [2631] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1121),
  [2633] = {.entry = {.count = 1, .reusable = true}}, SHIFT(574),
  [2635] = {.entry = {.count = 1, .reusable = true}}, SHIFT(579),
  [2637] = {.entry = {.count = 1, .reusable = false}}, SHIFT(581),
  [2639] = {.entry = {.count = 1, .reusable = true}}, SHIFT(582),
  [2641] = {.entry = {.count = 1, .reusable = true}}, SHIFT(584),
  [2643] = {.entry = {.count = 1, .reusable = false}}, SHIFT(585),
  [2645] = {.entry = {.count = 1, .reusable = true}}, SHIFT(585),
  [2647] = {.entry = {.count = 1, .reusable = true}}, SHIFT(588),
  [2649] = {.entry = {.count = 1, .reusable = true}}, SHIFT(591),
  [2651] = {.entry = {.count = 1, .reusable = false}}, SHIFT(592),
  [2653] = {.entry = {.count = 1, .reusable = true}}, SHIFT(502),
  [2655] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__hll_var_command_argument_list_default_format_repeat2, 2, 0, 0),
  [2657] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__hll_var_command_argument_list_default_format_repeat2, 2, 0, 0),
  [2659] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1285),
  [2661] = {.entry = {.count = 1, .reusable = true}}, SHIFT(460),
  [2663] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1832),
  [2665] = {.entry = {.count = 1, .reusable = true}}, SHIFT(795),
  [2667] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1837),
  [2669] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1871),
  [2671] = {.entry = {.count = 1, .reusable = true}}, SHIFT(882),
  [2673] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1936),
  [2675] = {.entry = {.count = 1, .reusable = true}}, SHIFT(756),
  [2677] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1872),
  [2679] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1881),
  [2681] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1087),
  [2683] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1887),
  [2685] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__hll_var_command_argument_list_default_format_repeat2, 3, 0, 0),
  [2687] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__hll_var_command_argument_list_default_format_repeat2, 3, 0, 0),
  [2689] = {.entry = {.count = 1, .reusable = true}}, SHIFT(903),
  [2691] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1883),
  [2693] = {.entry = {.count = 1, .reusable = true}}, SHIFT(187),
  [2695] = {.entry = {.count = 1, .reusable = true}}, SHIFT(188),
  [2697] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_block, 7, 0, 34),
  [2699] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_if_block, 7, 0, 34),
  [2701] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2005),
  [2703] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_block, 7, 0, 34), SHIFT(1695),
  [2706] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_if_block, 7, 0, 34), SHIFT(1835),
  [2709] = {.entry = {.count = 1, .reusable = false}}, SHIFT(186),
  [2711] = {.entry = {.count = 1, .reusable = false}}, SHIFT(190),
  [2713] = {.entry = {.count = 1, .reusable = false}}, SHIFT(240),
  [2715] = {.entry = {.count = 1, .reusable = true}}, SHIFT(179),
  [2717] = {.entry = {.count = 1, .reusable = true}}, SHIFT(242),
  [2719] = {.entry = {.count = 1, .reusable = false}}, SHIFT(242),
  [2721] = {.entry = {.count = 1, .reusable = false}}, SHIFT(196),
  [2723] = {.entry = {.count = 1, .reusable = false}}, SHIFT(200),
  [2725] = {.entry = {.count = 1, .reusable = true}}, SHIFT(470),
  [2727] = {.entry = {.count = 1, .reusable = true}}, SHIFT(914),
  [2729] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2102),
  [2731] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_hll_argument_list_repeat1, 2, 0, 0),
  [2733] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2032),
  [2735] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_if_block, 7, 0, 34), SHIFT(2009),
  [2738] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_block, 7, 0, 34), SHIFT(1694),
  [2741] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_if_block, 7, 0, 34), SHIFT(1934),
  [2744] = {.entry = {.count = 1, .reusable = false}}, SHIFT(189),
  [2746] = {.entry = {.count = 1, .reusable = true}}, SHIFT(909),
  [2748] = {.entry = {.count = 1, .reusable = true}}, SHIFT(515),
  [2750] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2055),
  [2752] = {.entry = {.count = 3, .reusable = false}}, REDUCE(sym_memory_space, 2, 0, 29), REDUCE(sym_memory_space, 4, 0, 62), REDUCE(sym_memory_space, 6, 0, 91),
  [2756] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_memory_space, 2, 0, 29), REDUCE(sym_memory_space, 4, 0, 62), REDUCE(sym_memory_space, 6, 0, 91),
  [2760] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_memory_space, 2, 0, 29),
  [2762] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_memory_space, 2, 0, 29),
  [2764] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_hll_argument_list_repeat1, 3, 0, 0),
  [2766] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1999),
  [2768] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2429),
  [2770] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_block, 6, 0, 34),
  [2772] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_if_block, 6, 0, 34),
  [2774] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_block, 6, 0, 34), SHIFT(1687),
  [2777] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_if_block, 6, 0, 34), SHIFT(1920),
  [2780] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__path_expression_repeat2, 2, 0, 0), SHIFT_REPEAT(2107),
  [2783] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_memory_space, 2, 0, 29), REDUCE(sym_memory_space, 4, 0, 60),
  [2786] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_memory_space, 2, 0, 29), REDUCE(sym_memory_space, 4, 0, 60),
  [2789] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_option_expression, 4, 0, 73),
  [2791] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_memory_space, 2, 0, 29), REDUCE(sym_memory_space, 4, 0, 62),
  [2794] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_memory_space, 2, 0, 29), REDUCE(sym_memory_space, 4, 0, 62),
  [2797] = {.entry = {.count = 1, .reusable = true}}, SHIFT(912),
  [2799] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2166),
  [2801] = {.entry = {.count = 1, .reusable = true}}, SHIFT(814),
  [2803] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2075),
  [2805] = {.entry = {.count = 1, .reusable = false}}, SHIFT(527),
  [2807] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1315),
  [2809] = {.entry = {.count = 1, .reusable = true}}, SHIFT(528),
  [2811] = {.entry = {.count = 1, .reusable = true}}, SHIFT(529),
  [2813] = {.entry = {.count = 1, .reusable = false}}, SHIFT(530),
  [2815] = {.entry = {.count = 1, .reusable = true}}, SHIFT(531),
  [2817] = {.entry = {.count = 1, .reusable = true}}, SHIFT(532),
  [2819] = {.entry = {.count = 1, .reusable = false}}, SHIFT(533),
  [2821] = {.entry = {.count = 1, .reusable = true}}, SHIFT(533),
  [2823] = {.entry = {.count = 1, .reusable = true}}, SHIFT(534),
  [2825] = {.entry = {.count = 1, .reusable = true}}, SHIFT(535),
  [2827] = {.entry = {.count = 1, .reusable = false}}, SHIFT(536),
  [2829] = {.entry = {.count = 1, .reusable = true}}, SHIFT(512),
  [2831] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1320),
  [2833] = {.entry = {.count = 1, .reusable = true}}, SHIFT(791),
  [2835] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2163),
  [2837] = {.entry = {.count = 1, .reusable = true}}, SHIFT(793),
  [2839] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_if_block, 6, 0, 34), SHIFT(2009),
  [2842] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_block, 6, 0, 34), SHIFT(1693),
  [2845] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_if_block, 6, 0, 34), SHIFT(1932),
  [2848] = {.entry = {.count = 1, .reusable = true}}, SHIFT(788),
  [2850] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2216),
  [2852] = {.entry = {.count = 1, .reusable = true}}, SHIFT(779),
  [2854] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2234),
  [2856] = {.entry = {.count = 1, .reusable = true}}, SHIFT(746),
  [2858] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_block, 5, 0, 34),
  [2860] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_if_block, 5, 0, 34),
  [2862] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_block, 5, 0, 34), SHIFT(1690),
  [2865] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_if_block, 5, 0, 34), SHIFT(1855),
  [2868] = {.entry = {.count = 1, .reusable = true}}, SHIFT(905),
  [2870] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2057),
  [2872] = {.entry = {.count = 1, .reusable = true}}, SHIFT(923),
  [2874] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2064),
  [2876] = {.entry = {.count = 1, .reusable = true}}, SHIFT(874),
  [2878] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_option_expression, 4, 0, 73),
  [2880] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1966),
  [2882] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_block, 6, 0, 34), SHIFT(1689),
  [2885] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_if_block, 6, 0, 34), SHIFT(1909),
  [2888] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1272),
  [2890] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_block, 7, 0, 34), SHIFT(1692),
  [2893] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_if_block, 7, 0, 34), SHIFT(1913),
  [2896] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_if_block, 5, 0, 34), SHIFT(2024),
  [2899] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_block, 5, 0, 34), SHIFT(1697),
  [2902] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_if_block, 5, 0, 34), SHIFT(1940),
  [2905] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_if_block, 6, 0, 34), SHIFT(2024),
  [2908] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_block, 6, 0, 34), SHIFT(1698),
  [2911] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_if_block, 6, 0, 34), SHIFT(1813),
  [2914] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_if_block, 7, 0, 34), SHIFT(2024),
  [2917] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_block, 7, 0, 34), SHIFT(1699),
  [2920] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_if_block, 7, 0, 34), SHIFT(1943),
  [2923] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_block, 5, 0, 34), SHIFT(1688),
  [2926] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_if_block, 5, 0, 34), SHIFT(1906),
  [2929] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_if_block, 5, 0, 34), SHIFT(2009),
  [2932] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_block, 5, 0, 34), SHIFT(1691),
  [2935] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_if_block, 5, 0, 34), SHIFT(1930),
  [2938] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__path_expression_repeat1, 2, 0, 0), SHIFT_REPEAT(2342),
  [2941] = {.entry = {.count = 1, .reusable = true}}, SHIFT(143),
  [2943] = {.entry = {.count = 1, .reusable = false}}, SHIFT(96),
  [2945] = {.entry = {.count = 1, .reusable = false}}, SHIFT(202),
  [2947] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6),
  [2949] = {.entry = {.count = 1, .reusable = true}}, SHIFT(206),
  [2951] = {.entry = {.count = 1, .reusable = true}}, SHIFT(207),
  [2953] = {.entry = {.count = 1, .reusable = true}}, SHIFT(208),
  [2955] = {.entry = {.count = 1, .reusable = false}}, SHIFT(208),
  [2957] = {.entry = {.count = 1, .reusable = false}}, SHIFT(209),
  [2959] = {.entry = {.count = 1, .reusable = false}}, SHIFT(210),
  [2961] = {.entry = {.count = 1, .reusable = true}}, SHIFT(211),
  [2963] = {.entry = {.count = 1, .reusable = false}}, SHIFT(211),
  [2965] = {.entry = {.count = 1, .reusable = true}}, SHIFT(214),
  [2967] = {.entry = {.count = 1, .reusable = true}}, SHIFT(232),
  [2969] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__command_argument, 1, 0, 0),
  [2971] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__command_argument, 1, 0, 0), SHIFT(2063),
  [2974] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2292),
  [2976] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2063),
  [2978] = {.entry = {.count = 1, .reusable = true}}, SHIFT(142),
  [2980] = {.entry = {.count = 1, .reusable = false}}, SHIFT(92),
  [2982] = {.entry = {.count = 1, .reusable = false}}, SHIFT(146),
  [2984] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5),
  [2986] = {.entry = {.count = 1, .reusable = true}}, SHIFT(147),
  [2988] = {.entry = {.count = 1, .reusable = true}}, SHIFT(148),
  [2990] = {.entry = {.count = 1, .reusable = true}}, SHIFT(149),
  [2992] = {.entry = {.count = 1, .reusable = false}}, SHIFT(154),
  [2994] = {.entry = {.count = 1, .reusable = false}}, SHIFT(161),
  [2996] = {.entry = {.count = 1, .reusable = true}}, SHIFT(164),
  [2998] = {.entry = {.count = 1, .reusable = false}}, SHIFT(164),
  [3000] = {.entry = {.count = 1, .reusable = true}}, SHIFT(166),
  [3002] = {.entry = {.count = 1, .reusable = true}}, SHIFT(176),
  [3004] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2054),
  [3006] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2282),
  [3008] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_comma_expression, 3, 0, 63),
  [3010] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_labeled_expression, 2, 0, 8),
  [3012] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_labeled_expression, 2, 0, 8),
  [3014] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1779),
  [3016] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1424),
  [3018] = {.entry = {.count = 1, .reusable = true}}, SHIFT(355),
  [3020] = {.entry = {.count = 1, .reusable = true}}, SHIFT(120),
  [3022] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2000),
  [3024] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1801),
  [3026] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1428),
  [3028] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__binary_expression, 3, 0, 38), SHIFT(2292),
  [3031] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1235),
  [3033] = {.entry = {.count = 1, .reusable = true}}, SHIFT(607),
  [3035] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1066),
  [3037] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__binary_expression, 3, 0, 38), SHIFT(2282),
  [3040] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1297),
  [3042] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_hll_type_qualifier, 1, 0, 0),
  [3044] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_type_qualifier, 1, 0, 0),
  [3046] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_if_block_repeat1, 2, 0, 0),
  [3048] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_if_block_repeat1, 2, 0, 0),
  [3050] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_if_block_repeat1, 2, 0, 0), SHIFT_REPEAT(2263),
  [3053] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_if_block_repeat1, 2, 0, 0), SHIFT_REPEAT(1757),
  [3056] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_if_block_repeat1, 2, 0, 0), SHIFT_REPEAT(1955),
  [3059] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1229),
  [3061] = {.entry = {.count = 1, .reusable = true}}, SHIFT(602),
  [3063] = {.entry = {.count = 1, .reusable = false}}, SHIFT(596),
  [3065] = {.entry = {.count = 1, .reusable = false}}, SHIFT(603),
  [3067] = {.entry = {.count = 1, .reusable = true}}, SHIFT(604),
  [3069] = {.entry = {.count = 1, .reusable = true}}, SHIFT(605),
  [3071] = {.entry = {.count = 1, .reusable = false}}, SHIFT(606),
  [3073] = {.entry = {.count = 1, .reusable = true}}, SHIFT(606),
  [3075] = {.entry = {.count = 1, .reusable = true}}, SHIFT(608),
  [3077] = {.entry = {.count = 1, .reusable = false}}, SHIFT(609),
  [3079] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__path_expression_repeat1, 2, 0, 0), SHIFT_REPEAT(2335),
  [3082] = {.entry = {.count = 1, .reusable = true}}, SHIFT(598),
  [3084] = {.entry = {.count = 1, .reusable = true}}, SHIFT(506),
  [3086] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1067),
  [3088] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_if_block_repeat1, 2, 0, 0), SHIFT_REPEAT(2337),
  [3091] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_if_block_repeat1, 2, 0, 0), SHIFT_REPEAT(1753),
  [3094] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_if_block_repeat1, 2, 0, 0), SHIFT_REPEAT(2014),
  [3097] = {.entry = {.count = 1, .reusable = false}}, SHIFT(724),
  [3099] = {.entry = {.count = 1, .reusable = true}}, SHIFT(729),
  [3101] = {.entry = {.count = 1, .reusable = false}}, SHIFT(736),
  [3103] = {.entry = {.count = 1, .reusable = true}}, SHIFT(736),
  [3105] = {.entry = {.count = 1, .reusable = true}}, SHIFT(737),
  [3107] = {.entry = {.count = 1, .reusable = true}}, SHIFT(288),
  [3109] = {.entry = {.count = 1, .reusable = false}}, SHIFT(709),
  [3111] = {.entry = {.count = 1, .reusable = true}}, SHIFT(714),
  [3113] = {.entry = {.count = 1, .reusable = true}}, SHIFT(526),
  [3115] = {.entry = {.count = 1, .reusable = false}}, SHIFT(526),
  [3117] = {.entry = {.count = 1, .reusable = false}}, SHIFT(567),
  [3119] = {.entry = {.count = 1, .reusable = true}}, SHIFT(586),
  [3121] = {.entry = {.count = 1, .reusable = true}}, SHIFT(601),
  [3123] = {.entry = {.count = 1, .reusable = false}}, SHIFT(613),
  [3125] = {.entry = {.count = 1, .reusable = true}}, SHIFT(613),
  [3127] = {.entry = {.count = 1, .reusable = true}}, SHIFT(614),
  [3129] = {.entry = {.count = 1, .reusable = true}}, SHIFT(615),
  [3131] = {.entry = {.count = 1, .reusable = false}}, SHIFT(636),
  [3133] = {.entry = {.count = 1, .reusable = true}}, SHIFT(497),
  [3135] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1473),
  [3137] = {.entry = {.count = 1, .reusable = false}}, SHIFT(731),
  [3139] = {.entry = {.count = 1, .reusable = true}}, SHIFT(733),
  [3141] = {.entry = {.count = 1, .reusable = true}}, SHIFT(735),
  [3143] = {.entry = {.count = 1, .reusable = true}}, SHIFT(738),
  [3145] = {.entry = {.count = 1, .reusable = false}}, SHIFT(518),
  [3147] = {.entry = {.count = 1, .reusable = true}}, SHIFT(727),
  [3149] = {.entry = {.count = 1, .reusable = true}}, SHIFT(508),
  [3151] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_argument_list_repeat1, 3, 0, 0),
  [3153] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_argument_list_repeat1, 3, 0, 0), SHIFT(2054),
  [3156] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1484),
  [3158] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1442),
  [3160] = {.entry = {.count = 1, .reusable = true}}, SHIFT(276),
  [3162] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1443),
  [3164] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1472),
  [3166] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_argument_list_repeat1, 4, 0, 0),
  [3168] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_argument_list_repeat1, 4, 0, 0), SHIFT(2054),
  [3171] = {.entry = {.count = 1, .reusable = true}}, SHIFT(268),
  [3173] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1402),
  [3175] = {.entry = {.count = 1, .reusable = true}}, SHIFT(253),
  [3177] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__non_labeled_statement, 1, 0, 0),
  [3179] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__non_labeled_statement, 1, 0, 0),
  [3181] = {.entry = {.count = 1, .reusable = true}}, SHIFT(91),
  [3183] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2053),
  [3185] = {.entry = {.count = 1, .reusable = true}}, SHIFT(259),
  [3187] = {.entry = {.count = 1, .reusable = true}}, SHIFT(260),
  [3189] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1455),
  [3191] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1457),
  [3193] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_argument_list_repeat1, 2, 0, 0),
  [3195] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_argument_list_repeat1, 2, 0, 0), SHIFT(2054),
  [3198] = {.entry = {.count = 1, .reusable = true}}, SHIFT(293),
  [3200] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1420),
  [3202] = {.entry = {.count = 1, .reusable = true}}, SHIFT(270),
  [3204] = {.entry = {.count = 1, .reusable = true}}, SHIFT(272),
  [3206] = {.entry = {.count = 1, .reusable = true}}, SHIFT(280),
  [3208] = {.entry = {.count = 1, .reusable = false}}, SHIFT(165),
  [3210] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8),
  [3212] = {.entry = {.count = 1, .reusable = true}}, SHIFT(168),
  [3214] = {.entry = {.count = 1, .reusable = false}}, SHIFT(169),
  [3216] = {.entry = {.count = 1, .reusable = false}}, SHIFT(170),
  [3218] = {.entry = {.count = 1, .reusable = true}}, SHIFT(171),
  [3220] = {.entry = {.count = 1, .reusable = false}}, SHIFT(171),
  [3222] = {.entry = {.count = 1, .reusable = true}}, SHIFT(172),
  [3224] = {.entry = {.count = 1, .reusable = true}}, SHIFT(173),
  [3226] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2258),
  [3228] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_range_expression, 4, 0, 52),
  [3230] = {.entry = {.count = 1, .reusable = true}}, SHIFT(479),
  [3232] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1419),
  [3234] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1068),
  [3236] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_range_expression, 5, 0, 72),
  [3238] = {.entry = {.count = 1, .reusable = true}}, SHIFT(344),
  [3240] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1075),
  [3242] = {.entry = {.count = 1, .reusable = true}}, SHIFT(672),
  [3244] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_range_expression, 4, 0, 53),
  [3246] = {.entry = {.count = 1, .reusable = true}}, SHIFT(589),
  [3248] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__repeat_block_pre_condition_format, 3, 0, 3),
  [3250] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__repeat_block_pre_condition_format, 3, 0, 3),
  [3252] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__repeat_block_pre_condition_format, 3, 0, 3), SHIFT(2290),
  [3255] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__repeat_block_pre_condition_format, 3, 0, 3), SHIFT(1991),
  [3258] = {.entry = {.count = 1, .reusable = true}}, SHIFT(728),
  [3260] = {.entry = {.count = 1, .reusable = true}}, SHIFT(570),
  [3262] = {.entry = {.count = 1, .reusable = true}}, SHIFT(628),
  [3264] = {.entry = {.count = 1, .reusable = false}}, SHIFT(110),
  [3266] = {.entry = {.count = 1, .reusable = true}}, SHIFT(167),
  [3268] = {.entry = {.count = 1, .reusable = true}}, SHIFT(145),
  [3270] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__command_argument, 1, 0, 0), SHIFT(2197),
  [3273] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__repeat_block_pre_condition_format, 4, 0, 3),
  [3275] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__repeat_block_pre_condition_format, 4, 0, 3),
  [3277] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__repeat_block_pre_condition_format, 4, 0, 3), SHIFT(2305),
  [3280] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__repeat_block_pre_condition_format, 4, 0, 3), SHIFT(1998),
  [3283] = {.entry = {.count = 1, .reusable = true}}, SHIFT(692),
  [3285] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_recursive_macro_expansion, 3, 0, 0),
  [3287] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_recursive_macro_expansion, 3, 0, 0),
  [3289] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1389),
  [3291] = {.entry = {.count = 1, .reusable = true}}, SHIFT(523),
  [3293] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_recursive_macro_expansion, 4, 0, 0),
  [3295] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_recursive_macro_expansion, 4, 0, 0),
  [3297] = {.entry = {.count = 1, .reusable = true}}, SHIFT(543),
  [3299] = {.entry = {.count = 1, .reusable = true}}, SHIFT(568),
  [3301] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2197),
  [3303] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_range_expression, 3, 0, 38),
  [3305] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__binary_expression, 3, 0, 38), SHIFT(2258),
  [3308] = {.entry = {.count = 1, .reusable = true}}, SHIFT(667),
  [3310] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_labeled_expression, 3, 0, 8),
  [3312] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_labeled_expression, 3, 0, 8),
  [3314] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1429),
  [3316] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_recursive_macro_expansion, 2, 0, 0),
  [3318] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_recursive_macro_expansion, 2, 0, 0),
  [3320] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1388),
  [3322] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1370),
  [3324] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(1429),
  [3327] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_repeat_block, 1, 0, 2),
  [3329] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_repeat_block, 1, 0, 2),
  [3331] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameter_declaration, 3, 0, 17),
  [3333] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_parameter_declaration, 3, 0, 17),
  [3335] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_else_block, 4, 0, 3),
  [3337] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_else_block, 4, 0, 3),
  [3339] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_subroutine_block, 6, 0, 37),
  [3341] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_subroutine_block, 6, 0, 37),
  [3343] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_block, 9, 0, 34),
  [3345] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_if_block, 9, 0, 34),
  [3347] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__repeat_block_pre_condition_format, 6, 0, 34),
  [3349] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__repeat_block_pre_condition_format, 6, 0, 34),
  [3351] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameter_declaration, 6, 0, 70),
  [3353] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_parameter_declaration, 6, 0, 70),
  [3355] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_subroutine_call_expression, 6, 0, 71),
  [3357] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_subroutine_call_expression, 6, 0, 71),
  [3359] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_macro_assignment_expression, 6, 0, 72),
  [3361] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_macro_assignment_expression, 6, 0, 72),
  [3363] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__repeat_block_post_condition_format, 9, 1, 109),
  [3365] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__repeat_block_post_condition_format, 9, 1, 109),
  [3367] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1676),
  [3369] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1750),
  [3371] = {.entry = {.count = 1, .reusable = true}}, SHIFT(952),
  [3373] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_block, 7, 0, 0),
  [3375] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_block, 7, 0, 0),
  [3377] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_block, 10, 0, 34),
  [3379] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_if_block, 10, 0, 34),
  [3381] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_else_block, 3, 0, 3),
  [3383] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_else_block, 3, 0, 3),
  [3385] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameter_declaration, 5, 0, 49),
  [3387] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_parameter_declaration, 5, 0, 49),
  [3389] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_if_block_repeat1, 3, 0, 0),
  [3391] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_if_block_repeat1, 3, 0, 0),
  [3393] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_block, 8, 0, 34),
  [3395] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_if_block, 8, 0, 34),
  [3397] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_macro_assignment_expression, 5, 0, 52),
  [3399] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_macro_assignment_expression, 5, 0, 52),
  [3401] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_elif_block, 7, 0, 123),
  [3403] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_elif_block, 7, 0, 123),
  [3405] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_macro_assignment_expression, 5, 0, 53),
  [3407] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_macro_assignment_expression, 5, 0, 53),
  [3409] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_while_block, 6, 0, 34),
  [3411] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_while_block, 6, 0, 34),
  [3413] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_elif_block, 8, 0, 123),
  [3415] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_elif_block, 8, 0, 123),
  [3417] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_subroutine_call_expression, 5, 0, 48),
  [3419] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_subroutine_call_expression, 5, 0, 48),
  [3421] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__statement, 2, 0, 0),
  [3423] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__statement, 2, 0, 0),
  [3425] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_command_expression, 2, 0, 4),
  [3427] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_command_expression, 2, 0, 4),
  [3429] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_command_expression, 2, 0, 5),
  [3431] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_command_expression, 2, 0, 5),
  [3433] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_while_block, 5, 0, 34),
  [3435] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_while_block, 5, 0, 34),
  [3437] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_block, 6, 0, 0),
  [3439] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_block, 6, 0, 0),
  [3441] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_block, 4, 0, 0),
  [3443] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_block, 4, 0, 0),
  [3445] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__repeat_block_post_condition_format, 7, 1, 87),
  [3447] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__repeat_block_post_condition_format, 7, 1, 87),
  [3449] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__repeat_block_post_condition_format, 8, 1, 99),
  [3451] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__repeat_block_post_condition_format, 8, 1, 99),
  [3453] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__repeat_block_pre_condition_format, 4, 0, 34),
  [3455] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__repeat_block_pre_condition_format, 4, 0, 34),
  [3457] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameter_declaration, 4, 0, 36),
  [3459] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_parameter_declaration, 4, 0, 36),
  [3461] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_macro_definition, 4, 0, 36),
  [3463] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_macro_definition, 4, 0, 36),
  [3465] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_subroutine_call_expression, 4, 0, 37),
  [3467] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_subroutine_call_expression, 4, 0, 37),
  [3469] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_labeled_expression, 4, 0, 8),
  [3471] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_labeled_expression, 4, 0, 8),
  [3473] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_macro_assignment_expression, 4, 0, 38),
  [3475] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_macro_assignment_expression, 4, 0, 38),
  [3477] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_command_expression, 3, 0, 14),
  [3479] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_command_expression, 3, 0, 14),
  [3481] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_macro_definition, 3, 0, 17),
  [3483] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_macro_definition, 3, 0, 17),
  [3485] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_command_expression, 3, 0, 15),
  [3487] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_command_expression, 3, 0, 15),
  [3489] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_block, 5, 0, 0),
  [3491] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_block, 5, 0, 0),
  [3493] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_subroutine_block, 5, 0, 37),
  [3495] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_subroutine_block, 5, 0, 37),
  [3497] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_subroutine_call_expression, 7, 0, 88),
  [3499] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_subroutine_call_expression, 7, 0, 88),
  [3501] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__repeat_block_pre_condition_format, 5, 0, 34),
  [3503] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__repeat_block_pre_condition_format, 5, 0, 34),
  [3505] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__hll_var_command_argument_list_default_format_repeat1, 2, 0, 0),
  [3507] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__hll_var_command_argument_list_default_format_repeat1, 2, 0, 0),
  [3509] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_subroutine_block_repeat1, 2, 0, 0),
  [3511] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_subroutine_block_repeat1, 2, 0, 0),
  [3513] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_subroutine_block_repeat1, 2, 0, 0), SHIFT_REPEAT(1511),
  [3516] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1915),
  [3518] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1681),
  [3520] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2192),
  [3522] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2229),
  [3524] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2350),
  [3526] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1847),
  [3528] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1840),
  [3530] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(1516),
  [3533] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1530),
  [3535] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1524),
  [3537] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__label, 2, 0, 6),
  [3539] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__label, 2, 0, 6),
  [3541] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1736),
  [3543] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1684),
  [3545] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_abstract_pointer_declarator, 2, 0, 0),
  [3547] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1528),
  [3549] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1661),
  [3551] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2437),
  [3553] = {.entry = {.count = 1, .reusable = true}}, SHIFT(313),
  [3555] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1577),
  [3557] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_abstract_pointer_declarator, 1, 0, 0),
  [3559] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1522),
  [3561] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1537),
  [3563] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_parameter_declaration, 1, 0, 76),
  [3565] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1527),
  [3567] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2297),
  [3569] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2022),
  [3571] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2274),
  [3573] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2411),
  [3575] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2244),
  [3577] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_type_descriptor, 2, 0, 41),
  [3579] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1665),
  [3581] = {.entry = {.count = 1, .reusable = true}}, SHIFT(317),
  [3583] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1526),
  [3585] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_hll_type_descriptor, 2, 0, 41), SHIFT(1563),
  [3588] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_hll_type_descriptor, 1, 0, 24), REDUCE(sym_hll_type_descriptor, 2, 0, 41),
  [3591] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_hll_type_descriptor, 1, 0, 24), REDUCE(sym_hll_type_descriptor, 2, 0, 41), SHIFT(1562),
  [3595] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_type_descriptor, 2, 0, 24),
  [3597] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_hll_type_descriptor, 2, 0, 24), SHIFT(1561),
  [3600] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_type_descriptor, 4, 0, 67),
  [3602] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_hll_type_descriptor, 4, 0, 67), SHIFT(1558),
  [3605] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_type_descriptor, 1, 0, 24),
  [3607] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_hll_type_descriptor, 1, 0, 24), SHIFT(1573),
  [3610] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_type_descriptor, 3, 0, 41),
  [3612] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_hll_type_descriptor, 3, 0, 41), SHIFT(1567),
  [3615] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_hll_type_descriptor, 2, 0, 24), REDUCE(sym_hll_type_descriptor, 3, 0, 41),
  [3618] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_hll_type_descriptor, 2, 0, 24), REDUCE(sym_hll_type_descriptor, 3, 0, 41), SHIFT(1571),
  [3622] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_type_descriptor, 3, 0, 67),
  [3624] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_hll_type_descriptor, 3, 0, 67), SHIFT(1569),
  [3627] = {.entry = {.count = 1, .reusable = true}}, SHIFT(156),
  [3629] = {.entry = {.count = 1, .reusable = true}}, SHIFT(157),
  [3631] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_abstract_array_declarator, 4, 0, 79),
  [3633] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_hll_abstract_array_declarator, 4, 0, 79), SHIFT(1621),
  [3636] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_hll_abstract_array_declarator, 4, 0, 79), SHIFT(325),
  [3639] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_hll_abstract_array_declarator, 4, 0, 79), SHIFT(1619),
  [3642] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_abstract_array_declarator, 4, 0, 92),
  [3644] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_hll_abstract_array_declarator, 4, 0, 92), SHIFT(1621),
  [3647] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_hll_abstract_array_declarator, 4, 0, 92), SHIFT(325),
  [3650] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_hll_abstract_array_declarator, 4, 0, 92), SHIFT(1620),
  [3653] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_abstract_array_declarator, 4, 0, 93),
  [3655] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_hll_abstract_array_declarator, 4, 0, 93), SHIFT(1621),
  [3658] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_hll_abstract_array_declarator, 4, 0, 93), SHIFT(325),
  [3661] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_hll_abstract_array_declarator, 4, 0, 93), SHIFT(1623),
  [3664] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_abstract_array_declarator, 4, 0, 0),
  [3666] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_hll_abstract_array_declarator, 4, 0, 0), SHIFT(1621),
  [3669] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_hll_abstract_array_declarator, 4, 0, 0), SHIFT(325),
  [3672] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_hll_abstract_array_declarator, 4, 0, 0), SHIFT(1628),
  [3675] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_abstract_array_declarator, 5, 0, 92),
  [3677] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_hll_abstract_array_declarator, 5, 0, 92), SHIFT(1621),
  [3680] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_hll_abstract_array_declarator, 5, 0, 92), SHIFT(325),
  [3683] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_hll_abstract_array_declarator, 5, 0, 92), SHIFT(1631),
  [3686] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_abstract_array_declarator, 5, 0, 93),
  [3688] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_hll_abstract_array_declarator, 5, 0, 93), SHIFT(1621),
  [3691] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_hll_abstract_array_declarator, 5, 0, 93), SHIFT(325),
  [3694] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_hll_abstract_array_declarator, 5, 0, 93), SHIFT(1632),
  [3697] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_abstract_array_declarator, 5, 0, 104),
  [3699] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_hll_abstract_array_declarator, 5, 0, 104), SHIFT(1621),
  [3702] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_hll_abstract_array_declarator, 5, 0, 104), SHIFT(325),
  [3705] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_hll_abstract_array_declarator, 5, 0, 104), SHIFT(1633),
  [3708] = {.entry = {.count = 1, .reusable = false}}, SHIFT(155),
  [3710] = {.entry = {.count = 1, .reusable = true}}, SHIFT(159),
  [3712] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_abstract_array_declarator, 6, 0, 104),
  [3714] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_hll_abstract_array_declarator, 6, 0, 104), SHIFT(1621),
  [3717] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_hll_abstract_array_declarator, 6, 0, 104), SHIFT(325),
  [3720] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_hll_abstract_array_declarator, 6, 0, 104), SHIFT(1635),
  [3723] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_abstract_array_declarator, 3, 0, 79),
  [3725] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_hll_abstract_array_declarator, 3, 0, 79), SHIFT(1621),
  [3728] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_hll_abstract_array_declarator, 3, 0, 79), SHIFT(325),
  [3731] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_hll_abstract_array_declarator, 3, 0, 79), SHIFT(1610),
  [3734] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_abstract_array_declarator, 3, 0, 0),
  [3736] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_hll_abstract_array_declarator, 3, 0, 0), SHIFT(1621),
  [3739] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_hll_abstract_array_declarator, 3, 0, 0), SHIFT(325),
  [3742] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_hll_abstract_array_declarator, 3, 0, 0), SHIFT(1614),
  [3745] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_abstract_array_declarator, 2, 0, 0),
  [3747] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_hll_abstract_array_declarator, 2, 0, 0), SHIFT(1621),
  [3750] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_hll_abstract_array_declarator, 2, 0, 0), SHIFT(325),
  [3753] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_hll_abstract_array_declarator, 2, 0, 0), SHIFT(1599),
  [3756] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1037),
  [3758] = {.entry = {.count = 1, .reusable = true}}, SHIFT(158),
  [3760] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1554),
  [3762] = {.entry = {.count = 1, .reusable = true}}, SHIFT(353),
  [3764] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1122),
  [3766] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_hll_type_descriptor_repeat1, 2, 0, 0),
  [3768] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_hll_type_descriptor_repeat1, 2, 0, 0), SHIFT_REPEAT(1526),
  [3771] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_hll_type_descriptor_repeat1, 2, 0, 0),
  [3773] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__hll_declaration_specifiers_repeat1, 2, 0, 0),
  [3775] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__hll_declaration_specifiers_repeat1, 2, 0, 0), SHIFT_REPEAT(1526),
  [3778] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1621),
  [3780] = {.entry = {.count = 1, .reusable = true}}, SHIFT(325),
  [3782] = {.entry = {.count = 1, .reusable = false}}, SHIFT(233),
  [3784] = {.entry = {.count = 1, .reusable = true}}, SHIFT(234),
  [3786] = {.entry = {.count = 1, .reusable = true}}, SHIFT(235),
  [3788] = {.entry = {.count = 1, .reusable = true}}, SHIFT(150),
  [3790] = {.entry = {.count = 1, .reusable = true}}, SHIFT(151),
  [3792] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(1577),
  [3795] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1642),
  [3797] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2393),
  [3799] = {.entry = {.count = 1, .reusable = true}}, SHIFT(322),
  [3801] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1651),
  [3803] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1076),
  [3805] = {.entry = {.count = 1, .reusable = false}}, SHIFT(203),
  [3807] = {.entry = {.count = 1, .reusable = true}}, SHIFT(486),
  [3809] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1585),
  [3811] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1599),
  [3813] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1608),
  [3815] = {.entry = {.count = 1, .reusable = true}}, SHIFT(488),
  [3817] = {.entry = {.count = 1, .reusable = true}}, SHIFT(465),
  [3819] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1595),
  [3821] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1645),
  [3823] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1648),
  [3825] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1081),
  [3827] = {.entry = {.count = 1, .reusable = true}}, SHIFT(431),
  [3829] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1594),
  [3831] = {.entry = {.count = 1, .reusable = true}}, SHIFT(493),
  [3833] = {.entry = {.count = 1, .reusable = true}}, SHIFT(443),
  [3835] = {.entry = {.count = 1, .reusable = true}}, SHIFT(494),
  [3837] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1597),
  [3839] = {.entry = {.count = 1, .reusable = true}}, SHIFT(428),
  [3841] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1610),
  [3843] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1614),
  [3845] = {.entry = {.count = 1, .reusable = true}}, SHIFT(440),
  [3847] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1603),
  [3849] = {.entry = {.count = 1, .reusable = true}}, SHIFT(442),
  [3851] = {.entry = {.count = 1, .reusable = true}}, SHIFT(445),
  [3853] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1607),
  [3855] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1586),
  [3857] = {.entry = {.count = 1, .reusable = true}}, SHIFT(447),
  [3859] = {.entry = {.count = 1, .reusable = true}}, SHIFT(463),
  [3861] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1611),
  [3863] = {.entry = {.count = 1, .reusable = true}}, SHIFT(466),
  [3865] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1619),
  [3867] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1620),
  [3869] = {.entry = {.count = 1, .reusable = true}}, SHIFT(476),
  [3871] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1617),
  [3873] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1623),
  [3875] = {.entry = {.count = 1, .reusable = true}}, SHIFT(483),
  [3877] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1628),
  [3879] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1574),
  [3881] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1631),
  [3883] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1627),
  [3885] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1632),
  [3887] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1633),
  [3889] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1582),
  [3891] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1635),
  [3893] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1657),
  [3895] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1581),
  [3897] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1588),
  [3899] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1592),
  [3901] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1636),
  [3903] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1602),
  [3905] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1629),
  [3907] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1637),
  [3909] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1059),
  [3911] = {.entry = {.count = 1, .reusable = true}}, SHIFT(434),
  [3913] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1656),
  [3915] = {.entry = {.count = 1, .reusable = true}}, SHIFT(429),
  [3917] = {.entry = {.count = 1, .reusable = true}}, SHIFT(478),
  [3919] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1653),
  [3921] = {.entry = {.count = 1, .reusable = true}}, SHIFT(458),
  [3923] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1810),
  [3925] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1704),
  [3927] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2369),
  [3929] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2159),
  [3931] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1754),
  [3933] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2408),
  [3935] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2303),
  [3937] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2317),
  [3939] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1696),
  [3941] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__hll_pointer_declarator_specifier, 1, 0, 0),
  [3943] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__hll_pointer_declarator_specifier, 1, 0, 0),
  [3945] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__hll_pointer_declarator_specifier, 1, 0, 0), SHIFT(1783),
  [3948] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1659),
  [3950] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1964),
  [3952] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2382),
  [3954] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2250),
  [3956] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2251),
  [3958] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2173),
  [3960] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2415),
  [3962] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1664),
  [3964] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__hll_pointer_declarator_specifier, 3, 0, 0),
  [3966] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__hll_pointer_declarator_specifier, 3, 0, 0),
  [3968] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__hll_pointer_declarator_specifier_repeat1, 1, 0, 0),
  [3970] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__hll_pointer_declarator_specifier, 3, 0, 0), SHIFT(1975),
  [3973] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_hll_type_descriptor_repeat2, 2, 0, 0), SHIFT_REPEAT(1526),
  [3976] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_hll_type_descriptor_repeat2, 2, 0, 0), SHIFT_REPEAT(1927),
  [3979] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_sized_type_specifier, 2, 0, 0),
  [3981] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_hll_sized_type_specifier, 2, 0, 0),
  [3983] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_hll_sized_type_specifier, 2, 0, 0), SHIFT(1722),
  [3986] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__hll_pointer_declarator_specifier, 4, 0, 0),
  [3988] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__hll_pointer_declarator_specifier, 4, 0, 0),
  [3990] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__hll_pointer_declarator_specifier, 4, 0, 0), SHIFT(1975),
  [3993] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__hll_pointer_declarator_specifier, 2, 0, 0),
  [3995] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__hll_pointer_declarator_specifier, 2, 0, 0),
  [3997] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__hll_pointer_declarator_specifier, 2, 0, 0), SHIFT(1975),
  [4000] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_sized_type_specifier, 1, 0, 0),
  [4002] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_hll_sized_type_specifier, 1, 0, 0),
  [4004] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_hll_sized_type_specifier, 1, 0, 0), SHIFT(1722),
  [4007] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_sized_type_specifier, 2, 0, 41),
  [4009] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_hll_sized_type_specifier, 2, 0, 41),
  [4011] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__hll_declaration_specifiers_repeat2, 2, 0, 0),
  [4013] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__hll_declaration_specifiers_repeat2, 2, 0, 0),
  [4015] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__hll_declaration_specifiers_repeat2, 2, 0, 0), SHIFT_REPEAT(1782),
  [4018] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_union_specifier, 3, 0, 55),
  [4020] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_hll_union_specifier, 3, 0, 55),
  [4022] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__hll_type_identifier, 1, 0, 23),
  [4024] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2041),
  [4026] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1744),
  [4028] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1708),
  [4030] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1842),
  [4032] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__hll_declaration_specifiers, 3, 0, 41),
  [4034] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__hll_declaration_specifiers, 3, 0, 41),
  [4036] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1782),
  [4038] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_struct_specifier, 3, 0, 55),
  [4040] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_hll_struct_specifier, 3, 0, 55),
  [4042] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__hll_declaration_specifiers, 1, 0, 24),
  [4044] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__hll_declaration_specifiers, 1, 0, 24),
  [4046] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__hll_declaration_specifiers, 2, 0, 24),
  [4048] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__hll_declaration_specifiers, 2, 0, 24),
  [4050] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_enum_specifier, 3, 0, 55),
  [4052] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_hll_enum_specifier, 3, 0, 55),
  [4054] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__hll_declaration_specifiers, 2, 0, 41),
  [4056] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__hll_declaration_specifiers, 2, 0, 41),
  [4058] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1937),
  [4060] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2005),
  [4062] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1727),
  [4064] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1831),
  [4066] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1966),
  [4068] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1908),
  [4070] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1912),
  [4072] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1919),
  [4074] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2009),
  [4076] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1931),
  [4078] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1914),
  [4080] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1933),
  [4082] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1935),
  [4084] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1868),
  [4086] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(1696),
  [4089] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2024),
  [4091] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1941),
  [4093] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1942),
  [4095] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1944),
  [4097] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1512),
  [4099] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_pointer_declarator, 2, 0, 58),
  [4101] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1962),
  [4103] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2092),
  [4105] = {.entry = {.count = 1, .reusable = false}}, SHIFT(936),
  [4107] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1740),
  [4109] = {.entry = {.count = 1, .reusable = false}}, SHIFT_EXTRA(),
  [4111] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_array_declarator, 5, 0, 100),
  [4113] = {.entry = {.count = 1, .reusable = false}}, SHIFT(750),
  [4115] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1709),
  [4117] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1741),
  [4119] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_type_pattern, 1, 0, 0),
  [4121] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_hll_type_pattern, 1, 0, 0),
  [4123] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_array_declarator, 5, 0, 101),
  [4125] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__hll_declaration_specifiers, 3, 0, 41), SHIFT(1782),
  [4128] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2096),
  [4130] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2225),
  [4132] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1707),
  [4134] = {.entry = {.count = 1, .reusable = false}}, SHIFT(770),
  [4136] = {.entry = {.count = 1, .reusable = false}}, SHIFT(994),
  [4138] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1718),
  [4140] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_array_declarator, 5, 0, 102),
  [4142] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_declaration, 3, 0, 59),
  [4144] = {.entry = {.count = 1, .reusable = false}}, SHIFT(548),
  [4146] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1720),
  [4148] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_array_declarator, 6, 0, 113),
  [4150] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_array_declarator, 3, 0, 75),
  [4152] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_array_declarator, 5, 0, 103),
  [4154] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1350),
  [4156] = {.entry = {.count = 1, .reusable = false}}, SHIFT(964),
  [4158] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_array_declarator, 6, 0, 114),
  [4160] = {.entry = {.count = 1, .reusable = false}}, SHIFT(560),
  [4162] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_parameter_declaration, 2, 0, 40),
  [4164] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1515),
  [4166] = {.entry = {.count = 1, .reusable = true}}, SHIFT(324),
  [4168] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1876),
  [4170] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_hll_sized_type_specifier_repeat1, 2, 0, 0),
  [4172] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1738),
  [4174] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2218),
  [4176] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__hll_declaration_specifiers, 2, 0, 24), SHIFT(1782),
  [4179] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_array_declarator, 4, 0, 90),
  [4181] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_subroutine_block_repeat1, 2, 0, 0), SHIFT_REPEAT(1727),
  [4184] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_array_declarator, 8, 0, 122),
  [4186] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1260),
  [4188] = {.entry = {.count = 1, .reusable = false}}, SHIFT(868),
  [4190] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1731),
  [4192] = {.entry = {.count = 1, .reusable = false}}, SHIFT(869),
  [4194] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_declaration, 2, 0, 40),
  [4196] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_array_declarator, 6, 0, 110),
  [4198] = {.entry = {.count = 1, .reusable = false}}, SHIFT(873),
  [4200] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1748),
  [4202] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1342),
  [4204] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__hll_declaration_specifiers, 2, 0, 41), SHIFT(1782),
  [4207] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_array_declarator, 4, 0, 89),
  [4209] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1329),
  [4211] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1735),
  [4213] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_string_repeat1, 2, 0, 0), SHIFT_REPEAT(2092),
  [4216] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_string_repeat1, 2, 0, 0),
  [4218] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_string_repeat1, 2, 0, 0), SHIFT_REPEAT(1740),
  [4221] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_hll_type_pattern_repeat1, 2, 0, 0), SHIFT_REPEAT(1810),
  [4224] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_hll_type_pattern_repeat1, 2, 0, 0), SHIFT_REPEAT(1741),
  [4227] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_hll_type_pattern_repeat1, 2, 0, 0),
  [4229] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_hll_type_pattern_repeat1, 2, 0, 0),
  [4231] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1669),
  [4233] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1945),
  [4235] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__host_command_argument_list_default_format, 1, 0, 0),
  [4237] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1685),
  [4239] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_array_declarator, 7, 0, 120),
  [4241] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_array_declarator, 7, 0, 118),
  [4243] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_abstract_pointer_declarator, 3, 0, 75),
  [4245] = {.entry = {.count = 1, .reusable = false}}, SHIFT(846),
  [4247] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_array_declarator, 6, 0, 111),
  [4249] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__hll_declaration_specifiers, 1, 0, 24), SHIFT(1782),
  [4252] = {.entry = {.count = 1, .reusable = false}}, SHIFT(944),
  [4254] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1701),
  [4256] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_abstract_pointer_declarator, 2, 0, 58),
  [4258] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2337),
  [4260] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2016),
  [4262] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2266),
  [4264] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1760),
  [4266] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_array_declarator, 6, 0, 112),
  [4268] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_array_declarator, 7, 0, 119),
  [4270] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2263),
  [4272] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1965),
  [4274] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1345),
  [4276] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1717),
  [4278] = {.entry = {.count = 1, .reusable = false}}, SHIFT(417),
  [4280] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1762),
  [4282] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2331),
  [4284] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_pointer_declarator, 3, 0, 75),
  [4286] = {.entry = {.count = 1, .reusable = false}}, SHIFT(424),
  [4288] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1244),
  [4290] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1729),
  [4292] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_type_descriptor, 5, 0, 97),
  [4294] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_type_descriptor, 3, 0, 65),
  [4296] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_format_expression_repeat1, 2, 0, 74), SHIFT_REPEAT(2423),
  [4299] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_format_expression_repeat1, 2, 0, 74),
  [4301] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_format_expression_repeat1, 2, 0, 74),
  [4303] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__hll_var_pattern_command_argument_list_format_repeat1, 2, 0, 0),
  [4305] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1977),
  [4307] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1836),
  [4309] = {.entry = {.count = 1, .reusable = true}}, SHIFT(315),
  [4311] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1799),
  [4313] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2423),
  [4315] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_format_expression, 3, 0, 54),
  [4317] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_format_expression, 3, 0, 54),
  [4319] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_type_descriptor, 6, 0, 108),
  [4321] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_type_descriptor, 3, 0, 66),
  [4323] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2021),
  [4325] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_type_descriptor, 5, 0, 98),
  [4327] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_hll_sized_type_specifier_repeat1, 2, 0, 0), SHIFT_REPEAT(2345),
  [4330] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_hll_type_descriptor, 4, 0, 81), REDUCE(sym_hll_type_descriptor, 5, 0, 97),
  [4333] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_type_descriptor, 4, 0, 81),
  [4335] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_format_expression, 2, 0, 33),
  [4337] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_format_expression, 2, 0, 33),
  [4339] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1922),
  [4341] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1770),
  [4343] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_hll_type_descriptor, 3, 0, 65), REDUCE(sym_hll_type_descriptor, 4, 0, 83),
  [4346] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1869),
  [4348] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_type_descriptor, 2, 0, 45),
  [4350] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_type_descriptor, 4, 0, 83),
  [4352] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_hll_type_descriptor, 2, 0, 45), REDUCE(sym_hll_type_descriptor, 3, 0, 66),
  [4355] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__hll_var_pattern_command_argument_list_format_repeat1, 2, 0, 0), SHIFT_REPEAT(2369),
  [4358] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_hll_type_pattern_repeat1, 1, 0, 51),
  [4360] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_hll_type_pattern_repeat1, 1, 0, 51),
  [4362] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_type_descriptor, 4, 0, 84),
  [4364] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__hll_var_pattern_command_argument_list_format_repeat2, 2, 0, 0), SHIFT_REPEAT(1958),
  [4367] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__hll_var_pattern_command_argument_list_format_repeat2, 2, 0, 0), SHIFT_REPEAT(1822),
  [4370] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__command_arguments, 5, 0, 0),
  [4372] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1951),
  [4374] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(1815),
  [4377] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1823),
  [4379] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_parenthesized_declarator, 4, 0, 0),
  [4381] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_hll_parenthesized_declarator, 4, 0, 0),
  [4383] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1860),
  [4385] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__host_command_argument_list_default_format, 2, 0, 0),
  [4387] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__command_arguments_repeat3, 2, 0, 0),
  [4389] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__command_arguments_repeat3, 2, 0, 0), SHIFT_REPEAT(1951),
  [4392] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1958),
  [4394] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1839),
  [4396] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__command_arguments_repeat2, 2, 0, 0),
  [4398] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1815),
  [4400] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_parameter_list, 3, 0, 0),
  [4402] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_hll_parameter_list, 3, 0, 0),
  [4404] = {.entry = {.count = 1, .reusable = true}}, SHIFT(932),
  [4406] = {.entry = {.count = 1, .reusable = false}}, SHIFT(930),
  [4408] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1907),
  [4410] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1910),
  [4412] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2010),
  [4414] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1833),
  [4416] = {.entry = {.count = 1, .reusable = true}}, SHIFT(346),
  [4418] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2193),
  [4420] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1973),
  [4422] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1838),
  [4424] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_abstract_parenthesized_declarator, 4, 0, 0),
  [4426] = {.entry = {.count = 1, .reusable = true}}, SHIFT(796),
  [4428] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1946),
  [4430] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_hll_type_pattern_repeat1, 2, 0, 0), SHIFT_REPEAT(1958),
  [4433] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_hll_type_pattern_repeat1, 2, 0, 0), SHIFT_REPEAT(1839),
  [4436] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_parameter_list, 2, 0, 0),
  [4438] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(1842),
  [4441] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_abstract_array_declarator, 4, 0, 94),
  [4443] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1204),
  [4445] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_abstract_array_declarator, 4, 0, 80),
  [4447] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_function_declarator, 2, 0, 57),
  [4449] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_hll_function_declarator, 2, 0, 57),
  [4451] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1666),
  [4453] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__hll_var_command_with_default_format, 1, 0, 0),
  [4455] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__hll_var_command_with_default_format, 1, 0, 0),
  [4457] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_abstract_array_declarator, 4, 0, 95),
  [4459] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__var_command_argument_list_non_hll_format_repeat1, 2, 0, 0), SHIFT_REPEAT(2366),
  [4462] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__var_command_argument_list_non_hll_format_repeat1, 2, 0, 0), SHIFT_REPEAT(2369),
  [4465] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_parameter_list, 4, 0, 0),
  [4467] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1036),
  [4469] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1496),
  [4471] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1507),
  [4473] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2003),
  [4475] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2134),
  [4477] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1508),
  [4479] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1433),
  [4481] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__command_arguments, 6, 0, 0),
  [4483] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_parenthesized_declarator, 5, 0, 0),
  [4485] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_hll_parenthesized_declarator, 5, 0, 0),
  [4487] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1663),
  [4489] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2434),
  [4491] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__hll_var_command_with_default_format, 2, 0, 0),
  [4493] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__hll_var_command_with_default_format, 2, 0, 0),
  [4495] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__command_identifier, 2, 0, 1),
  [4497] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__command_identifier, 2, 0, 1),
  [4499] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__command_identifier, 1, 0, 1),
  [4501] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__command_identifier, 1, 0, 1),
  [4503] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_hll_parameter_list, 4, 0, 0),
  [4505] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_abstract_function_declarator, 2, 0, 57),
  [4507] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_abstract_parenthesized_declarator, 5, 0, 0),
  [4509] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1078),
  [4511] = {.entry = {.count = 1, .reusable = true}}, SHIFT(761),
  [4513] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_abstract_array_declarator, 5, 0, 94),
  [4515] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_abstract_array_declarator, 5, 0, 105),
  [4517] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_abstract_array_declarator, 5, 0, 106),
  [4519] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_abstract_array_declarator, 5, 0, 80),
  [4521] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_abstract_array_declarator, 5, 0, 107),
  [4523] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_abstract_array_declarator, 5, 0, 95),
  [4525] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1486),
  [4527] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1502),
  [4529] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1475),
  [4531] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1476),
  [4533] = {.entry = {.count = 1, .reusable = true}}, SHIFT(906),
  [4535] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__command_arguments, 7, 0, 0),
  [4537] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2207),
  [4539] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1477),
  [4541] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1478),
  [4543] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1479),
  [4545] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1480),
  [4547] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_abstract_array_declarator, 6, 0, 105),
  [4549] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_abstract_array_declarator, 6, 0, 106),
  [4551] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_abstract_array_declarator, 6, 0, 115),
  [4553] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_abstract_array_declarator, 6, 0, 107),
  [4555] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_abstract_array_declarator, 6, 0, 116),
  [4557] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_abstract_array_declarator, 6, 0, 117),
  [4559] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_abstract_array_declarator, 6, 0, 95),
  [4561] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_macro_definition_repeat1, 2, 0, 18),
  [4563] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_macro_definition_repeat1, 2, 0, 18), SHIFT_REPEAT(2003),
  [4566] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_abstract_array_declarator, 7, 0, 115),
  [4568] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_abstract_array_declarator, 7, 0, 116),
  [4570] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_abstract_array_declarator, 7, 0, 117),
  [4572] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_abstract_array_declarator, 7, 0, 121),
  [4574] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_format_expression_repeat1, 2, 0, 33),
  [4576] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_format_expression_repeat1, 2, 0, 33),
  [4578] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_abstract_array_declarator, 8, 0, 121),
  [4580] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__command_arguments, 4, 0, 0),
  [4582] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__command_identifier_repeat1, 2, 0, 0), SHIFT_REPEAT(2434),
  [4585] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__command_identifier_repeat1, 2, 0, 0),
  [4587] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__command_identifier_repeat1, 2, 0, 0),
  [4589] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_parenthesized_declarator, 3, 0, 0),
  [4591] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_hll_parenthesized_declarator, 3, 0, 0),
  [4593] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1817),
  [4595] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1818),
  [4597] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_hll_parameter_list, 2, 0, 0),
  [4599] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_function_declarator, 3, 0, 77),
  [4601] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_hll_function_declarator, 3, 0, 77),
  [4603] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_argument_list_repeat1, 2, 0, 0), SHIFT_REPEAT(120),
  [4606] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_argument_list_repeat1, 2, 0, 0), SHIFT_REPEAT(2193),
  [4609] = {.entry = {.count = 1, .reusable = true}}, SHIFT(933),
  [4611] = {.entry = {.count = 1, .reusable = false}}, SHIFT(929),
  [4613] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_abstract_parenthesized_declarator, 3, 0, 0),
  [4615] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_abstract_array_declarator, 3, 0, 80),
  [4617] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1439),
  [4619] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1440),
  [4621] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_abstract_function_declarator, 3, 0, 77),
  [4623] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1449),
  [4625] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1453),
  [4627] = {.entry = {.count = 1, .reusable = true}}, SHIFT(894),
  [4629] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__host_command_argument_list_default_format_repeat2, 2, 0, 0),
  [4631] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__host_command_argument_list_default_format_repeat2, 2, 0, 0),
  [4633] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__host_command_argument_list_default_format_repeat2, 2, 0, 0), SHIFT_REPEAT(1685),
  [4636] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__host_command_argument_list_default_format_repeat1, 2, 0, 0), SHIFT_REPEAT(1945),
  [4639] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__host_command_argument_list_default_format_repeat1, 2, 0, 0),
  [4641] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__host_command_argument_list_default_format_repeat1, 2, 0, 0),
  [4643] = {.entry = {.count = 1, .reusable = true}}, SHIFT(886),
  [4645] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1950),
  [4647] = {.entry = {.count = 1, .reusable = true}}, SHIFT(875),
  [4649] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1960),
  [4651] = {.entry = {.count = 1, .reusable = true}}, SHIFT(888),
  [4653] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1983),
  [4655] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_option_expression, 2, 0, 39),
  [4657] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_option_expression, 2, 0, 39), SHIFT(119),
  [4660] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1481),
  [4662] = {.entry = {.count = 1, .reusable = false}}, SHIFT(30),
  [4664] = {.entry = {.count = 1, .reusable = true}}, SHIFT(950),
  [4666] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1969),
  [4668] = {.entry = {.count = 1, .reusable = true}}, SHIFT(257),
  [4670] = {.entry = {.count = 1, .reusable = false}}, SHIFT(115),
  [4672] = {.entry = {.count = 1, .reusable = true}}, SHIFT(896),
  [4674] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1975),
  [4676] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__command_identifier_repeat1, 2, 0, 21),
  [4678] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__command_identifier_repeat1, 2, 0, 21),
  [4680] = {.entry = {.count = 1, .reusable = true}}, SHIFT(265),
  [4682] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2214),
  [4684] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__var_command_argument_list_non_hll_format_repeat1, 2, 0, 0),
  [4686] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__hll_var_command_argument_list_default_format, 4, 0, 0),
  [4688] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2176),
  [4690] = {.entry = {.count = 1, .reusable = true}}, SHIFT(948),
  [4692] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2426),
  [4694] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__var_command_argument_list_non_hll_format, 2, 0, 0),
  [4696] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1967),
  [4698] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__hll_pointer_declarator_specifier_repeat1, 2, 0, 0),
  [4700] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__hll_pointer_declarator_specifier_repeat1, 2, 0, 0), SHIFT_REPEAT(1526),
  [4703] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__hll_default_format_var_command, 1, 0, 3),
  [4705] = {.entry = {.count = 1, .reusable = false}}, SHIFT(321),
  [4707] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__non_hll_var_command, 1, 0, 3),
  [4709] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1686),
  [4711] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_hll_string_literal_repeat1, 2, 0, 0),
  [4713] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_hll_string_literal_repeat1, 2, 0, 0), SHIFT_REPEAT(1983),
  [4716] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1676),
  [4718] = {.entry = {.count = 1, .reusable = true}}, SHIFT(275),
  [4720] = {.entry = {.count = 1, .reusable = false}}, SHIFT(106),
  [4722] = {.entry = {.count = 1, .reusable = true}}, SHIFT(802),
  [4724] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1993),
  [4726] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__hll_var_command_argument_list_default_format, 6, 0, 0),
  [4728] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2305),
  [4730] = {.entry = {.count = 1, .reusable = true}}, SHIFT(805),
  [4732] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2301),
  [4734] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_hll_argument_list_repeat1, 4, 0, 0),
  [4736] = {.entry = {.count = 1, .reusable = true}}, SHIFT(94),
  [4738] = {.entry = {.count = 1, .reusable = true}}, SHIFT(125),
  [4740] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1462),
  [4742] = {.entry = {.count = 1, .reusable = false}}, SHIFT(31),
  [4744] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__var_command_argument_list_non_hll_format, 1, 0, 0),
  [4746] = {.entry = {.count = 1, .reusable = true}}, SHIFT(255),
  [4748] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2195),
  [4750] = {.entry = {.count = 1, .reusable = true}}, SHIFT(277),
  [4752] = {.entry = {.count = 1, .reusable = false}}, SHIFT(139),
  [4754] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_format_expression_repeat1, 2, 0, 74), SHIFT_REPEAT(2426),
  [4757] = {.entry = {.count = 1, .reusable = true}}, SHIFT(284),
  [4759] = {.entry = {.count = 1, .reusable = true}}, SHIFT(768),
  [4761] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2012),
  [4763] = {.entry = {.count = 1, .reusable = true}}, SHIFT(766),
  [4765] = {.entry = {.count = 1, .reusable = false}}, SHIFT(109),
  [4767] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1310),
  [4769] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2019),
  [4771] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1326),
  [4773] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__other_command, 1, 0, 3),
  [4775] = {.entry = {.count = 1, .reusable = false}}, SHIFT(29),
  [4777] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_labeled_expression_repeat1, 2, 0, 0),
  [4779] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_labeled_expression_repeat1, 2, 0, 0), SHIFT_REPEAT(2021),
  [4782] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_labeled_expression_repeat1, 2, 0, 0),
  [4784] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2294),
  [4786] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2027),
  [4788] = {.entry = {.count = 1, .reusable = true}}, SHIFT(286),
  [4790] = {.entry = {.count = 1, .reusable = false}}, SHIFT(140),
  [4792] = {.entry = {.count = 1, .reusable = true}}, SHIFT(292),
  [4794] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2333),
  [4796] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1132),
  [4798] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__hll_var_command_argument_list_default_format, 5, 0, 0),
  [4800] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1120),
  [4802] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2028),
  [4804] = {.entry = {.count = 1, .reusable = true}}, SHIFT(101),
  [4806] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2129),
  [4808] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1852),
  [4810] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1517),
  [4812] = {.entry = {.count = 1, .reusable = true}}, SHIFT(37),
  [4814] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1974),
  [4816] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2025),
  [4818] = {.entry = {.count = 1, .reusable = true}}, SHIFT(741),
  [4820] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2190),
  [4822] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2394),
  [4824] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2395),
  [4826] = {.entry = {.count = 1, .reusable = true}}, SHIFT(801),
  [4828] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1751),
  [4830] = {.entry = {.count = 1, .reusable = true}}, SHIFT(797),
  [4832] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1889),
  [4834] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1890),
  [4836] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1892),
  [4838] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__function_identifier_repeat1, 2, 0, 0),
  [4840] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__function_identifier_repeat1, 2, 0, 0), SHIFT_REPEAT(2387),
  [4843] = {.entry = {.count = 1, .reusable = true}}, SHIFT(721),
  [4845] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2058),
  [4847] = {.entry = {.count = 1, .reusable = true}}, SHIFT(108),
  [4849] = {.entry = {.count = 1, .reusable = true}}, SHIFT(881),
  [4851] = {.entry = {.count = 1, .reusable = true}}, SHIFT(708),
  [4853] = {.entry = {.count = 1, .reusable = true}}, SHIFT(725),
  [4855] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2053),
  [4857] = {.entry = {.count = 1, .reusable = true}}, SHIFT(726),
  [4859] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2065),
  [4861] = {.entry = {.count = 1, .reusable = true}}, SHIFT(22),
  [4863] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2066),
  [4865] = {.entry = {.count = 1, .reusable = true}}, SHIFT(117),
  [4867] = {.entry = {.count = 1, .reusable = true}}, SHIFT(902),
  [4869] = {.entry = {.count = 1, .reusable = true}}, SHIFT(730),
  [4871] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21),
  [4873] = {.entry = {.count = 1, .reusable = true}}, SHIFT(23),
  [4875] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2070),
  [4877] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1873),
  [4879] = {.entry = {.count = 1, .reusable = true}}, SHIFT(24),
  [4881] = {.entry = {.count = 1, .reusable = true}}, SHIFT(907),
  [4883] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1004),
  [4885] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2364),
  [4887] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2409),
  [4889] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1375),
  [4891] = {.entry = {.count = 1, .reusable = true}}, SHIFT(616),
  [4893] = {.entry = {.count = 1, .reusable = true}}, SHIFT(126),
  [4895] = {.entry = {.count = 1, .reusable = true}}, SHIFT(127),
  [4897] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2215),
  [4899] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2002),
  [4901] = {.entry = {.count = 1, .reusable = true}}, SHIFT(637),
  [4903] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2084),
  [4905] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2003),
  [4907] = {.entry = {.count = 1, .reusable = true}}, SHIFT(685),
  [4909] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2169),
  [4911] = {.entry = {.count = 1, .reusable = true}}, SHIFT(559),
  [4913] = {.entry = {.count = 1, .reusable = true}}, SHIFT(563),
  [4915] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2088),
  [4917] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17),
  [4919] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2089),
  [4921] = {.entry = {.count = 1, .reusable = true}}, SHIFT(44),
  [4923] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2170),
  [4925] = {.entry = {.count = 1, .reusable = true}}, SHIFT(587),
  [4927] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20),
  [4929] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18),
  [4931] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2091),
  [4933] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19),
  [4935] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1841),
  [4937] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2418),
  [4939] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2419),
  [4941] = {.entry = {.count = 1, .reusable = true}}, SHIFT(759),
  [4943] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1710),
  [4945] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1539),
  [4947] = {.entry = {.count = 1, .reusable = true}}, SHIFT(612),
  [4949] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2099),
  [4951] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1865),
  [4953] = {.entry = {.count = 1, .reusable = true}}, SHIFT(625),
  [4955] = {.entry = {.count = 1, .reusable = true}}, SHIFT(626),
  [4957] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2103),
  [4959] = {.entry = {.count = 1, .reusable = true}}, SHIFT(84),
  [4961] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2104),
  [4963] = {.entry = {.count = 1, .reusable = true}}, SHIFT(462),
  [4965] = {.entry = {.count = 1, .reusable = true}}, SHIFT(635),
  [4967] = {.entry = {.count = 1, .reusable = true}}, SHIFT(82),
  [4969] = {.entry = {.count = 1, .reusable = true}}, SHIFT(85),
  [4971] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2106),
  [4973] = {.entry = {.count = 1, .reusable = true}}, SHIFT(86),
  [4975] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2385),
  [4977] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2431),
  [4979] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2433),
  [4981] = {.entry = {.count = 1, .reusable = true}}, SHIFT(918),
  [4983] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1734),
  [4985] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_macro_definition_repeat1, 2, 0, 16),
  [4987] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_macro_definition_repeat1, 2, 0, 16),
  [4989] = {.entry = {.count = 1, .reusable = true}}, SHIFT(671),
  [4991] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2112),
  [4993] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__hll_var_pattern_command_argument_list_format, 3, 0, 0),
  [4995] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2145),
  [4997] = {.entry = {.count = 1, .reusable = true}}, SHIFT(687),
  [4999] = {.entry = {.count = 1, .reusable = true}}, SHIFT(688),
  [5001] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2116),
  [5003] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16),
  [5005] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2117),
  [5007] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1897),
  [5009] = {.entry = {.count = 1, .reusable = true}}, SHIFT(707),
  [5011] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15),
  [5013] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14),
  [5015] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2119),
  [5017] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13),
  [5019] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1703),
  [5021] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1898),
  [5023] = {.entry = {.count = 1, .reusable = true}}, SHIFT(519),
  [5025] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2125),
  [5027] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1899),
  [5029] = {.entry = {.count = 1, .reusable = true}}, SHIFT(521),
  [5031] = {.entry = {.count = 1, .reusable = true}}, SHIFT(522),
  [5033] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2128),
  [5035] = {.entry = {.count = 1, .reusable = true}}, SHIFT(943),
  [5037] = {.entry = {.count = 1, .reusable = true}}, SHIFT(945),
  [5039] = {.entry = {.count = 1, .reusable = true}}, SHIFT(524),
  [5041] = {.entry = {.count = 1, .reusable = true}}, SHIFT(102),
  [5043] = {.entry = {.count = 1, .reusable = true}}, SHIFT(103),
  [5045] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2131),
  [5047] = {.entry = {.count = 1, .reusable = true}}, SHIFT(104),
  [5049] = {.entry = {.count = 1, .reusable = true}}, SHIFT(913),
  [5051] = {.entry = {.count = 1, .reusable = true}}, SHIFT(537),
  [5053] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2136),
  [5055] = {.entry = {.count = 1, .reusable = true}}, SHIFT(540),
  [5057] = {.entry = {.count = 1, .reusable = true}}, SHIFT(541),
  [5059] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2139),
  [5061] = {.entry = {.count = 1, .reusable = true}}, SHIFT(87),
  [5063] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2140),
  [5065] = {.entry = {.count = 1, .reusable = true}}, SHIFT(544),
  [5067] = {.entry = {.count = 1, .reusable = true}}, SHIFT(88),
  [5069] = {.entry = {.count = 1, .reusable = true}}, SHIFT(89),
  [5071] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2142),
  [5073] = {.entry = {.count = 1, .reusable = true}}, SHIFT(83),
  [5075] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1713),
  [5077] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1543),
  [5079] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__hll_var_pattern_command_argument_list_format_repeat2, 2, 0, 0),
  [5081] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1544),
  [5083] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__hll_var_pattern_command_argument_list_format, 2, 0, 0),
  [5085] = {.entry = {.count = 1, .reusable = true}}, SHIFT(561),
  [5087] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2151),
  [5089] = {.entry = {.count = 1, .reusable = true}}, SHIFT(600),
  [5091] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2167),
  [5093] = {.entry = {.count = 1, .reusable = true}}, SHIFT(565),
  [5095] = {.entry = {.count = 1, .reusable = true}}, SHIFT(566),
  [5097] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2155),
  [5099] = {.entry = {.count = 1, .reusable = true}}, SHIFT(25),
  [5101] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2156),
  [5103] = {.entry = {.count = 1, .reusable = true}}, SHIFT(569),
  [5105] = {.entry = {.count = 1, .reusable = true}}, SHIFT(27),
  [5107] = {.entry = {.count = 1, .reusable = true}}, SHIFT(26),
  [5109] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2158),
  [5111] = {.entry = {.count = 1, .reusable = true}}, SHIFT(28),
  [5113] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1989),
  [5115] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1972),
  [5117] = {.entry = {.count = 1, .reusable = true}}, SHIFT(611),
  [5119] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2076),
  [5121] = {.entry = {.count = 1, .reusable = true}}, SHIFT(891),
  [5123] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1763),
  [5125] = {.entry = {.count = 1, .reusable = true}}, SHIFT(794),
  [5127] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1730),
  [5129] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1902),
  [5131] = {.entry = {.count = 1, .reusable = true}}, SHIFT(547),
  [5133] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1549),
  [5135] = {.entry = {.count = 1, .reusable = true}}, SHIFT(595),
  [5137] = {.entry = {.count = 1, .reusable = true}}, SHIFT(73),
  [5139] = {.entry = {.count = 1, .reusable = true}}, SHIFT(334),
  [5141] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2375),
  [5143] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2377),
  [5145] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__var_command_with_non_hll_format, 3, 0, 0),
  [5147] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__var_command_with_non_hll_format, 3, 0, 0),
  [5149] = {.entry = {.count = 1, .reusable = true}}, SHIFT(474),
  [5151] = {.entry = {.count = 1, .reusable = true}}, SHIFT(79),
  [5153] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2211),
  [5155] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1612),
  [5157] = {.entry = {.count = 1, .reusable = true}}, SHIFT(599),
  [5159] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2056),
  [5161] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1622),
  [5163] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1625),
  [5165] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1630),
  [5167] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1634),
  [5169] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1954),
  [5171] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1624),
  [5173] = {.entry = {.count = 1, .reusable = true}}, SHIFT(122),
  [5175] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2077),
  [5177] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1824),
  [5179] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2252),
  [5181] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2440),
  [5183] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2370),
  [5185] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2277),
  [5187] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__function_identifier, 2, 0, 9),
  [5189] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2387),
  [5191] = {.entry = {.count = 1, .reusable = true}}, SHIFT(113),
  [5193] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2273),
  [5195] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1639),
  [5197] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1431),
  [5199] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1979),
  [5201] = {.entry = {.count = 1, .reusable = true}}, SHIFT(622),
  [5203] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2217),
  [5205] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1850),
  [5207] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__hll_var_pattern_command_argument_list_format, 1, 0, 0),
  [5209] = {.entry = {.count = 1, .reusable = true}}, SHIFT(80),
  [5211] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1856),
  [5213] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_hll_parameter_list_repeat1, 2, 0, 0),
  [5215] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_hll_parameter_list_repeat1, 2, 0, 0), SHIFT_REPEAT(1517),
  [5218] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2323),
  [5220] = {.entry = {.count = 1, .reusable = true}}, SHIFT(130),
  [5222] = {.entry = {.count = 1, .reusable = true}}, SHIFT(639),
  [5224] = {.entry = {.count = 1, .reusable = true}}, SHIFT(666),
  [5226] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2235),
  [5228] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_hll_argument_list_repeat1, 2, 0, 0), SHIFT_REPEAT(460),
  [5231] = {.entry = {.count = 1, .reusable = true}}, SHIFT(34),
  [5233] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2236),
  [5235] = {.entry = {.count = 1, .reusable = true}}, SHIFT(963),
  [5237] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2391),
  [5239] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2397),
  [5241] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1638),
  [5243] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1885),
  [5245] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1529),
  [5247] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__hll_var_definition_command, 3, 0, 22),
  [5249] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__var_definition_command_argument_list_format, 1, 0, 0),
  [5251] = {.entry = {.count = 1, .reusable = true}}, SHIFT(751),
  [5253] = {.entry = {.count = 1, .reusable = true}}, SHIFT(679),
  [5255] = {.entry = {.count = 1, .reusable = true}}, SHIFT(35),
  [5257] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__command_arguments_repeat3, 2, 0, 0),
  [5259] = {.entry = {.count = 1, .reusable = true}}, SHIFT(36),
  [5261] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2036),
  [5263] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__command_arguments_repeat2, 2, 0, 0), SHIFT_REPEAT(2366),
  [5266] = {.entry = {.count = 1, .reusable = true}}, SHIFT(475),
  [5268] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__hll_var_command, 1, 0, 4),
  [5270] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__hll_var_definition_command, 5, 0, 56),
  [5272] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__hll_var_command_argument_list_non_default_format, 7, 0, 0),
  [5274] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2444),
  [5276] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1641),
  [5278] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2373),
  [5280] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2373),
  [5282] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1660),
  [5284] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1658),
  [5286] = {.entry = {.count = 1, .reusable = true}}, SHIFT(132),
  [5288] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2441),
  [5290] = {.entry = {.count = 1, .reusable = true}}, SHIFT(174),
  [5292] = {.entry = {.count = 1, .reusable = false}}, SHIFT(175),
  [5294] = {.entry = {.count = 1, .reusable = true}}, SHIFT(686),
  [5296] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2176),
  [5298] = {.entry = {.count = 1, .reusable = true}}, SHIFT(105),
  [5300] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2195),
  [5302] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1485),
  [5304] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1487),
  [5306] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1490),
  [5308] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1492),
  [5310] = {.entry = {.count = 1, .reusable = true}}, SHIFT(243),
  [5312] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1471),
  [5314] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1444),
  [5316] = {.entry = {.count = 1, .reusable = true}}, SHIFT(472),
  [5318] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1723),
  [5320] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2378),
  [5322] = {.entry = {.count = 1, .reusable = true}}, SHIFT(492),
  [5324] = {.entry = {.count = 1, .reusable = true}}, SHIFT(131),
  [5326] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2379),
  [5328] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2379),
  [5330] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1446),
  [5332] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1425),
  [5334] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2414),
  [5336] = {.entry = {.count = 1, .reusable = true}}, SHIFT(177),
  [5338] = {.entry = {.count = 1, .reusable = false}}, SHIFT(178),
  [5340] = {.entry = {.count = 1, .reusable = true}}, SHIFT(901),
  [5342] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__host_command, 3, 0, 22),
  [5344] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2427),
  [5346] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2427),
  [5348] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1493),
  [5350] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1495),
  [5352] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__function_identifier_repeat1, 2, 0, 44),
  [5354] = {.entry = {.count = 1, .reusable = true}}, SHIFT(118),
  [5356] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2381),
  [5358] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2381),
  [5360] = {.entry = {.count = 1, .reusable = true}}, SHIFT(191),
  [5362] = {.entry = {.count = 1, .reusable = false}}, SHIFT(192),
  [5364] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__other_command, 3, 0, 22),
  [5366] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2413),
  [5368] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2413),
  [5370] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1470),
  [5372] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2389),
  [5374] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2389),
  [5376] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__var_command, 1, 0, 4),
  [5378] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2368),
  [5380] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2368),
  [5382] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2365),
  [5384] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2365),
  [5386] = {.entry = {.count = 1, .reusable = true}}, SHIFT(128),
  [5388] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__hll_default_format_var_command, 3, 0, 22),
  [5390] = {.entry = {.count = 1, .reusable = true}}, SHIFT(123),
  [5392] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__hll_var_command_argument_list_non_default_format, 6, 0, 0),
  [5394] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2416),
  [5396] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1505),
  [5398] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1506),
  [5400] = {.entry = {.count = 1, .reusable = true}}, SHIFT(134),
  [5402] = {.entry = {.count = 1, .reusable = true}}, SHIFT(135),
  [5404] = {.entry = {.count = 1, .reusable = true}}, SHIFT(481),
  [5406] = {.entry = {.count = 1, .reusable = true}}, SHIFT(482),
  [5408] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1497),
  [5410] = {.entry = {.count = 1, .reusable = true}}, SHIFT(816),
  [5412] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1441),
  [5414] = {.entry = {.count = 1, .reusable = true}}, SHIFT(339),
  [5416] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__hll_non_default_format_var_command, 5, 0, 50),
  [5418] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1767),
  [5420] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1967),
  [5422] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_option_expression, 2, 0, 39), SHIFT(99),
  [5425] = {.entry = {.count = 1, .reusable = true}}, SHIFT(749),
  [5427] = {.entry = {.count = 1, .reusable = true}}, SHIFT(136),
  [5429] = {.entry = {.count = 1, .reusable = true}}, SHIFT(137),
  [5431] = {.entry = {.count = 1, .reusable = true}}, SHIFT(484),
  [5433] = {.entry = {.count = 1, .reusable = true}}, SHIFT(138),
  [5435] = {.entry = {.count = 1, .reusable = true}}, SHIFT(485),
  [5437] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__non_hll_var_command, 3, 0, 22),
  [5439] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1500),
  [5441] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1984),
  [5443] = {.entry = {.count = 1, .reusable = true}}, SHIFT(246),
  [5445] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__var_command, 1, 0, 5),
  [5447] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2214),
  [5449] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1985),
  [5451] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2198),
  [5453] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1677),
  [5455] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1320),
  [5457] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1464),
  [5459] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1465),
  [5461] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1722),
  [5463] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1460),
  [5465] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2425),
  [5467] = {.entry = {.count = 1, .reusable = true}}, SHIFT(201),
  [5469] = {.entry = {.count = 1, .reusable = false}}, SHIFT(215),
  [5471] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1988),
  [5473] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2079),
  [5475] = {.entry = {.count = 1, .reusable = true}}, SHIFT(883),
  [5477] = {.entry = {.count = 1, .reusable = true}}, SHIFT(669),
  [5479] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2187),
  [5481] = {.entry = {.count = 1, .reusable = true}}, SHIFT(90),
  [5483] = {.entry = {.count = 1, .reusable = true}}, SHIFT(436),
  [5485] = {.entry = {.count = 1, .reusable = true}}, SHIFT(713),
  [5487] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1466),
  [5489] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1467),
  [5491] = {.entry = {.count = 1, .reusable = true}}, SHIFT(98),
  [5493] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2410),
  [5495] = {.entry = {.count = 1, .reusable = true}}, SHIFT(946),
  [5497] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2321),
  [5499] = {.entry = {.count = 1, .reusable = true}}, SHIFT(887),
  [5501] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2006),
  [5503] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2398),
  [5505] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2386),
  [5507] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1519),
  [5509] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1131),
  [5511] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1090),
  [5513] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2421),
  [5515] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__hll_var_call_expression_function, 3, 0, 42),
  [5517] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2424),
  [5519] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1376),
  [5521] = {.entry = {.count = 1, .reusable = true}}, SHIFT(880),
  [5523] = {.entry = {.count = 1, .reusable = true}}, SHIFT(765),
  [5525] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__hll_var_if_command, 3, 0, 20),
  [5527] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2376),
  [5529] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2448),
  [5531] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2289),
  [5533] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2240),
  [5535] = {.entry = {.count = 1, .reusable = true}}, SHIFT(790),
  [5537] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2447),
  [5539] = {.entry = {.count = 1, .reusable = true}}, SHIFT(919),
  [5541] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1866),
  [5543] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2430),
  [5545] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2407),
  [5547] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2402),
  [5549] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2302),
  [5551] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2145),
  [5553] = {.entry = {.count = 1, .reusable = true}},  ACCEPT_INPUT(),
  [5555] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1016),
  [5557] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1953),
  [5559] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1796),
  [5561] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1851),
  [5563] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__host_command_with_default_format, 3, 0, 19),
  [5565] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2201),
  [5567] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2412),
  [5569] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1019),
  [5571] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2279),
  [5573] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1325),
  [5575] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1386),
  [5577] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__hll_var_definition_command_expression, 3, 0, 0),
  [5579] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1421),
  [5581] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2405),
  [5583] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2450),
  [5585] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2383),
  [5587] = {.entry = {.count = 1, .reusable = true}}, SHIFT(333),
  [5589] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1901),
  [5591] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1509),
  [5593] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2043),
  [5595] = {.entry = {.count = 1, .reusable = true}}, SHIFT(804),
  [5597] = {.entry = {.count = 1, .reusable = true}}, SHIFT(343),
  [5599] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2015),
  [5601] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2371),
  [5603] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2388),
  [5605] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1964),
  [5607] = {.entry = {.count = 1, .reusable = true}}, SHIFT(878),
  [5609] = {.entry = {.count = 1, .reusable = true}}, SHIFT(786),
  [5611] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1119),
  [5613] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2435),
  [5615] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_macro_definition_command, 1, 0, 0),
  [5617] = {.entry = {.count = 1, .reusable = true}}, SHIFT(951),
  [5619] = {.entry = {.count = 1, .reusable = true}}, SHIFT(480),
  [5621] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1308),
  [5623] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2406),
  [5625] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1054),
};

enum ts_external_scanner_symbol_identifiers {
  ts_external_token_label_identifier = 0,
  ts_external_token__and_operator_pre_hook = 1,
  ts_external_token__decimal_number = 2,
  ts_external_token__decimal_number_pre_hook = 3,
  ts_external_token_hll_number_literal = 4,
  ts_external_token__hll_number_literal_pre_hook = 5,
  ts_external_token_path = 6,
  ts_external_token_AMP_AMP = 7,
  ts_external_token_AMP = 8,
  ts_external_token__ampersand_char = 9,
};

static const TSSymbol ts_external_scanner_symbol_map[EXTERNAL_TOKEN_COUNT] = {
  [ts_external_token_label_identifier] = sym_label_identifier,
  [ts_external_token__and_operator_pre_hook] = sym__and_operator_pre_hook,
  [ts_external_token__decimal_number] = sym__decimal_number,
  [ts_external_token__decimal_number_pre_hook] = sym__decimal_number_pre_hook,
  [ts_external_token_hll_number_literal] = sym_hll_number_literal,
  [ts_external_token__hll_number_literal_pre_hook] = sym__hll_number_literal_pre_hook,
  [ts_external_token_path] = sym_path,
  [ts_external_token_AMP_AMP] = anon_sym_AMP_AMP,
  [ts_external_token_AMP] = anon_sym_AMP,
  [ts_external_token__ampersand_char] = sym__ampersand_char,
};

static const bool ts_external_scanner_states[20][EXTERNAL_TOKEN_COUNT] = {
  [1] = {
    [ts_external_token_label_identifier] = true,
    [ts_external_token__and_operator_pre_hook] = true,
    [ts_external_token__decimal_number] = true,
    [ts_external_token__decimal_number_pre_hook] = true,
    [ts_external_token_hll_number_literal] = true,
    [ts_external_token__hll_number_literal_pre_hook] = true,
    [ts_external_token_path] = true,
    [ts_external_token_AMP] = true,
    [ts_external_token__ampersand_char] = true,
  },
  [2] = {
    [ts_external_token_label_identifier] = true,
    [ts_external_token_AMP_AMP] = true,
    [ts_external_token_AMP] = true,
  },
  [3] = {
    [ts_external_token_label_identifier] = true,
    [ts_external_token__and_operator_pre_hook] = true,
    [ts_external_token__decimal_number_pre_hook] = true,
    [ts_external_token_path] = true,
    [ts_external_token_AMP_AMP] = true,
    [ts_external_token_AMP] = true,
  },
  [4] = {
    [ts_external_token__and_operator_pre_hook] = true,
    [ts_external_token__decimal_number_pre_hook] = true,
    [ts_external_token_path] = true,
    [ts_external_token_AMP] = true,
  },
  [5] = {
    [ts_external_token_label_identifier] = true,
    [ts_external_token__and_operator_pre_hook] = true,
    [ts_external_token_AMP_AMP] = true,
    [ts_external_token_AMP] = true,
  },
  [6] = {
    [ts_external_token__hll_number_literal_pre_hook] = true,
    [ts_external_token_AMP_AMP] = true,
    [ts_external_token_AMP] = true,
  },
  [7] = {
    [ts_external_token__decimal_number_pre_hook] = true,
    [ts_external_token_path] = true,
    [ts_external_token_AMP] = true,
  },
  [8] = {
    [ts_external_token__hll_number_literal_pre_hook] = true,
    [ts_external_token_AMP] = true,
  },
  [9] = {
    [ts_external_token_label_identifier] = true,
    [ts_external_token__and_operator_pre_hook] = true,
    [ts_external_token_path] = true,
    [ts_external_token_AMP_AMP] = true,
    [ts_external_token_AMP] = true,
  },
  [10] = {
    [ts_external_token_AMP_AMP] = true,
    [ts_external_token_AMP] = true,
  },
  [11] = {
    [ts_external_token__and_operator_pre_hook] = true,
    [ts_external_token_path] = true,
  },
  [12] = {
    [ts_external_token__and_operator_pre_hook] = true,
  },
  [13] = {
    [ts_external_token__and_operator_pre_hook] = true,
    [ts_external_token_AMP] = true,
  },
  [14] = {
    [ts_external_token__decimal_number_pre_hook] = true,
    [ts_external_token_hll_number_literal] = true,
  },
  [15] = {
    [ts_external_token_path] = true,
  },
  [16] = {
    [ts_external_token_AMP] = true,
  },
  [17] = {
    [ts_external_token_AMP] = true,
    [ts_external_token__ampersand_char] = true,
  },
  [18] = {
    [ts_external_token__decimal_number] = true,
  },
  [19] = {
    [ts_external_token_hll_number_literal] = true,
  },
};

#ifdef __cplusplus
extern "C" {
#endif
void *tree_sitter_t32_external_scanner_create(void);
void tree_sitter_t32_external_scanner_destroy(void *);
bool tree_sitter_t32_external_scanner_scan(void *, TSLexer *, const bool *);
unsigned tree_sitter_t32_external_scanner_serialize(void *, char *);
void tree_sitter_t32_external_scanner_deserialize(void *, const char *, unsigned);

#ifdef TREE_SITTER_HIDE_SYMBOLS
#define TS_PUBLIC
#elif defined(_WIN32)
#define TS_PUBLIC __declspec(dllexport)
#else
#define TS_PUBLIC __attribute__((visibility("default")))
#endif

TS_PUBLIC const TSLanguage *tree_sitter_t32(void) {
  static const TSLanguage language = {
    .abi_version = LANGUAGE_VERSION,
    .symbol_count = SYMBOL_COUNT,
    .alias_count = ALIAS_COUNT,
    .token_count = TOKEN_COUNT,
    .external_token_count = EXTERNAL_TOKEN_COUNT,
    .state_count = STATE_COUNT,
    .large_state_count = LARGE_STATE_COUNT,
    .production_id_count = PRODUCTION_ID_COUNT,
    .supertype_count = SUPERTYPE_COUNT,
    .field_count = FIELD_COUNT,
    .max_alias_sequence_length = MAX_ALIAS_SEQUENCE_LENGTH,
    .parse_table = &ts_parse_table[0][0],
    .small_parse_table = ts_small_parse_table,
    .small_parse_table_map = ts_small_parse_table_map,
    .parse_actions = ts_parse_actions,
    .symbol_names = ts_symbol_names,
    .field_names = ts_field_names,
    .field_map_slices = ts_field_map_slices,
    .field_map_entries = ts_field_map_entries,
    .symbol_metadata = ts_symbol_metadata,
    .public_symbol_map = ts_symbol_map,
    .alias_map = ts_non_terminal_alias_map,
    .alias_sequences = &ts_alias_sequences[0][0],
    .lex_modes = (const void*)ts_lex_modes,
    .lex_fn = ts_lex,
    .keyword_lex_fn = ts_lex_keywords,
    .keyword_capture_token = sym_identifier,
    .external_scanner = {
      &ts_external_scanner_states[0][0],
      ts_external_scanner_symbol_map,
      tree_sitter_t32_external_scanner_create,
      tree_sitter_t32_external_scanner_destroy,
      tree_sitter_t32_external_scanner_scan,
      tree_sitter_t32_external_scanner_serialize,
      tree_sitter_t32_external_scanner_deserialize,
    },
    .primary_state_ids = ts_primary_state_ids,
    .name = "t32",
    .max_reserved_word_set_size = 0,
    .metadata = {
      .major_version = 6,
      .minor_version = 0,
      .patch_version = 1,
    },
  };
  return &language;
}
#ifdef __cplusplus
}
#endif
